/*
 * AppPwmDriver.c
 *
 *  Created on: 28.08.2013
 *
 */

#include "AppPwmDriver.h"


#include "Gtm/Std/IfxGtmCmu.h"
#include "Gtm/Trig/IfxGtm_Trig.h"

#include "Ifx_Cfg_Pwm.h"

AppPwmDriver_3ChPwm	g_AppPwm_3ChPwm;

void AppPwmDriver_init(void)
{

	switch(cfg_Pwm_3Phase.usedUnit) /* cfg_Pwm_3Phase ist global in Ifx_Cfg_Pwm.c definiert und enthlt parameter fr die 3 Phasen PWM wie */
									/*	- frequenz ( 20khz) , Totzeit, verwendetes Timer modul */
									/*	- warum ist dies nicht teil der init routine ? 		*/
	{
		case AppPwmDriver_Unit_Gtm_Tom1: /* Generic Timer Module (Gtm) wie in cfg_Pwm_3Phase definiert */
										 /* TOM: Timer OUtput Module */
		{
			Ifx_GTM* gtm = &MODULE_GTM;
			float32 frequency = IfxGtmCmu_getModuleFrequency(gtm);
			boolean status = TRUE;

			/* Enables the GTM */
			IfxGtm_enable(gtm); /* setze CLC Register disable bit auf 0 */
			/* Set the global clock frequency to the max */
			IfxGtmCmu_setGclkFrequency(gtm, frequency); /* setzt CMU Nominator und Denominator Register */
														/* macht aber irgendwie keinen Sinn */
			/* Enable the fix clock */
			IfxGtmCmu_enableClocks(gtm, IFXGTMCMU_CLKEN_FXCLK); /* setzt CMU CLK Enable Register */
			{
				// Setup Timer for PWM Generation
				IfxGtmTom_Timer_Config tmrConfig;

				tmrConfig.gtm = gtm;
				tmrConfig.base = cfg_Pwm_3Phase.pwmTimer; /* hier steckt die PWM Frequenz drin */
				tmrConfig.clock	= IfxGtmTom_Ch_ClkSrc_cmuFxclk0;
				tmrConfig.tom = IfxGtmTom_1;

				if(cfg_Pwm_3Phase.timerChannelSel != NULL_PTR)
				{
					tmrConfig.timerChannel =  *(IfxGtmTom_Ch *)cfg_Pwm_3Phase.timerChannelSel;
					/* Was ist ein timerChannel */
					/* Ausgangspins fr PWM Signal ? */
					/* hier timer channel 0 */
					/* untig komplex ! */
				}else
				{
					status = FALSE;
				}

				if(cfg_Pwm_3Phase.pwmTimer.trigger.enabled != FALSE)
				{
					if(cfg_Pwm_3Phase.triggerChannelSel != NULL_PTR)
					{
						tmrConfig.triggerChannel =  (IfxGtmTom_ToutMap*)(cfg_Pwm_3Phase.triggerChannelSel);
						/* legt unter anderem Ausgangspins fest */
					}else
					{
						status = FALSE;
					}

				}
				if(status == TRUE)
				{
					status = IfxGtmTom_Timer_init(&g_AppPwm_3ChPwm.tmr, &tmrConfig);
					/* g_AppPwm_3ChPwm.tmr ist vom Typ: IfxGtmTom_Timer eine generische Struktur zur initialisierung */
					/*	des Timer Output Moduls, hier wird also einfach tmrConfig  */
					//IfxGtm_Trig_toVadc(gtm, IfxGtm_AdcGroup_0, IfxGtm_AdcTrig_1, IfxGtm_AdcTrigSource_tom1,IfxGtm_AdcTrigChannel_7);
					/* IfxGtm_Trig_toVadc wird verwendet um den ADC mittels des Gtm zu triggern */
					/* wie genau funktioniert das ? */
					/* ADCTRIG0OUT0 wird gesetzt - im prinzip wird festgelegt auf welchen TOM mit Welchem Channel mit welchem Trigger*/
					/* die ADC Gruppe regagiert (Eine ADC Gruppe ist einfach ein ADC analogem Multiplexer */

					//IfxGtm_Trig_toVadc(gtm, IfxGtm_AdcGroup_1, IfxGtm_AdcTrig_1, IfxGtm_AdcTrigSource_tom1,IfxGtm_AdcTrigChannel_7);
				}

				g_AppPwm_3ChPwm.tmr.base.functions.run(&g_AppPwm_3ChPwm.tmr.base);
				/* nehme mal an das dies den Timer startet */
				/* setze TOM TGC0 Enable/Disable Control Register und TOM TGC0 Enable/Disable Status Register auf 11 */
			}

			if(status != FALSE) // if status is TRUE
			{
			/* Setup a 3 phase PWM */
				IfxGtmTom_PwmHl_Config pwmConfig;

				pwmConfig.base = cfg_Pwm_3Phase.pwmCh;
				pwmConfig.base.timer = &g_AppPwm_3ChPwm.tmr.base;

				pwmConfig.ccx = (IfxGtmTom_ToutMapP *)(cfg_Pwm_3Phase.PwmCcxChannelSel) ; /* output pins oberer teil B6 Brcke */
				pwmConfig.coutx = (IfxGtmTom_ToutMapP *)cfg_Pwm_3Phase.PwmCoutxChannelSel ; /* outputpins unterer teil B6 Brcke */
				pwmConfig.tom = IfxGtmTom_1;

				IfxGtmTom_PwmHl_init(&g_AppPwm_3ChPwm.ch, &pwmConfig); /* das hier nochmal ansehen */

				g_AppPwm_3ChPwm.ch.base.functions.setMode(&g_AppPwm_3ChPwm.ch.base,Pwm_Mode_centerAligned);
			}

		}	break;

		case AppPwmDriver_Unit_Gtm_Tom0:
		case AppPwmDriver_Unit_Gtm_Atom0:
		case AppPwmDriver_Unit_Gtm_Atom1:
		case AppPwmDriver_Unit_Gtm_Atom2:
		case AppPwmDriver_Unit_Gtm_Atom3:
			break;
		default: break;
	}
}


AppPwmDriver_3ChPwm* AppPwmDriver_get3ChannelPwm(void)
{
	return(&g_AppPwm_3ChPwm);
}


void AppPwmDriver_update3ChannelPwm(AppPwmDriver_3ChPwm *pwm, TimerVal *tOn, TimerVal adcTon)

{

	pwm->tmr.base.functions.disableUpdate(&pwm->tmr.base);
	//pwm->tmr.base.functions.setTrigger(&pwm->tmr.base, adcTon);
    pwm->ch.base.functions.setOnTime(&pwm->ch.base, tOn); /* verweist auf: IfxGtmTom_PwmHl_updateCenterAligned */
    pwm->tmr.base.functions.applyUpdate(&pwm->tmr.base);

}
