/**
 * GPIO_driver.c



 *
 *  Created on: 19.11.2015
 *      Author: uacqk
 */
#include "GPIO_driver.h"

/**
 * @brief set selected pin to GPIO Output
 * @param conf Portnumber and Pinnumber
 */
void initGpio(GPIO_config* conf) {
	uint8 left_shift;
	if(conf->pin < 4) {
		left_shift= (conf->pin%4)*8 +7;
		conf->port->IOCR0.U |=  (1 << left_shift) ; // GP output Push-Pull
	}
	else if (conf->pin < 8) {
		left_shift= (conf->pin%4)*8 +7;
		conf->port->IOCR4.U |=  (1 << left_shift) ; // GP output Push-Pull
	}
	else if (conf->pin < 12) {
		left_shift= (conf->pin%4)*8 +7;
		conf->port->IOCR8.U |=  (1 << left_shift) ; // GP output Push-Pull
	}
	else {
		left_shift= (conf->pin%4)*8 +7;
		conf->port->IOCR12.U |=  (1 << left_shift) ; // GP output Push-Pull
	}

}

/**
 * @brief set pin to high
 * @param conf Portnumber and Pinnumber
 */
void set_GPIO(GPIO_config* conf) {
	conf->port->OMR.U= (1<< conf->pin);
}

/**
 * @brief set pin to low
 * @param conf Portnumber and Pinnumber
 */
void clear_GPIO(GPIO_config* conf) {
	conf->port->OMR.U= (1<< (conf->pin + 16));
}
/**
 * @brief toggle pin
 * @param conf Portnumber and Pinnumber
 */
void toggle_GPIO(GPIO_config* conf) {
	conf->port->OMR.U= (  (1<< (conf->pin + 16)) | (1 << conf->pin) );
}

/**
 * @brief set pin to tristate input
 * @param conf Portnumber and Pinnumber
 */
void setInput_tristate(GPIO_config* conf) {
	uint8 left_shift;
	uint8 eight_bit_zero=0;
	if(conf->pin < 4) {
		left_shift=0;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}
	else if (conf->pin < 8) {
		left_shift=7;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}
	else if (conf->pin < 12) {
		left_shift=15;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}
	else {
		left_shift=23;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}

}

/**
 * @brief set pin to input with internal pull down
 * @param conf Portnumber and Pinnumber
 */
void setInput_pull_down(GPIO_config* conf) {
	uint8 left_shift;
	uint8 eight_bit_zero=1;
	if(conf->pin < 4) {
		left_shift=0;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}
	else if (conf->pin < 8) {
		left_shift=7;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}
	else if (conf->pin < 12) {
		left_shift=15;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}
	else {
		left_shift=23;
		conf->port->IOCR0.U &= (eight_bit_zero << left_shift);
	}

}

/**
 * @brief set start configuration so that AURX can not be damged
 * @param conf Portnumber and Pinnumber
 */
void set_IO_start() {
// QSPI 3
	GPIO_config P22_0={&MODULE_P22,0};
	GPIO_config P22_1={&MODULE_P22,1};
	GPIO_config P22_2={&MODULE_P22,2};
	GPIO_config P22_3={&MODULE_P22,3};
	GPIO_config P33_10={&MODULE_P33,10};
	GPIO_config P33_9={&MODULE_P33,9};

	setInput_tristate(&P22_0);
	setInput_tristate(&P22_1);
	initGpio(&P22_2);
	initGpio(&P22_3);
	initGpio(&P33_10);
	initGpio(&P33_9);
//Qspi2
	GPIO_config P15_7= {&MODULE_P15,7};
	GPIO_config P15_4= {&MODULE_P15,4};
	GPIO_config P15_6= {&MODULE_P15,6};
	GPIO_config P15_2= {&MODULE_P15,2};
	GPIO_config P14_7= {&MODULE_P14,7};
	GPIO_config P14_6= {&MODULE_P14,6};
	GPIO_config P20_10={&MODULE_P20,10};

	setInput_tristate(&P15_7);
	setInput_tristate(&P15_4);
	initGpio(&P15_6);
	initGpio(&P15_2);
	initGpio(&P14_7);
	initGpio(&P14_6);
	initGpio(&P20_10);

//PWM2
	GPIO_config P02_0= {&MODULE_P02,0};
	GPIO_config P02_1= {&MODULE_P02,1};
	GPIO_config P02_2= {&MODULE_P02,2};
	GPIO_config P02_3= {&MODULE_P02,3};
	GPIO_config P02_4= {&MODULE_P02,4};
	GPIO_config P02_5= {&MODULE_P02,5};

	initGpio(&P02_0);
	initGpio(&P02_1);
	initGpio(&P02_2);
	initGpio(&P02_3);
	initGpio(&P02_4);
	initGpio(&P02_5);

//ENCODER
	GPIO_config P02_6= {&MODULE_P02,6};
	GPIO_config P02_7= {&MODULE_P02,7};
	GPIO_config P02_8= {&MODULE_P02,8};

	setInput_tristate(&P02_6);
	setInput_tristate(&P02_7);
	setInput_pull_down(&P02_8);

// CREE SIGNALE
	GPIO_config P33_3= {&MODULE_P33,3}; // RDY_CREE
	GPIO_config P33_4= {&MODULE_P33,4}; // RST_CREE
	GPIO_config P33_1={&MODULE_P33,1};
	GPIO_config P33_8={&MODULE_P33,8};



	setInput_tristate(&P33_1);
	setInput_tristate(&P33_8);

	initGpio(&P33_3);
	initGpio(&P33_4);
	set_GPIO(&P33_3); // set RDY_Cree to high
	set_GPIO(&P33_4); // set rst_Cree to high

}


