/*
 * Spi_Interface.c
 *
 *  Created on: 23.11.2015
 *      Author: uacqk
 *
 */

#include "Spi_interface.h"

/**
 * @brief initialize QSPI3 Module for communiaction with TLI4970 current sensor
 * @param config struct for accessing spi configuration
 */
void initSpi_TLI4970(spi_config* config) {



    IfxQspi_SpiMaster_Config        spiMasterConfig;
    IfxQspi_SpiMaster_ChannelConfig spiMasterChannelConfig;
    Ifx_QSPI                       *qspi3SFR;

   IfxQspi_SpiMaster_initModuleConfig(&spiMasterConfig, &MODULE_QSPI3);

    /* set the maximum baudrate */
    spiMasterConfig.base.maximumBaudrate = 10000000;

    /* ISR priorities and interrupt target */
    spiMasterConfig.base.txPriority    = ISR_PRIORITY_TX_EMPTY;
    spiMasterConfig.base.rxPriority    = ISR_PRIORITY_RX_EMPTY;
    spiMasterConfig.base.erPriority    = ISR_PRIORITY_QSPI3_ER;
    spiMasterConfig.base.isrProvider   = (IfxSrc_Tos)IfxCpu_getCoreId();
    spiMasterConfig.dma.txDmaChannelId = IFX_TX_CHANNELID;
    spiMasterConfig.dma.rxDmaChannelId = IFX_RX_CHANNELID;
    spiMasterConfig.dma.useDma         = FALSE;

    /* pin configuration */
    const IfxQspi_SpiMaster_Pins pins = {&IfxQspi3_SCLK_P22_3_OUT,                               /* SCLK */
                                         IfxPort_OutputMode_pushPull,
										 NULL_PTR ,  IfxPort_Mode_inputNoPullDevice , /* MTSR = MOSI*/
										 &IfxQspi3_MRSTE_P22_1_IN,  IfxPort_InputMode_noPullDevice ,  /* MRST = MISO*/
                                         IfxPort_PadDriver_cmosAutomotiveSpeed1                   /* pad driver mode */
    									};


//  const IfxQspi_SpiMaster_Pins pins = {&IfxQspi3_SCLK_P22_3_OUT,                               /* SCLK */
//                                       IfxPort_OutputMode_pushPull,
//										 &IfxQspi3_MTSR_P10_6_OUT ,  IfxPort_Mode_inputNoPullDevice , /* MTSR = MOSI*/
//										 &IfxQspi3_MRSTE_P22_1_IN,  IfxPort_InputMode_pullUp ,  /* MRST = MISO*/
//                                         IfxPort_PadDriver_cmosAutomotiveSpeed1                   /* pad driver mode */
//    									};

    spiMasterConfig.pins = &pins;

    /* initialize module, write Master Config to registers */
    /* fixme Abgleich mit original IfxQspi_SpiMaster_initModule noetig */
    IfxQspi_SpiMaster_initModule(&config->spiMaster, &spiMasterConfig);

    qspi3SFR = spiMasterConfig.qspi;
    volatile Ifx_SRC_SRCR *src = IfxQspi_getErrorSrc(qspi3SFR);
    // ISR in Case of SPI Error
    IfxSrc_init(src, IfxSrc_Tos_cpu0, ISR_PRIORITY_QSPI3_ER);
    IfxSrc_enable(src);


    /* create channel config */


    for(int i=0;i<SPI_NR_OF_SLAVES;i++){
		IfxQspi_SpiMaster_initChannelConfig(&spiMasterChannelConfig,
			&config->spiMaster);

		/* set the baudrate for this channel */
		spiMasterChannelConfig.base.baudrate = 5000000.0;

		/* set the transfer data width */
		spiMasterChannelConfig.base.mode.dataWidth = 16;

		spiMasterChannelConfig.base.mode.csTrailDelay = 2;
		spiMasterChannelConfig.base.mode.csInactiveDelay = 2;
		spiMasterChannelConfig.base.mode.csLeadDelay = 4 ;
		spiMasterChannelConfig.base.mode.shiftClock = SpiIf_ShiftClock_shiftTransmitDataOnLeadingEdge;


		if(i== 0) {
		spiMasterChannelConfig.sls.output.pin    = &IfxQspi3_SLSO12_P22_2_OUT;
		spiMasterChannelConfig.sls.output.mode   = IfxPort_OutputMode_pushPull;
		spiMasterChannelConfig.sls.output.driver = IfxPort_PadDriver_cmosAutomotiveSpeed1;
		}
		else if(i==1) {
			spiMasterChannelConfig.sls.output.pin    = &IfxQspi3_SLSO11_P33_10_OUT;
			spiMasterChannelConfig.sls.output.mode   = IfxPort_OutputMode_pushPull;
			spiMasterChannelConfig.sls.output.driver = IfxPort_PadDriver_cmosAutomotiveSpeed1;
		}
		else {
			spiMasterChannelConfig.sls.output.pin    = &IfxQspi3_SLSO1_P33_9_OUT ;
			spiMasterChannelConfig.sls.output.mode   = IfxPort_OutputMode_pushPull;
			spiMasterChannelConfig.sls.output.driver = IfxPort_PadDriver_cmosAutomotiveSpeed1;
		}

		/* initialize channel */
		IfxQspi_SpiMaster_initChannel(&config->spiMasterChannel[i],&spiMasterChannelConfig);




    }
}

void spi_request_tripple(spi_config* config){

	//config->spi3TxBuffer[0]=0x3333;
	//config->spi3TxBuffer[1]=0x1111;
	//config->spi3TxBuffer[2]=0x3333;

    while (IfxQspi_SpiMaster_getStatus(&config->spiMasterChannel[0]) == SpiIf_Status_busy){
    	__nop();

    }


    IfxQspi_SpiMaster_exchange(&config->spiMasterChannel[0], &config->spi3TxBuffer[0],&config->spi3RxBuffer[0], 1);


}

void Qspi_SpiMaster_write_input_fifo(IfxQspi_SpiMaster_Channel *chHandle){

    IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
    Ifx_QSPI          *qspiSFR = handle->qspi;
    static SizeT          count;
    volatile uint8              cs      = chHandle->bacon.B.CS;


   // boolean            interruptState = IfxCpu_disableInterrupts();
     count= IfxQspi_getTransmitFifoLevel(qspiSFR);
   // IfxQspi_writeBasicConfigurationBeginStream(qspiSFR, chHandle->bacon.U);
   // IfxQspi_writeTransmitFifo(qspiSFR, cs, 0x5555);

    IfxQspi_writeBasicConfigurationEndStream(qspiSFR, chHandle->bacon.U);
    IfxQspi_writeTransmitFifo(qspiSFR, cs, 0x5555);
 //   IfxQspi_writeBasicConfigurationEndStream(qspiSFR, chHandle->bacon.U);
 //   IfxQspi_writeTransmitFifo(qspiSFR, cs, 0x5555);
   // IfxQspi_writeBasicConfigurationEndStream(qspiSFR, chHandle->bacon.U);
   //IfxQspi_writeTransmitFifo(qspiSFR, 0, 0x5555);
    //IfxQspi_writeTransmitFifo(qspiSFR, 3, 0x5555);
   // IfxCpu_restoreInterrupts(interruptState);


}

uint32 Qspi_SpiMaster_read_input_fifo(IfxQspi_SpiMaster_Channel *chHandle){

    IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
    Ifx_QSPI          *qspiSFR = handle->qspi;
    static SizeT          count;
    volatile uint8              cs      = chHandle->bacon.B.CS;

    if(qspiSFR->STATUS.B.RXFIFOLEVEL >=4) {
    	return qspiSFR->RXEXIT.U ;
    }

return 0;


}



uint32 Qspi_SpiMaster_get_bacon_entry(IfxQspi_SpiMaster_Channel *chHandle) {
    IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
    Ifx_QSPI          *qspiSFR = handle->qspi;
    return (uint32)&(qspiSFR->BACONENTRY.U) ;
}

uint32 Qspi_SpiMaster_get_data_entry(IfxQspi_SpiMaster_Channel *chHandle) {
	volatile uint8              cs      = chHandle->bacon.B.CS;
    IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
    Ifx_QSPI          *qspiSFR = handle->qspi;
    return (uint32)&qspiSFR->DATAENTRY[cs%8].U ;
}

void Dma_write_bacon_entry_start(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves) {
	uint8 nr_of_transmit_cycles= buffer_length / nr_of_slaves ;
	uint8 iterator=0;
	for(int i=0;i<nr_of_transmit_cycles;i++){
		for(int spi_channel=0;spi_channel<nr_of_slaves;spi_channel++){
			tx_fifo->bacon_entry_1[iterator]=(uint32)get_bacon_first(spi_config_handle->spiMasterChannel[spi_channel].bacon.U);
			iterator++ ;
		}
	}

}

void Dma_write_bacon_entry_end(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves) {
	uint8 nr_of_transmit_cycles= buffer_length / nr_of_slaves ;
	uint8 iterator=0;
	for(int i=0;i<nr_of_transmit_cycles;i++){
		for(int spi_channel=0;spi_channel<nr_of_slaves;spi_channel++){
			tx_fifo->bacon_entry_2[iterator]=(uint32)get_bacon_last(spi_config_handle->spiMasterChannel[spi_channel].bacon.U);
			iterator++ ;
		}
	}

}

void Dma_write_data_entry_1(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves,uint16 data){
	uint8 nr_of_transmit_cycles= buffer_length / nr_of_slaves ;
	uint8 iterator=0;
	for(int i=0;i<nr_of_transmit_cycles;i++){
		for(int spi_channel=0;spi_channel<nr_of_slaves;spi_channel++){
			tx_fifo->data_entry_1[iterator]=data;
			iterator++ ;
		}
	}

}

void Dma_write_data_entry_2(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves,uint16 data){
	uint8 nr_of_transmit_cycles= buffer_length / nr_of_slaves ;
	uint8 iterator=0;
	for(int i=0;i<nr_of_transmit_cycles;i++){
		for(int spi_channel=0;spi_channel<nr_of_slaves;spi_channel++){
			tx_fifo->data_entry_2[iterator]=data;
			iterator++ ;
		}
	}

}

void Dma_setup_spi_entry(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves,uint16 data){
	Dma_write_bacon_entry_start(spi_config_handle,tx_fifo, buffer_length,nr_of_slaves);
	Dma_write_bacon_entry_end(spi_config_handle,tx_fifo, buffer_length,nr_of_slaves) ;
	Dma_write_data_entry_1(spi_config_handle,tx_fifo, buffer_length,nr_of_slaves,data);
	Dma_write_data_entry_2(spi_config_handle,tx_fifo, buffer_length,nr_of_slaves,data);
}


uint32 get_bacon_first(uint32 bacon_val) {
	Ifx_QSPI_BACON bacon;
	bacon.U=bacon_val;
	bacon.B.LAST = 0;
	return bacon.U;
}

uint32 get_bacon_last(uint32 bacon_val) {
	Ifx_QSPI_BACON bacon;
	bacon.U=bacon_val;
	bacon.B.LAST = 1;
	return bacon.U;
}

void spi_write_Dma_src_addr_buffer(uint32 * buf,spi_config *spi_config_handle) {
	buf[0]=(uint32)get_bacon_last(spi_config_handle->spiMasterChannel[0].bacon.U);
	buf[1]=0x5555;
	buf[2]=(uint32)get_bacon_last(spi_config_handle->spiMasterChannel[1].bacon.U);
	buf[3]=0x5555;
	buf[4]=(uint32)get_bacon_last(spi_config_handle->spiMasterChannel[2].bacon.U);
	buf[5]=0x5555;
	buf[6]=(uint32)get_bacon_first(spi_config_handle->spiMasterChannel[2].bacon.U);
	buf[7]=0x5555;
	buf[8]=(uint32)get_bacon_last(spi_config_handle->spiMasterChannel[2].bacon.U);
}


uint32 Qspi_SpiMaster_get_rx_addr(IfxQspi_SpiMaster_Channel *chHandle) {
    IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
    Ifx_QSPI          *qspiSFR = handle->qspi;
    return (uint32)&qspiSFR->RXEXIT;
}

float32 convert_TLI_raw_value(uint32 value_raw) {
	sint16 raw_current= (sint16)(value_raw & 0x1FFF) ;
	float32 current;
	raw_current= raw_current - 4096 ;
	current = (float32)raw_current / 80.0 ;
	return current;
}

float32 avarage_sensor_values(qspi_dma_rx_value *rx_value) {
	float32 av_value=0;
	float32 temp=0;
	for(int i=0; i<4;i++) {
		temp=convert_TLI_raw_value(rx_value[i].value);
		av_value=av_value+temp;
	}
	av_value=av_value /4.0;
	return av_value;
}


void SPI_set_my_delay(IfxQspi_SpiMaster_Channel *chHandle, const IfxQspi_SpiMaster_ChannelConfig *chConfig) {
    IfxQspi_SpiMaster *handle  = chConfig->base.driver->driver;
    Ifx_QSPI          *qspiSFR = handle->qspi;

    chHandle->base.driver           = chConfig->base.driver;
    chHandle->channelId             = (IfxQspi_ChannelId)chConfig->sls.output.pin->slsoNr;
    uint8 cs = chHandle->channelId % 8;

    static float32 freq;
    static float32 leading_delay;
    static float32 nr_of_cycles_float;
    static uint32 nr_of_cycles;


    freq=IfxQspi_getModuleFrequency(qspiSFR);
    leading_delay= 100.0e-9 ;

    nr_of_cycles_float = leading_delay*freq;
    nr_of_cycles = (uint32)(nr_of_cycles_float);


        chHandle->bacon.B.LPRE=3;
        chHandle->bacon.B.TPRE=3;
        chHandle->bacon.B.LEAD=4;

}

uint8 Qspi_SpiMaster_get_rx_fill_level(IfxQspi_SpiMaster_Channel *chHandle) {
    IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
    Ifx_QSPI          *qspiSFR = handle->qspi;


    return IfxQspi_getReceiveFifoLevel(qspiSFR);

}












