/*
 * Spi_burst_interface.c

 *
 *  Created on: 26.11.2015
 *      Author: uacqk
 */

#include "Spi_burst_interface.h"

void initSpi_TLI4970_burst(spi_config* config) {
    IfxQspi_SpiMaster_Config        spiMasterConfig;
    IfxQspi_SpiMaster_ChannelConfig spiMasterChannelConfig;
    Ifx_QSPI                       *qspi3SFR;

   IfxQspi_SpiMaster_initModuleConfig(&spiMasterConfig, &MODULE_QSPI3);

    /* set the maximum baudrate */
    spiMasterConfig.base.maximumBaudrate = 10000000;

    /* ISR priorities and interrupt target */
    spiMasterConfig.base.txPriority    = ISR_PRIORITY_TX_EMPTY;
    spiMasterConfig.base.rxPriority    = ISR_PRIORITY_RX_EMPTY;
    spiMasterConfig.base.erPriority    = ISR_PRIORITY_QSPI3_ER;
    spiMasterConfig.base.isrProvider   = (IfxSrc_Tos)IfxCpu_getCoreId();
    spiMasterConfig.dma.txDmaChannelId = IFX_TX_CHANNELID;
    spiMasterConfig.dma.rxDmaChannelId = IFX_RX_CHANNELID;
    spiMasterConfig.dma.useDma         = TRUE;

    /* pin configuration */
    const IfxQspi_SpiMaster_Pins pins = {&IfxQspi3_SCLK_P22_3_OUT,                               /* SCLK */
                                         IfxPort_OutputMode_pushPull,
										 &IfxQspi3_MTSR_P22_0_OUT ,  IfxPort_OutputMode_pushPull , /* MTSR = MOSI*/
										 &IfxQspi3_MRSTE_P22_1_IN,  IfxPort_InputMode_pullUp ,  /* MRST = MISO*/
                                         IfxPort_PadDriver_cmosAutomotiveSpeed1                   /* pad driver mode */
    									};

    spiMasterConfig.pins = &pins;

    /* initialize module */
    DMA_TEST_IfxQspi_SpiMaster_initModule(&config->spiMaster, &spiMasterConfig);

    qspi3SFR = spiMasterConfig.qspi;
    volatile Ifx_SRC_SRCR *src = IfxQspi_getErrorSrc(qspi3SFR);
    // erstmal kein interrupt im Fehlerfall
    IfxSrc_init(src, IfxSrc_Tos_cpu0, ISR_PRIORITY_QSPI3_ER);
    IfxSrc_enable(src);


    /* create channel config */


    for(int i=0;i<SPI_NR_OF_SLAVES;i++){
    	IfxQspi_SpiMaster_initChannelConfig(&spiMasterChannelConfig,&config->spiMaster);

		/* set the baudrate for this channel */
		spiMasterChannelConfig.base.baudrate = 5000000;

		/* set the transfer data width */
		spiMasterChannelConfig.base.mode.dataWidth = 16;

		spiMasterChannelConfig.base.mode.csTrailDelay = 2;
		spiMasterChannelConfig.base.mode.csInactiveDelay = 2;
		spiMasterChannelConfig.base.mode.shiftClock = SpiIf_ShiftClock_shiftTransmitDataOnTrailingEdge;


		if(i== 0) {
		spiMasterChannelConfig.sls.output.pin    = &IfxQspi3_SLSO12_P22_2_OUT;
		spiMasterChannelConfig.sls.output.mode   = IfxPort_OutputMode_pushPull;
		spiMasterChannelConfig.sls.output.driver = IfxPort_PadDriver_cmosAutomotiveSpeed1;
		}
		else if(i==1) {
			spiMasterChannelConfig.sls.output.pin    = &IfxQspi3_SLSO11_P33_10_OUT;
			spiMasterChannelConfig.sls.output.mode   = IfxPort_OutputMode_pushPull;
			spiMasterChannelConfig.sls.output.driver = IfxPort_PadDriver_cmosAutomotiveSpeed1;
		}
		else {
			spiMasterChannelConfig.sls.output.pin    = &IfxQspi3_SLSO1_P33_9_OUT ;
			spiMasterChannelConfig.sls.output.mode   = IfxPort_OutputMode_pushPull;
			spiMasterChannelConfig.sls.output.driver = IfxPort_PadDriver_cmosAutomotiveSpeed1;
		}

		/* initialize channel */
		IfxQspi_SpiMaster_initChannel(&config->spiMasterChannel[i],&spiMasterChannelConfig);
		// workaround: Override TX handler

    }

}



void DMA_TEST_IfxQspi_SpiMaster_initModule(IfxQspi_SpiMaster *handle, const IfxQspi_SpiMaster_Config *config)
{
    Ifx_QSPI *qspiSFR = config->qspi;

    Ifx_DMA  *dmaSFR  = &MODULE_DMA;

    /* handle.base must be at offset 0 to be compatible with the standard interface SscIf */
    {
        uint16 password = IfxScuWdt_getCpuWatchdogPassword();
        IfxScuWdt_clearCpuEndinit(password);
        IfxQspi_setEnableModuleRequest(qspiSFR);
        IfxQspi_setSleepMode(qspiSFR, (config->allowSleepMode != FALSE) ? IfxQspi_SleepMode_enable : IfxQspi_SleepMode_disable);
        IfxScuWdt_setCpuEndinit(password);
    }

    {                                                        /* Configure GLOBAL, Note: at the moment default values for GLOBAL */
        Ifx_QSPI_GLOBALCON globalcon;
        globalcon.U        = 0;
        globalcon.B.TQ     = IfxQspi_calculateTimeQuantumLength(qspiSFR, config->base.maximumBaudrate);
        globalcon.B.EXPECT = IfxQspi_ExpectTimeout_2097152;  /* 2^(EXPECT+6) : timeout for expect phase in Tqspi */
        //globalcon.B.LB      = 0 ;                             /* 0 : disable loop-back w*/
        //globalcon.B.DEL0    = 0;                             /* 0 : disable delayed mode for SLSO 0 */
        //globalcon.B.STROBE  = 0;                             /* (STROBE+1) : strobe delay for SLSO 0 in Tq */
        //globalcon.B.SRF     = 0;                             /* 0 : disable stop-on-RXFIFO full feature */
        //globalcon.B.STIP    = 0;                             /* 0 : MRST = 0 when QSPI is deselected in slave mode */
        //globalcon.B.EN      = 0;                             /* 0 : PAUSE requested, 1 : RUN requested */
        globalcon.B.MS       = IfxQspi_Mode_master;            /* select master mode */
        globalcon.B.AREN     = (config->pauseOnBaudrateSpikeErrors != FALSE) ? 1U : 0U;
        globalcon.B.RESETS   = 1;
        qspiSFR->GLOBALCON.U = globalcon.U;
    }

    {   /* Configure interrupt requests */
        Ifx_QSPI_GLOBALCON1 globalcon1;
        globalcon1.U           = 0;
        //TODO: globalcon1.B.ERRORENS;
        globalcon1.B.TXEN      = (config->base.txPriority > 0) || (config->dma.useDma);
        globalcon1.B.RXEN      = (config->base.rxPriority > 0) || (config->dma.useDma);
        globalcon1.B.TXFIFOINT = config->txFifoThreshold;
        globalcon1.B.RXFIFOINT = config->rxFifoThreshold;

        qspiSFR->GLOBALCON1.U  = globalcon1.U;
    }

    /* Configure I/O pins for master mode */
    const IfxQspi_SpiMaster_Pins *pins = config->pins;

    if (pins != NULL_PTR)
    {
        const IfxQspi_Sclk_Out *sclkOut = pins->sclk;

        if (sclkOut != NULL_PTR)
        {
            IfxQspi_initSclkOutPin(sclkOut, pins->sclkMode, pins->pinDriver);
        }

        const IfxQspi_Mtsr_Out *mtsrOut = pins->mtsr;

        if (mtsrOut != NULL_PTR)
        {
            IfxQspi_initMtsrOutPin(mtsrOut, pins->mtsrMode, pins->pinDriver);
        }

        const IfxQspi_Mrst_In *mrstIn = pins->mrst;

        if (mrstIn != NULL_PTR)
        {
            IfxQspi_initMrstInPin(mrstIn, pins->mrstMode);
        }
    }

    handle->qspi                     = qspiSFR;
    handle->base.driver              = handle;
    handle->base.sending             = 0U;
    handle->base.activeChannel       = NULL_PTR;

    handle->base.functions.exchange  = (SpiIf_Exchange) & IfxQspi_SpiMaster_exchange;
    handle->base.functions.getStatus = (SpiIf_GetStatus) & IfxQspi_SpiMaster_getStatus;

    if (config->dma.useDma)
    {
        handle->base.functions.onTx = (SpiIf_OnEvent) & IfxQspi_SpiMaster_isrDmaTransmit;
        handle->base.functions.onRx = (SpiIf_OnEvent) & IfxQspi_SpiMaster_isrDmaReceive;
    }
    else
    {
        handle->base.functions.onTx = (SpiIf_OnEvent) & IfxQspi_SpiMaster_isrTransmit;
        handle->base.functions.onRx = (SpiIf_OnEvent) & IfxQspi_SpiMaster_isrReceive;
    }

    handle->base.functions.onError = (SpiIf_OnEvent) & IfxQspi_SpiMaster_isrError;

    if (config->dma.useDma)
    {
        handle->dma.useDma = TRUE;
        IfxDma_Dma               dma;
        IfxDma_Dma_createModuleHandle(&dma, dmaSFR);

        IfxDma_Dma_ChannelConfig dmaCfg;
        IfxDma_Dma_initChannelConfig(&dmaCfg, &dma);

        {
            handle->dma.txDmaChannelId     = config->dma.txDmaChannelId;
            dmaCfg.channelId               = handle->dma.txDmaChannelId;
            dmaCfg.hardwareRequestEnabled  = FALSE; // will be triggered from FFT service request
            dmaCfg.channelInterruptEnabled = FALSE;  // trigger interrupt after transaction

            // source address and transfer count will be configured during runtime
            dmaCfg.sourceAddress               = 0;
            dmaCfg.sourceAddressCircularRange  = IfxDma_ChannelIncrementCircular_16;
            dmaCfg.sourceCircularBufferEnabled = TRUE;
            dmaCfg.transferCount               = 1;
            dmaCfg.moveSize                    = IfxDma_ChannelMoveSize_32bit;

            // destination address is fixed; use circular mode to stay at this address for each move
            dmaCfg.destinationAddress               = (uint32)&qspiSFR->BACONENTRY.U ;
            dmaCfg.destinationAddressCircularRange  = IfxDma_ChannelIncrementCircular_16;
            dmaCfg.destinationCircularBufferEnabled = TRUE;

            dmaCfg.requestMode                      = IfxDma_ChannelRequestMode_completeTransactionPerRequest;
            dmaCfg.operationMode                    = IfxDma_ChannelOperationMode_continuous;
            dmaCfg.blockMode                        = IfxDma_ChannelMove_2;

            IfxDma_Dma_initChannel(&handle->dma.txDmaChannel, &dmaCfg);
        }

        {
            handle->dma.rxDmaChannelId     = config->dma.rxDmaChannelId;
            dmaCfg.channelId               = handle->dma.rxDmaChannelId;
            dmaCfg.hardwareRequestEnabled  = FALSE; // will be triggered from qspi service request
            dmaCfg.channelInterruptEnabled = FALSE;  // trigger interrupt after transaction

            // source address is fixed; use circular mode to stay at this address for each move
            dmaCfg.sourceAddress               = (uint32)&qspiSFR->RXEXIT.U;
            dmaCfg.sourceAddressCircularRange  = IfxDma_ChannelIncrementCircular_1;
            dmaCfg.sourceCircularBufferEnabled = TRUE;

            // destination address and transfer count will be configured during runtime
            dmaCfg.destinationAddress               = 0;
            dmaCfg.destinationAddressCircularRange  = IfxDma_ChannelIncrementCircular_none;
            dmaCfg.destinationCircularBufferEnabled = FALSE;
            dmaCfg.transferCount                    = 0;

            dmaCfg.requestMode                      = IfxDma_ChannelRequestMode_completeTransactionPerRequest;
            dmaCfg.operationMode                    = IfxDma_ChannelOperationMode_single;
            dmaCfg.moveSize                         = IfxDma_ChannelMoveSize_8bit;
            dmaCfg.blockMode                        = IfxDma_ChannelMove_1;

            IfxDma_Dma_initChannel(&handle->dma.rxDmaChannel, &dmaCfg);
        }
        /* Dma channel interrupt configuration */
        {
            volatile Ifx_SRC_SRCR *src = IfxDma_getSrcPointer(dmaSFR, (IfxDma_ChannelId)config->dma.txDmaChannelId);
            IfxSrc_init(src, (IfxSrc_Tos)IfxCpu_getCoreId(), config->base.txPriority);
            IfxSrc_enable(src);

            src = IfxDma_getSrcPointer(dmaSFR, (IfxDma_ChannelId)config->dma.rxDmaChannelId);
            IfxSrc_init(src, (IfxSrc_Tos)IfxCpu_getCoreId(), config->base.rxPriority);
            IfxSrc_enable(src);
        }
    }

    /* Qspi interrupt configuration */
    {
        /** NOTE: If not DMA, the interrupt service provider is assigned to the CPU ID where
         * this function is called from */

        IfxQspi_clearAllEventFlags(qspiSFR);

//      if (handle->dma.useDma)
//        {
//            volatile Ifx_SRC_SRCR *src = IfxQspi_getTransmitSrc(qspiSFR);
//            IfxSrc_init(src, IfxSrc_Tos_dma, config->dma.txDmaChannelId);
//            IfxSrc_enable(src);

//            src = IfxQspi_getReceiveSrc(qspiSFR);
//            IfxSrc_init(src, IfxSrc_Tos_dma, config->dma.rxDmaChannelId);
//            IfxSrc_enable(src);
//        }
//        else
        {
            if (config->base.txPriority != 0)
            {
                volatile Ifx_SRC_SRCR *src = IfxQspi_getTransmitSrc(qspiSFR);
                IfxSrc_init(src, config->base.isrProvider, config->base.txPriority);
                IfxSrc_enable(src);
            }

            if (config->base.rxPriority != 0)
            {
                volatile Ifx_SRC_SRCR *src = IfxQspi_getReceiveSrc(qspiSFR);
                IfxSrc_init(src, config->base.isrProvider, config->base.rxPriority);
                IfxSrc_enable(src);
            }
        }
    }

    IfxQspi_run(qspiSFR);
}







SpiIf_Status DMAIfxQspi_SpiMaster_exchange(IfxQspi_SpiMaster_Channel *chHandle,uint32* src, void *dest, SizeT count,uint32* test_addr)
{
    IfxQspi_SpiMaster *handle = (IfxQspi_SpiMaster *)chHandle->base.driver;
    SpiIf_Status       status = DMAIfxQspi_SpiMaster_lock(handle);
    static uint8 test_cs ;
    test_cs=chHandle->bacon.B.CS ;

    if (1)
    {
        /* initiate transfer when resource is free */
        handle->base.activeChannel      = &chHandle->base;
        chHandle->base.flags.onTransfer = 1;
        chHandle->base.tx.data          = (void *)src;
        chHandle->base.tx.remaining     = count;
        chHandle->firstWrite            = TRUE;
        chHandle->base.rx.data          = dest;
        chHandle->base.rx.remaining     = count;

        if (chHandle->activateSlso != NULL_PTR)
        {
            chHandle->activateSlso(chHandle);
        }
        Qspi_dma_write_burst(chHandle,test_addr,src);
       // __enable();
        //chHandle->base.txHandler(handle->base.activeChannel);
    }

    return status;
}

void Qspi_dma_write_burst(IfxQspi_SpiMaster_Channel *chHandle, uint32 *test_addr, uint32 * src_addr) {
	Ifx_DMA               *dmaSFR         = &MODULE_DMA;
	IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
	IfxDma_ChannelId       txDmaChannelId = handle->dma.txDmaChannelId;
	SpiIf_Job         *job    = &chHandle->base.tx;


	//IfxDma_setChannelTransferCount(dmaSFR, txDmaChannelId, 2);

    IfxDma_setChannelSourceAddress(dmaSFR, txDmaChannelId, (void *)IFXCPU_GLB_ADDR_DSPR(IfxCpu_getCoreId(), src_addr));
    IfxDma_setChannelSourceIncrementStep(dmaSFR, txDmaChannelId, IfxDma_ChannelIncrementStep_1,
        IfxDma_ChannelIncrementDirection_positive, IfxDma_ChannelIncrementCircular_16);

    IfxDma_setChannelDestinationAddress(dmaSFR, txDmaChannelId, (void *)IFXCPU_GLB_ADDR_DSPR(IfxCpu_getCoreId(), test_addr));
    IfxDma_setChannelDestinationIncrementStep(dmaSFR, txDmaChannelId, IfxDma_ChannelIncrementStep_1,
            IfxDma_ChannelIncrementDirection_positive, IfxDma_ChannelIncrementCircular_16);


    //IfxDma_enableChannelTransaction(dmaSFR, txDmaChannelId);
    //IfxDma_startChannelTransaction(dmaSFR, txDmaChannelId);






}

static SpiIf_Status DMAIfxQspi_SpiMaster_lock(IfxQspi_SpiMaster *handle)
{
    sint32 sending = __swap(&handle->base.sending, 1UL);
    return (sending == 0) ? SpiIf_Status_ok : SpiIf_Status_busy;
}


void Qspi_dma_channelTransaction_test(IfxQspi_SpiMaster_Channel *chHandle){
	Ifx_DMA               *dmaSFR         = &MODULE_DMA;
	IfxQspi_SpiMaster *handle = chHandle->base.driver->driver;
	IfxDma_ChannelId       txDmaChannelId = handle->dma.txDmaChannelId;
    //IfxDma_enableChannelTransaction(dmaSFR, txDmaChannelId);
    IfxDma_startChannelTransaction(dmaSFR, txDmaChannelId);


}

