/*
 * Spi_interface.h

 *
 *  Created on: 23.11.2015
 *      Author: uacqk
 *  @brief initialize SPI interface
 *  @ingroup interfaces
 */

#ifndef SPI_INTERFACE_H_
#define SPI_INTERFACE_H_

#include "_PinMap/IfxQspi_PinMap.h"
#include "QspiDmA/SpiMaster/IfxQspi_SpiMaster.h"
#include "Dma/Std/IfxDma.h"
#include "Cpu/Std/Platform_Types.h"


#define SPI_NR_OF_SLAVES 3

#define IFX_TX_CHANNELID IfxDma_ChannelId_1
#define IFX_RX_CHANNELID IfxDma_ChannelId_2

    /* ISR priorities and interrupt target */
    #define ISR_PRIORITY_TX_EMPTY 98
    #define ISR_PRIORITY_RX_EMPTY 99
    #define ISR_PRIORITY_QSPI3_ER 97
	#define QSPI3_BUFFER_SIZE 10

#define QSPI3_DMA_BUFFER_SIZE 32

typedef struct {
    uint32 spi3TxBuffer[QSPI3_BUFFER_SIZE];                               /**< \brief Qspi3 Transmit buffer */
    uint32 spi3RxBuffer[QSPI3_BUFFER_SIZE];                               /**< \brief Qspi3 receive buffer */
    IfxQspi_SpiMaster         spiMaster;        /**< \brief Spi Master handle */
    IfxQspi_SpiMaster_Channel spiMasterChannel[SPI_NR_OF_SLAVES]; /**< \brief Spi Master Channel handle */
}spi_config;

typedef struct {
	uint32 bacon_entry_1[QSPI3_DMA_BUFFER_SIZE];
	uint32 bacon_entry_2[QSPI3_DMA_BUFFER_SIZE];
	uint32 data_entry_1[QSPI3_DMA_BUFFER_SIZE];
	uint32 data_entry_2[QSPI3_DMA_BUFFER_SIZE];
}qspi__dma_tx_fifo;

typedef struct {
	uint32 status_entry_1[QSPI3_DMA_BUFFER_SIZE];
	uint32 status_entry_2[QSPI3_DMA_BUFFER_SIZE];
	uint32 data_entry_1[QSPI3_DMA_BUFFER_SIZE];
	uint32 data_entry_2[QSPI3_DMA_BUFFER_SIZE];
}qspi__dma_rx_fifo;

typedef struct {
	uint32 status;
	uint32 value;
}qspi_dma_rx_value;

typedef struct {
	qspi_dma_rx_value sensor1[4];
	qspi_dma_rx_value sensor2[4];
	qspi_dma_rx_value sensor3[4];
}qspi_dma_rx_stucture;

void initSpi_TLI4970(spi_config* config);
void spi_request_tripple(spi_config* config);
uint32 Qspi_SpiMaster_get_bacon_entry(IfxQspi_SpiMaster_Channel *chHandle) ;
uint32 Qspi_SpiMaster_get_data_entry(IfxQspi_SpiMaster_Channel *chHandle) ;

void Dma_write_bacon_entry_start(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves);
void Dma_write_bacon_entry_end(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves);
void Dma_write_data_entry_1(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves,uint16 data);
void Dma_write_data_entry_2(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves,uint16 data);
uint32 get_bacon_first(uint32 bacon_val);
uint32 get_bacon_last(uint32 bacon_val);
void Dma_setup_spi_entry(spi_config *spi_config_handle,qspi__dma_tx_fifo* tx_fifo, uint8 buffer_length,uint8 nr_of_slaves,uint16 data);
void Qspi_SpiMaster_write_input_fifo(IfxQspi_SpiMaster_Channel *chHandle);
uint32 Qspi_SpiMaster_get_rx_addr(IfxQspi_SpiMaster_Channel *chHandle) ;
float32 convert_TLI_raw_value(uint32 value_raw);
float32 avarage_sensor_values(qspi_dma_rx_value *rx_value) ;

void SPI_set_my_delay(IfxQspi_SpiMaster_Channel *chHandle, const IfxQspi_SpiMaster_ChannelConfig *chConfig);

uint32 Qspi_SpiMaster_read_input_fifo(IfxQspi_SpiMaster_Channel *chHandle);
void spi_write_Dma_src_addr_buffer(uint32 * buf,spi_config *spi_config_handle);





#endif /* 0_SRC_0_APPSW_TRICORE_APPLICATION_SPI_INTERFACE_H_ */
