/*
 * open_loop_pwm.c


 *
 *  Created on: 20.11.2015
 *      Author: uacqk
 */

#include "open_loop_pwm.h"

void init_open_loop_driver (open_loop_driver* driver,float32 frequency,float32 amplitude ,float32 pwm_period, TimerVal pwm_ticks) {
	driver->complex_ptr.imag=0;
	driver->complex_ptr.real=0;
	driver->supply_voltage=30;
	driver->electrical_angle=0;
	driver->amplitude=amplitude;
	driver->pwm_period=pwm_period;
	driver->pwm_period_ticks=pwm_ticks;
	driver->delta_angle=2* PI *(frequency* pwm_period);
}


void set_open_sin_frequency(open_loop_driver* driver, float32 frequency ) {
	float32 delta_tetha = 2* PI *(frequency* driver->pwm_period);
	driver->delta_angle=delta_tetha;
}

void do_open_loop_step(open_loop_driver* driver) {
	driver->electrical_angle+=(driver->delta_angle) ;
	if(driver->electrical_angle > 2 * PI) {
		driver->electrical_angle =driver->electrical_angle - 2 * PI ;
	}
	driver->complex_ptr.real = driver->amplitude * cos(driver->electrical_angle)/driver->supply_voltage;
	driver->complex_ptr.imag = driver->amplitude * sin(driver->electrical_angle)/driver->supply_voltage;
	//SpaceVectorModulation(driver->complex_ptr, driver->pwm_period_ticks , driver->tOn);


}

void do_measured_step(open_loop_driver* driver,sint16 sensor_pos, T3Phase *currents) {
	static float32 pos;
	static float32 pos_grad;
	static float32 pos_diff;
	static float32 I_d_open;
	static float32 I_q_open;
	CplxStdReal cosSin;
	CplxStdReal mdq, mab;
	//pos=(float32)sensor_pos*2*PI/1024.0 ;
	pos=driver->electrical_angle;


	pos_grad=((float32)(sensor_pos))*2*PI/1080.0 ;

    mab = Clarke(currents);

    cosSin = LookUp_CosinusSinus(sensor_pos);

    mdq = Park(&mab, &cosSin);

    I_d_open=mdq.real;
    I_q_open=mdq.imag;


	pos=pos_grad;

	pos+=(driver->delta_angle);
	if(pos>= 2 * PI) {
		pos =pos - 2 * PI ;
	}
	driver->electrical_angle=pos;
	driver->complex_ptr.real = driver->amplitude * cos(driver->electrical_angle)/driver->supply_voltage;
	driver->complex_ptr.imag = driver->amplitude * sin(driver->electrical_angle)/driver->supply_voltage;
	SpaceVectorModulation(driver->complex_ptr, driver->pwm_period_ticks , driver->tOn);


}





