/*
 * pwm_generation.c



 *
 *  Created on: 16.11.2015
 *      Author: uacqk
 */

#include "pwm_generation.h"
#include "cstart.h"

/**
 * @brief pins to control high side transistors
 */
const IfxGtmTom_ToutMapP High_transistors[3] = {
		 &IfxGtm_TOM1_1_TOUT11_P00_2,
		 &IfxGtm_TOM1_3_TOUT13_P00_4,
		 &IfxGtm_TOM1_5_TOUT15_P00_6
	};

/**
 * @brief pins to control low side transistors
 */
const IfxGtmTom_ToutMapP Low_transistors[3] = {
		&IfxGtm_TOM1_2_TOUT12_P00_3,
		&IfxGtm_TOM1_4_TOUT14_P00_5,
		&IfxGtm_TOM1_6_TOUT16_P00_7
	};


/**
 *@brief global struct to access 50us Timer
 */
IfxGtmTom_Timer Timer_driver;

/**
 *@brief global struct to access PWM registers
 */
IfxGtmTom_PwmHl PWM_driver;

/**
 * @brief initialize PWM
 * to init PWM :
 * 1. enable Generic Timer Module (GTM)
 * 2. initialize Timer
 * 3. startup timer
 * 4. set PWM settings
 */
void initPwm(){
	unsigned int tom_nr=1; // use Timer Output Module 1
	unsigned int tgc_nr=0; // use TGC Module 0
	unsigned int timer_channel=0; // timer channel =0
	unsigned int clk_source = 0; // source = fixed Clock, no divider


	float32 pwm_freq = 20000.0;
	float32 pwm_period = 1 / pwm_freq;


	Ifx_GTM* gtm = &MODULE_GTM ; // Start Address of Generic Timer Module
	float32 spbFrequency = IfxScuCcu_getSpbFrequency();




	IfxGtm_enable(gtm); // Enable gtm by setting gtm->CLC.B.DISR = 0;

	// setting PWM Freqency by setting Numerator and Denominator in
	// CMU Global Clock Control Numerator Register
	IfxGtmCmu_setGclkFrequency(gtm, spbFrequency);


	uint32 pwm_period_ticks = pwm_period * spbFrequency;

	/* 	setzte CMU Clock Enable Register und verwende die fixed clock als Quelle */
	/* Enable the fix clock */
	gtm->CMU.CLK_EN.U = IFXGTMCMU_CLKEN_FXCLK;

	// Setup Timer for PWM Generation
	IfxGtmTom_Timer_Config tmrConfig;

	tmrConfig.gtm = gtm;
	tmrConfig.base.frequency=pwm_freq;
	tmrConfig.base.countDir=Timer_CountDir_up;
	tmrConfig.base.isrPriority = 0 ;
	tmrConfig.base.minResolution = 0.1e-6 ;
	tmrConfig.base.isrProvider = IfxSrc_Tos_cpu0;
	tmrConfig.clock	= IfxGtmTom_Ch_ClkSrc_cmuFxclk0;
	tmrConfig.tom = IfxGtmTom_1;
	tmrConfig.timerChannel=IfxGtmTom_Ch_0  ;

	tmrConfig.triggerChannel= &IfxGtm_TOM1_7_TOUT17_P00_8;

	// init trigger for 50us current control loop
	tmrConfig.base.trigger.enabled = TRUE;
	tmrConfig.base.trigger.dutyCycle=0.5;
	tmrConfig.base.trigger.isrPriority=CONTROL_ISR_PRIO;
	tmrConfig.base.trigger.isrProvider=IfxSrc_Tos_cpu0 ;
	tmrConfig.base.trigger.outputFeature = 0;
	tmrConfig.base.trigger.outputOption = 0;      							/**< \brief Output option */
	tmrConfig.base.trigger.outputMode = IfxPort_OutputMode_pushPull;          /**< \brief Output mode *//* FIXME use generic type (No specific tricore AURIX type ) */
	tmrConfig.base.trigger.outputDriver = IfxPort_PadDriver_cmosAutomotiveSpeed2;       /**< \brief Output pad driver *//* FIXME use generic type (No specific tricore AURIX type ) */
	tmrConfig.base.trigger.risingEdgeAtPeriod = TRUE;  /**< \brief Set the clock signal polarity, if TRUE, the rising edge is at the period, else at the trigger offset. When the timer is stopped, the output is set to high */
	tmrConfig.base.trigger.outputEnabled = TRUE;

	//enable_gtm_interrupts(&tmrConfig);

	IfxGtmTom_Timer_init(&Timer_driver, &tmrConfig); // write tmr Config into registers



	/* ALL DONE IN IfxGtmTom_Timer_init */
//	Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL); /* Pointer auf TOM1 channel 0 Control Register */
//	tomCh->CTRL.B.CLK_SRC_SR = clk_source ;
//
//	tomCh->SR0.U = pwm_period_ticks ; /* SR= Oberes Compare Register (shadow) */
//	tomCh->CTRL.B.TRIGOUT = 1; /* generate trigger from current channel */
//
//    IfxGtmTom_Tgc_setChannelsForceUpdate(tgc, 1, 0, 0, 0);
//    IfxGtmTom_Tgc_trigger(tgc);
//    IfxGtmTom_Tgc_setChannelsForceUpdate(tgc, 0, 1, 0, 0);


//

	Timer_driver.base.functions.run(&Timer_driver.base);		// start timer

	/* initialisiere PWM */

	 IfxGtmTom_PwmHl_Config pwm_config;

	pwm_config.tom= (IfxGtmTom)tom_nr;
	pwm_config.base.timer = &Timer_driver.base ;
	pwm_config.base.deadtime=1.0e-6;
	pwm_config.base.minPulse = 0;
	pwm_config.base.outputMode =IfxPort_OutputMode_pushPull;
	pwm_config.base.channelCount = NUMBER_OF_CHANNELS ;
	pwm_config.base.emergencyEnabled = FALSE;
	pwm_config.base.outputDriver = IfxPort_PadDriver_cmosAutomotiveSpeed1;
	pwm_config.base.ccxActiveState = ActiveState_high; // on state of high transistors
	pwm_config.base.ccxFeature = NULL_PTR ;
	pwm_config.base.ccxOption = NULL_PTR;
	pwm_config.base.coutxActiveState = ActiveState_high; // on state of low transistors
	pwm_config.base.coutxFeature = NULL_PTR;
	pwm_config.base.coutxOption = NULL_PTR ;

	pwm_config.ccx = High_transistors;	// pin definition
	pwm_config.coutx = Low_transistors ; // pin definition


	IfxGtmTom_PwmHl_init(&PWM_driver, &pwm_config);	// write pwm_config to registers
	PWM_driver.base.functions.setMode(&PWM_driver.base,Pwm_Mode_centerAligned);	// set centerAligned PWM


}

/**
 * @brief update shadowregisters of PWM
 */
void set_three_channel_PWM(IfxGtmTom_Timer* timer_driver,IfxGtmTom_PwmHl* PWM_driver,TimerVal *tOn) {
	MyIfxGtmTom_Tgc_disableChannelsUpdate(timer_driver);
	IfxGtmTom_Timer_setTrigger(timer_driver, 2);
	MyIfxGtmTom_PwmHl_updateCenterAligned(PWM_driver,tOn);
	MyIfxGtmTom_Tgc_enableChannelsUpdate(timer_driver);

}

void MyIfxGtmTom_Timer_applyUpdate(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask)
{
    tgc->GLB_CTRL.U = MyIfxGtmTom_Tgc_buildFeature(enableMask, disableMask, IFX_GTM_TOM_TGC0_GLB_CTRL_UPEN_CTRL0_OFF);
}


void MyIfxGtmTom_Tgc_enableChannelsUpdate(IfxGtmTom_Timer *driver){
	MyIfxGtmTom_Timer_applyUpdate(driver->tgc, driver->channelsMask, 0);

}

void MyIfxGtmTom_Tgc_disableChannelsUpdate(IfxGtmTom_Timer *driver){
	MyIfxGtmTom_Timer_applyUpdate(driver->tgc, 0,driver->channelsMask);

}

/******************************************************************************/
/** @brief Build the register value for the feature enable/disable
 *
 * \param enableMask Mask for the channel feature enable (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the channel feature disable (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param bitfieldOffset Offset of the channel 0 bitfield in the register
 *
 * \return Returns the register value
 */
static uint32 MyIfxGtmTom_Tgc_buildFeature(uint16 enableMask, uint16 disableMask, uint8 bitfieldOffset)
{
    uint8  i;
    uint32 reg  = 0;
    uint32 mask = enableMask | (disableMask << 16);

    for (i = 0; i < 8; i++)
    {
        /* Bitfield length is 2 bits */
        uint8 shift = (i * 2) + bitfieldOffset;

        if (mask & 0x1)
        {
            reg |= IfxGtm_FeatureControl_enable << shift;
        }

        if (mask & 0x10000)
        {
            reg |= IfxGtm_FeatureControl_disable << shift;
        }

        mask = mask >> 1;
    }

    return reg;
}

/** @brief Update the x output duty cycle in center aligned and center aligned inverted modes
 *
 * \return None.
 * \private
 */
 void MyIfxGtmTom_PwmHl_updateCenterAligned(IfxGtmTom_PwmHl *driver, TimerVal *tOn)
{
    uint8    channelIndex;
    TimerVal period;
    TimerVal deadtime = driver->base.deadtime;

    period = driver->base.timer->period;

    for (channelIndex = 0; channelIndex < driver->base.channelCount; channelIndex++)
    {
        TimerVal x;             /* x=period*dutyCycle, x=OnTime+deadTime */
        TimerVal cm0, cm1;
        x = tOn[channelIndex];

        if (driver->base.inverted != FALSE)
        {
            x = period - x;
        }
        else
        {}

        if ((x < driver->base.minPulse) || (x <= deadtime))
        {                       /* For deadtime condition: avoid leading edge of top channel to occur after the trailing edge */
            x = 0;
        }
        else if (x > driver->base.maxPulse)
        {
            x = period;
        }
        else
        {}

        /* Special handling due to GTM issue */
        if (x == period)
        {                       /* 100% duty cycle */
            IfxGtmTom_Ch_setCompareShadow(driver->tom, driver->ccxTemp[channelIndex],
                period + 1 /* No compare event */,
                2 /* 1st compare event (issue: expected to be 1) */ + deadtime);
            IfxGtmTom_Ch_setCompareShadow(driver->tom, driver->coutxTemp[channelIndex],
                period + 2 /* No compare event, issues has been seen with +1 */,
                2 /* 1st compare event (issue: expected to be 1) */);
        }
        else if (x == 0)
        {
            cm0 = 1;
            cm1 = period + 2;
            IfxGtmTom_Ch_setCompareShadow(driver->tom, driver->ccxTemp[channelIndex], cm0, cm1);
            IfxGtmTom_Ch_setCompareShadow(driver->tom, driver->coutxTemp[channelIndex], cm0 + deadtime, cm1);
        }
        else
        {                           /* x% duty cycle */
            cm1 = (period - x) / 2; // CM1 /* FIXME issue if CM1 <= 1, should be limited for up to AB step at least */
            cm0 = (period + x) / 2; // CM0
            IfxGtmTom_Ch_setCompareShadow(driver->tom, driver->ccxTemp[channelIndex], cm0, cm1 + deadtime);
            IfxGtmTom_Ch_setCompareShadow(driver->tom, driver->coutxTemp[channelIndex], cm0 + deadtime, cm1);
        }
    }
}

void enable_gtm_interrupts(IfxGtmTom_Timer_Config* tmrConfig) {

	Ifx_GTM* gtm= tmrConfig->gtm;
	Ifx_GTM_TOM* tom=&gtm->TOM[tmrConfig->tom];
	IfxGtmTom_Ch channel = tmrConfig->timerChannel;
	Ifx_GTM_TOM_CH       *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

	//setzte gtm Global Enable Register

	tomCh->IRQ_EN.U=0x03;
	tomCh->IRQ_MODE.U=0x02;


}

TimerVal get_pwm_period_ticks(IfxGtmTom_Timer *driver,float32 frequency) {
	Timer  *timer  = &driver->base;
	TimerVal period = timer->functions.sToTick(timer, 1.0 / frequency);
	return period;
}


