/**
 * pwm_generation.h

 *
 *  Created on: 16.11.2015
 *      Author: uacqk
 *      @brief generate 3-phase PWM via the GTM Module
 *      Is used to init and access the GTM Module to generate a 3-phase PWM to control a PMSM
 *      @ingroup interfaces
 */

#ifndef PWM_GENERATION_H_
#define PWM_GENERATION_H_

#include "IfxGtm_reg.h"
#include "IfxGtm_regdef.h"
#include "Gtm/Std/IfxGtm.h"
#include "Scu/Std/IfxScuCcu.h"
#include "_Impl/IfxGtm_cfg.h"
#include "_PinMap/IfxGtm_PinMap.h"
#include "Gtm/Std/IfxGtmTom.h"
#include "Gtm/Tom/PwmHl/IfxGtmTom_PwmHl.h"
#include "If/PwmHl.h"
#include "TC234_startup.h"

#define NUMBER_OF_CHANNELS 3

#define PWM_DEADTIME 1.0e-6

#define PWM_MINPULSE 0

extern IfxGtmTom_Timer Timer_driver;
extern IfxGtmTom_PwmHl PWM_driver;

/** \\brief  Offset for Ifx_GTM_TOM_TGC0_GLB_CTRL_Bits.UPEN_CTRL0 */
#define IFX_GTM_TOM_TGC0_GLB_CTRL_UPEN_CTRL0_OFF (16)

void initPwm();

void set_three_channel_PWM(IfxGtmTom_Timer* timer_driver,IfxGtmTom_PwmHl* PWM_driver,TimerVal *tOn) ;
void MyIfxGtmTom_Timer_applyUpdate(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask);
void MyIfxGtmTom_Tgc_enableChannelsUpdate(IfxGtmTom_Timer *driver);
void MyIfxGtmTom_Tgc_disableChannelsUpdate(IfxGtmTom_Timer *driver);
static uint32 MyIfxGtmTom_Tgc_buildFeature(uint16 enableMask, uint16 disableMask, uint8 bitfieldOffset);
void enable_gtm_interrupts(IfxGtmTom_Timer_Config* tmrConfig);

void MyIfxGtmTom_PwmHl_updateCenterAligned(IfxGtmTom_PwmHl *driver, TimerVal *tOn);
TimerVal get_pwm_period_ticks(IfxGtmTom_Timer *driver,float32 frequency);










#endif /* 0_SRC_0_APPSW_TRICORE_APPLICATION_PWM_GENERATION_H_ */
