/**
 * vadc_interface.c

 *
 *
 *  Created on: 17.02.2016
 *      Author: uacqk
 */

#include "vadc_interface.h"


/**
 * @brief initialize torque sensor
 *
 * The NCTE 2000 torque sensor converts a torque into a voltage between 0 and 5 Volts. This Voltage is read out by the VADC_peripherial
 * of the AURIX device.
 *
 * @param vadc_module VADC handle structure to be initialized
 * @param Vadc_input_channel VADC channel handle structure to be initialized
 *
 * to start up the vadc
 * 1. f_pll2 has to be set f_adc does not exist this is an error in the documentation
 * 2. init VADC Module
 * 3. init VADC Group
 * 4. init VADC Channel
 * 5. fill channel Queue
 * 6. set Gating condition
 */

void init_vadc_for_torque_sensor(IfxVadc_Adc* vadc_module,IfxVadc_Adc_Channel* Vadc_input_channel) {

	static uint32 frequency;
	frequency = IfxScuCcu_getAdcFrequency();
	uint32 used_group = 1;


	IfxScuCcu_setPll2Frequency(120000000.0);
	IfxScuCcu_selectAdcClock(IfxScuCcu_AdcClockSelection_fpll2);
	frequency = IfxScuCcu_getAdcFrequency();

	IfxVadc_Adc_GroupConfig		groupConfig;
	IfxVadc_Adc_ChannelConfig 	channelConfig;

	IfxVadc_Adc_Group Vadc_Group;


	// vadc Handle data structure


	// vadc configuration structure
	IfxVadc_Adc_Config IfxVadc_adc_module_config =
	{
		.vadc	= (&MODULE_VADC),						 //* VADC_Module is used   */
		.moduleFrequency = (100000000U),				 //* digital clock = 100MHz   */
		.analogFrequency = (20000000U),					 //*analog clock = 20MHz  this is the clock the SAR ADC uses for sampling */
		.disablePostCalibrationGroup[0] = FALSE,			 /* post calibration enabled - calibration against temperature sweep etc.. */
		.disablePostCalibrationGroup[1] = FALSE,
		.disablePostCalibrationGroup[2] = FALSE,
		.disablePostCalibrationGroup[3] = FALSE,
	};

	IfxVadc_Adc_GroupConfig adc_group_config = {
			.groupId = IfxVadc_GroupId_1,
			.module  = NULL_PTR,
			.arbiter                        = {
				.arbiterRoundLength = IfxVadc_ArbitrationMode_4_slots,
				.reqSlotMode[0]     = IfxVadc_RequestSlotStartMode_cancelInjectRepeat,
				.reqSlotMode[1]     = IfxVadc_RequestSlotStartMode_waitForStart,
				.reqSlotMode[2]     = IfxVadc_RequestSlotStartMode_waitForStart,
				.reqSlotPrio[0]     = IfxVadc_ReqSlotPrio_highest,
				.reqSlotPrio[1]     = IfxVadc_ReqSlotPrio_low,
				.reqSlotPrio[2]     = IfxVadc_ReqSlotPrio_lowest,
				.usedReqSlots[0]    = TRUE,         /* Enable Queue mode */
				.usedReqSlots[1]    = FALSE,         /* Disable Scan mode */
				.usedReqSlots[2]    = FALSE,         /* Disable Background scan */
			},
			.backgroundScanReq              = {
				.autoscanEnable             = FALSE,
				.triggerConfig.gatemode     = IfxVadc_GatingMode_disabled,
				.triggerConfig.triggermode  = IfxVadc_TriggerMode_noExternalTrigger,
				.triggerConfig.gateInput    = IfxVadc_GatingSource_0,
				.triggerConfig.triggerInput = IfxVadc_TriggerSource_0,
			},
			.scanRequest                    = {
				.autoscanEnable             = FALSE,
				.triggerConfig.gatemode     = IfxVadc_GatingMode_disabled,
				.triggerConfig.gateInput    = IfxVadc_GatingSource_0,
				.triggerConfig.triggermode  = IfxVadc_TriggerMode_noExternalTrigger,
				.triggerConfig.triggerInput = IfxVadc_TriggerSource_0,
			},
			.queueRequest                   = {
				.flushQueueAfterInit        = TRUE,
				.triggerConfig.gatemode     = IfxVadc_GatingMode_always,
				.triggerConfig.gateInput    = IfxVadc_GatingSource_1,
				.triggerConfig.triggermode  = IfxVadc_TriggerMode_noExternalTrigger,
				.triggerConfig.triggerInput = IfxVadc_TriggerSource_15,
			},
			.inputClass[0].resolution = IfxVadc_ChannelResolution_12bit,
			.inputClass[0].sampleTime = 1.0e-6,                        /* Set sample time to 1us */
			.inputClass[1].resolution = IfxVadc_ChannelResolution_12bit,
			.inputClass[1].sampleTime = 1.0e-6,                        /* Set sample time to 1us */
		};


	AppVadc_AnalogInput_cfg adc_channel = {
			.groupId				 = IfxVadc_GroupId_1,
			.hwChannel = {
				.channelId           = IfxVadc_ChannelId_0,
				.group               = NULL_PTR,
				.inputClass          = IfxVadc_InputClass_group0,
				.reference           = IfxVadc_ChannelReference_standard,
				.resultRegister      = IfxVadc_ChannelResult_0,
				.globalResultUsage   = FALSE,
				.lowerBoundary       = IfxVadc_BoundarySelection_group0,
				.upperBoundary       = IfxVadc_BoundarySelection_group0,
				.boundaryMode        = IfxVadc_BoundaryExtension_standard,
				.limitCheck          = IfxVadc_LimitCheck_noCheck,
				.synchonize          = FALSE,
				.backgroundChannel   = FALSE,
				.rightAlignedStorage = FALSE,
				.resultPriority      = 0,
				.resultSrcNr         = IfxVadc_SrcNr_group0,
				.resultServProvider  = IfxSrc_Tos_cpu0,
				.channelPriority     = 0,
				.channelSrcNr        = IfxVadc_SrcNr_group0,
				.channelServProvider = IfxSrc_Tos_cpu0
			},
			.coversionSetup =
			{
				.requestSource = IfxVadc_RequestSource_queue,
				.priority	= 1,
				.refill 	= TRUE,
				.trigger    = TRUE
			},
			.limits = {
					.min = 0,
					.max =5,
					.status = 0,
					.onOutOfRange	= NULL_PTR,
					.object			= NULL_PTR,
					.info			= 0
			},
			.gain	=	1,
			.offset	= 	1,
		};


	/* sets analog and digital clk divider in GLOBCFG Register
	 * 		   sets ANONC to normal mode in all GxARBCFG Register
	 * 		   calibrates VADC Module
	 */
	IfxVadc_Adc_initModule(vadc_module, &IfxVadc_adc_module_config);

	// initialize Group 1

		groupConfig = adc_group_config;
			/* IfxVadc_adc_group_config: properties of different ADC Groups */
		groupConfig.module =vadc_module;

		/* write group config to Group configuration registers
		 *  A ADC group consists of
		 *  - Result and Validation registers
		 *  - Arbitration which triggers sampling
		 *  - SAR-ADC & Sample and Hold Unit
		 *  - Analog Input Multiplexer
		 *  - set GxARBPR: Arbitration Priority and turn on enabled slots
		 *
		 */
		IfxVadc_Adc_initGroup(&Vadc_Group, &groupConfig);

		channelConfig = adc_channel.hwChannel ;
		channelConfig.group= &Vadc_Group;

		// set channel configuration
		IfxVadc_Adc_initChannel(Vadc_input_channel, &channelConfig);

		// set GxQINR0 register
		//
		IfxVadc_Adc_addToQueue(Vadc_input_channel,IFXVADC_QUEUE_REFILL);	//  Trigger just refill


		// set GxQCTRL0 register
		//set gate to 1 so sampling is always enabled
		vadc_module->vadc->G[1].QMR0.B.ENGT = 1 ;



}
/**
 * @brief initiate sampling
 * @param vadc_module pointer to vadc module handle struct
 * @param ch_id channel id number
 */
void trigger_vadc(IfxVadc_Adc* vadc_module,IfxVadc_ChannelId ch_id) {
	vadc_module->vadc->G[ch_id].QMR0.B.TREV=1; // generate Trigger Event
}

/**
 * @brief read result register
 * @param channel pointer to Channel handle struct
 */
uint32 return_raw(IfxVadc_Adc_Channel *channel) {
	uint32 rawValue;
	rawValue = IfxVadc_Adc_getResult(channel).B.RESULT;
	return rawValue;
}

/**
 * @brief convert raw_value to voltage
 * @param raw_value value in lsb
 */
float32 convert_raw_to_voltage(uint32 raw_value) {
	float32 voltage;
	voltage = (float32)raw_value * VADC_CONVERSION_VALUE;
	return voltage;
}
