
/**
 * @defgroup interfaces
 */

/**
 * @file vadc_interface.h

 *@brief interface for initialization and readout of Vadc
 *
 * this interface is for initialization of the VADC
 *  Created on: 17.02.2016
 *      Author: uacqk
 *
 *
 *
 * @ingroup interfaces
 */


#ifndef VADC_INTERFACE_H_
#define VADC_INTERFACE_H_

#include "Vadc/Adc/IfxVadc_Adc.h"

#define VADC_CONVERSION_VALUE 5.0/(4096)

/**
 * @brief struct to report status of measurement
 */
typedef enum
{
	AppVadc_LimitsStatus_Ok,
	AppVadc_LimitsStatus_Min,
	AppVadc_LimitsStatus_Max,
	AppVadc_LimitsStatus_OutOfRange
}AppVadc_LimitsStatus;

typedef void (*AppVadc_Limits_onOutOfRange)(void *object, AppVadc_LimitsStatus status, uint32 info);

/**
 * @brief struct to define limits  of measurement
 */
typedef struct
{
    float32 min;
    float32 max;
    AppVadc_LimitsStatus status;
    AppVadc_Limits_onOutOfRange onOutOfRange;
    void* object;
    uint32 info;
} AppVadc_Limits_1_float32;


typedef struct
{
	IfxVadc_RequestSource	requestSource;
	uint16					priority;				// for request source queued [range 1..8] 1 means first in the queue 8 last in queue
	boolean					refill;					// for request source queued refill in queue
	boolean					trigger;				// for request source queued seperate trigger for channel
}AppVadc_Conversion_cfg;

/**
 * @brief configuration of analog input
 * @param groupId contains Id of the used group
 * @param hwChannel config of channel properties on register level eg. reference voltage
 * @param conversionSetup not clear what this does - not so important
 * @param limits can be used for limitation of input signal - not so important
 * @param gain gan be used to compensate gain
 * @param can be used to compensate offset
 */
typedef struct
{
	IfxVadc_GroupId 			groupId;
	IfxVadc_Adc_ChannelConfig 	hwChannel;
	AppVadc_Conversion_cfg		coversionSetup;
	AppVadc_Limits_1_float32	limits;
	float32						gain;
	float32						offset;
}AppVadc_AnalogInput_cfg;


void init_vadc_for_torque_sensor(IfxVadc_Adc* vadc_module,IfxVadc_Adc_Channel* Vadc_input_channel);
void trigger_vadc(IfxVadc_Adc* vadc_module,IfxVadc_ChannelId ch_id);
uint32 return_raw(IfxVadc_Adc_Channel *channel);

float32 convert_raw_to_voltage(uint32 raw_value) ;

#endif /* 0_SRC_0_APPSW_TRICORE_APPLICATION_VADC_INTERFACE_H_ */
