/*
 * vector_control.c

 *
 *  Created on: 13.01.2016
 *      Author: uacqk
 */


#include "vector_control.h"

void init_fo_controller(TFoc* foc,uint32 pwmFrequency) {
	Foc_Init(foc);
    Foc_SetIdLimit(foc, CFG_M0_ID_LIMIT	);
    Foc_SetIqLimit(foc, CFG_M0_IQ_LIMIT	);

    Pic_SetKpKi_StdReal(&(foc->piId), CFG_M0_PI_KP, CFG_M0_PI_KI, 1.0/pwmFrequency, 0, 0);
    Pic_SetLimit(&(foc->piId),-CFG_M0_PI_ID_LIMIT_MAX,CFG_M0_PI_ID_LIMIT_MAX);

    Pic_SetKpKi_StdReal(&(foc->piIq), CFG_M0_PI_KP, CFG_M0_PI_KI, 1.0/pwmFrequency, 0, 0);
    Pic_SetLimit(&(foc->piIq),-CFG_M0_PI_IQ_LIMIT_MAX,CFG_M0_PI_IQ_LIMIT_MAX);


	foc->limitAmpl = eMotorBoardVoltageMax;

	foc->limit.imag = eMotorBoardCurrentMax;
	foc->limit.real = eMotorBoardCurrentMax;


}

CplxStdReal fo_current_ctrl_step(TFoc* foc, sint16 sensor_pos_electrical,T3Phase* phase_currents) {
	CplxStdReal I_rot; // pointer in the alpha,betha System (rotor fixed system)



	I_rot=Foc_Do(foc, sensor_pos_electrical, phase_currents);
	return I_rot;
}


void set_Id_ref_current(TFoc *foc, StdReal id) {

	void Foc_SetId(foc, id);

}

void set_Iq_ref_current(TFoc *foc, StdReal id) {

	Foc_SetIq(foc, id);

}

CplxStdReal own_fo_current_ctrl_step(TFoc* foc, sint16 electricalAngle,T3Phase*currents) {
	CplxStdReal I_rot; // pointer in the alpha,betha System (rotor fixed system)


		CplxStdReal cosSin;
		CplxStdReal mdq, mab;
		static float32 I_d_error,I_q_error;
		static float32 I_d_measured,I_q_measured;

	    /* Clarke Park transformation */
	    mab = Clarke(currents);

	    cosSin = LookUp_CosinusSinus(electricalAngle);

	    mdq = Park(&mab, &cosSin);

	    I_d_measured =mdq.real;
	    I_q_measured =mdq.imag;

	    foc->nfo_mdq = mdq;

	    /* Pure PI controller only with symmetrical Limitation of Vq and Vd*/

	    /* Pi controller */

	    I_d_error=__subs_rSR_iSR_iSR(foc->ref.real, mdq.real);
	    I_q_error=__subs_rSR_iSR_iSR(foc->ref.imag, mdq.imag) ;
	    	/* __subs_rSR_iSR_iSR: saturierte differenz ein einfaches - htte es auch getan */
	    mdq.imag =  Pic_Do(&foc->piIq, __subs_rSR_iSR_iSR(foc->ref.imag, mdq.imag));
	    mdq.real =  Pic_Do(&foc->piId, __subs_rSR_iSR_iSR(foc->ref.real, mdq.real));
	    // Limitation of Vq and Vd with anti wind up
	    mdq = OWN_Foc_LimitVqVd(&foc->piId,&foc->piIq, mdq, foc->limitAmpl); /* Anti Windup , Voltage Decoupling ?*/

	    /* Reverse Park transformation */
	    mab = Park_Reverse(&mdq, &cosSin);
	    foc->nfo_mab = mab;
	    return mab;

}


CplxStdReal OWN_Foc_LimitVqVd(TPic* Pic_d,TPic* Pic_q, CplxStdReal mdq,StdReal Limit )
{
    /* Note 0.9 is the maximum for where Vref in the lies in the circle (continuous) */
	StdReal ModIndex = sqrt((mdq.imag * mdq.imag) + (mdq.real * mdq.real));
    ModIndex = (Limit / ModIndex );
    if(ModIndex < 1)
    {
    	mdq.imag *= ModIndex;
    	mdq.real *= ModIndex;
    	// Correct PI-Output with new calculated values for anti wind up reason
    	Pic_d->uk = mdq.real;
    	Pic_q->uk = mdq.imag;
    }
    return mdq;
}

