/**
 * \file AscIf.h
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1262.4
 * $Date: $2013-07-12 16:20:30 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup library_srvsw_if_asc ASC interface types
 * This module defines the generic ASC interface types
 * \ingroup library_srvsw_if
 *
 */

#ifndef ASCIF_H
#define ASCIF_H

#include "Cpu/Std/Ifx_Types.h"

/** \addtogroup library_srvsw_if_asc
 * \{ */

/** \brief ASC check mechanism flags.
 */
typedef struct
{
    uint32 parity : 1;
    uint32 frame : 1;
    uint32 overrun : 1;
} AscIf_Check;

typedef struct
{
    uint32 parity : 1;
    uint32 frame : 1;
    uint32 overrun : 1;
} AscIf_Error;

/** \brief ASC input / output definition.
 */
typedef enum
{
    AscIf_Io_a,                         /**< \brief  Output A */
    AscIf_Io_b,                         /**< \brief  Output B */
    AscIf_Io_c,                         /**< \brief  Output C */
    AscIf_Io_d,                         /**< \brief  Output D */
    AscIf_Io_e,                         /**< \brief  Output E */
    AscIf_Io_f,                         /**< \brief  Output F */
} AscIf_Io;

/** \brief ASC parity definition.
 */
typedef enum
{
    IfxAsc_Parity_even,                     /**< \brief  Even parity */
    IfxAsc_Parity_odd,                      /**< \brief  Odd parity */
    IfxAsc_Parity_none,                     /**< \brief  No parity */
    IfxAsc_Parity_error                     /**< \brief  Setting error */
} AscIf_Parity;

/** \brief ASC stop bit definition.
 */
typedef enum
{
    AscIf_ShiftDir_msb,                         /**< \brief  Shift direction: MSB first */
    AscIf_ShiftDir_lsb,                         /**< \brief  Shift direction: LSB first */
} AscIf_ShiftDir;

/** \brief ASC stop bit definition.
 */
typedef enum
{
    IfxAsc_StopBit_1,                       /**< \brief  1 stop bit */
    IfxAsc_StopBit_2,                       /**< \brief  2 stop bits */
    IfxAsc_StopBit_error                    /**< \brief  Setting error */
} AscIf_StopBit;

/** \brief ASC Mode definition.
 */
typedef enum
{
    AscIf_SyncMode_sync,                    /**< \brief  Synchronous mode */
    AscIf_SyncMode_async                    /**< \brief  Asynchronous mode */
} AscIf_SyncMode;

#endif /* ASCIF_H */
