/**
 * \file PosIf.c
 * \brief Position sensor interface
 *
 * \license
 * You can use this file under the terms of the IFX License.
 *
 * This file is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * IFX License for more details (IFX_License.txt).
 *
 * This file may be used, copied, and distributed, with or without
 * modification, provided that all copyright notices are retained;
 * that all modifications to this file are prominently noted in the
 * modified file; and that this paragraph is not modified.
 *
 *
 * $Revision: $1346.3
 * $Date: $2013-06-24 18:38:09 GMT
 *
 */

#include "PosIf.h"

void      PosIf_setOffset_base(PosIf *handle, PosIf_Raw offset);
PosIf_Raw PosIf_resetOffset_base(PosIf *handle);
void      PosIf_setupElAngleConst_base(PosIf *handle, sint32 motorPolePairs);
StdReal   PosIf_updateSpeed_base(PosIf *handle, boolean update);
PosIf_Raw PosIf_updatePosition_base(PosIf *handle);

const PosIf_Calls g_PosIf_Functions = {
    &PosIf_resetOffset_base,
    &PosIf_setOffset_base,
    &PosIf_setupElAngleConst_base,
    &PosIf_setupSpeedConst_base,
    &PosIf_updatePosition_base,
    &PosIf_updateSpeed_base,
};

/** \brief Initialize the position sensor interface
 * \note This function shall not be called directly by user's application */
void PosIf_init(PosIf *handle, const PosIf_Config *config)
{
    handle->functions         = &g_PosIf_Functions;
    handle->offset            = config->offset;
    handle->periodPerRotation = config->periodPerRotation;
    handle->resolution        = config->resolution;
    handle->reversed          = config->reversed;
    handle->motorPolePairs	  = config->motorPolePairs;
    PosIf_reset(handle);
}


PosIf_Raw PosIf_resetOffset_base(PosIf *handle)
{
    PosIf_Raw offset;

    offset = (handle->offset - handle->position);
    PosIf_setOffset(handle, offset);

    return handle->offset;
}


void PosIf_setOffset_base(PosIf *handle, PosIf_Raw offset)
{
    handle->offset = offset;
}


void PosIf_setupSpeedConst_base(PosIf *handle)
{
    handle->speedConst = 1.0 / handle->periodPerRotation;
}


void PosIf_setupElAngleConst_base(PosIf *handle, sint32 motorPolePairs)
{
    handle->elAngleConst = (float32)motorPolePairs *
                           ((float32)POSIF_ANGLE_RANGE / (handle->periodPerRotation * handle->resolution));
}


StdReal PosIf_updateSpeed_base(PosIf *handle, boolean update)
{
    /* Should be overridden by implementor module */
    (void)handle;               /* ignore compiler warning */
    (void)update;               /* ignore compiler warning */
    return 0.0;
}


PosIf_Raw PosIf_updatePosition_base(PosIf *handle)
{
    /* Should be overridden by implementor module */
    (void)handle;               /* ignore compiler warning */
    return 0;
}
