/**
 * \file Pwm.h
 * \brief Generic PWM definition.
 *
 *
 * \license
 * You can use this file under the terms of the IFX License.
 *
 * This file is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the IFX License for more details (IFX_License.txt).
 *
 * This file may be used, copied, and distributed, with or without modification, provided
 * that all copyright notices are retained; that all modifications to this file are
 * prominently noted in the modified file; and that this paragraph is not modified.
 *
 * \copyright Copyright (C) 2012 Infineon Technologies AG
 *
 *
 * $Revision: $1406.4
 * $Date: $2013-07-12 16:20:31 GMT
 *
 * \defgroup library_srvsw_if_pwm PWM interface
 * \ingroup library_srvsw_if
 *
 */

#ifndef PWM_H
#define PWM_H

/** \addtogroup library_srvsw_if_pwm
 * \{ */

/**
 * Defines the PWM modes
 *
 * The 1st member shall start with value 0, and the next members value shall be the previous member +1
 * pwmMode_off shall be the member with the higher index
 */
typedef enum
{
    Pwm_Mode_centerAligned         = 0, /**< \brief Center aligned mode */
    Pwm_Mode_centerAlignedInverted = 1, /**< \brief Center aligned inverted aligned mode */
    Pwm_Mode_leftAligned           = 2, /**< \brief Left aligned mode */
    Pwm_Mode_rightAligned          = 3, /**< \brief Right aligned mode */
    Pwm_Mode_off                   = 4, /**< \brief All switch open */
    Pwm_Mode_init                  = 5  /**< \brief Initialisation mode, do not use at run time */
} Pwm_Mode;

#endif /* PWM_H */
