/**
 * \file PwmHl.c
 * \brief Generic complementary (dual) PWM channel object.
 *
 * \license
 * You can use this file under the terms of the IFX License.
 *
 * This file is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the IFX License for more details (IFX_License.txt).
 *
 * This file may be used, copied, and distributed, with or without modification, provided
 * that all copyright notices are retained; that all modifications to this file are
 * prominently noted in the modified file; and that this paragraph is not modified.
 *
 * \copyright Copyright (C) 2011 Infineon Technologies AG
 *
 *
 * $Revision: $1431.3
 * $Date: $2013-06-24 18:38:09 GMT
 *
 */

#include "PwmHl.h"
#include "_Utilities/Ifx_Assert.h"

void PwmHl_initConfig(PwmHl_Config *config)
{
    config->timer            = NULL_PTR;
    config->deadtime         = 0;
    config->minPulse         = 0;
    config->channelCount     = 0;
    config->emergencyEnabled = FALSE;
    config->outputMode       = IfxPort_OutputMode_pushPull;
    config->outputDriver     = IfxPort_PadDriver_cmosAutomotiveSpeed1;
    config->ccxActiveState   = ActiveState_high;
    config->ccxFeature       = NULL_PTR;
    config->ccxOption        = NULL_PTR;
    config->coutxActiveState = ActiveState_high;
    config->coutxFeature     = NULL_PTR;
    config->coutxOption      = NULL_PTR;
}


/** Set the dead time, the new dead time will first be used by the next call to setOnTime() or setOffTime.
 *
 */
boolean PwmHl_setDeadtime(PwmHl *handle, float32 deadtime)
{
    TimerVal value = Timer_sToTick(handle->timer, deadtime);

    /* FIXME warn if dead time in out of range: > 1/2 period, ... */
    handle->deadtime = value;

    return TRUE;
}


/** Return the deadtime
 *
 */
float32 PwmHl_getDeadtime(PwmHl *handle)
{
    return Timer_tickToS(handle->timer, handle->deadtime);
}


boolean PwmHl_setMinPulse(PwmHl *handle, float32 minPulse)
{
    TimerVal value = Timer_sToTick(handle->timer, minPulse);

    handle->minPulse = value + handle->deadtime;
    handle->maxPulse = handle->timer->period - handle->minPulse;

    return TRUE;
}


float32 PwmHl_getMinPulse(PwmHl *handle)
{
    return Timer_tickToS(handle->timer, handle->minPulse - handle->deadtime);
}


/** Return the PWM mode
 *
 */
Pwm_Mode PwmHl_getMode(PwmHl *handle)
{
    return handle->mode;
}
