/**
 * \file Timer.c
 *
 * \license
 * You can use this file under the terms of the IFX License.
 *
 * This file is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the IFX License for more details (IFX_License.txt).
 *
 * This file may be used, copied, and distributed, with or without modification, provided
 * that all copyright notices are retained; that all modifications to this file are
 * prominently noted in the modified file; and that this paragraph is not modified.
 *
 * \copyright Copyright (C) 2011 Infineon Technologies AG
 *
 *
 * $Revision: $1314.4
 * $Date: $2013-07-01 19:06:17 GMT
 *
 */

#include "Timer.h"

/** Initialize the configuration structure to default
 *
 * \param config Timer configuration. This parameter is initialised by the function
 *
 */
void Timer_initConfig(Timer_Config *config)
{
    config->frequency                  = 0;
    config->isrPriority                = 0;
    config->isrProvider                = IfxSrc_Tos_cpu0;
    config->minResolution              = 0;
    config->trigger.outputFeature      = IFXPORT_OUTOUTFEATURE_NONE;
    config->trigger.outputOption       = If_IoOption_a;
    config->trigger.outputMode         = IfxPort_OutputMode_pushPull;
    config->trigger.outputDriver       = IfxPort_PadDriver_cmosAutomotiveSpeed1;
    config->trigger.risingEdgeAtPeriod = FALSE;
    config->trigger.outputEnabled      = FALSE;
    config->trigger.enabled            = FALSE;
    config->trigger.dutyCycle          = 0.0;
    config->trigger.isrPriority        = 0;
    config->trigger.isrProvider        = IfxSrc_Tos_cpu0;
    config->countDir                   = Timer_CountDir_up;
}


TimerVal Timer_getPeriod(Timer *handle)
{
    return handle->period;
}


float32 Timer_getFrequency(Timer *handle)
{
    return 1.0 / handle->functions.tickToS(handle, handle->functions.getPeriod(handle));
}


boolean Timer_setFrequency(Timer *handle, float32 frequency)
{
    TimerVal period = handle->functions.sToTick(handle, 1.0 / frequency);

    return handle->functions.setPeriod(handle, period);
}


/** Get the timer clock resolution in seconds */
float32 Timer_getResolution(Timer *handle)
{
    return 1.0 / handle->clockFreq;
}


/** Convert timer ticks to seconds */
float32 Timer_tickToS(Timer *handle, TimerVal ticks)
{
    return ticks / handle->clockFreq;
}


/** Convert time in seconds to timer ticks */
TimerVal Timer_sToTick(Timer *handle, float32 seconds)
{
    return seconds * handle->clockFreq;
}
