/**
 * \file Ifx_Types.h
 *  Type definition, this files defines all types used by the IFX HAL and libraries
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1487.1
 * $Date: $2013-08-02 19:30:28 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */
#ifndef IFX_TYPES_H
#define IFX_TYPES_H

/******************************************************************************/
#include "Tricore/Compilers/Compilers.h" /* mapping compiler specific keywords */
#include "Platform_Types.h"

/*******************************************************************************
**                      Global Data Types                                     **
**                      (Types not defined by AUTOSAR)                        **
*******************************************************************************/
typedef signed long long   sint64;          /**< \brief -9223372036854775808 .. +9223372036854775807     */
typedef unsigned long long uint64;          /**< \brief                    0 .. 18446744073709551615     */

typedef const char        *pchar;           /**< \brief const char pointer                               */
typedef void              *pvoid;           /**< \brief void pointer                                     */
typedef volatile void     *vvoid;           /**< \brief volatile void pointer                            */

typedef sint64             TTime;           /**< \brief Time in ticks */
#define TIME_INFINITE ((TTime)0x7FFFFFFFFFFFFFFFLL)
#define TIME_NULL     ((TTime)0x0000000000000000LL)

#define ONES          (0xFFFFFFFFFFFFFFFFU)
#define ZEROS         (0x0000000000000000U)

#if CFG_LONG_SIZE_T
#define SIZE_T_MAX    (0x7FFFFFFFL)
typedef sint32 SizeT;                       /**< \brief Type used for data stream size */
#else
#define SIZE_T_MAX    (0x7FFF)
typedef sint16 SizeT;                       /**< \brief Type used for data stream size */
#endif

/** \brief Circular buffer definition. */
typedef struct
{
    void  *base;                /**< \brief buffer base address */
    uint16 index;               /**< \brief buffer current index */
    uint16 length;              /**< \brief buffer length*/
} CircBuf;

typedef uint16 Priority;        /**< \brief Used in interrupt service priorities */
typedef uint32 TimerVal;        /**< \brief Used in timer values */
typedef sint32 SignedTimerVal;  /**< \brief Used in signed timer values */

typedef pvoid  AddrVal;         /**< \brief Used in address values */

typedef struct
{
    uint16 priority;
    uint16 provider;
} IsrSetting;

/** \brief Signal active state definition. */
typedef enum
{
    ActiveState_low  = 0,       /**< \brief The signal is low active */
    ActiveState_high = 1        /**< \brief The signal is high active */
} ActiveState;

typedef enum
{
    ParityMode_even = 0,
    ParityMode_odd  = 1
} ParityMode;

/** \brief Module address and index map */
typedef struct
{
    volatile void *module;      /**< \brief Module address */
    sint32         index;       /**< \brief Module index */
} IfxModule_IndexMap;

#ifdef __DCC__
#include "Ifx_TypesDcc.h"

#elif defined(__TASKING__)
#include "Ifx_TypesTasking.h"

#elif defined(__GNUC__)
#include "Ifx_TypesGnuc.h"

#elif defined(__MSVC__)
#include "Ifx_TypesMsvc.h"
#else
#error Unsupported compiler.
#endif

#endif /* IFX_TYPES_H */
