/**
 * \file IfxGpt12_IncrEnc.h

 * \brief GPT12-based Incremental Encoder Interface
 * \ingroup ifxmicro_gpt12_increnc
 *
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: 1313 $
 * $Date: 2013-01-03 15:19:54 +0100 (Thu, 03 Jan 2013) $
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup ifxmicro_gpt12_increnc Incremental encoder interface
 * \ingroup ifxmicro_gpt12
 *
 */

#ifndef IFXGPT12_INCRENC_H
#define IFXGPT12_INCRENC_H
//________________________________________________________________________________________
// INCLUDES

#include "Gpt12/Std/IfxGpt12.h"
#include "If/PosIf.h"
#include "Src/Std/IfxSrc.h"

#define GPT12_INCRENC_COUNT (1)

//________________________________________________________________________________________
// DATA STRUCTURES

/** GPT12 incremental encoder data structure */
typedef struct
{
    PosIf           base;
    uint32          timerOffset;
    Ifx_GPT12*      module;
} IfxGpt12_IncrEnc;

/** GPT12 incremental encoder configuration structure */
typedef struct
{
    PosIf_Config        base;               /**< \brief Configuration data of \ref mod_PosIf */
    Ifx_GPT12*          module;             /**< \brief Pointer to base address of GPT12 module */
    Priority            servPriority;
    IfxSrc_Tos          isrProvider;
    IfxGpt12_TxIn_In*   pinForwardTxIn;     /**< \brief Should be connecting to T3. See \ref ifxmicro_gpt12_pinmap "GPT12 pin map data" */
    IfxGpt12_TxEud_In*  pinBackwardTxEud;   /**< \brief Should be connecting to T3  See \ref ifxmicro_gpt12_pinmap "GPT12 pin map data" */
    IfxGpt12_TxIn_In*   pinZeroTxIn;        /**< \brief Should be connecting to T4  See \ref ifxmicro_gpt12_pinmap "GPT12 pin map data" */
    IfxPort_InputMode   pinMode;
} IfxGpt12_IncrEnc_Config;

//________________________________________________________________________________________
// FUNCTION PROTOTYPES

/** \addtogroup ifxmicro_gpt12_increnc
 * \{ */

/** \name Initialisation function
 *
 * After initialisation, the \ref mod_PosIf functions shall be used.
 * Example:
 * \code
 * IfxGpt12_IncrEnc_Config driverConfig;
 * IfxGpt12_IncrEnc        driverData;
 * IfxGpt12_IncrEnc_init (&driverConfig, &driverConfig);
 *
 * ...
 * // periodically called:
 * newPosition = PosIf_updatePosition(&driverData.base);
 * \endcode
 * Prototype:
 * \{ */
IFX_EXTERN void      IfxGpt12_IncrEnc_init(IfxGpt12_IncrEnc* gptEnc, const IfxGpt12_IncrEnc_Config* config);
/**
 * \} */

/** \name Interrupt handler
 * \{ */
IFX_EXTERN void      IfxGpt12_IncrEnc_isrOnZeroPulse(IfxGpt12_IncrEnc* gptEnc);
/** \} */

/** \} */

//________________________________________________________________________________________
// INLINE FUNCTION IMPLEMENTATIONS



#endif
