/**
 * \file IfxGpt12.c
 * \brief GPT12 basic functionality
 *
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: 1274 $
 * $Date: 2012-12-14 16:58:44 +0100 (Fri, 14 Dec 2012) $
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 */

#include "IfxGpt12.h"
#include "Scu/Std/IfxScuWdt.h"
#include "Scu/Std/IfxScuCcu.h"


/** Enable the GPT12 module */
void IfxGpt12_enableModule(Ifx_GPT12* gpt12)
{
    uint16 passwd = IfxScuWdt_getCpuWatchdogPassword();
    IfxScuWdt_clearCpuEndinit(passwd);
    IFXGPT12(gpt12).CLC.U = 0x00000000;
    while ((IFXGPT12(gpt12).CLC.U & 0x00000002) == 0x2) { }
    IfxScuWdt_setCpuEndinit(passwd);
}

const uint16 Gpt2ModulPrescaler[4] = {4,2,16,8};
const uint16 Gpt1ModulPrescaler[4] = {8,4,32,16};

float32 IfxGpt12_getTimerFrequency(Ifx_GPT12* gpt12, IfxGpt12_Timer timer)
{

	uint16 divider = 1;
	float32 sbbFrequency  = IfxScuCcu_getSpbFrequency();
	switch(timer)
	{
	case IfxGpt12_Timer2:
		divider = Gpt1ModulPrescaler[gpt12->T3CON.B.BPS1]<<gpt12->T2CON.B.T2I;
		break;
	case IfxGpt12_Timer3:
		divider = Gpt1ModulPrescaler[gpt12->T3CON.B.BPS1]<<gpt12->T3CON.B.T3I;
		break;
	case IfxGpt12_Timer4:
		divider = Gpt1ModulPrescaler[gpt12->T3CON.B.BPS1]<<gpt12->T4CON.B.T4I;
		break;
	case IfxGpt12_Timer5:
		divider = Gpt2ModulPrescaler[gpt12->T6CON.B.BPS2]<<gpt12->T5CON.B.T5I;
		break;
	case IfxGpt12_Timer6:
		divider = Gpt2ModulPrescaler[gpt12->T6CON.B.BPS2]<<gpt12->T6CON.B.T6I;
		break;
	default: divider = 1; break;
	}
	return(sbbFrequency/divider);

}

void IfxGpt12_startTimer(Ifx_GPT12* gpt12, IfxGpt12_Timer timer)
{
	switch(timer)
	{
	case IfxGpt12_Timer2:
		gpt12->T2CON.B.T2R = 1;
		break;
	case IfxGpt12_Timer3:
		gpt12->T3CON.B.T3R = 1;
		break;
	case IfxGpt12_Timer4:
		gpt12->T4CON.B.T4R = 1;
		break;
	case IfxGpt12_Timer5:
		gpt12->T5CON.B.T5R = 1;
		break;
	case IfxGpt12_Timer6:
		gpt12->T6CON.B.T6R = 1;
		break;
	default:  break;
	}
}

void IfxGpt12_stopTimer(Ifx_GPT12* gpt12, IfxGpt12_Timer timer)
{
	switch(timer)
	{
	case IfxGpt12_Timer2:
		gpt12->T2CON.B.T2R = 0;
		break;
	case IfxGpt12_Timer3:
		gpt12->T3CON.B.T3R = 0;
		break;
	case IfxGpt12_Timer4:
		gpt12->T4CON.B.T4R = 0;
		break;
	case IfxGpt12_Timer5:
		gpt12->T5CON.B.T5R = 0;
		break;
	case IfxGpt12_Timer6:
		gpt12->T6CON.B.T6R = 0;
		break;
	default:  break;
	}
}
