/**
 * \file IfxGpt12.h
 * \brief GPT12 basic functionality
 * \ingroup ifxmicro_gpt12_std
 *
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: 1274 $
 * $Date: 2012-12-14 16:58:44 +0100 (Fri, 14 Dec 2012) $
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup ifxmicro_gpt12_std Basic functionality
 * \ingroup ifxmicro_gpt12
 *
 */

#ifndef IFXGPT12_H
#define IFXGPT12_H

#include "_Impl/IfxGpt12_cfg.h"
#include "_PinMap/IfxGpt12_PinMap.h"


typedef enum{
	IfxGpt12_Timer2 = 0,
	IfxGpt12_Timer3 = 1,
	IfxGpt12_Timer4 = 2,
	IfxGpt12_Timer5 = 3,
	IfxGpt12_Timer6 = 4
}IfxGpt12_Timer;

enum {
    IfxGpt12_TxCON_TxM_timerMode            = 0,
    IfxGpt12_TxCON_TxM_counterMode          = 1,
    IfxGpt12_TxCON_TxM_lowActiveTimerMode   = 2,
    IfxGpt12_TxCON_TxM_highActiveTimerMode  = 3,
    IfxGpt12_TxCON_TxM_reloadMode           = 4,    /**< \brief only for T2, T4 */
    IfxGpt12_TxCON_TxM_captureMode          = 5,    /**< \brief only for T2, T4 */
    IfxGpt12_TxCON_TxM_incrementalRotationMode = 6,     /**< \brief only for T3, T2, T4 */
    IfxGpt12_TxCON_TxM_incrementalEdgeMode     = 7      /**< \brief only for T3, T2, T4 */
};

enum {
    IfxGpt12_TxCON_TxI_incrementalIgnored,
    IfxGpt12_TxCON_TxI_incrementalBothTxInEdges,
    IfxGpt12_TxCON_TxI_incrementalBothTxEudEdges,
    IfxGpt12_TxCON_TxI_incrementalAllTxInAndTxEudEdges,
};

enum {
    IfxGpt12_TxCON_TxI_ignored          = 0,
    IfxGpt12_TxCON_TxI_risingEdge       = 1,
    IfxGpt12_TxCON_TxI_fallingEdge      = 2,
    IfxGpt12_TxCON_TxI_bothEdges        = 3,
    IfxGpt12_TxCON_TxI_risingEdgeT3Otl  = 5,    /**< \brief only for T2, T4. Not in capture mode */
    IfxGpt12_TxCON_TxI_fallingEdgeT3Otl = 6,    /**< \brief only for T2, T4. Not in capture mode */
    IfxGpt12_TxCON_TxI_bothEdgesT3Otl   = 7     /**< \brief only for T2, T4. Not in capture mode */
};

enum {
    IfxGpt12_TxCON_TxR_stopRun,
    IfxGpt12_TxCON_TxR_startRun
};

enum {
    IfxGpt12_TxCON_TxRC_ownTxR,
    IfxGpt12_TxCON_TxRC_remoteTxR
};

enum {
    IfxGpt12_TxCON_TxEUD_directionOnTxUdControl,
    IfxGpt12_TxCON_TxEUD_directionOnTxEudControl
};

//________________________________________________________________________________________
// FUNCTION PROTOTYPES

/** \addtogroup ifxmicro_gpt12_std
 * \{ */
/** \brief API to enable the GPT12 Module.
 * This API enables the GPT12 peripheral module.
 * \return none
 */
IFX_EXTERN void IfxGpt12_enableModule(Ifx_GPT12* module);

/** \brief API to get Timer  frequency.
 * This API returns the frequency of the selected timer.
 * \return timer frequency in Hz
 */
IFX_EXTERN float32 IfxGpt12_getTimerFrequency(Ifx_GPT12* gpt12, IfxGpt12_Timer timer);

/** \brief API to starts Timer .
 * This API starts the selected timer.
 * \return none
 */
IFX_EXTERN void IfxGpt12_startTimer(Ifx_GPT12* gpt12, IfxGpt12_Timer timer);

/** \brief API to stops Timer .
 * This API stops the selected timer.
 * \return none
 */
IFX_EXTERN void IfxGpt12_stopTimer(Ifx_GPT12* gpt12, IfxGpt12_Timer timer);
/** \} */

#endif

