/**
 * \file IfxGtm_Mapping.c
 * \brief Mapping API
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1433.6
 * $Date: $2013-08-09 16:42:17 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 */

#include "IfxGtm_Mapping.h"
#include "_Utilities/Ifx_Assert.h"
/**
 * \param gtm Base address of GTM module
 * \param outputFeature Resource Id for output IO, e.g. Gpta_Io_x. Value IFXPORT_OUTOUTFEATURE_NONE is considered as NONE
 * \param outputOption Output option
 * \param outputMode Output mode
 * \param padDriver Pad driver settings
 */
boolean IfxGtm_Mapping_setPinModeOutput(Ifx_GTM *gtm, sint32 outputFeature, If_IoOption outputOption, IfxPort_OutputMode outputMode, IfxPort_PadDriver padDriver)
{
    boolean found = FALSE;

    if (outputFeature != IFXPORT_OUTOUTFEATURE_NONE)
    {
        uint32 i;

        /* Find port */
        for (i = 0; i < IFXGTM_CFG_PORT_MAP_COUNT; i++)
        {
            if (IfxGtm_cfg_PortMap[i].map.module == gtm)
            {
                if (IfxGtm_cfg_PortMap[i].feature == outputFeature)
                {
                    if (IfxGtm_cfg_PortMap[i].option == outputOption)
                    {
                        IfxPort_setPinModeOutput(IfxGtm_cfg_PortMap[i].map.pin.port,
                            IfxGtm_cfg_PortMap[i].map.pin.pinIndex, outputMode,
                            IfxGtm_cfg_PortMap[i].map.select);
                        IfxPort_setPinPadDriver(IfxGtm_cfg_PortMap[i].map.pin.port,
                            IfxGtm_cfg_PortMap[i].map.pin.pinIndex, padDriver);
                        found = TRUE;
                        break;
                    }
                }
            }
        }

        IFX_ASSERT(VERBOSE_LEVEL_ERROR, found == TRUE);
    }

    return found;
}
