/**
 * \file IfxGtmAtom.c
 * \brief GTM ATOM basic functionality
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1479.7
 * $Date: $2013-08-09 16:42:18 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 */

/******************************************************************************/
#include "IfxGtmAtom.h"
#include "IfxGtm_bf.h"
#include "IfxGtmCmu.h"
/******************************************************************************/
/** Number of channels per ATOM AGC */
#define IFXGTMATOM_AGC_CHANNEL_COUNT (8)
/******************************************************************************/
#if VALIDATE_CODE
/** The following ensure that the assumption make in the code implementation are verified
 */
#    if    ((IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH1_OFF - 1) != IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF) \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH2_OFF - 2) != IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH3_OFF - 3) != IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH4_OFF - 4) != IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH5_OFF - 5) != IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH6_OFF - 6) != IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH7_OFF - 7) != IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF)
#       error "Error: bitfield definition not supported"
#    endif

#    if    ((IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL1_OFF - 2) != IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF) \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL2_OFF - 4) != IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL3_OFF - 6) != IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL4_OFF - 8) != IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF)     \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL5_OFF - 10) != IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF)    \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL6_OFF - 12) != IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF)    \
    || ((IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL7_OFF - 14) != IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF)
#       error "Error: bitfield definition not supported"
#    endif

#endif
/******************************************************************************/
/*                           Functions                                        */
/******************************************************************************/

/******************************************************************************/

/** Clear the channel Zero notification
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmAtom_Ch_clearZeroNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->IRQ_NOTIFY.B.CCU0TC = 1;
}


/** Clear the channel One notification
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmAtom_Ch_clearOneNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->IRQ_NOTIFY.B.CCU1TC = 1;
}


boolean IfxGtmAtom_Ch_isZeroNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    boolean          result;
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    result = atomCh->IRQ_NOTIFY.B.CCU0TC != 0;

    return result;
}


boolean IfxGtmAtom_Ch_isOneNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    boolean          result;
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    result = atomCh->IRQ_NOTIFY.B.CCU1TC != 0;

    return result;
}


/** Return the ATOM channel input clock frequency
 *
 */
float32 IfxGtmAtom_Ch_getClockFrequency(Ifx_GTM *gtm, Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    IfxGtmCmu_Clk clock;

    clock = IfxGtmAtom_Ch_getClockSource(atom, channel);

    return IfxGtmCmu_getClkFrequency(gtm, clock, TRUE);
}


/** Return the channel clock source
 *
 * \param tom Pointer to the ATOM object
 * \param channel Channel index
 *
 * \return Return the clock source
 */
IfxGtmCmu_Clk IfxGtmAtom_Ch_getClockSource(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    IfxGtmCmu_Clk    clock;
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    clock = atomCh->CTRL.B_CH_CTRL_DEFAULT.CLK_SRC;

    return clock;
}


/** Get the ATOM output level
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 *
 * \retval TRUE the output is high
 * \retval FALSE the output is low
 */
boolean IfxGtmAtom_Ch_getOutputLevel(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    boolean          result;
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    result = atomCh->STAT.B.OL == 1;

    return result;
}


/** \brief Return a pointer to the ATOM channel SRC
 *
 * \param gtm Specifies GTM module
 * \param atom Specifies the atom object
 * \param channel Specifies the atom channel object
 *
 * \return Return a pointer to the ATOM channel SRC
 */
volatile Ifx_SRC_SRCR *IfxGtmAtom_Ch_getSrcPointer(Ifx_GTM *gtm, IfxGtmAtom atom, IfxGtmAtom_Ch channel)
{
   //return &MODULE_SRC.GTM.ATOM[atom][channel / 2];
}


/** Raise the interrupt for Compare 1
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmAtom_Ch_raiseInterruptOne(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->IRQ_FORCINT.B.TRG_CCU1TC = 1;
}


/** Raise the interrupt for Compare 0
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmAtom_Ch_raiseInterruptZero(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->IRQ_FORCINT.B.TRG_CCU0TC = 1;
}


/** Set the channel clock source
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param clock Channel clock source
 *
 * \return none
 */
void IfxGtmAtom_Ch_setClockSource(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmCmu_Clk clock)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CTRL.B_CH_CTRL_DEFAULT.CLK_SRC = clock;
}


/** Set the compare 0 and 1 values
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param compareZero Compare zero value
 * \param compareOne compare one value
 *
 * \return none
 */
void IfxGtmAtom_Ch_setCompare(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 compareZero, uint32 compareOne)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CM0.U = compareZero; // TK: replaced .B access to optimize runtime
    atomCh->CM1.U = compareOne;
}


/** Set the compare 1 value
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param compareOne compare one value
 *
 * \return none
 */
void IfxGtmAtom_Ch_setCompareOne(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 compareOne)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CM1.U = compareOne; // TK: replaced .B access to optimize runtime
}


/** Set the compare 1 shadow value
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param shadowOne compare one shadow value
 *
 * \return none
 */
void IfxGtmAtom_Ch_setCompareOneShadow(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 shadowOne)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->SR1.U = shadowOne; // TK: replaced .B access to optimize runtime
}


/** Set the compare 0 and 1 shadow values
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param shadowZero Compare zero shadow value
 * \param shadowOne compare one shadow value
 *
 * \return none
 */
void IfxGtmAtom_Ch_setCompareShadow(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 shadowZero, uint32 shadowOne)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->SR0.U = shadowZero; // TK: replaced .B access to optimize runtime
    atomCh->SR1.U = shadowOne;
}


/** Set the compare 0 value
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param compareZero Compare zero value
 *
 * \return none
 */
void IfxGtmAtom_Ch_setCompareZero(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 compareZero)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CM0.U = compareZero; // TK: replaced .B access to optimize runtime
}


/** Set the compare 0 shadow value
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param shadowZero Compare zero shadow value
 *
 * \return none
 */
void IfxGtmAtom_Ch_setCompareZeroShadow(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 shadowZero)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->SR0.U = shadowZero; // TK: replaced .B access to optimize runtime
}


/** Set the counter value
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param value Counter value
 *
 * \return none
 */
void IfxGtmAtom_Ch_setCounterValue(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 value)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CN0.U = value; // TK: replaced .B access to optimize runtime
}


/** Set the channel notification
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param mode Interrupt mode
 * \param interruptOnCompareZero If TRUE, an interrupt is generated on compare 0, else no interrupt is generated
 * \param interruptOnCompareOne If TRUE, an interrupt is generated on compare 1, else no interrupt is generated
 *
 * \return none
 */
void IfxGtmAtom_Ch_setNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtm_IrqMode mode, boolean interruptOnCompareZero, boolean interruptOnCompareOne)
{
    Ifx_GTM_ATOM_CH       *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    Ifx_GTM_ATOM_CH_IRQ_EN en;

    en.U = atomCh->IRQ_EN.U;

    /* Disable all interrupts of the interrupt set to change mode */
    atomCh->IRQ_EN.U            = ZEROS;
    atomCh->IRQ_MODE.B.IRQ_MODE = mode;
    atomCh->IRQ_EN.U            = en.U; /* Set the values back */

    en.B.CCU0TC_IRQ_EN          = interruptOnCompareZero ? 1 : 0;
    en.B.CCU1TC_IRQ_EN          = interruptOnCompareOne ? 1 : 0;
    atomCh->IRQ_EN.U            = en.U;
}


/** Enable/disable the one shot mode
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param enabled if TRUE, the feature is enabled, else disabled
 *
 * \return none
 */
void IfxGtmAtom_Ch_setOneShotMode(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, boolean enabled)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CTRL.B_CH_CTRL_DEFAULT.OSM = enabled ? 1 : 0;
}


/** Set the channel clock source either from local or from previous channel
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param event Channel reset event
 *
 * \return none
 */
void IfxGtmAtom_Ch_setResetSource(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmAtom_Ch_ResetEvent event)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CTRL.B_CH_CTRL_DEFAULT.RST_CCU0 = event;
}


/** Set the Signal level
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param activeState Signal level active state. In case the channel is reset, the output is set to not active. The signal is active between 0 and the leading edge (CM1) and inactive between the leading edge and the trailing edge (CM0).
 *
 * \return none
 */
void IfxGtmAtom_Ch_setSignalLevel(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, ActiveState activeState)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CTRL.B_CH_CTRL_DEFAULT.SL = activeState == ActiveState_high ? 1 : 0;
}


/** Set the channel trigger output
 *
 * \param atom Pointer to the ATOM object
 * \param channel Channel index
 * \param trigger Channel trigger output mode
 *
 * \return none
 */
void IfxGtmAtom_Ch_setTriggerOutput(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmAtom_Ch_OutputTrigger trigger)
{
    Ifx_GTM_ATOM_CH *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CTRL.B_CH_CTRL_DEFAULT.TRIGOUT = trigger;
}


void IfxGtmAtom_Ch_configurePwmMode(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmCmu_Clk clock, ActiveState activeState, IfxGtmAtom_Ch_ResetEvent resetEvent, IfxGtmAtom_Ch_OutputTrigger trigger)
{
    Ifx_GTM_ATOM_CH_CTRL_CH_CTRL_DEFAULT_Bits ctrl = {
        .MODE     = IfxGtmAtom_Mode_outputPwm,
        .CLK_SRC  = clock,
        .RST_CCU0 = resetEvent,
        .SL       = (activeState == ActiveState_high ? 1 : 0),
        .TRIGOUT  = trigger,
    };
    Ifx_GTM_ATOM_CH                          *atomCh = (Ifx_GTM_ATOM_CH *)((uint32)&atom->CH0_RDADDR.U + 0x80 * channel);

    atomCh->CTRL.B_CH_CTRL_DEFAULT = ctrl;
}


/******************************************************************************/
/** Build the register value for the feature enable/disable
 *
 * \param enableMask Mask for the channel feature enable (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the channel feature disable (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param bitfieldOffset Offset of the channel 0 bitfield in the register
 *
 * \return Returns the register value
 */
static uint32 IfxGtmAtom_Agc_buildFeature(uint16 enableMask, uint16 disableMask, uint8 bitfieldOffset)
{
    uint8  i;
    uint32 reg  = 0;
    uint32 mask = enableMask | (disableMask << 16);

    for (i = 0; i < IFXGTMATOM_AGC_CHANNEL_COUNT; i++)
    {
        /* Bitfield length is 2 bits */
        uint8 shift = (i * 2) + bitfieldOffset;

        if (mask & 0x1)
        {
            reg |= IfxGtm_FeatureControl_enable << shift;
        }

        if (mask & 0x10000)
        {
            reg |= IfxGtm_FeatureControl_disable << shift;
        }

        mask = mask >> 1;
    }

    return reg;
}


/** Enable/disable one or more channels (ENDIS)
 *
 * \param agc Pointer to the AGC object
 * \param enableMask Mask for the enabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param immediate if TRUE, the action is done immediately else, the action is done on TGC trigger (CTRL_TRIG)
 *
 * \return none
 */
void IfxGtmAtom_Agc_enableChannels(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask, boolean immediate)
{
    uint32 value;


    value = IfxGtmAtom_Agc_buildFeature(enableMask, disableMask, IFX_GTM_ATOM_AGC_ENDIS_CTRL_ENDIS_CTRL0_OFF);

    if (immediate)
    {
        agc->ENDIS_CTRL.U = value;
        agc->ENDIS_STAT.U = value;
    }
    else
    {
        agc->ENDIS_CTRL.U = value;
    }
}


/** Enable/disable one or more channels for the force update feature (FUPD)
 *
 * \param agc Pointer to the AGC object
 * \param enableMask Mask for the enabled channels force update (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channel force update (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param resetEnableMask Mask for the enabled channels counter reset on force update (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param resetDisableMask Mask for the disabled channels with no counter reset on force update (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
void IfxGtmAtom_Agc_setChannelsForceUpdate(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask, uint16 resetEnableMask, uint16 resetDisableMask)
{
    uint32 regEnable, regReset;

    regEnable        = IfxGtmAtom_Agc_buildFeature(enableMask, disableMask, IFX_GTM_ATOM_AGC_FUPD_CTRL_FUPD_CTRL0_OFF);
    regReset         =
        IfxGtmAtom_Agc_buildFeature(resetEnableMask, resetDisableMask, IFX_GTM_ATOM_AGC_FUPD_CTRL_RSTCN0_CH0_OFF);
    agc->FUPD_CTRL.U = regEnable | regReset;
}


/** Enable/disable one or more channels output (OUTEN)
 *
 * \param agc Pointer to the AGC object
 * \param enableMask Mask for the enabled channels output (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channels  output (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param immediate if TRUE, the action is done immediately else, the action is done on TGC trigger (CTRL_TRIG)
 *
 * \return none
 */
void IfxGtmAtom_Agc_enableChannelsOutput(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask, boolean immediate)
{
    uint32 value;

    value = IfxGtmAtom_Agc_buildFeature(enableMask, disableMask, IFX_GTM_ATOM_AGC_OUTEN_CTRL_OUTEN_CTRL0_OFF);

    if (immediate)
    {
        agc->OUTEN_CTRL.U = value;
        agc->OUTEN_STAT.U = value;
    }
    else
    {
        agc->OUTEN_CTRL.U = value;
    }
}


/** Enable/disable the AGC channels trigger
 *
 * \param agc Pointer to the AGC object
 * \param enableMask Mask for the enabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
void IfxGtmAtom_Agc_enableChannelsTrigger(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask)
{
    agc->INT_TRIG.U = IfxGtmAtom_Agc_buildFeature(enableMask, disableMask, IFX_GTM_ATOM_AGC_INT_TRIG_INT_TRIG0_OFF);
}


/** Enable/disable one or more channels for update (UPEN)
 *
 * \param agc Pointer to the AGC object
 * \param enableMask Mask for the enabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channel (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
void IfxGtmAtom_Agc_enableChannelsUpdate(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask)
{
    agc->GLB_CTRL.U = IfxGtmAtom_Agc_buildFeature(enableMask, disableMask, IFX_GTM_ATOM_AGC_GLB_CTRL_UPEN_CTRL0_OFF);
}


/** Enable/disable the time base trigger
 *
 * \param agc Pointer to the AGC object
 * \param enabled If TRUE, the trigger is enabled else disabled
 *
 * \return none
 */
void IfxGtmAtom_Agc_enableTimeTrigger(Ifx_GTM_ATOM_AGC *agc, boolean enabled)
{
    agc->ACT_TB.B.TB_TRIG = enabled ? 1 : 0;
}


/** Reset one or more channels
 *
 * \param agc Pointer to the AGC object
 * \param resetMask Mask for the channel reset (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
void IfxGtmAtom_Agc_resetChannels(Ifx_GTM_ATOM_AGC *agc, uint32 resetMask)
{
    uint8  i;
    uint32 reg = 0;

    for (i = 0; i < IFXGTMATOM_AGC_CHANNEL_COUNT; i++)
    {
        if (resetMask & 0x1)
        {
            reg |= 1 << i;
        }

        resetMask = resetMask >> 1;
    }

    agc->GLB_CTRL.U = reg << IFX_GTM_ATOM_AGC_GLB_CTRL_RST_CH0_OFF;
}


/** Set the trigger time base and time base value
 *
 * \param agc Pointer to the AGC object
 * \param base Time base used for comparison
 * \param value Compare value that raise the trigger
 *
 * \return none
 */
void IfxGtmAtom_Agc_setTimeTrigger(Ifx_GTM_ATOM_AGC *agc, IfxGtmTbu_Ts base, uint32 value)
{
    Ifx_GTM_ATOM_AGC_ACT_TB act_tb;

    act_tb.U         = agc->ACT_TB.U;
    act_tb.B.TBU_SEL = base;
    act_tb.B.ACT_TB  = value;
    agc->ACT_TB.U    = act_tb.U;
}


/** Raise the trigger for the channel enable/disable settings,  output enable settings, and force update event (CTRL_TRIG)
 *
 * \param agc Pointer to the AGC object
 *
 * \return none
 */
void IfxGtmAtom_Agc_trigger(Ifx_GTM_ATOM_AGC *agc)
{
    agc->GLB_CTRL.U = 1 << IFX_GTM_ATOM_AGC_GLB_CTRL_HOST_TRIG_OFF;
}


/******************************************************************************/
