/**
 * \file IfxGtmAtom.h
 * \brief GTM ATOM basic functionality
 * \ingroup IfxLld_Gtm_std_atom
 *
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1479.6
 * $Date: $2013-08-09 16:42:18 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup IfxLld_Gtm_std_atom ATOM basic functionality
 * \ingroup IfxLld_Gtm_std
 */

#ifndef IFXGTMATOM_H_
#define IFXGTMATOM_H_

/******************************************************************************/
#include "IfxGtm.h"
#include "IfxGtmTbu.h"
#include "IfxGtmCmu.h"
#include "Src/Std/IfxSrc.h"
/******************************************************************************/
/** ATOM mode */
typedef enum
{
    IfxGtmAtom_Mode_outputImmediate,
    IfxGtmAtom_Mode_outputCompare,
    IfxGtmAtom_Mode_outputPwm,
    IfxGtmAtom_Mode_outputSerial
} IfxGtmAtom_Mode;

/** Reset event for channel counter CN0 */
typedef enum
{
    IfxGtmAtom_Ch_ResetEvent_onCm0     = 0,
    IfxGtmAtom_Ch_ResetEvent_onTrigger = 1
} IfxGtmAtom_Ch_ResetEvent;

/** Reset source for channel counter CN0 */
typedef enum
{
    IfxGtmAtom_Ch_OutputTrigger_forward  = 0,   /** Forward the trigger from the previous channel */
    IfxGtmAtom_Ch_OutputTrigger_generate = 1    /** Generate the trigger from the current channel */
} IfxGtmAtom_Ch_OutputTrigger;
/******************************************************************************/
/*                           Function prototypes                              */
/******************************************************************************/
/**
 * \addtogroup IfxLld_Gtm_std_atom
 * \{ */

/**
 * \name Channel functions
 * \{ */
IFX_EXTERN void                   IfxGtmAtom_Ch_clearZeroNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN void                   IfxGtmAtom_Ch_clearOneNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN float32                IfxGtmAtom_Ch_getClockFrequency(Ifx_GTM *gtm, Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN IfxGtmCmu_Clk          IfxGtmAtom_Ch_getClockSource(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN boolean                IfxGtmAtom_Ch_getOutputLevel(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN boolean                IfxGtmAtom_Ch_isZeroNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN boolean                IfxGtmAtom_Ch_isOneNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN volatile Ifx_SRC_SRCR *IfxGtmAtom_Ch_getSrcPointer(Ifx_GTM *gtm, IfxGtmAtom atom, IfxGtmAtom_Ch channel);

IFX_EXTERN void IfxGtmAtom_Ch_raiseInterruptOne(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN void IfxGtmAtom_Ch_raiseInterruptZero(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel);
IFX_EXTERN void IfxGtmAtom_Ch_setClockSource(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmCmu_Clk clock);
IFX_EXTERN void IfxGtmAtom_Ch_setCompare(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 compareZero, uint32 compareOne);
IFX_EXTERN void IfxGtmAtom_Ch_setCompareOne(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 compareOne);
IFX_EXTERN void IfxGtmAtom_Ch_setCompareOneShadow(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 shadowOne);
IFX_EXTERN void IfxGtmAtom_Ch_setCompareShadow(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 shadowZero, uint32 shadowOne);
IFX_EXTERN void IfxGtmAtom_Ch_setCompareZero(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 compareZero);
IFX_EXTERN void IfxGtmAtom_Ch_setCompareZeroShadow(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 shadowZero);
IFX_EXTERN void IfxGtmAtom_Ch_setCounterValue(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, uint32 value);
IFX_EXTERN void IfxGtmAtom_Ch_setGatedCounter(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, boolean enabled);
IFX_EXTERN void IfxGtmAtom_Ch_setNotification(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtm_IrqMode mode, boolean interruptOnCompareZero, boolean interruptOnCompareOne);
IFX_EXTERN void IfxGtmAtom_Ch_setOneShotMode(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, boolean enabled);
IFX_EXTERN void IfxGtmAtom_Ch_setResetSource(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmAtom_Ch_ResetEvent event);
IFX_EXTERN void IfxGtmAtom_Ch_setSignalLevel(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, ActiveState activeState);
IFX_EXTERN void IfxGtmAtom_Ch_setTriggerOutput(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmAtom_Ch_OutputTrigger trigger);
IFX_EXTERN void IfxGtmAtom_Ch_configurePwmMode(Ifx_GTM_ATOM *atom, IfxGtmAtom_Ch channel, IfxGtmCmu_Clk clock, ActiveState activeState, IfxGtmAtom_Ch_ResetEvent event, IfxGtmAtom_Ch_OutputTrigger trigger);
/** \} */

/** \name AGC functions
 * \{ */
IFX_EXTERN void IfxGtmAtom_Agc_enableChannels(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask, boolean immediate);
IFX_EXTERN void IfxGtmAtom_Agc_setChannelsForceUpdate(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask, uint16 resetEnableMask, uint16 resetDisableMask);
IFX_EXTERN void IfxGtmAtom_Agc_enableChannelsOutput(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask, boolean immediate);
IFX_EXTERN void IfxGtmAtom_Agc_enableChannelsTrigger(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask);
IFX_EXTERN void IfxGtmAtom_Agc_enableChannelsUpdate(Ifx_GTM_ATOM_AGC *agc, uint16 enableMask, uint16 disableMask);
IFX_EXTERN void IfxGtmAtom_Agc_enableTimeTrigger(Ifx_GTM_ATOM_AGC *agc, boolean enabled);
IFX_EXTERN void IfxGtmAtom_Agc_resetChannels(Ifx_GTM_ATOM_AGC *agc, uint32 resetMask);
IFX_EXTERN void IfxGtmAtom_Agc_setTimeTrigger(Ifx_GTM_ATOM_AGC *agc, IfxGtmTbu_Ts base, uint32 value);
IFX_EXTERN void IfxGtmAtom_Agc_trigger(Ifx_GTM_ATOM_AGC *agc);
/** \} */

/** \} */
/******************************************************************************/
/*                           Functions                                        */
/******************************************************************************/

/******************************************************************************/

#endif /* IFXGTMATOM_H_ */
