/**
 * \file IfxGtmCmu.h
 * \brief GTM CMU basic functionality
 * \ingroup IfxLld_Gtm_std_cmu
 *
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1415.5
 * $Date: $2013-08-09 16:42:18 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup IfxLld_Gtm_std_cmu CMU basic functionality
 * \ingroup IfxLld_Gtm_std
 *
 */

#ifndef IFXGTMCMU_H
#define IFXGTMCMU_H
/******************************************************************************/
#include "_Impl/IfxGtm_cfg.h"
/******************************************************************************/
typedef enum
{
    IfxGtmCmu_Clk_0 = 0,
    IfxGtmCmu_Clk_1 = 1,
    IfxGtmCmu_Clk_2 = 2,
    IfxGtmCmu_Clk_3 = 3,
    IfxGtmCmu_Clk_4 = 4,
    IfxGtmCmu_Clk_5 = 5,
    IfxGtmCmu_Clk_6 = 6,
    IfxGtmCmu_Clk_7 = 7
} IfxGtmCmu_Clk;

typedef enum
{
    IfxGtmCmu_Eclk_0 = 0,
    IfxGtmCmu_Eclk_1 = 1,
    IfxGtmCmu_Eclk_2 = 2
} IfxGtmCmu_Eclk;

typedef enum
{
    IfxGtmCmu_Fxclk_0 = 0,
    IfxGtmCmu_Fxclk_1 = 1,
    IfxGtmCmu_Fxclk_2 = 2,
    IfxGtmCmu_Fxclk_3 = 3,
    IfxGtmCmu_Fxclk_4 = 4
} IfxGtmCmu_Fxclk;
/******************************************************************************/
/*                           Function prototypes                              */
/******************************************************************************/

/** \addtogroup IfxLld_Gtm_std_cmu
 * \{ */
IFX_EXTERN void    IfxGtmCmu_enableClocks(Ifx_GTM *gtm, uint32 clkMask);
IFX_EXTERN float32 IfxGtmCmu_getClkFrequency(Ifx_GTM *gtm, IfxGtmCmu_Clk clkIndex, boolean assumeEnabled);
IFX_EXTERN float32 IfxGtmCmu_getEclkFrequency(Ifx_GTM *gtm, IfxGtmCmu_Eclk clkIndex, boolean assumeEnabled);
IFX_EXTERN float32 IfxGtmCmu_getFxClkFrequency(Ifx_GTM *gtm, IfxGtmCmu_Fxclk clkIndex, boolean assumeEnabled);
IFX_EXTERN float32 IfxGtmCmu_getGclkFrequency(Ifx_GTM *gtm);
IFX_EXTERN float32 IfxGtmCmu_getModuleFrequency(Ifx_GTM *gtm);
IFX_EXTERN boolean IfxGtmCmu_isClkClockEnabled(Ifx_GTM *gtm, IfxGtmCmu_Clk clkIndex);
IFX_EXTERN boolean IfxGtmCmu_isEclkClockEnabled(Ifx_GTM *gtm, IfxGtmCmu_Eclk clkIndex);
IFX_EXTERN boolean IfxGtmCmu_isFxClockEnabled(Ifx_GTM *gtm);
IFX_EXTERN void    IfxGtmCmu_selectClkInput(Ifx_GTM *gtm, IfxGtmCmu_Clk clkIndex, boolean useGlobal);
IFX_EXTERN void    IfxGtmCmu_setClkFrequency(Ifx_GTM *gtm, IfxGtmCmu_Clk clkIndex, float32 frequency);
IFX_EXTERN void    IfxGtmCmu_setEclkFrequency(Ifx_GTM *gtm, IfxGtmCmu_Eclk clkIndex, float32 frequency);
IFX_EXTERN void    IfxGtmCmu_setGclkFrequency(Ifx_GTM *gtm, float32 frequency);
/** \} */

/******************************************************************************/
/*                           Functions                                        */
/******************************************************************************/

/******************************************************************************/
#endif /* IFXGTMCMU_H */
