/**
 * \file IfxGtm_Tim.h
 * \brief GTM TIM basic functionalities
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $
 * $Date: $
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup ifxmicro_gtm_std_tim TIM basic functionality
 * \ingroup ifxmicro_gtm_std
 *
 */

#ifndef IFXGTM_TIM_H_
#define IFXGTM_TIM_H_

/******************************************************************************/
#include "_Impl/IfxGtm_cfg.h"
#include "_Reg/IfxGtm_regdef.h"
/******************************************************************************/

typedef enum
{
	IfxGtm_Tim_Module_0 = 0,
	IfxGtm_Tim_Module_1,
	IfxGtm_Tim_Module_2,
	IfxGtm_Tim_Module_3,
}IfxGtm_Tim_Module;

typedef enum
{
	IfxGtm_Tim_Channel_0 = 0,
	IfxGtm_Tim_Channel_1,
	IfxGtm_Tim_Channel_2,
	IfxGtm_Tim_Channel_3,
	IfxGtm_Tim_Channel_4,
	IfxGtm_Tim_Channel_5,
	IfxGtm_Tim_Channel_6,
	IfxGtm_Tim_Channel_7
}IfxGtm_Tim_Channel;

typedef enum
{
	IfxGtm_channelOption_0,
	IfxGtm_channelOption_1,
	IfxGtm_channelOption_2,
	IfxGtm_channelOption_3,
	IfxGtm_channelOption_4,
	IfxGtm_channelOption_5,
	IfxGtm_channelOption_6,
	IfxGtm_channelOption_7,
	IfxGtm_channelOption_8,
	IfxGtm_channelOption_9,
	IfxGtm_channelOption_a,
	IfxGtm_channelOption_b,
	IfxGtm_channelOption_c,
	IfxGtm_channelOption_d,
	IfxGtm_channelOption_e,
	IfxGtm_channelOption_f
}IfxGtm_channelOption;

typedef enum
{
	Ifx_Gtm_Tim_FilterMode_immediateEdgePropagation,
	Ifx_Gtm_Tim_FilterMode_deglitch,
}Ifx_Gtm_Tim_FilterMode;


typedef enum
{
	Ifx_Gtm_Tim_CounterMode_upDownCounter,
	Ifx_Gtm_Tim_CounterMode_holdCounter,
}Ifx_Gtm_Tim_CounterMode;

typedef enum
{
	Ifx_Gtm_Tim_Mode_measurePwm = 0,
	Ifx_Gtm_Tim_Mode_pulseIntegration = 1,
	Ifx_Gtm_Tim_Mode_eventMode = 2,
	Ifx_Gtm_Tim_Mode_prescalerMode = 3,
	Ifx_Gtm_Tim_Mode_bitCompression = 4,
	Ifx_Gtm_Tim_Mode_gatedPeriodicSampling = 5
}Ifx_Gtm_Tim_Mode;

typedef enum
{
	Ifx_Gtm_Tim_Gpr0Sel_tBU_TS0,
	Ifx_Gtm_Tim_Gpr0Sel_tBU_TS1,
	Ifx_Gtm_Tim_Gpr0Sel_tBU_TS2,
	Ifx_Gtm_Tim_Gpr0Sel_cnts,
}Ifx_Gtm_Tim_Gpr0Sel;

typedef enum
{
	Ifx_Gtm_Tim_Gpr1Sel_tBU_TS0,
	Ifx_Gtm_Tim_Gpr1Sel_tBU_TS1,
	Ifx_Gtm_Tim_Gpr1Sel_tBU_TS2,
	Ifx_Gtm_Tim_Gpr1Sel_cnt,
}Ifx_Gtm_Tim_Gpr1Sel;

typedef enum
{
	Ifx_Gtm_Tim_FilterClock_cmuClk0,
	Ifx_Gtm_Tim_FilterClock_cmuClk1,
	Ifx_Gtm_Tim_FilterClock_cmuClk6,
	Ifx_Gtm_Tim_FilterClock_cmuClk7,
}Ifx_Gtm_Tim_FilterClock;


typedef enum
{
	Ifx_Gtm_Tim_Clock_cmuClk0,
	Ifx_Gtm_Tim_Clock_cmuClk1,
	Ifx_Gtm_Tim_Clock_cmuClk2,
	Ifx_Gtm_Tim_Clock_cmuClk3,
	Ifx_Gtm_Tim_Clock_cmuClk4,
	Ifx_Gtm_Tim_Clock_cmuClk5,
	Ifx_Gtm_Tim_Clock_cmuClk6,
	Ifx_Gtm_Tim_Clock_cmuClk7,
}Ifx_Gtm_Tim_Clock;

typedef struct
{
	IfxGtm_Tim_Module	module;		/**< \brief TIM Module*/
	IfxGtm_Tim_Channel	channel;	/**< \brief TiM channel*/
	IfxGtm_channelOption chOption; /**< \brief Channel option*/
	boolean filterEnable;			/**< \brief Input Filter enable*/
	Ifx_Gtm_Tim_FilterClock	filterClock;
	Ifx_Gtm_Tim_Mode mode;			/**< \brief Input channel mode */
	Ifx_Gtm_Tim_Gpr0Sel	gpr0Sel;
	Ifx_Gtm_Tim_Gpr0Sel	gpr1Sel;
	Ifx_Gtm_Tim_FilterMode filterModeRisingEdge;
	Ifx_Gtm_Tim_FilterMode filterModeFallingEdge;
	Ifx_Gtm_Tim_CounterMode counterModeRisingEdge;
	Ifx_Gtm_Tim_CounterMode counterModeFallingEdge;
	Ifx_Gtm_Tim_Clock	clock;
}IfxGtm_Tim_Config;


void IfxGtm_Tim_init(Ifx_GTM* gtm, IfxGtm_Tim_Config* config);
void IfxGtm_Tim_initConfig(IfxGtm_Tim_Config* config);

IFX_INLINE uint32 IfxGtm_Tim_getCnt(Ifx_GTM* gtm,IfxGtm_Tim_Module	module,	IfxGtm_Tim_Channel	channel )
{
	Ifx_GTM_TIM_CH_CNT *ptr = &gtm->TIM[module].CH0_CNT;
	ptr +=	(channel*0x20);
	return(ptr->B.CNT);
}

IFX_INLINE uint32 IfxGtm_Tim_getPulse(Ifx_GTM* gtm,IfxGtm_Tim_Module	module,	IfxGtm_Tim_Channel	channel )
{
	Ifx_GTM_TIM_CH_GPR0 *ptr = &gtm->TIM[module].CH0_GPR0;
	ptr +=	(channel*0x20);
	return(ptr->B.GPR0);
}

IFX_INLINE uint32 IfxGtm_Tim_getPeriod(Ifx_GTM* gtm,IfxGtm_Tim_Module	module,	IfxGtm_Tim_Channel	channel )
{
	Ifx_GTM_TIM_CH_GPR1 *ptr = &gtm->TIM[module].CH0_GPR1;
	ptr +=	(channel*0x20);
	return(ptr->B.GPR1);
}

#endif /* IFXGTM_TIM_H_ */
