/**
 * \file IfxGtmTom.c
 * \brief GTM TOM basic functionality
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1479.8
 * $Date: $2013-08-09 16:42:22 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 */

/******************************************************************************/
#include "IfxGtmTom.h"
#include "IfxGtm_bf.h"
#include "IfxGtmCmu.h"
/******************************************************************************/
/** Number of channels per TOM TGC */
#define IFXGTMTOM_TGC_CHANNEL_COUNT (8)
/******************************************************************************/
#if VALIDATE_CODE
/** The following ensure that the assumption make in the code implementation are verified
 */
#    if    ((IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH1_OFF - 1) != IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH0_OFF) \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH2_OFF - 2) != IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH3_OFF - 3) != IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH4_OFF - 4) != IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH5_OFF - 5) != IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH6_OFF - 6) != IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH7_OFF - 7) != IFX_GTM_TOM_TGC_GLB_CTRL_RST_CH0_OFF)
#       error "Error: bitfield definition not supported"
#    endif

#    if    ((IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL1_OFF - 2) != IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL0_OFF) \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL2_OFF - 4) != IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL3_OFF - 6) != IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL4_OFF - 8) != IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL0_OFF)     \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL5_OFF - 10) != IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL0_OFF)    \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL6_OFF - 12) != IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL0_OFF)    \
    || ((IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL7_OFF - 14) != IFX_GTM_TOM_TGC_GLB_CTRL_UPEN_CTRL0_OFF)
#       error "Error: bitfield definition not supported"
#    endif

#endif
/******************************************************************************/
/*                           Functions                                        */
/******************************************************************************/

/** Clear the channel Zero notification
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmTom_Ch_clearZeroNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->IRQ_NOTIFY.B.CCU0TC = 1;
}


/** Clear the channel One notification
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmTom_Ch_clearOneNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->IRQ_NOTIFY.B.CCU1TC = 1;
}


boolean IfxGtmTom_Ch_isZeroNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    boolean         result;
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    result = tomCh->IRQ_NOTIFY.B.CCU0TC != 0;

    return result;
}


boolean IfxGtmTom_Ch_isOneNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    boolean         result;
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    result = tomCh->IRQ_NOTIFY.B.CCU1TC != 0;

    return result;
}


/** Return the TOM channel input clock frequency
 *
 */
float32 IfxGtmTom_Ch_getClockFrequency(Ifx_GTM *gtm, Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    IfxGtmTom_Ch_ClkSrc clock;
    IfxGtmCmu_Fxclk     clkIndex[5] = {
        IfxGtmCmu_Fxclk_0,      /*IfxGtmTom_Ch_ClkSrc_cmuFxclk0 */
        IfxGtmCmu_Fxclk_1,      /*IfxGtmTom_Ch_ClkSrc_cmuFxclk1 */
        IfxGtmCmu_Fxclk_2,      /*IfxGtmTom_Ch_ClkSrc_cmuFxclk2 */
        IfxGtmCmu_Fxclk_3,      /*IfxGtmTom_Ch_ClkSrc_cmuFxclk3 */
        IfxGtmCmu_Fxclk_4       /*IfxGtmTom_Ch_ClkSrc_cmuFxclk4 */
    };

    clock = IfxGtmTom_Ch_getClockSource(tom, channel);

    if (clock == IfxGtmTom_Ch_ClkSrc_noClock)
    {
        return 0.0;
    }
    else
    {
        return IfxGtmCmu_getFxClkFrequency(gtm, clkIndex[clock], TRUE);
    }
}


/** Return the channel clock source
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 *
 * \return Return the clock source
 */
IfxGtmTom_Ch_ClkSrc IfxGtmTom_Ch_getClockSource(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    IfxGtmTom_Ch_ClkSrc clock = IfxGtmTom_Ch_ClkSrc_noClock;
    Ifx_GTM_TOM_CH     *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    clock = tomCh->CTRL.B.CLK_SRC_SR;

    return clock;
}


/** Get the TOM output level
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 *
 * \retval TRUE the output is high
 * \retval FALSE the output is low
 */
boolean IfxGtmTom_Ch_getOutputLevel(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    boolean         result;
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    result = tomCh->STAT.B.OL == 1;

    return result;
}


/** \brief Return a pointer to the TOM channel SRC
 *
 * \param gtm Specifies GTM module
 * \param tom Specifies the tom object
 * \param channel Specifies the tom channel object
 *
 * \return Return a pointer to the TOM channel SRC
 */
volatile Ifx_SRC_SRCR *IfxGtmTom_Ch_getSrcPointer(Ifx_GTM *gtm, IfxGtmTom tom, IfxGtmTom_Ch channel)
{
  // return &MODULE_SRC.GTM.TOM[tom][channel / 2];

	return (&MODULE_SRC.GTM.GTM[0].TOM[tom][channel / 2]);

}


/** Raise the interrupt for Compare 1
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmTom_Ch_raiseInterruptOne(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->IRQ_FORCINT.B.TRG_CCU1TC0 = 1;
}


/** Raise the interrupt for Compare 0
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 *
 * \return none
 */
void IfxGtmTom_Ch_raiseInterruptZero(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->IRQ_FORCINT.B.TRG_CCU0TC0 = 1;
}


/** Set the channel clock source
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param clock Channel clock source
 *
 * \return none
 */
void IfxGtmTom_Ch_setClockSource(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtmTom_Ch_ClkSrc clock)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel); /* Pointer auf TOM0 channel x Control Register */

    tomCh->CTRL.B.CLK_SRC_SR = clock; /* select clock source hier: "IfxGtmTom_Ch_ClkSrc_cmuFxclk0" =  */
    								  /* 0: CMU Clock not divided */
}


/** Set the compare 0 and 1 values
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param compareZero Compare zero value
 * \param compareOne compare one value
 *
 * \return none
 */
void IfxGtmTom_Ch_setCompare(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 compareZero, uint32 compareOne)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CM0.U = compareZero; // TK: replaced .B access to optimize runtime
    tomCh->CM1.U = compareOne;
}


/** Set the compare 1 value
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param compareOne compare one value
 *
 * \return none
 */
void IfxGtmTom_Ch_setCompareOne(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 compareOne)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CM1.U = compareOne; // TK: replaced .B access to optimize runtime
}


/** Set the compare 1 shadow value
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param shadowOne compare one shadow value
 *
 * \return none
 */
void IfxGtmTom_Ch_setCompareOneShadow(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 shadowOne)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->SR1.U = shadowOne; // TK: replaced .B access to optimize runtime
}


/** Set the compare 0 and 1 shadow values
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param shadowZero Compare zero shadow value
 * \param shadowOne compare one shadow value
 *
 * \return none
 */
void IfxGtmTom_Ch_setCompareShadow(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 shadowZero, uint32 shadowOne)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->SR0.U = shadowZero; // TK: replaced .B access to optimize runtime
    tomCh->SR1.U = shadowOne;
}


/** Set the compare 0 value
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param compareZero Compare zero value
 *
 * \return none
 */
void IfxGtmTom_Ch_setCompareZero(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 compareZero)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CM0.U = compareZero; // TK: replaced .B access to optimize runtime
}


/** Set the compare 0 shadow value
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param shadowZero Compare zero shadow value
 *
 * \return none
 */
void IfxGtmTom_Ch_setCompareZeroShadow(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 shadowZero)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->SR0.U = shadowZero; // TK: replaced .B access to optimize runtime
}


/** Set the counter value
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param value Counter value
 *
 * \return none
 */
void IfxGtmTom_Ch_setCounterValue(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 value)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CN0.U = value; // TK: replaced .B access to optimize runtime
}


/** Enable/disable the gated counter mode (channel 0 to 7 only)
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param enabled if TRUE, the feature is enabled, else disabled
 *
 * \return none
 */
void IfxGtmTom_Ch_setGatedCounter(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled)
{
    if (channel <= IfxGtmTom_Ch_7)
    {
        Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);
        tomCh->CTRL.B.GCM = enabled ? 1 : 0;
    }
    else
    {}
}


/** Set the channel notification
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param mode Interrupt mode
 * \param interruptOnCompareZero If TRUE, an interrupt is generated on compare 0, else no interrupt is generated
 * \param interruptOnCompareOne If TRUE, an interrupt is generated on compare 1, else no interrupt is generated
 *
 * \return none
 */
void IfxGtmTom_Ch_setNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtm_IrqMode mode, boolean interruptOnCompareZero, boolean interruptOnCompareOne)
{
    Ifx_GTM_TOM_CH       *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    Ifx_GTM_TOM_CH_IRQ_EN en;

    en.U = tomCh->IRQ_EN.U;

    /* Disable all interrupts of the interrupt set to change mode */
    tomCh->IRQ_EN.U            = ZEROS;
    tomCh->IRQ_MODE.B.IRQ_MODE = mode;
    tomCh->IRQ_EN.U            = en.U; /* Set the values back */

    en.B.CCU0TC_IRQ_EN         = interruptOnCompareZero ? 1 : 0;
    en.B.CCU1TC_IRQ_EN         = interruptOnCompareOne ? 1 : 0;
    tomCh->IRQ_EN.U            = en.U;
}


/** Enable/disable the one shot mode
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param enabled if TRUE, the feature is enabled, else disabled
 *
 * \return none
 */
void IfxGtmTom_Ch_setOneShotMode(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CTRL.B.OSM = enabled ? 1 : 0;
}


/** Enable/disable the PCM mode (channel 15 only)
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param enabled if TRUE, the feature is enabled, else disabled
 *
 * \return none
 */
void IfxGtmTom_Ch_setPcm(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled)
{
    if (channel == IfxGtmTom_Ch_15)
    {
        tom->CH15_CTRL.B.BITREV = enabled ? 1 : 0;  /* FIXME check when datasheet updated, currently not specified */
    }
    else
    {}
}


/** Set the channel clock source either from local or from previous channel
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param event Channel reset event
 *
 * \return none
 */
void IfxGtmTom_Ch_setResetSource(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtmTom_Ch_ResetEvent event)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CTRL.B.RST_CCU0 = event;
}


/** Set the Signal level
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param activeState Signal level active state. In case the channel is reset, the output is set to not active. The signal is active between 0 and the leading edge (CM1) and inactive between the leading edge and the trailing edge (CM0).
 *
 * \return none
 */
void IfxGtmTom_Ch_setSignalLevel(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, ActiveState activeState)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CTRL.B.SL = activeState == ActiveState_high ? 1 : 0;
}


/** Enable/disable the SPE mode (channel 0 to 7 only)
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param enabled if TRUE, the feature is enabled, else disabled
 *
 * \return none
 */
void IfxGtmTom_Ch_setSpe(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled)
{
    if (channel <= IfxGtmTom_Ch_7)
    {
        Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);
        tomCh->CTRL.B.SPEM = enabled ? 1 : 0;
    }
    else
    {}
}


/** Set the channel trigger output
 *
 * \param tom Pointer to the TOM object
 * \param channel Channel index
 * \param trigger Channel trigger output mode
 *
 * \return none
 */
void IfxGtmTom_Ch_setTriggerOutput(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtmTom_Ch_OutputTrigger trigger)
{
    Ifx_GTM_TOM_CH *tomCh = (Ifx_GTM_TOM_CH *)((uint32)&tom->CH0_CTRL.U + 0x40 * channel);

    tomCh->CTRL.B.TRIGOUT = trigger;
}


/******************************************************************************/
/** Build the register value for the feature enable/disable
 *
 * \param enableMask Mask for the channel feature enable (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the channel feature disable (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param bitfieldOffset Offset of the channel 0 bitfield in the register
 *
 * \return Returns the register value
 */
static uint32 IfxGtmTom_Tgc_buildFeature(uint16 enableMask, uint16 disableMask, uint8 bitfieldOffset)
{
    uint8  i;
    uint32 reg  = 0;
    uint32 mask = enableMask | (disableMask << 16);

    for (i = 0; i < IFXGTMTOM_TGC_CHANNEL_COUNT; i++)
    {
        /* Bitfield length is 2 bits */
        uint8 shift = (i * 2) + bitfieldOffset;

        if (mask & 0x1)
        {
            reg |= IfxGtm_FeatureControl_enable << shift;
        }

        if (mask & 0x10000)
        {
            reg |= IfxGtm_FeatureControl_disable << shift;
        }

        mask = mask >> 1;
    }

    return reg;
}


/** Enable/disable one or more channels (ENDIS)
 *
 * \param tgc Pointer to the TGC object
 * \param enableMask Mask for the enabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param immediate if TRUE, the action is done immediately else, the action is done on TGC trigger (CTRL_TRIG)
 *
 * \return none
 */
void IfxGtmTom_Tgc_enableChannels(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask, boolean immediate)
{
    uint32 value;



    value = IfxGtmTom_Tgc_buildFeature(enableMask, disableMask, IFX_GTM_TOM_TGC0_ENDIS_CTRL_ENDIS_CTRL0_OFF);

    if (immediate)
    {
        tgc->ENDIS_CTRL.U = value;
        tgc->ENDIS_STAT.U = value;
    }
    else
    {
        tgc->ENDIS_CTRL.U = value;
    }
}


/** Enable/disable one or more channels for the force update feature (FUPD)
 *
 * \param tgc Pointer to the TGC object
 * \param enableMask Mask for the enabled channels force update (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channel force update (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param resetEnableMask Mask for the enabled channels counter reset on force update (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param resetDisableMask Mask for the disabled channels with no counter reset on force update (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
void IfxGtmTom_Tgc_setChannelsForceUpdate(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask, uint16 resetEnableMask, uint16 resetDisableMask)
{
    uint32 regEnable, regReset;

    regEnable        = IfxGtmTom_Tgc_buildFeature(enableMask, disableMask, IFX_GTM_TOM_TGC0_FUPD_CTRL_FUPD_CTRL0_OFF);
    regReset         =
        IfxGtmTom_Tgc_buildFeature(resetEnableMask, resetDisableMask, IFX_GTM_TOM_TGC0_FUPD_CTRL_RSTCN0_CH0_OFF);
    tgc->FUPD_CTRL.U = regEnable | regReset;
}


/** Enable/disable one or more channels output (OUTEN)
 *
 * \param tgc Pointer to the TGC object
 * \param enableMask Mask for the enabled channels output (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channels  output (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param immediate if TRUE, the action is done immediately else, the action is done on TGC trigger (CTRL_TRIG)
 *
 * \return none
 */
void IfxGtmTom_Tgc_enableChannelsOutput(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask, boolean immediate)
{
    uint32 value;

    value = IfxGtmTom_Tgc_buildFeature(enableMask, disableMask, IFX_GTM_TOM_TGC0_OUTEN_CTRL_OUTEN_CTRL0_OFF);

    if (immediate)
    {
        tgc->OUTEN_CTRL.U = value;
        tgc->OUTEN_STAT.U = value;
    }
    else
    {
        tgc->OUTEN_CTRL.U = value;
    }
}


/** Enable/disable the TGC channels trigger
 *
 * \param tgc Pointer to the TGC object
 * \param enableMask Mask for the enabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
void IfxGtmTom_Tgc_enableChannelsTrigger(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask)
{
    tgc->INT_TRIG.U = IfxGtmTom_Tgc_buildFeature(enableMask, disableMask, IFX_GTM_TOM_TGC0_INT_TRIG_INT_TRIG0_OFF);
}


/** Enable/disable one or more channels for update (UPEN)
 *
 * \param tgc Pointer to the TGC object
 * \param enableMask Mask for the enabled channels (bit 0: Channel 0, bit 1: channel 1, ...)
 * \param disableMask Mask for the disabled channel (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
//void IfxGtmTom_Timer_applyUpdate(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask)
//{
//    tgc->GLB_CTRL.U = IfxGtmTom_Tgc_buildFeature(enableMask, disableMask, IFX_GTM_TOM_TGC0_GLB_CTRL_UPEN_CTRL0_OFF);
//}


/** Enable/disable the time base trigger
 *
 * \param tgc Pointer to the TGC object
 * \param enabled If TRUE, the trigger is enabled else disabled
 *
 * \return none
 */
void IfxGtmTom_Tgc_enableTimeTrigger(Ifx_GTM_TOM_TGC *tgc, boolean enabled)
{
    tgc->ACT_TB.B.TB_TRIG = enabled ? 1 : 0;
}


/** Reset one or more channels
 *
 * \param tgc Pointer to the TGC object
 * \param resetMask Mask for the channel reset (bit 0: Channel 0, bit 1: channel 1, ...)
 *
 * \return none
 */
void IfxGtmTom_Tgc_resetChannels(Ifx_GTM_TOM_TGC *tgc, uint32 resetMask)
{
    uint8  i;
    uint32 reg = 0;

    for (i = 0; i < IFXGTMTOM_TGC_CHANNEL_COUNT; i++)
    {
        if (resetMask & 0x1)
        {
            reg |= 1 << i;
        }

        resetMask = resetMask >> 1;
    }

    tgc->GLB_CTRL.U = reg << IFX_GTM_TOM_TGC0_GLB_CTRL_RST_CH0_OFF;
}


/** Set the trigger time base and time base value
 *
 * \param tgc Pointer to the TGC object
 * \param base Time base used for comparison
 * \param value Compare value that raise the trigger
 *
 * \return none
 */
void IfxGtmTom_Tgc_setTimeTrigger(Ifx_GTM_TOM_TGC *tgc, IfxGtmTbu_Ts base, uint32 value)
{
    Ifx_GTM_TOM_TGC0_ACT_TB act_tb;

    act_tb.U         = tgc->ACT_TB.U;
    act_tb.B.TBU_SEL = base;
    act_tb.B.ACT_TB  = value;
    tgc->ACT_TB.U    = act_tb.U;
}


/** Raise the trigger for the channel enable/disable settings,  output enable settings, and force update event (CTRL_TRIG)
 *
 * \param tgc Pointer to the TGC object
 *
 * \return none
 */
void IfxGtmTom_Tgc_trigger(Ifx_GTM_TOM_TGC *tgc)
{
    tgc->GLB_CTRL.U = 1 << IFX_GTM_TOM_TGC0_GLB_CTRL_HOST_TRIG_OFF;
}


/******************************************************************************/
