/**
 * \file IfxGtmTom.h
 * \brief GTM TOM basic functionality
 * \ingroup IfxLld_Gtm_std_tom
 *
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1479.6
 * $Date: $2013-08-09 16:42:22 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup IfxLld_Gtm_std_tom TOM basic functionality
 * \ingroup IfxLld_Gtm_std
 *
 */

#ifndef IFXGTMTOM_H
#define IFXGTMTOM_H
/******************************************************************************/
#include "_Impl/IfxGtm_cfg.h"
#include "IfxGtm.h"
#include "IfxGtmTbu.h"
#include "Src/Std/IfxSrc.h"
/******************************************************************************/
/* FIXME try to find a way for optimization for TOM Channel access (merge type for CH0-14  and CH15 to avoid if ...) */
/******************************************************************************/
/** Clock source for the TOM channels */
typedef enum
{
    IfxGtmTom_Ch_ClkSrc_cmuFxclk0 = 0,  /* div 1 */
    IfxGtmTom_Ch_ClkSrc_cmuFxclk1 = 1,  /* div 16 */
    IfxGtmTom_Ch_ClkSrc_cmuFxclk2 = 2,  /* div 256 */
    IfxGtmTom_Ch_ClkSrc_cmuFxclk3 = 3,  /* div 4096 */
    IfxGtmTom_Ch_ClkSrc_cmuFxclk4 = 4,  /* div 32768 */
    IfxGtmTom_Ch_ClkSrc_noClock   = 5
} IfxGtmTom_Ch_ClkSrc;

/** Reset event for channel counter CN0 */
typedef enum
{
    IfxGtmTom_Ch_ResetEvent_onCm0     = 0,
    IfxGtmTom_Ch_ResetEvent_onTrigger = 1
} IfxGtmTom_Ch_ResetEvent;

/** Reset source for channel counter CN0 */
typedef enum
{
    IfxGtmTom_Ch_OutputTrigger_forward  = 0, /** Forward the trigger from the previous channel */
    IfxGtmTom_Ch_OutputTrigger_generate = 1  /** Generate the trigger from the current channel */
} IfxGtmTom_Ch_OutputTrigger;

/******************************************************************************/
/*                           Function prototypes                              */
/******************************************************************************/
/** \addtogroup IfxLld_Gtm_std_tom
 * \{ */

/** \name Channel functions
 * \{ */
IFX_EXTERN void                   IfxGtmTom_Ch_clearZeroNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN void                   IfxGtmTom_Ch_clearOneNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN float32                IfxGtmTom_Ch_getClockFrequency(Ifx_GTM *gtm, Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN IfxGtmTom_Ch_ClkSrc    IfxGtmTom_Ch_getClockSource(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN boolean                IfxGtmTom_Ch_getOutputLevel(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN boolean                IfxGtmTom_Ch_isZeroNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN boolean                IfxGtmTom_Ch_isOneNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN volatile Ifx_SRC_SRCR *IfxGtmTom_Ch_getSrcPointer(Ifx_GTM *gtm, IfxGtmTom tom, IfxGtmTom_Ch channel);
IFX_EXTERN void                   IfxGtmTom_Ch_raiseInterruptOne(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN void                   IfxGtmTom_Ch_raiseInterruptZero(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel);
IFX_EXTERN void                   IfxGtmTom_Ch_setClockSource(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtmTom_Ch_ClkSrc clock);
IFX_EXTERN void                   IfxGtmTom_Ch_setCompare(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 compareZero, uint32 compareOne);
IFX_EXTERN void                   IfxGtmTom_Ch_setCompareOne(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 compareOne);
IFX_EXTERN void                   IfxGtmTom_Ch_setCompareOneShadow(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 shadowOne);
IFX_EXTERN void                   IfxGtmTom_Ch_setCompareShadow(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 shadowZero, uint32 shadowOne);
IFX_EXTERN void                   IfxGtmTom_Ch_setCompareZero(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 compareZero);
IFX_EXTERN void                   IfxGtmTom_Ch_setCompareZeroShadow(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 shadowZero);
IFX_EXTERN void                   IfxGtmTom_Ch_setCounterValue(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, uint32 value);
IFX_EXTERN void                   IfxGtmTom_Ch_setGatedCounter(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled);
IFX_EXTERN void                   IfxGtmTom_Ch_setNotification(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtm_IrqMode mode, boolean interruptOnCompareZero, boolean interruptOnCompareOne);
IFX_EXTERN void                   IfxGtmTom_Ch_setOneShotMode(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled);
IFX_EXTERN void                   IfxGtmTom_Ch_setPcm(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled);
IFX_EXTERN void                   IfxGtmTom_Ch_setResetSource(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtmTom_Ch_ResetEvent event);
IFX_EXTERN void                   IfxGtmTom_Ch_setSignalLevel(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, ActiveState activeState);
IFX_EXTERN void                   IfxGtmTom_Ch_setSpe(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, boolean enabled);
IFX_EXTERN void                   IfxGtmTom_Ch_setTriggerOutput(Ifx_GTM_TOM *tom, IfxGtmTom_Ch channel, IfxGtmTom_Ch_OutputTrigger trigger);
/** \} */

/** \name TGC functions
 * \{ */
IFX_EXTERN void IfxGtmTom_Tgc_enableChannels(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask, boolean immediate);
IFX_EXTERN void IfxGtmTom_Tgc_setChannelsForceUpdate(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask, uint16 resetEnableMask, uint16 resetDisableMask);
IFX_EXTERN void IfxGtmTom_Tgc_enableChannelsOutput(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask, boolean immediate);
IFX_EXTERN void IfxGtmTom_Tgc_enableChannelsTrigger(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask);
IFX_EXTERN void IfxGtmTom_Tgc_enableChannelsUpdate(Ifx_GTM_TOM_TGC *tgc, uint16 enableMask, uint16 disableMask);
IFX_EXTERN void IfxGtmTom_Tgc_enableTimeTrigger(Ifx_GTM_TOM_TGC *tgc, boolean enabled);
IFX_EXTERN void IfxGtmTom_Tgc_resetChannels(Ifx_GTM_TOM_TGC *tgc, uint32 resetMask);
IFX_EXTERN void IfxGtmTom_Tgc_setTimeTrigger(Ifx_GTM_TOM_TGC *tgc, IfxGtmTbu_Ts base, uint32 value);
IFX_EXTERN void IfxGtmTom_Tgc_trigger(Ifx_GTM_TOM_TGC *tgc);
/** \} */

/** \} */

/******************************************************************************/
/*                           Functions                                        */
/******************************************************************************/

/******************************************************************************/
#endif /* IFXGTMTOM_H */
