/**
 * \file IfxGtm_Spe.c
 * \brief GTM SPE basic functionalities
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $
 * $Date: $
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */


#include "IfxGtm_Spe.h"
#include "math.h"
#include "IfxGtm_bf.h"



/** Init the Gtm Spe Module
 *
 *
 * \param gtm pointer to the GTM module
 * \param config pointer to config of the Spe Module
 *
 * \return None
 */
void IfxGtm_Spe_init(Ifx_GTM* gtm, IfxGtm_Spe_Config* config)
{
	uint32	inputPattern = 0,i;
	Ifx_GTM_SPE_CTRL_STAT ctrlStat;
	ctrlStat.B.FSOM = (config->fastShutOffEnable!=FALSE) ? 1 : 0 ;
	ctrlStat.B.FSOL = config->fastShutOffLevel;
	ctrlStat.B.SIE0 = (config->enableChx!=FALSE) ? 1 : 0;
	ctrlStat.B.SIE1 = (config->enableChy!=FALSE) ? 1 : 0;
	ctrlStat.B.SIE2 = (config->enableChz!=FALSE) ? 1 : 0;
	ctrlStat.B.TRIG_SEL = config->triggerSelection;
	ctrlStat.B.TIM_SEL = (config->timSel!=FALSE) ? 1 : 0;;
	ctrlStat.B.SPE_EN = 1;
	gtm->SPE[config->channel].CTRL_STAT.U = ctrlStat.U;
	for(i=0;i<8;i++)
	{
		//gtm->SPE[config->channel].OUT_PAT[i].U	= config->outputPattern[i];
		inputPattern	|= (config->inputPattern[i]&0xF)<<(4*i);
	}
	gtm->SPE[config->channel].PAT.U = inputPattern;
	gtm->SPE[config->channel].OUT_CTRL.U = config->outControl;


}


/** Init the Gtm Spe Module
 *
 *
 * \param gtm pointer to the GTM module
 * \param config pointer to config of the Spe Module
 *
 * \return None
 */
void IfxGtm_Spe_initConfig(IfxGtm_Spe_Config* config)
{
	config->fastShutOffEnable =FALSE;
	config->channel = IfxGtm_Spe_Channel_0;
	config->enableChx = TRUE;
	config->enableChy = TRUE;
	config->enableChz = TRUE;
	config->triggerSelection = IfxGtm_Spe_TrigSel_Spe_NIPD;
	config->timSel = 0;

	// configure Input pattern in forward direction
	config->inputPattern[0] = (0x5u<<1u) | 1u;
	config->inputPattern[1] = (0x4u<<1u) | 1u;
	config->inputPattern[2] = (0x6u<<1u) | 1u;
	config->inputPattern[3] = (0x2u<<1u) | 1u;
	config->inputPattern[4] = (0x3u<<1u) | 1u;
	config->inputPattern[5] = (0x1u<<1u) | 1u;
	config->inputPattern[6] = (0x0u<<1u) | 0u;
	config->inputPattern[7] = (0x0u<<1u) | 0u;

	// configure Output pattern in forward direction and shut off level
	config->outputPattern[0] = 0;
	config->outputPattern[1] = 0;
	config->outputPattern[2] = 0;
	config->outputPattern[3] = 0;
	config->outputPattern[4] = 0;
	config->outputPattern[5] = 0;
	config->outputPattern[6] = 0;
	config->outputPattern[7] = 0;
	config->fastShutOffLevel = 0;
}
