/**
 * \file IfxGtm_Spe.h
 * \brief GTM SPE basic functionalities
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $
 * $Date: $
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup ifxmicro_gtm_std_spe SPE basic functionality
 * \ingroup ifxmicro_gtm_std
 *
 */

#ifndef IFXGTM_SPE_H_
#define IFXGTM_SPE_H_

/******************************************************************************/
#include "_Impl/IfxGtm_cfg.h"
#include "_Reg/IfxGtm_regdef.h"
/******************************************************************************/

typedef enum
{
    IfxGtm_Spe_Channel_0 = 0,
    IfxGtm_Spe_Channel_1 = 1
} IfxGtm_Spe_Channel;

typedef enum
{
	IfxGtm_Spe_TrigSel_Spe_NIPD = 0,
	IfxGtm_Spe_TrigSel_TomCh0_Ccu0 = 1,
	IfxGtm_Spe_TrigSel_TomCh0_Ccu1 = 2,
	IfxGtm_Spe_TrigSel_TomCh2_Ccu1 = 3
}IfxGtm_Spe_TrigSel;

typedef enum
{
	IfxGtm_Spe_OutControl_TomCh0Sour = 0,
	IfxGtm_Spe_OutControl_TomCh1Sour = 1,
	IfxGtm_Spe_OutControl_0 = 2,
	IfxGtm_Spe_OutControl_1 = 3
}IfxGtm_Spe_OutControl;

typedef struct
{
	uint8	ipValid:1;
	uint8	levelChx:1;
	uint8	levelChy:1;
	uint8	levelChz:1;
}IfxGtm_Spe_InputPattern_bits;

typedef struct
{
	IfxGtm_Spe_Channel	channel;	/**< \brief Spe channel*/
	uint8	inputPattern[8];		/**< \brief define the input Pattern */
	uint8 	outputPattern[8];		/**< \brief defines the output pattern */
	uint8	fastShutOffLevel;		/**< \brief defines the output pattern of Tom channel 0..7*/
	IfxGtm_Spe_TrigSel	triggerSelection; /**< \brief defines the trigger selection */
	boolean	timSel;					/**< \brief tim input signal selection 0 TIM00 is used, 1 TIM1 is used for SPE 0 and SPE 1 */
	boolean fastShutOffEnable;		/**< \brief defines fast shut off is enabled */
	boolean	enableChx;
	boolean	enableChy;
	boolean	enableChz;
	IfxGtm_Spe_OutControl	outControl;	/**< \brief out control selection */
}IfxGtm_Spe_Config;

IFX_EXTERN void IfxGtm_Spe_init(Ifx_GTM* gtm, IfxGtm_Spe_Config* config);
IFX_EXTERN void IfxGtm_Spe_initConfig(IfxGtm_Spe_Config* config);

#endif /* IFXGTM_SPE_H_ */
