/**
 * \file IfxGtm_trig.h
 * \brief GTM trigger functions
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1460.5
 * $Date: $2013-08-09 16:42:23 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup IfxLld_Gtm_trig Trigger functions
 * \ingroup IfxLld_Gtm
 *
 */

/* *INDENT-OFF*  Note: this file is manually indented by the author */

#ifndef IFXGTM_TRIG_H
#define IFXGTM_TRIG_H

#include "Cpu/Std/Ifx_Types.h"
#include "_Impl/IfxGtm_cfg.h"
#include "Gtm/Std/IfxGtmTim.h"

typedef enum
{
    IfxGtm_DsadcTrigSource_tomX_6,
    IfxGtm_DsadcTrigSource_tomX_7,
    IfxGtm_DsadcTrigSource_tomX_13,
    IfxGtm_DsadcTrigSource_tomX_14,
    IfxGtm_DsadcTrigSource_atomX_4,
    IfxGtm_DsadcTrigSource_atomX_5,
    IfxGtm_DsadcTrigSource_atomX_6,
    IfxGtm_DsadcTrigSource_atomX_7
} IfxGtm_DsadcTrigSource;

typedef enum
{
    IfxGtm_AdcTrig_0 = 0,
    IfxGtm_AdcTrig_1,
    IfxGtm_AdcTrig_count,/**< \brief count of the enum definition  */
} IfxGtm_AdcTrig;

typedef enum
{
    IfxGtm_DsadcTrig_0,
    IfxGtm_DsadcTrig_1
} IfxGtm_DsadcTrig;

typedef enum
{/* FIXME to be moved to file _impl/IfxGtm_cfg.h */

    IfxGtm_AdcTrigSource_atom0 = 0,
    IfxGtm_AdcTrigSource_atom1,
    IfxGtm_AdcTrigSource_atom2,
    IfxGtm_AdcTrigSource_atom3,
    IfxGtm_AdcTrigSource_atom4,
    IfxGtm_AdcTrigSource_tom0,
    IfxGtm_AdcTrigSource_tom1,
    IfxGtm_AdcTrigSource_count/**< \brief count of the enum definition  */
} IfxGtm_AdcTrigSource;

typedef enum
{/* FIXME to be moved to file _impl/IfxGtm_cfg.h */
    IfxGtm_AdcTrigChannel_4 = 0,
    IfxGtm_AdcTrigChannel_5,
    IfxGtm_AdcTrigChannel_6,
    IfxGtm_AdcTrigChannel_7,
    IfxGtm_AdcTrigChannel_13,
    IfxGtm_AdcTrigChannel_14,
    IfxGtm_AdcTrigChannel_15,
    IfxGtm_AdcTrigChannel_count/**< \brief count of the enum definition  */
} IfxGtm_AdcTrigChannel;

typedef enum
{
    IfxGtm_AdcGroup_0,   /**< \brief For ADC group 0 */
    IfxGtm_AdcGroup_1,   /**< \brief For ADC group 1 */
    IfxGtm_AdcGroup_2,   /**< \brief For ADC group 2 */
    IfxGtm_AdcGroup_3,   /**< \brief For ADC group 3 */
    IfxGtm_AdcGroup_4,   /**< \brief For ADC group 4 */
    IfxGtm_AdcGroup_5,   /**< \brief For ADC group 5 */
    IfxGtm_AdcGroup_6,   /**< \brief For ADC group 6 */
    IfxGtm_AdcGroup_7,   /**< \brief For ADC group 7 */
    IfxGtm_AdcGroup_8    /**< \brief For ADC background scan */
} IfxGtm_AdcGroup;

/**
 * \addtogroup IfxLld_Gtm_trig
 * \{
 */
IFX_EXTERN boolean IfxGtm_Trig_fromDsadc(Ifx_GTM* gtm, uint32 dsadcChannel, IfxGtmTim tim, IfxGtmTim_Ch timChannel);
IFX_EXTERN void    IfxGtm_Trig_toDsadc(Ifx_GTM* gtm, uint32 dsadcChannel, IfxGtm_DsadcTrig dsadcTrig, IfxGtm_DsadcTrigSource sel); /* FIXME Change API to be similar to IfxGtm_Trig_toVadc() */
IFX_EXTERN boolean IfxGtm_Trig_toVadc(Ifx_GTM* gtm, IfxGtm_AdcGroup adcGroup, IfxGtm_AdcTrig adcTrig, IfxGtm_AdcTrigSource source, IfxGtm_AdcTrigChannel channel);
/** \} */
#endif /* IFXGTMMAPPING_H */

/* *INDENT-ON*  Note: this file is manually indented by the author */
