/**
 * \file IfxVadc.c
 * \brief VADC functions
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $0.7
 * $Date: $2013-07-01 13:24:26 GMT
 *
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */

/*________________________________________________________________________________________ */
/* INCLUDES */

#include "IfxVadc.h"

/*________________________________________________________________________________________ */
/* FUNCTION IMPLEMENTATIONS (BACKGROUND/AUTO-SCAN) */

IfxVadc_Status IfxVadc_getBackgroundScanStatus(Ifx_VADC *vadc)
{
    IfxVadc_Status status = IfxVadc_Status_noError;
    uint8          i;

    for (i = 0; i < 8; i++)
    {
        if (vadc->BRSPND[i].U)
        {
            return IfxVadc_Status_ChannelsStillPending;
        }
        else
        {
            continue;
        }
    }

    return status;
}


void IfxVadc_setBackgroundScan(Ifx_VADC *vadc, IfxVadc_GroupId groupId, uint32 channels, uint32 mask)
{
    channels                = (vadc->BRSSEL[groupId].U & ~mask) | channels;
    vadc->BRSSEL[groupId].U = channels;
}


void IfxVadc_startBackgroundScan(Ifx_VADC *vadc, boolean continuous)
{
    vadc->BRSMR.B.LDEV = 1;     /* execute Load event to start the conversion */
}


/*________________________________________________________________________________________ */
/* FUNCTION IMPLEMENTATIONS (CHANNEL SCAN) */

IfxVadc_Status IfxVadc_getScanStatus(Ifx_VADC_G *group)
{
    IfxVadc_Status status = IfxVadc_Status_noError;

    if (group->ASPND.U)
    {
        return IfxVadc_Status_ChannelsStillPending;
    }
    else
    {
        return status;
    }
}


void IfxVadc_setScan(Ifx_VADC_G *group, uint32 channels, uint32 mask, boolean continuous)
{
    if (continuous != FALSE)
    {
        channels       = (group->ASSEL.U & ~mask) | channels;
        group->ASSEL.U = channels;  /* if continuous is selected put the request into sel register */
    }
    else
    {
        channels       = (group->ASPND.U & ~mask) | channels;
        group->ASPND.U = channels;  /* scan the channels just once */
    }
}


void IfxVadc_startScan(Ifx_VADC_G *group)
{
    group->ASMR.B.LDEV = 1;     /* set Load event. Channels stored in ASSEL will be copied into pending register and conversion will start */
}


/*________________________________________________________________________________________ */
/* FUNCTION IMPLEMENTATIONS (CHANNEL QUEUE) */

void IfxVadc_addToQueue(Ifx_VADC_G *group, IfxVadc_ChannelId channel, uint32 options)
{
    group->QBUR_QINR0.U = channel | options;
}


void IfxVadc_clearQueue(Ifx_VADC_G *group)
{
    group->QMR0.B.FLUSH = 1;
}


IfxVadc_Status IfxVadc_getQueueStatus(Ifx_VADC_G *group)
{
    IfxVadc_Status status = IfxVadc_Status_noError;

    /* just fill level is checked */
    if (0x7 == group->QSR0.B.FILL)
    {
        status = IfxVadc_Status_queueFull;
    }
    else
    {
        status = IfxVadc_Status_noError;
    }

    return status;
}


void IfxVadc_startQueue(Ifx_VADC_G *group)
{
    group->QMR0.B.TREV = 1;
}


/*________________________________________________________________________________________ */
/* EOF */
