/**
 * \file IfxVadc.h
 * \brief VADC functions
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $0.7
 * $Date: $2013-07-01 13:24:26 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_Vadc VADC
 * \ingroup  IfxLld
 * \defgroup IfxLld_Vadc_Std Standard Drivers
 * \ingroup  IfxLld_Vadc
 * \defgroup IfxLld_Vadc_Std_Enumerations Enumerations
 * \ingroup  IfxLld_Vadc_Std
 * \defgroup IfxLld_Vadc_Std_BackGround_AutoScan Background autoscan functions
 * \ingroup  IfxLld_Vadc_Std
 * \defgroup IfxLld_Vadc_Std_ChannelScan Channel scan functions
 * \ingroup  IfxLld_Vadc_Std
 * \defgroup IfxLld_Vadc_Std_Queue Queue Request functions
 * \ingroup  IfxLld_Vadc_Std
 */

#ifndef IFXVADC_H_
#define IFXVADC_H_

#include <Scu/Std/IfxScuCcu.h>
#include <Scu/Std/IfxScuWdt.h>
#include <Cpu/Std/IfxCpu.h>
#include <_Impl/IfxVadc_cfg.h>

/** \addtogroup IfxLld_Vadc_Std_Enumerations
 * \{ */

/*  \brief API return values */
typedef enum
{
    IfxVadc_Status_noError = 0,             /** \brief No error during api execution    */
    IfxVadc_Status_notInitialised,          /** \brief Appropriate initialisation not done    */
    IfxVadc_Status_invalidGroup,            /** \brief Invalid group number    */
    IfxVadc_Status_invalidChannel,          /** \brief Invalid channel number    */
    IfxVadc_Status_queueFull,               /** \brief Queue is full    */
    IfxVadc_Status_noAccess,                /** \brief Access to the group/channel is disabled    */
    IfxVadc_Status_ChannelsStillPending     /** \brief Conversion for some of the channels are still pending     */
} IfxVadc_Status;

/** Access protection for Group registers */
typedef enum
{
    IfxVadc_Protection_channelControl0       = 0,           /** \brief Access control for GxCHCTR0    */
    IfxVadc_Protection_channelControl1       = 1,           /** \brief Access control for GxCHCTR1    */
    IfxVadc_Protection_channelControl2       = 2,           /** \brief Access control for GxCHCTR2    */
    IfxVadc_Protection_channelControl3       = 3,           /** \brief Access control for GxCHCTR3    */
    IfxVadc_Protection_channelControl4       = 4,           /** \brief Access control for GxCHCTR4    */
    IfxVadc_Protection_channelControl5       = 5,           /** \brief Access control for GxCHCTR5    */
    IfxVadc_Protection_channelControl6       = 6,           /** \brief Access control for GxCHCTR6    */
    IfxVadc_Protection_channelControl7       = 7,           /** \brief Access control for GxCHCTR7    */
    IfxVadc_Protection_channelControl8       = 8,           /** \brief Access control for GxCHCTR8    */
    IfxVadc_Protection_channelControl9       = 9,           /** \brief Access control for GxCHCTR9    */
    IfxVadc_Protection_channelControl10      = 10,          /** \brief Access control for GxCHCTR10    */
    IfxVadc_Protection_channelControl11      = 11,          /** \brief Access control for GxCHCTR11    */
    IfxVadc_Protection_channelControl12      = 12,          /** \brief Access control for GxCHCTR12    */
    IfxVadc_Protection_channelControl13      = 13,          /** \brief Access control for GxCHCTR13    */
    IfxVadc_Protection_channelControl14      = 14,          /** \brief Access control for GxCHCTR14    */
    IfxVadc_Protection_externalMultiplexer   = 15,          /** \brief Access control for EMUXSEL, GxEMUXCTR    */
    IfxVadc_Protection_initGroup0            = 16,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup1            = 17,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup2            = 18,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup3            = 19,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup4            = 20,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup5            = 21,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup6            = 22,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup7            = 23,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup8            = 24,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup9            = 25,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup10           = 26,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup11           = 27,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup12           = 28,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup13           = 29,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_initGroup14           = 30,          /** \brief Access control for GxARBCFG, GxARBPR, GxCHASS, GxRRASS, GxICLASS0/1, GxSYNCTR    */
    IfxVadc_Protection_globalConfig          = 31,          /** \brief Access control for GLOBCFG    */
    IfxVadc_Protection_serviceGroup0         = 32,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup1         = 33,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup2         = 34,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup3         = 35,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup4         = 36,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup5         = 37,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup6         = 38,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup7         = 39,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup8         = 40,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup9         = 41,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup10        = 42,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup11        = 43,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup12        = 44,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup13        = 45,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_serviceGroup14        = 46,          /** \brief Access control for GxSEFLAG, GxSEVNP, GxCEFLAG, GxCEVNP0/1/2, GxREFLAG, GxREVNP0/1, GxSRACT    */
    IfxVadc_Protection_testFunction          = 47,          /** \brief Access control for GLOBTF    */
    IfxVadc_Protection_resultRegisterGroup0  = 48,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES15    */
    IfxVadc_Protection_resultRegisterGroup1  = 49,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES16    */
    IfxVadc_Protection_resultRegisterGroup2  = 50,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES17    */
    IfxVadc_Protection_resultRegisterGroup3  = 51,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES18    */
    IfxVadc_Protection_resultRegisterGroup4  = 52,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES19    */
    IfxVadc_Protection_resultRegisterGroup5  = 53,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES20    */
    IfxVadc_Protection_resultRegisterGroup6  = 54,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES21    */
    IfxVadc_Protection_resultRegisterGroup7  = 55,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES22    */
    IfxVadc_Protection_resultRegisterGroup8  = 56,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES23    */
    IfxVadc_Protection_resultRegisterGroup9  = 57,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES24    */
    IfxVadc_Protection_resultRegisterGroup10 = 58,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES25    */
    IfxVadc_Protection_resultRegisterGroup11 = 59,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES26    */
    IfxVadc_Protection_resultRegisterGroup12 = 60,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES27    */
    IfxVadc_Protection_resultRegisterGroup13 = 61,          /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES28    */
    IfxVadc_Protection_resultRegisterGroup14 = 62           /** \brief Access control for GxRCR0  GxRCR15, GxBOUND, GxRES0  GxRES29    */
} IfxVadc_Protection;

/** Arbitration priority, Group x */
typedef enum
{
    IfxVadc_ReqSlotPrio_lowest  = 0,                        /** \brief Lowest priority     */
    IfxVadc_ReqSlotPrio_low     = 1,                        /** \brief Lowpriority         */
    IfxVadc_ReqSlotPrio_high    = 2,                        /** \brief High priority       */
    IfxVadc_ReqSlotPrio_highest = 3                         /** \brief Highest priority    */
} IfxVadc_ReqSlotPrio;

/*  \brief External trigger gating */
typedef enum
{
    IfxVadc_GatingSource_0  = 0,                             /** \brief Input signal REQGTx_0  */
    IfxVadc_GatingSource_1  = 1,                             /** \brief Input signal REQGTx_1  */
    IfxVadc_GatingSource_2  = 2,                             /** \brief Input signal REQGTx_2  */
    IfxVadc_GatingSource_3  = 3,                             /** \brief Input signal REQGTx_3  */
    IfxVadc_GatingSource_4  = 4,                             /** \brief Input signal REQGTx_4  */
    IfxVadc_GatingSource_5  = 5,                             /** \brief Input signal REQGTx_5  */
    IfxVadc_GatingSource_6  = 6,                             /** \brief Input signal REQGTx_6  */
    IfxVadc_GatingSource_7  = 7,                             /** \brief Input signal REQGTx_7  */
    IfxVadc_GatingSource_8  = 8,                             /** \brief Input signal REQGTx_8  */
    IfxVadc_GatingSource_9  = 9,                             /** \brief Input signal REQGTx_9  */
    IfxVadc_GatingSource_10 = 10,                            /** \brief Input signal REQGTx_10 */
    IfxVadc_GatingSource_11 = 11,                            /** \brief Input signal REQGTx_11 */
    IfxVadc_GatingSource_12 = 12,                            /** \brief Input signal REQGTx_12 */
    IfxVadc_GatingSource_13 = 13,                            /** \brief Input signal REQGTx_13 */
    IfxVadc_GatingSource_14 = 14,                            /** \brief Input signal REQGTx_14 */
    IfxVadc_GatingSource_15 = 15                             /** \brief Input signal REQGTx_15 */
} IfxVadc_GatingSource;

/** \brief Trigger request source */
typedef enum
{
    IfxVadc_TriggerSource_0  = 0,                            /** \brief Input signal REQTRx_0  */
    IfxVadc_TriggerSource_1  = 1,                            /** \brief Input signal REQTRx_1  */
    IfxVadc_TriggerSource_2  = 2,                            /** \brief Input signal REQTRx_2  */
    IfxVadc_TriggerSource_3  = 3,                            /** \brief Input signal REQTRx_3  */
    IfxVadc_TriggerSource_4  = 4,                            /** \brief Input signal REQTRx_4  */
    IfxVadc_TriggerSource_5  = 5,                            /** \brief Input signal REQTRx_5  */
    IfxVadc_TriggerSource_6  = 6,                            /** \brief Input signal REQTRx_6  */
    IfxVadc_TriggerSource_7  = 7,                            /** \brief Input signal REQTRx_7  */
    IfxVadc_TriggerSource_8  = 8,                            /** \brief Input signal REQTRx_8  */
    IfxVadc_TriggerSource_9  = 9,                            /** \brief Input signal REQTRx_9  */
    IfxVadc_TriggerSource_10 = 10,                           /** \brief Input signal REQTRx_10 */
    IfxVadc_TriggerSource_11 = 11,                           /** \brief Input signal REQTRx_11 */
    IfxVadc_TriggerSource_12 = 12,                           /** \brief Input signal REQTRx_12 */
    IfxVadc_TriggerSource_13 = 13,                           /** \brief Input signal REQTRx_13 */
    IfxVadc_TriggerSource_14 = 14,                           /** \brief Input signal REQTRx_14 */
    IfxVadc_TriggerSource_15 = 15                            /** \brief Input signal REQTRx_15 */
} IfxVadc_TriggerSource;

/** \brief Request source start mode */
typedef enum
{
    IfxVadc_RequestSlotStartMode_waitForStart       = 0,    /**< \brief Wait for start         */
    IfxVadc_RequestSlotStartMode_cancelInjectRepeat = 1     /**< \brief Cancel-Inject-Repeat   */
} IfxVadc_RequestSlotStartMode;

/*  \brief Arbitration round length */
typedef enum
{
    IfxVadc_ArbitrationMode_4_slots  = 0,                   /**< \brief An arbitration round contains 4 arbitration slots.  */
    IfxVadc_ArbitrationMode_8_slots  = 1,                   /**< \brief An arbitration round contains 8 arbitration slots.  */
    IfxVadc_ArbitrationMode_16_slots = 2,                   /**< \brief An arbitration round contains 16 arbitration slots. */
    IfxVadc_ArbitrationMode_20_slots = 3                    /**< \brief An arbitration round contains 20 arbitration slots. */
} IfxVadc_ArbitrationRounds;

/** \brief gating definition */
typedef enum
{
    IfxVadc_GatingMode_disabled   = 0,                      /**< \brief Gating is disabled, no conversion request are issued                                                   */
    IfxVadc_GatingMode_always     = 1,                      /**< \brief Conversion request is issued if at least 1 conversion pending bit is set                               */
    IfxVadc_GatingMode_gatingHigh = 2,                      /**< \brief Conversion request is issued if at least 1 conversion pending bit is set and the gating signal is high */
    IfxVadc_GatingMode_gatingLow  = 3                       /**< \brief Conversion request is issued if at least 1 conversion pending bit is set and the gating signal is low  */
} IfxVadc_GatingMode;

/** \brief trigger definition */
typedef enum
{
    IfxVadc_TriggerMode_noExternalTrigger = 0,              /**< \brief No external trigger                */
    IfxVadc_TriggerMode_uponFallingEdge   = 1,              /**< \brief Trigger event upon a falling edge  */
    IfxVadc_TriggerMode_uponRisingEdge    = 2,              /**< \brief Trigger event upon a rising edge   */
    IfxVadc_TriggerMode_uponAnyEdge       = 3               /**< \brief Trigger event upon any edge        */
} IfxVadc_TriggerMode;

/** \brief ADC channel resolution */
typedef enum
{
    IfxVadc_ChannelResolution_12bit     = 0,                /**< \brief 12-bit conversion        */
    IfxVadc_ChannelResolution_10bit     = 1,                /**< \brief 10-bit conversion        */
    IfxVadc_ChannelResolution_8bit      = 2,                /**< \brief 8-bit conversion         */
    IfxVadc_ChannelResolution_10bitFast = 5                 /**< \brief 10-bit cfast compare mode*/
} IfxVadc_ChannelResolution;

/** \brief Request sources */
typedef enum
{
    IfxVadc_RequestSource_queue      = 0,                   /**< \brief 8 stage Queue request   */
    IfxVadc_RequestSource_scan       = 1,                   /**< \brief scan request            */
    IfxVadc_RequestSource_background = 2                    /**< \brief background scan request */
} IfxVadc_RequestSource;

/** \brief inputClass */
typedef enum
{
    IfxVadc_InputClass_group0  = 0,                         /**< \brief Use group class 0  */
    IfxVadc_InputClass_group1  = 1,                         /**< \brief Use group class 1  */
    IfxVadc_InputClass_global0 = 2,                         /**< \brief Use global class 0 */
    IfxVadc_InputClass_global1 = 3,                         /**< \brief Use global class 1 */
} IfxVadc_InputClasses;

/** \brief BoundarySel */
typedef enum
{
    IfxVadc_BoundarySelection_group0  = 0,                  /**< \brief Use group class 0  */
    IfxVadc_BoundarySelection_group1  = 1,                  /**< \brief Use group class 1  */
    IfxVadc_BoundarySelection_global0 = 2,                  /**< \brief Use global class 0 */
    IfxVadc_BoundarySelection_global1 = 3,                  /**< \brief Use global class 1 */
} IfxVadc_BoundarySelection;

/** \brief Channel Result */
typedef enum
{
    IfxVadc_ChannelResult_0  = 0,                            /**< \brief Use Channel result 0  */
    IfxVadc_ChannelResult_1  = 1,                            /**< \brief Use Channel result 1  */
    IfxVadc_ChannelResult_2  = 2,                            /**< \brief Use Channel result 2  */
    IfxVadc_ChannelResult_3  = 3,                            /**< \brief Use Channel result 3  */
    IfxVadc_ChannelResult_4  = 4,                            /**< \brief Use Channel result 4  */
    IfxVadc_ChannelResult_5  = 5,                            /**< \brief Use Channel result 5  */
    IfxVadc_ChannelResult_6  = 6,                            /**< \brief Use Channel result 6  */
    IfxVadc_ChannelResult_7  = 7,                            /**< \brief Use Channel result 7  */
    IfxVadc_ChannelResult_8  = 8,                            /**< \brief Use Channel result 8  */
    IfxVadc_ChannelResult_9  = 9,                            /**< \brief Use Channel result 9  */
    IfxVadc_ChannelResult_10 = 10,                           /**< \brief Use Channel result 10 */
    IfxVadc_ChannelResult_11 = 11,                           /**< \brief Use Channel result 11 */
    IfxVadc_ChannelResult_12 = 12,                           /**< \brief Use Channel result 12 */
    IfxVadc_ChannelResult_13 = 13,                           /**< \brief Use Channel result 13 */
    IfxVadc_ChannelResult_14 = 14,                           /**< \brief Use Channel result 14 */
    IfxVadc_ChannelResult_15 = 15,                           /**< \brief Use Channel result 15 */
} IfxVadc_ChannelResult;

/** \brief ADC channel reference */
typedef enum
{
    IfxVadc_ChannelReference_standard = 0,                  /**< \brief use Varef as reference */
    IfxVadc_ChannelReference_channel0 = 1,                  /**< \brief use CH0 as reference   */
} IfxVadc_ChannelReference;

/** \brief ADC channel limit check */
typedef enum
{
    IfxVadc_LimitCheck_noCheck            = 0,              /**< \brief Normal compare mode Event Never                                    Fast Compare mode Event Never                                            */
    IfxVadc_LimitCheck_eventIfInArea      = 1,              /**< \brief Normal compare mode Event If result is inside the boundary band    Fast Compare mode Event If result switches to high (above comp. value)   */
    IfxVadc_LimitCheck_eventIfOutsideArea = 2,              /**< \brief Normal compare mode Event If result is outside the boundary band   Fast Compare mode Event If result switches to low (below comp. value)    */
    IfxVadc_LimitCheck_always             = 3,              /**< \brief Normal compare mode Event Always                                   Fast Compare mode Event Always                                           */
} IfxVadc_LimitCheck;

/** \brief Boundary Extension */
typedef enum
{
    IfxVadc_BoundaryExtension_standard            = 0,      /**< \brief Boundary Standard mode. BNDSELU/BNDSELL as Boundaries       */
    IfxVadc_BoundaryExtension_fastCompareResult1  = 1,      /**< \brief Fast compare mode use as upper boundary  Channel result   1 */
    IfxVadc_BoundaryExtension_fastCompareResult2  = 2,      /**< \brief Fast compare mode use as upper boundary  Channel result   2 */
    IfxVadc_BoundaryExtension_fastCompareResult3  = 3,      /**< \brief Fast compare mode use as upper boundary  Channel result   3 */
    IfxVadc_BoundaryExtension_fastCompareResult4  = 4,      /**< \brief Fast compare mode use as upper boundary  Channel result   4 */
    IfxVadc_BoundaryExtension_fastCompareResult5  = 5,      /**< \brief Fast compare mode use as upper boundary  Channel result   5 */
    IfxVadc_BoundaryExtension_fastCompareResult6  = 6,      /**< \brief Fast compare mode use as upper boundary  Channel result   6 */
    IfxVadc_BoundaryExtension_fastCompareResult7  = 7,      /**< \brief Fast compare mode use as upper boundary  Channel result   7 */
    IfxVadc_BoundaryExtension_fastCompareResult8  = 8,      /**< \brief Fast compare mode use as upper boundary  Channel result   8 */
    IfxVadc_BoundaryExtension_fastCompareResult9  = 9,      /**< \brief Fast compare mode use as upper boundary  Channel result   9 */
    IfxVadc_BoundaryExtension_fastCompareResult10 = 10,     /**< \brief Fast compare mode use as upper boundary  Channel result  10 */
    IfxVadc_BoundaryExtension_fastCompareResult11 = 11,     /**< \brief Fast compare mode use as upper boundary  Channel result  11 */
    IfxVadc_BoundaryExtension_fastCompareResult12 = 12,     /**< \brief Fast compare mode use as upper boundary  Channel result  12 */
    IfxVadc_BoundaryExtension_fastCompareResult13 = 13,     /**< \brief Fast compare mode use as upper boundary  Channel result  13 */
    IfxVadc_BoundaryExtension_fastCompareResult14 = 14,     /**< \brief Fast compare mode use as upper boundary  Channel result  14 */
    IfxVadc_BoundaryExtension_fastCompareResult15 = 15,     /**< \brief Fast compare mode use as upper boundary  Channel result  15 */
} IfxVadc_BoundaryExtension;

/** \brief Service Node */
typedef enum
{
    IfxVadc_SrcNr_group0  = 0,                              /**< \brief service request line 0 of group      */
    IfxVadc_SrcNr_group1  = 1,                              /**< \brief service request line 1 of group      */
    IfxVadc_SrcNr_group2  = 2,                              /**< \brief service request line 2 of group      */
    IfxVadc_SrcNr_group3  = 3,                              /**< \brief service request line 3 of group      */
    IfxVadc_SrcNr_shared0 = 4,                              /**< \brief Select shared service request line 0 */
    IfxVadc_SrcNr_shared1 = 5,                              /**< \brief Select shared service request line 1 */
    IfxVadc_SrcNr_shared2 = 6,                              /**< \brief Select shared service request line 2 */
    IfxVadc_SrcNr_shared3 = 7,                              /**< \brief Select shared service request line 3 */
} IfxVadc_SrcNr;

/** \} */
/** \addtogroup IfxLld_Vadc_Std_BackGround_AutoScan
 * \{ */

/** \brief Get conversion result for the group
 *
 * \code
 *     Ifx_VADC* vadc = &MODULE_VADC
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = TRUE; // use continuous autoscan
 *
 *     //confiure wait for read mode for global result register
 *     IfxVadc_configureWaitForReadMode(group,IfxVadc_ChannelResult0, TRUE);
 *     IfxVadc_configureWaitForReadMode(group,IfxVadc_ChannelResult1, TRUE);
 *
 *     // configure autoscan
 *     IfxVadc_setScan(group, channels, mask, continuous);
 *
 *     // start the autoscan
 *     IfxVadc_startScan(group);
 *
 *    // wait for conversion to finish
 *
 *    // fetch the 2 results of conversion for group 0
 *   Ifx_VADC_RES results[10];
 *   result = IfxVadc_getGroupResult(group, results, 0, 2);
 * \endcode
 *
 * \param group pointer to the VADC group
 * \param results pointer to scaled conversion results
 * \param resultOffset offset for the first result
 * \param numResults number of results
 * \return void
 */
IFX_INLINE void IfxVadc_getGroupResult(Ifx_VADC_G *group, Ifx_VADC_RES *results, uint32 resultOffset, uint32 numResults)
{
    uint32 idx;

    for (idx = 0; idx < numResults; idx++)
    {
        results[idx].U = group->RES[resultOffset + idx].U;
    }
}


/** \brief Get conversion result (Function does not care about the alignment)
 * value = raw * gain + offset.
 *
 * \code
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = TRUE; // use continuous autoscan
 *
 *     //confiure wait for read mode for global result register
 *     IfxVadc_configureWaitForReadMode(group,IfxVadc_ChannelResult0, TRUE);
 *     IfxVadc_configureWaitForReadMode(group,IfxVadc_ChannelResult1, TRUE);
 *
 *     // configure autoscan
 *     IfxVadc_setScan(group, channels, mask, continuous);
 *
 *     // start the autoscan
 *     IfxVadc_startScan(group);
 *
 *    // wait for conversion to finish
 *
 *    // fetch the result of conversion from result register 0 for group 0
 *   Ifx_VADC_RES result;
 *   result = IfxVadc_getResult(group, IfxVadc_ChannelResult0);
 * \endcode
 *
 * \param group pointer to the VADC group
 * \param resultIdx result register index
 * \return scaled Conversion result
 */
IFX_INLINE Ifx_VADC_RES IfxVadc_getResult(Ifx_VADC_G *group, uint32 resultIdx)
{
    Ifx_VADC_RES tmpResult;

    tmpResult.U = group->RES[resultIdx].U;

    return tmpResult;
}


/** \brief Get conversion result (Function does not care about the alignment)
 * value = raw * gain + offset.
 *
 * \code
 *     Ifx_VADC vadc;
 *     vadc.vadc = &MODULE_VADC;
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = FALSE; //not using continuous autoscan
 *
 *     //confiure wait for read mode for global result register
 *     IfxVadc_configureWaitForReadMode(group,IfxVadc_ChannelResult0, TRUE);
 *     IfxVadc_configureWaitForReadMode(group,IfxVadc_ChannelResult1, TRUE);
 *
 *     // configure autoscan
 *     IfxVadc_setScan(group, channels, mask, continuous);
 *
 *     // start the autoscan
 *     IfxVadc_startScan(group);
 *
 *    // wait for conversion to finish
 *
 *    // fetch the result of conversion for channel 2 of group 0
 *   Ifx_VADC_RESresult2;
 *   result = IfxVadc_getResultBasedOnRequestSource(&vadc, group, IfxVadc_ChannelId2, IfxVadc_RequestSource_scan);
 *   Ifx_VADC_RESresult5;
 *   result = IfxVadc_getResultBasedOnRequestSource(&vadc, group, IfxVadc_ChannelId5, IfxVadc_RequestSource_scan);
 * \endcode
 *
 * \param vadc VADC module pointer
 * \param group pointer to the VADC group
 * \param channel channel Id
 * \param sourceType type of request source
 * \return scaled Conversion result
 */
IFX_INLINE Ifx_VADC_RES IfxVadc_getResultBasedOnRequestSource(Ifx_VADC *vadc, Ifx_VADC_G *group, IfxVadc_ChannelId channel, IfxVadc_RequestSource sourceType)
{
    sint32       sourceResultRegister = -1;
    Ifx_VADC_RES tmpResult;

    switch (sourceType)
    {
    case IfxVadc_RequestSource_queue:
        sourceResultRegister = group->QCTRL0.B.SRCRESREG;
        break;

    case IfxVadc_RequestSource_scan:
        sourceResultRegister = group->ASCTRL.B.SRCRESREG;
        break;

    case IfxVadc_RequestSource_background:
        sourceResultRegister = vadc->BRSCTRL.B.SRCRESREG;
        break;
    }

    if (sourceResultRegister > 0)
    {
        tmpResult.U = group->RES[sourceResultRegister].U;

        return tmpResult;
    }
    else
    {
        if ((sourceType == IfxVadc_RequestSource_background) && (group->CHCTR[channel].B.RESTBS == 1))
        {
            tmpResult.B.VF     = vadc->GLOBRES.B.VF;
            tmpResult.B.FCR    = vadc->GLOBRES.B.FCR;
            tmpResult.B.CRS    = vadc->GLOBRES.B.CRS;
            tmpResult.B.EMUX   = vadc->GLOBRES.B.EMUX;
            tmpResult.B.CHNR   = vadc->GLOBRES.B.CHNR;
            tmpResult.B.DRC    = vadc->GLOBRES.B.GNR; //The bitfields are the same but interpretation is different. TODO- define a generic result register type.
            tmpResult.B.RESULT = vadc->GLOBRES.B.RESULT;

            return tmpResult;
        }
        else
        {
            tmpResult.U = group->RES[group->CHCTR[channel].B.RESREG].U;

            return tmpResult;
        }
    }
}


/** \brief  return conversion result stored in the Global result Register
 *
 * \code
 *     Ifx_VADC* vadc = &MODULE_VADC; // module pointer
 *     IfxVadc_GroupId groupId = IfxVadc_GroupId0; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = TRUE; // use continuous background scan
 *
 *     //confiure wait for read mode for global result register
 *     IfxVadc_configureWaitForReadModeForGlobalResultRegister(vadc, TRUE);
 *
 *     // configure background scan
 *     IfxVadc_setBackgroundScan(vadc, groupId, channels, mask);
 *
 *     // start the background scan
 *     IfxVadc_startBackgroundScan(vadc, continuous);
 *
 *     Ifx_VADC_GLOBRES result;
 *     result = IfxVadc_getGlobalResult (vadc);
 *
 * \endcode
 *
 * \param vadc pointer to the VADC module
 * \return global result register
 * \ingroup Vadc
 */
IFX_INLINE Ifx_VADC_GLOBRES IfxVadc_getGlobalResult(Ifx_VADC *vadc)
{
    Ifx_VADC_GLOBRES tmpGlobalResult;

    tmpGlobalResult.U = vadc->GLOBRES.U;

    return tmpGlobalResult;
}


/** \brief Gives the background scan status for a group
 *
 * \param vadc pointer to the VADC module
 * \return IfxVadc_Status
 */
IFX_EXTERN IfxVadc_Status IfxVadc_getBackgroundScanStatus(Ifx_VADC *vadc);

/** brief access function to enable/disable  wait for read mode for global result register
 * \param vadc pointer to the VADC
 * \param waitForRead wait for read mode enabled/disabled
 *
 */
IFX_INLINE void IfxVadc_configureWaitForReadModeForGlobalResultRegister(Ifx_VADC *vadc, boolean waitForRead)
{
    vadc->GLOBRCR.B.WFR = waitForRead;
}


/** \brief configures a background scan; can also stop autoscan if all channels are 0
 * Background scan can be enabled/disabled for the given channels which are selected with the mask
 *
 * \code
 *     Ifx_VADC* vadc = &MODULE_VADC; // module pointer
 *    IfxVadc_GroupId groupId = IfxVadc_GroupId0; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = TRUE; // use continuous background scan
 *
 *     //confiure wait for read mode for global result register
 *     IfxVadc_configureWaitForReadModeForGlobalResultRegister(vadc, TRUE);
 *
 *     // configure background scan
 *     IfxVadc_setBackgroundScan(vadc, groupId, channels, mask);
 *
 *     // start the background scan
 *     IfxVadc_startBackgroundScan(vadc, continuous);
 * \endcode
 *
 * \param vadc pointer to the VADC module
 * \param groupId group index
 * \param channels specifies the channels which should be enabled/disabled
 * \param mask specifies the channels which should be modified
 * \return void
 * \ingroup Vadc
 */
IFX_EXTERN void IfxVadc_setBackgroundScan(Ifx_VADC *vadc, IfxVadc_GroupId groupId, uint32 channels, uint32 mask);

/** \brief Starts a background scan in either continuous or single shot conversion mode as per the parameter
 *
 * \code
 *     Ifx_VADC* vadc = &MODULE_VADC; // module pointer
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = TRUE; // use continuous background scan
 *
 *     // configure background scan
 *     IfxVadc_setBackgroundScan(vadc, group, channels, mask);
 *
 *     // start the background scan
 *     IfxVadc_startBackgroundScan(vadc, continuous);
 * \endcode
 *
 * \param vadc pointer to the VADC module
 * \param continuous continuous or single shot conversion
 * \return void
 */
IFX_EXTERN void IfxVadc_startBackgroundScan(Ifx_VADC *vadc, boolean continuous);

/** brief access function to enable/disable  wait for read mode for result registers
 *
 * \param group pointer to the VADC group
 * \param resultIdx result register index
 * \param waitForRead wait for read mode enabled/disabled
 * \return void
 */
IFX_INLINE void IfxVadc_configureWaitForReadMode(Ifx_VADC_G *group, uint32 resultIdx, boolean waitForRead)
{
    group->RCR[resultIdx].B.WFR = waitForRead;
}


/** \} */
/** \addtogroup IfxLld_Vadc_Std_ChannelScan
 * \{ */

/** \brief returns Gives the scan status for a group
 *
 * \param group pointer to the VADC group
 * \return IfxVadc_Status
 * \ingroup Vadc
 */
IFX_EXTERN IfxVadc_Status IfxVadc_getScanStatus(Ifx_VADC_G *group);

/** \brief Configures an autoscan
 * Autoscan can be enabled/disabled for the given channels which are selected with the mask
 *
 * \code
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = TRUE; // use continuous autoscan
 *
 *     // configure autoscan
 *     IfxVadc_setScan(group, channels, mask, continuous);
 *
 *     // start the autoscan
 *     IfxVadc_startScan(group);
 * \endcode
 *
 * \param group pointer to the VADC group
 * \param channels specifies the channels which should be enabled/disabled
 * \param mask specifies the channels which should be modified
 * \param continuous specifies if single triggered or continuous autoscan
 * \return void
 * \ingroup Vadc
 */
IFX_EXTERN void IfxVadc_setScan(Ifx_VADC_G *group, uint32 channels, uint32 mask, boolean continuous);

/** \brief Starts an autoscan on the specified group
 *
 * \code
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     uint32 channels = (1 << 5) | (1 << 2); // enable channel #5 and #2
 *     uint32 mask = (1 << 7) | (1 << 5) | (1 << 2); // modify the selection for channel #7, #5 and #2; channel #7 will be disabled
 *     boolean continuous = TRUE; // use continuous autoscan
 *
 *     // configure autoscan
 *     IfxVadc_setScan(group, channels, mask, continuous);
 *
 *     // start the autoscan
 *     IfxVadc_startScan(group);
 * \endcode
 *
 * \param group pointer to the VADC group
 * \return void
 */
IFX_EXTERN void IfxVadc_startScan(Ifx_VADC_G *group);

/** \} */
/** \addtogroup IfxLld_Vadc_Std_Queue
 * \{ */

/** \brief Add an entry to the queue of a group for the specified channel with the following options set:
 *  refill incase of aborted conversion
 *  source interrupt enable/disable
 * external trigger control of the aborted conversion
 *
 * \code
 *
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     IfxVadc_ChannelId channel = 1; // for channel 1
 *
 *    // Add channel 1 to queue of group 0 with the refill turned on
 *     IfxVadc_addToQueue(qroup, channel, (1<<IFX_VADC_G_QBUR_QINR0_QBUR0_RF_OFF));
 * \endcode
 *
 * \param group pointer to the VADC group
 * \param channel specifies channel Id
 * \param options specifies the refill, source interrupt enable/disable and external trigger control selection
 * \return void
 */
IFX_EXTERN void IfxVadc_addToQueue(Ifx_VADC_G *group, IfxVadc_ChannelId channel, uint32 options);

/** \brief Flush the contents of the queue of a group
 * \param group pointer to the VADC group
 * \return void
 */
IFX_EXTERN void IfxVadc_clearQueue(Ifx_VADC_G *group);

/** \brief Gives the status of the Queue of a group by returning non zero value if the Queue is full
 *
 * \code
 *     Ifx_VADC_G* group = &MODULE_VADC.G[0]; // for group 0
 *     boolean queueFull = (IfxVadc_getQueueStatus(group)==IfxVadc_Status_queueFull)?TRUE:FALSE; // get Queue status for group 0
 * \endcode
 *
 * \param group pointer to the VADC group
 * \return IfxVadc_Status
 * \ingroup Vadc
 */
IFX_EXTERN IfxVadc_Status IfxVadc_getQueueStatus(Ifx_VADC_G *group);

/** \brief Starts a queue of a group by generating a trigger event through software
 * \param group pointer to the VADC group
 * \return void
 */
IFX_EXTERN void IfxVadc_startQueue(Ifx_VADC_G *group);

/** \} */

#endif /* IFXADC_H_ */
