/**
 * \file IfxCpu_cfg.h
 * \brief CPU on-chip implementation data.
 * \ingroup IfxLld_Cpu
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1391.4
 * $Date: $2013-06-26 11:22:16 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */

#ifndef IFXCPU_CFG_H
#define IFXCPU_CFG_H
/******************************************************************************/
#include "Cpu/Std/IfxCpu_Intrinsics.h"
#include "_Reg/IfxCpu_reg.h"

/******************************************************************************/
/*                           Macro                                            */
/******************************************************************************/
#define IFXCPU_COUNT   (2)               /**< \brief CPU count */

/******************************************************************************/
/*                           Enum                                             */
/******************************************************************************/
/* List of the available CPU resources */
typedef enum
{
    IfxCpu_ResourceCpu_0 = 0,                               /**< CPU 0 */
    IfxCpu_ResourceCpu_1,                                   /**< CPU 1 */
    IfxCpu_ResourceCpu_none                                 /**< None of the CPU  */
} IfxCpu_ResourceCpu;

/** Halt status */
typedef enum
{
    IfxCpu_DBGST_HALT_run = 0,
    IfxCpu_DBGST_HALT_halt = 1
} IfxCpu_DBGST_HALT;

/** Power management status */
typedef enum
{
    IfxCpu_PMCSR_PMST_normalMode = 1,
    IfxCpu_PMCSR_PMST_idleModeRequest = 2,
    IfxCpu_PMCSR_PMST_idleMode = 3,
    IfxCpu_PMCSR_PMST_sleepModeRequest = 4,
    IfxCpu_PMCSR_PMST_standbyModeRequest = 6
} IfxCpu_PMCSR_PMST;

extern const IfxModule_IndexMap IfxCpu_cfg_indexMap[IFXCPU_COUNT];

#endif /* IFXCPU_CFG_H */
