/**
 * \file IfxGtm_cfg.h
 * \brief GTM on-chip implementation data.
 * \ingroup IfxLld_Gtm
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1417.7
 * $Date: $2013-08-14 08:43:56 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_Gtm_cfg GTM Configuration
 * \ingroup IfxLld_Gtm
 *
 */

#ifndef IFXGTM_CFG_H_
#define IFXGTM_CFG_H_

/******************************************************************************/
#include "Cpu/Std/IfxCpu_Intrinsics.h"
#include "Ifx_Cfg.h"
#include "_Reg/IfxGtm_reg.h"
#include "If/Generic.h"         /* FIXME /Std driver shall not have dependencies to /1_SrvSw/If  */
#include "Port/Std/IfxPort.h"

/******************************************************************************/
/*                           Enum                                             */
/******************************************************************************/
/** \addtogroup IfxLld_Gtm_cfg
 * \{ */

/** Tim objects */
typedef enum
{
    IfxGtmTim_0,
    IfxGtmTim_1,
    IfxGtmTim_2
} IfxGtmTim;

/** Tim channels */
typedef enum
{
    IfxGtmTim_Ch_0,
    IfxGtmTim_Ch_1,
    IfxGtmTim_Ch_2,
    IfxGtmTim_Ch_3,
    IfxGtmTim_Ch_4,
    IfxGtmTim_Ch_5,
    IfxGtmTim_Ch_6,
    IfxGtmTim_Ch_7
} IfxGtmTim_Ch;


/** Tom objects */
typedef enum
{
    IfxGtmTom_0 = 0,
    IfxGtmTom_1 = 1
} IfxGtmTom;

/** Tom TGC */
typedef enum
{
    IfxGtmTom_Tgc_0 = 0,
    IfxGtmTom_Tgc_1 = 1
} IfxGtmTom_Tgc;

/** Tom channels */
typedef enum
{
    IfxGtmTom_Ch_0  = 0,
    IfxGtmTom_Ch_1  = 1,
    IfxGtmTom_Ch_2  = 2,
    IfxGtmTom_Ch_3  = 3,
    IfxGtmTom_Ch_4  = 4,
    IfxGtmTom_Ch_5  = 5,
    IfxGtmTom_Ch_6  = 6,
    IfxGtmTom_Ch_7  = 7,
    IfxGtmTom_Ch_8  = 8,
    IfxGtmTom_Ch_9  = 9,
    IfxGtmTom_Ch_10 = 10,
    IfxGtmTom_Ch_11 = 11,
    IfxGtmTom_Ch_12 = 12,
    IfxGtmTom_Ch_13 = 13,
    IfxGtmTom_Ch_14 = 14,
    IfxGtmTom_Ch_15 = 15
} IfxGtmTom_Ch;


/** ATOM objects */
typedef enum
{
    IfxGtmAtom_0 = 0,
    IfxGtmAtom_1 = 1,
    IfxGtmAtom_2 = 2,
    IfxGtmAtom_3 = 3
} IfxGtmAtom;

/** ATOM channels */
typedef enum
{
    IfxGtmAtom_Ch_none = -1,
    IfxGtmAtom_Ch_0    = 0,
    IfxGtmAtom_Ch_1    = 1,
    IfxGtmAtom_Ch_2    = 2,
    IfxGtmAtom_Ch_3    = 3,
    IfxGtmAtom_Ch_4    = 4,
    IfxGtmAtom_Ch_5    = 5,
    IfxGtmAtom_Ch_6    = 6,
    IfxGtmAtom_Ch_7    = 7
} IfxGtmAtom_Ch;

typedef enum
{
    IfxGtmDpll_SubInc_1 = 0,
    IfxGtmDpll_SubInc_2 = 1
} IfxGtmDpll_SubInc;
/** \} */

/** Enable disable feature
 */
typedef enum
{
    IfxGtm_FeatureControl_disabled = 0,
    IfxGtm_FeatureControl_disable  = 1,
    IfxGtm_FeatureControl_enable   = 2,
    IfxGtm_FeatureControl_enabled  = 3
} IfxGtm_FeatureControl;

typedef enum
{
    IfxGtm_PinFeature_tin0,
    /*
     * IfxGtm_PinFeature_tin1,
     * IfxGtm_PinFeature_tin2,
     * IfxGtm_PinFeature_tin3,
     * IfxGtm_PinFeature_tin4,
     * IfxGtm_PinFeature_tin5,
     * IfxGtm_PinFeature_tin6,
     * IfxGtm_PinFeature_tin7,
     * IfxGtm_PinFeature_tin8,
     * IfxGtm_PinFeature_tin9,
     * IfxGtm_PinFeature_tin10,
     * IfxGtm_PinFeature_tin11,
     * IfxGtm_PinFeature_tin12,
     * IfxGtm_PinFeature_tin13,
     * IfxGtm_PinFeature_tin14,
     * IfxGtm_PinFeature_tin15,
     * IfxGtm_PinFeature_tin16,
     * IfxGtm_PinFeature_tin17,
     * IfxGtm_PinFeature_tin18,
     * IfxGtm_PinFeature_tin19,
     */
    IfxGtm_PinFeature_tout0,
    IfxGtm_PinFeature_tout1,
    IfxGtm_PinFeature_tout2,
    IfxGtm_PinFeature_tout3,
    IfxGtm_PinFeature_tout4,
    IfxGtm_PinFeature_tout5,
    IfxGtm_PinFeature_tout6,
    IfxGtm_PinFeature_tout7,
    /*
     * IfxGtm_PinFeature_tout8,
     * IfxGtm_PinFeature_tout9,
     * IfxGtm_PinFeature_tout10,*/
	IfxGtm_PinFeature_tout11,
    IfxGtm_PinFeature_tout12,
    IfxGtm_PinFeature_tout13,
    IfxGtm_PinFeature_tout14,
    IfxGtm_PinFeature_tout15,
    IfxGtm_PinFeature_tout16,
    IfxGtm_PinFeature_tout17,

    IfxGtm_PinFeature_tout18,

    IfxGtm_PinFeature_tout80,
    IfxGtm_PinFeature_tout81,
    IfxGtm_PinFeature_tout82,
    IfxGtm_PinFeature_tout83,
    IfxGtm_PinFeature_tout84,
    IfxGtm_PinFeature_tout85,
    IfxGtm_PinFeature_tout86,
    IfxGtm_PinFeature_tout88,

    /*
     * IfxGtm_PinFeature_tout19,
     */
} IfxGtm_PinFeature;

/******************************************************************************/
#define IFXGTM_CFG_PORT_MAP_COUNT (25)  /* size of IfxGtm_cfg_PortMap */
/******************************************************************************/
/** Module port map item */
typedef struct
{
    If_IoOption       option;
    IfxGtm_PinFeature feature;
    IfxPort_Map       map;
} IfxGtm_PortMap;

/******************************************************************************/
extern const IfxGtm_PortMap IfxGtm_cfg_PortMap[IFXGTM_CFG_PORT_MAP_COUNT];
/******************************************************************************/

/**\defgroup IfxLld_Gtm_cfg_cmu_clock_enable_disable Clock enable / disable mask
 * \ingroup IfxLld_Gtm_cfg
 *
 * \addtogroup IfxLld_Gtm_cfg_cmu_clock_enable_disable
 * \{ */
#define IFXGTMCMU_CLKEN_CLK0   (0x00000002)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK0   */
#define IFXGTMCMU_CLKEN_CLK1   (0x00000008)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK1   */
#define IFXGTMCMU_CLKEN_CLK2   (0x00000020)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK2   */
#define IFXGTMCMU_CLKEN_CLK3   (0x00000080)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK3   */
#define IFXGTMCMU_CLKEN_CLK4   (0x00000200)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK4   */
#define IFXGTMCMU_CLKEN_CLK5   (0x00000800)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK5   */
#define IFXGTMCMU_CLKEN_CLK6   (0x00002000)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK6   */
#define IFXGTMCMU_CLKEN_CLK7   (0x00008000)             /**< \brief Mask for CMU_CLK_EN register (Enable): CLK7   */
#define IFXGTMCMU_CLKEN_ECLK0  (0x00020000)             /**< \brief Mask for CMU_CLK_EN register (Enable): ECLK0  */
#define IFXGTMCMU_CLKEN_ECLK1  (0x00080000)             /**< \brief Mask for CMU_CLK_EN register (Enable): ECLK1  */
#define IFXGTMCMU_CLKEN_ECLK2  (0x00200000)             /**< \brief Mask for CMU_CLK_EN register (Enable): ECLK2  */
#define IFXGTMCMU_CLKEN_FXCLK  (0x00800000)             /**< \brief Mask for CMU_CLK_EN register (Enable): FXCLK  */
#define IFXGTMCMU_CLKEN_ALL    (0x00AAAAAA)             /**< \brief Mask for CMU_CLK_EN register (Enable): All clocks  */
#define IFXGTMCMU_CLKDIS_CLK0  (0x00000001)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK0   */
#define IFXGTMCMU_CLKDIS_CLK1  (0x00000004)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK1   */
#define IFXGTMCMU_CLKDIS_CLK2  (0x00000010)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK2   */
#define IFXGTMCMU_CLKDIS_CLK3  (0x00000040)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK3   */
#define IFXGTMCMU_CLKDIS_CLK4  (0x00000100)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK4   */
#define IFXGTMCMU_CLKDIS_CLK5  (0x00000400)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK5   */
#define IFXGTMCMU_CLKDIS_CLK6  (0x00001000)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK6   */
#define IFXGTMCMU_CLKDIS_CLK7  (0x00004000)             /**< \brief Mask for CMU_CLK_EN register (Disable): CLK7   */
#define IFXGTMCMU_CLKDIS_ECLK0 (0x00010000)             /**< \brief Mask for CMU_CLK_EN register (Disable): ECLK0  */
#define IFXGTMCMU_CLKDIS_ECLK1 (0x00040000)             /**< \brief Mask for CMU_CLK_EN register (Disable): ECLK1  */
#define IFXGTMCMU_CLKDIS_ECLK2 (0x00100000)             /**< \brief Mask for CMU_CLK_EN register (Disable): ECLK2  */
#define IFXGTMCMU_CLKDIS_FXCLK (0x00400000)             /**< \brief Mask for CMU_CLK_EN register (Disable): FXCLK  */
#define IFXGTMCMU_CLKDIS_ALL   (0x00555555)             /**< \brief Mask for CMU_CLK_EN register (Disable): All clocks  */
/** \} */

// Temporary workaround for missing definitions in IfxGtm_regdef.h

/** ATOM AGC objects */
typedef volatile struct _Ifx_GTM_ATOM_AGC
{
    Ifx_GTM_ATOM_AGC_GLB_CTRL   GLB_CTRL;           /**< \brief 0, ATOM AGC Global control register */
    Ifx_GTM_ATOM_AGC_ENDIS_CTRL ENDIS_CTRL;         /**< \brief 4, ATOM AGC Enable/Disable Control Register */
    Ifx_GTM_ATOM_AGC_ENDIS_STAT ENDIS_STAT;         /**< \brief 8, ATOM AGC Enable/Disable Status Register */
    Ifx_GTM_ATOM_AGC_ACT_TB     ACT_TB;             /**< \brief C, TOM TGC0 Action Time Base Register */
    Ifx_GTM_ATOM_AGC_OUTEN_CTRL OUTEN_CTRL;         /**< \brief 10, ATOM AGC Output Enable Control Register */
    Ifx_GTM_ATOM_AGC_OUTEN_STAT OUTEN_STAT;         /**< \brief 14, ATOM AGC Output Enable Status Register */
    Ifx_GTM_ATOM_AGC_FUPD_CTRL  FUPD_CTRL;          /**< \brief 18, ATOM AGC Force Update Control Register */
    Ifx_GTM_ATOM_AGC_INT_TRIG   INT_TRIG;           /**< \brief 1C, ATOM AGC Internal Trigger Control Register */
    unsigned char               reserved_20[96];    /**< \brief 20 */
} Ifx_GTM_ATOM_AGC;

/** ATOM channel objects */
typedef volatile struct _Ifx_GTM_ATOM_CH
{
    Ifx_GTM_ATOM_CH_RDADDR      RDADDR;             /**< \brief 80, ATOM Channel 1 ARU Read Address Register */
    Ifx_GTM_ATOM_CH_CTRL        CTRL;               /**< \brief 84, ATOM Channel 1 Control in SOMI mode Register */
    Ifx_GTM_ATOM_CH_SR0         SR0;                /**< \brief 88, ATOM Channel 1 CCU0 Compare Shadow Register */
    Ifx_GTM_ATOM_CH_SR1         SR1;                /**< \brief 8C, ATOM Channel 1 CCU1 Compare Shadow Register */
    Ifx_GTM_ATOM_CH_CM0         CM0;                /**< \brief 90, ATOM Channel 1 CCU0 Compare Register */
    Ifx_GTM_ATOM_CH_CM1         CM1;                /**< \brief 94, ATOM Channel 1 CCU1 Compare Register */
    Ifx_GTM_ATOM_CH_CN0         CN0;                /**< \brief 98, ATOM Channel 1 CCU0 Counter Register */
    Ifx_GTM_ATOM_CH_STAT        STAT;               /**< \brief 9C, ATOM Channel 1 Status Register */
    Ifx_GTM_ATOM_CH_IRQ_NOTIFY  IRQ_NOTIFY;         /**< \brief A0, ATOM Channel 1 Interrupt Notification Register */
    Ifx_GTM_ATOM_CH_IRQ_EN      IRQ_EN;             /**< \brief A4, ATOM Channel 1 Interrupt Enable Register */
    Ifx_GTM_ATOM_CH_IRQ_FORCINT IRQ_FORCINT;        /**< \brief A8, ATOM Channel 1 Software Interrupt Generation Register */
    Ifx_GTM_ATOM_CH_IRQ_MODE    IRQ_MODE;           /**< \brief AC, ATOM IRQ Mode Configuration Register */
    unsigned char               reserved_B0[80];    /**< \brief B0, \internal Reserved */
} Ifx_GTM_ATOM_CH;

/** MCS channel objects */
typedef volatile struct _Ifx_GTM_MCS_CH
{
    Ifx_GTM_MCS_CH_R0   R0;                 /**< \brief 0, MCS Channel 0 Program Counter Register 0 */
    Ifx_GTM_MCS_CH_R1   R1;                 /**< \brief 4, MCS Channel 0 Program Counter Register 1 */
    Ifx_GTM_MCS_CH_R2   R2;                 /**< \brief 8, MCS Channel 0 Program Counter Register 2 */
    Ifx_GTM_MCS_CH_R3   R3;                 /**< \brief C, MCS Channel 0 Program Counter Register 3 */
    Ifx_GTM_MCS_CH_R4   R4;                 /**< \brief 10, MCS Channel 0 Program Counter Register 4 */
    Ifx_GTM_MCS_CH_R5   R5;                 /**< \brief 14, MCS Channel 0 Program Counter Register 5 */
    Ifx_GTM_MCS_CH_R6   R6;                 /**< \brief 18, MCS Channel 0 Program Counter Register 6 */
    Ifx_GTM_MCS_CH_R7   R7;                 /**< \brief 1C, MCS Channel 0 Program Counter Register 7 */
    Ifx_GTM_MCS_CH_CTRL CTRL;               /**< \brief 20, MCS Channel Control Register */
    Ifx_GTM_MCS_CH_ACB  ACB;                /**< \brief 24, MCS Channel ACB Register */
    Ifx_GTM_MCS_CTRG    CTRG;               /**< \brief 28, MCS Clear Trigger Control Register */
    Ifx_GTM_MCS_STRG    STRG;               /**< \brief 2C, MCS Set Trigger Control Register */
    unsigned char       reserved_30[16];    /**< \brief 30, \internal Reserved */
} Ifx_GTM_MCS_CH;

/** TIM channel objects */
typedef volatile struct _Ifx_GTM_TIM_CH
{
    Ifx_GTM_TIM_CH_GPR0        GPR0;                /**< \brief 0, TIM Channel 0 General Purpose 0 Register */
    Ifx_GTM_TIM_CH_GPR1        GPR1;                /**< \brief 4, TIM Channel 0 General Purpose 1 Register */
    Ifx_GTM_TIM_CH_CNT         CNT;                 /**< \brief 8, TIM Channel 0 SMU Counter Register */
    Ifx_GTM_TIM_CH_ECNT        ECNT;                /**< \brief C, TIM Channel 0 Edge Counter Register */
    Ifx_GTM_TIM_CH_CNTS        CNTS;                /**< \brief 10, TIM Channel 0 SMU Shadow Counter Register */
    Ifx_GTM_TIM_CH_TDUC        TDUC;                /**< \brief 14, TIM Channel 0 TDUC Register */
    Ifx_GTM_TIM_CH_TDUV        TDUV;                /**< \brief 18, TIM Channel 0 TDUV Register */
    Ifx_GTM_TIM_CH_FLT_RE      FLT_RE;              /**< \brief 1C, GTM_TIM Channel 0 Filter Parameter 0 Register */
    Ifx_GTM_TIM_CH_FLT_FE      FLT_FE;              /**< \brief 20, TIM Channel 0 Filter Parameter 1 Register */
    Ifx_GTM_TIM_CH_CTRL        CTRL;                /**< \brief 24, TIM Channel 0 Control Register */
    Ifx_GTM_TIM_CH_ECTRL       ECTRL;               /**< \brief 28, TIM Channel 0 External Capture Control Register */
    Ifx_GTM_TIM_CH_IRQ_NOTIFY  IRQ_NOTIFY;          /**< \brief 2C, TIM Channel 0 Interrupt Notification Register */
    Ifx_GTM_TIM_CH_IRQ_EN      IRQ_EN;              /**< \brief 30, TIM Channel 0 Interrupt Enable Register */
    Ifx_GTM_TIM_CH_IRQ_FORCINT IRQ_FORCINT;         /**< \brief 34, TIM Channel 0 Software Interrupt Force Register */
    Ifx_GTM_TIM_CH_IRQ_MODE    IRQ_MODE;            /**< \brief 38, TIM IRQ Mode Configuration Register */
    Ifx_GTM_TIM_CH_EIRQ_EN     EIRQ_EN;             /**< \brief 3C, TIM Channel 0 Error Interrupt Enable Register */
    unsigned char              reserved_40[56];     /**< \brief 40 */
} Ifx_GTM_TIM_CH;

/** TOM channel objects */
typedef volatile struct _Ifx_GTM_TOM_CH
{
    Ifx_GTM_TOM_CH_CTRL        CTRL;            /**< \brief 0, TOM Channel 0 Control Register<E2><80><99> */
    Ifx_GTM_TOM_CH_SR0         SR0;             /**< \brief 4, TOM Channel 0 CCU0 Compare Shadow Register */
    Ifx_GTM_TOM_CH_SR1         SR1;             /**< \brief 8, TOM Channel 0 CCU1 Compare Shadow Register */
    Ifx_GTM_TOM_CH_CM0         CM0;             /**< \brief C, TOM Channel 0 CCU0 Compare Register */
    Ifx_GTM_TOM_CH_CM1         CM1;             /**< \brief 10, TOM Channel 0 CCU1 Compare Register */
    Ifx_GTM_TOM_CH_CN0         CN0;             /**< \brief 14, TOM Channel 0 CCU0 Counter Register */
    Ifx_GTM_TOM_CH_STAT        STAT;            /**< \brief 18, TOM Channel Status Register */
    Ifx_GTM_TOM_CH_IRQ_NOTIFY  IRQ_NOTIFY;      /**< \brief 1C, TOM Channel 0 Interrupt Notification Register */
    Ifx_GTM_TOM_CH_IRQ_EN      IRQ_EN;          /**< \brief 20, TOM Channel 0 Interrupt Enable Register */
    Ifx_GTM_TOM_CH_IRQ_FORCINT IRQ_FORCINT;     /**< \brief 24, TOM Channel 0 Software Interrupt Generation Register */
    Ifx_GTM_TOM_CH_IRQ_MODE    IRQ_MODE;        /**< \brief 28, TOM IRQ Mode Configuration Register */
    unsigned char              reserved_2C[4];  /**< \brief 2C, \internal Reserved */
} Ifx_GTM_TOM_CH;

/** TOM channel objects */
typedef volatile struct _Ifx_GTM_TOM_CH15
{
    Ifx_GTM_TOM_CH15_CTRL        CTRL;              /**< \brief 3C0, TOM Channel 15 Control Register */
    Ifx_GTM_TOM_CH15_SR0         SR0;               /**< \brief 3C4, TOM Channel 15 CCU0 Compare Shadow Register */
    Ifx_GTM_TOM_CH15_SR1         SR1;               /**< \brief 3C8, TOM Channel 15 CCU1 Compare Shadow Register */
    Ifx_GTM_TOM_CH15_CM0         CM0;               /**< \brief 3CC, TOM Channel 15 CCU0 Compare Register */
    Ifx_GTM_TOM_CH15_CM1         CM1;               /**< \brief 3D0, TOM Channel 15 CCU1 Compare Register */
    Ifx_GTM_TOM_CH15_CN0         CN0;               /**< \brief 3D4, TOM Channel 15 CCU0 Counter Register */
    Ifx_GTM_TOM_CH15_STAT        STAT;              /**< \brief 3D8, TOM Channel Status Register */
    Ifx_GTM_TOM_CH15_IRQ_NOTIFY  IRQ_NOTIFY;        /**< \brief 3DC, TOM Channel 15 Interrupt Notification Register */
    Ifx_GTM_TOM_CH15_IRQ_EN      IRQ_EN;            /**< \brief 3E0, TOM Channel 15 Interrupt Enable Register */
    Ifx_GTM_TOM_CH15_IRQ_FORCINT IRQ_FORCINT;       /**< \brief 3E4, TOM Channel 15 Software Interrupt Generation Register */
    Ifx_GTM_TOM_CH15_IRQ_MODE    IRQ_MODE;          /**< \brief 3E8, TOM IRQ Mode Configuration Register */
} Ifx_GTM_TOM_CH15;

/** TOM TGC objects */
typedef volatile struct _Ifx_GTM_TOM_TGC
{
    Ifx_GTM_TOM_TGC0_GLB_CTRL  GLB_CTRL;            /**< \brief 30, TOM TGC0 Global Control Register */
    Ifx_GTM_TOM_TGC0_ACT_TB    ACT_TB;              /**< \brief 34, TOM TGC0 Action Time Base Register */
    Ifx_GTM_TOM_TGC0_FUPD_CTRL FUPD_CTRL;           /**< \brief 38, TOM TGC0 Force Update Control Register */
    Ifx_GTM_TOM_TGC0_INT_TRIG  INT_TRIG;            /**< \brief 3C, TOM TGC0 Internal Trigger Control Register */

    // not really part of TOM_TGC...
    Ifx_GTM_TOM_CH_CTRL         xxxCH1_CTRL;        /**< \brief 40, TOM Channel 1 Control Register<E2><80><99> */
    Ifx_GTM_TOM_CH_SR0          xxxCH1_SR0;         /**< \brief 44, TOM Channel 1 CCU0 Compare Shadow Register */
    Ifx_GTM_TOM_CH_SR1          xxxCH1_SR1;         /**< \brief 48, TOM Channel 1 CCU1 Compare Shadow Register */
    Ifx_GTM_TOM_CH_CM0          xxxCH1_CM0;         /**< \brief 4C, TOM Channel 1 CCU0 Compare Register */
    Ifx_GTM_TOM_CH_CM1          xxxCH1_CM1;         /**< \brief 50, TOM Channel 1 CCU1 Compare Register */
    Ifx_GTM_TOM_CH_CN0          xxxCH1_CN0;         /**< \brief 54, TOM Channel 1 CCU0 Counter Register */
    Ifx_GTM_TOM_CH_STAT         xxxCH1_STAT;        /**< \brief 58, TOM Channel Status Register */
    Ifx_GTM_TOM_CH_IRQ_NOTIFY   xxxCH1_IRQ_NOTIFY;  /**< \brief 5C, TOM Channel 1 Interrupt Notification Register */
    Ifx_GTM_TOM_CH_IRQ_EN       xxxCH1_IRQ_EN;      /**< \brief 60, TOM Channel 1 Interrupt Enable Register */
    Ifx_GTM_TOM_CH_IRQ_FORCINT  xxxCH1_IRQ_FORCINT; /**< \brief 64, TOM Channel 1 Software Interrupt Generation Register */
    Ifx_GTM_TOM_CH_IRQ_MODE     xxxCH1_IRQ_MODE;    /**< \brief 68, TOM IRQ Mode Configuration Register */
    unsigned char               reserved_6C[4];     /**< \brief 6C, \internal Reserved */

    Ifx_GTM_TOM_TGC0_ENDIS_CTRL ENDIS_CTRL;         /**< \brief 70, TOM TGC0 Enable/Disable Control Register */
    Ifx_GTM_TOM_TGC0_ENDIS_STAT ENDIS_STAT;         /**< \brief 74, TOM TGC0 Enable/Disable Status Register */
    Ifx_GTM_TOM_TGC0_OUTEN_CTRL OUTEN_CTRL;         /**< \brief 78, TOM TGC0 Output Enable Control Register */
    Ifx_GTM_TOM_TGC0_OUTEN_STAT OUTEN_STAT;         /**< \brief 7C, TOM TGC0 Output Enable Status Register */
} Ifx_GTM_TOM_TGC;

#endif /* IFXGTM_CFG_H_ */
