/**
 * \file IfxPsi5s_cfg.h
 * \brief PSI5S on-chip implementation data.
 * \ingroup IfxLld_Psi5s
 *
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1532.3
 * $Date: $2013-06-26 11:22:17 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */

#ifndef IFXPSI5S_CFG_H_
#define IFXPSI5S_CFG_H_

#include <_Reg/IfxPsi5s_bf.h>
#include <_Reg/IfxPsi5s_reg.h>
#include <Cpu/Std/Intrinsics.h>
#include <Src/Std/IfxSrc.h>

#define IFXPSI5S_NUM_CHANNELS 8

#define IFXPSI5S_STEP_RANGE 1024
#define IFXPSI5S_WDT_COUNT 7
#define IFXPSI5S_SLOT_COUNT 6
#define IFXPSI5S_ENABLE_CHANNELTRIGGER  (1 << 8)
#define IFXPSI5S_ENABLE_CHANNEL (1 << 16)

#define IFXPSI5S_BG_RANGE 8192
#define IFXPSI5S_FDV_RANGE 2048

#define IFXPSI5S_BAUDRATE_1562500  1562500
#define IFXPSI5S_GCR_CHANNELS_ENABLE_MASK (((1 << IFXPSI5S_NUM_CHANNELS) - 1) << 16)                //0x00FF0000
#define IFXPSI5S_GCR_CHANNEL_TRIGGER_COUNTERS_ENABLE_MASK (((1 << IFXPSI5S_NUM_CHANNELS) - 1) << 8) //0x0000FF00

#define IFXPSI5S_DEFAULT_SLOWCLOCK_FREQ 4000000
#define IFXPSI5S_DEFAULT_FASTCLOCK_FREQ 6000000
#define IFXPSI5S_DEFAULT_TIMESTAMP_FREQ 1000000

/** \brief Channel Id */
typedef enum
{
    IfxPsi5s_ChannelId_0,         /**< \brief Ifx_PSI5S Channel 0 */
    IfxPsi5s_ChannelId_1,         /**< \brief Ifx_PSI5S Channel 1 */
    IfxPsi5s_ChannelId_2,         /**< \brief Ifx_PSI5S Channel 2 */
    IfxPsi5s_ChannelId_3,         /**< \brief Ifx_PSI5S Channel 3 */
    IfxPsi5s_ChannelId_4,         /**< \brief Ifx_PSI5S Channel 4 */
    IfxPsi5s_ChannelId_5,         /**< \brief Ifx_PSI5S Channel 5 */
    IfxPsi5s_ChannelId_6,         /**< \brief Ifx_PSI5S Channel 6 */
    IfxPsi5s_ChannelId_7,         /**< \brief Ifx_PSI5S Channel 7 */
    IfxPsi5s_ChannelId_none = -1  /**< \brief None of the Ifx_PSI5S Channels */
} IfxPsi5s_ChannelId;

#endif /* IFXPSI5S_CFG_H_ */
