/**
 * \file IfxSent_cfg.h
 * \brief Sent on-chip implementation data 
 * \ingroup IfxLld_Sent 
 *
 * \copyright Copyright (c) 2013 Infineon Technologies AG. All rights reserved.
 *
 * $Date: $2013-08-05 13:18:48 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 *
 * \defgroup IfxLld_Sent_Impl Implementation
 * \ingroup IfxLld_Sent
 * \defgroup IfxLld_Sent_Impl_Enumerations Enumerations  
 * \ingroup IfxLld_Sent_Impl
 */

#ifndef IFXSENT_CFG_H
#define IFXSENT_CFG_H

/*******************************************************************************
**                                 Includes                                   **
*******************************************************************************/
#include "Cpu/Std/IfxCpu_Intrinsics.h"
#include "Cpu/Std/IfxCpu.h"
#include "Port/Std/IfxPort.h"
#include "Src/Std/IfxSrc.h"
#include "Scu/Std/IfxScuCcu.h"
#include "Scu/Std/IfxScuWdt.h"
#include "_Reg/IfxSent_bf.h"
#include "_Reg/IfxSent_reg.h"

/*******************************************************************************
**                                 Macros                                     **
*******************************************************************************/
/** \brief Specifies all interrupt events 
 */
#define IFXSENT_CFG_CHANNEL_INTEN (0x1FEDU)
                
/** \brief Specifies the step range for calculating module clock 
 */
#define IFXSENT_CFG_STEP_RANGE (1024)
                
/** \brief Specifies timeout value in transmission 
 */
#define IFXSENT_CFG_TIMEOUT_VALUE ((uint16)0xFFFFU)
                
                

/*******************************************************************************
**                             Enumerations                                   **
*******************************************************************************/
/** \addtogroup IfxLld_Sent_Impl_Enumerations
 * \{ */
/** \brief Specifies SENT channel number  
 */
typedef enum
{
    IfxSent_ChannelId_0 = 0,              /**< \brief Specifies Channel Number 0  */
    IfxSent_ChannelId_1,                       /**< \brief Specifies Channel Number 1  */
    IfxSent_ChannelId_2,                       /**< \brief Specifies Channel Number 2  */
    IfxSent_ChannelId_3,                       /**< \brief Specifies Channel Number 3  */
    IfxSent_ChannelId_4,                       /**< \brief Specifies Channel Number 4  */
    IfxSent_ChannelId_5,                       /**< \brief Specifies Channel Number 5  */
    IfxSent_ChannelId_none = -1            /**< \brief None of the Ifx_SENT Channels */
} IfxSent_ChannelId;

/** \} */ 


#endif /* IFXSENT_CFG_H */

