/**
 * \file IfxVadc_cfg.h
 * \brief VADC on-chip implementation data.
 * \ingroup IfxLld_Vadc
 *
 * \copyright Copyright (c) 2013 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1391.5
 * $Date: $2013-07-01 15:57:29 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */

#ifndef IFXVADC_CFG_H_
#define IFXVADC_CFG_H_

#include <_Reg/IfxVadc_bf.h>
#include <_Reg/IfxVadc_reg.h>
#include <Cpu/Std/IfxCpu_Intrinsics.h>
#include <Src/Std/IfxSrc.h>

#define IFXVADC_NUM_ADC_GROUPS          (4u)

/** \brief Maximum allowed analog frequency	*/
#define IFXVADC_ANALOG_FREQUENCY_MAX    (20000000u)

/** \brief Minimum allowed analog frequency	*/
#define IFXVADC_ANALOG_FREQUENCY_MIN    (500000u)

/** \brief Default analog frequency used in initModuleConfig function	*/
#define IFXVADC_DEFAULT_ANALOG_FREQ     20000000

/** \brief Number of Conversion request Slots	*/
#define IFXVADC_NUMBER_OF_REQUESTSLOTS      3

/** \brief Number of group specific Input Class */
#define IFXVADC_NUMBER_OF_INPUTCLASS 2

/** \brief Maximum number of configurable bitfields in ACCPROT0	 register*/
#define IFXVADC_MAXIMUM_BITFIELDS_IN_ACCPROT0_REGISTER 32

/** \brief Analog converter control configuration values for ANONC field */
#define IFXVADC_ANALOG_CONVERTER_OFF        0
#define IFXVADC_SLOW_STANDBY_MODE       1
#define IFXVADC_FAST_STANDBY_MODE       2
#define IFXVADC_NORMAL_MODE             3

#define IFXVADC_QUEUE_REFILL (1 << IFX_VADC_G_QBUR_QINR0_QBUR0_RF_OFF)
#define IFXVADC_QUEUE_EXT_TRIGGER (1 << IFX_VADC_G_QBUR_QINR0_QBUR0_EXTR_OFF)

extern const uint32 IfxVadc_cfg_srcAddresses[24];


/** \brief VADC Groups */
typedef enum
{
    IfxVadc_GroupId_0        = 0,                           /**< \brief Group 0       */
    IfxVadc_GroupId_1        = 1,                           /**< \brief Group 1       */
    IfxVadc_GroupId_2        = 2,                           /**< \brief Group 2       */
    IfxVadc_GroupId_3        = 3,                           /**< \brief Group 3       */
   // IfxVadc_GroupId_4        = 4,                           /**< \brief Group 4       */
    IfxVadc_GroupId_global0  = 8,                           /**< \brief group global0 */
    IfxVadc_GroupId_global1  = 9                            /**< \brief group global1 */
} IfxVadc_GroupId;

/** \brief VADC Channels */
typedef enum
{
    IfxVadc_ChannelId_0 = 0,                                /**< \brief Channel 0 */
    IfxVadc_ChannelId_1 = 1,                                /**< \brief Channel 1 */
    IfxVadc_ChannelId_2 = 2,                                /**< \brief Channel 2 */
    IfxVadc_ChannelId_3 = 3,                                /**< \brief Channel 3 */
    IfxVadc_ChannelId_4 = 4,                                /**< \brief Channel 4 */
    IfxVadc_ChannelId_5 = 5,                                /**< \brief Channel 5 */
    IfxVadc_ChannelId_6 = 6,                                /**< \brief Channel 6 */
    IfxVadc_ChannelId_7 = 7,                                /**< \brief Channel 7 */
    IfxVadc_ChannelId_8 = 8,                                /**< \brief Channel 0 */
    IfxVadc_ChannelId_9 = 9,                                /**< \brief Channel 1 */
    IfxVadc_ChannelId_10 = 10,                              /**< \brief Channel 2 */
    IfxVadc_ChannelId_11 = 11,                              /**< \brief Channel 3 */
    IfxVadc_ChannelId_12 = 12,                              /**< \brief Channel 4 */
    IfxVadc_ChannelId_13 = 13,                              /**< \brief Channel 5 */
  //  IfxVadc_ChannelId_14 = 14,                              /**< \brief Channel 6 */
  //  IfxVadc_ChannelId_15 = 15                               /**< \brief Channel 7 */
} IfxVadc_ChannelId;


#endif /* IFXADC_CFG_H_ */
