/**
 * \file IfxGpt12_PinMap.h
 * \brief GPT12 I/O map
 * \ingroup IfxLld_Gpt12
 *
 * \copyright Copyright (c) 2013 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1.1
 * $Date: $2013-08-07 08:57:35 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_Gpt12_pinmap GPT12 Pin Mapping
 * \ingroup IfxLld_Gpt12
 */

#ifndef IFXGPT12_PINMAP_H
#define IFXGPT12_PINMAP_H

#include <_Reg/IfxGpt12_reg.h>
#include <_Impl/IfxGpt12_cfg.h>
#include <Port/Std/IfxPort.h>

/** \addtogroup IfxLld_Gpt12_pinmap
 * \{ */

/** \brief CAPIN pin mapping structure */
typedef const struct
{
    Ifx_GPT12  *module;         /**< \brief Base address */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxGpt12_Capin_In;

/** \brief TxEUD pin mapping structure */
typedef const struct
{
    Ifx_GPT12  *module;         /**< \brief Base address */
    uint8       timer;          /**< \brief Timer number */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxGpt12_TxEud_In;

/** \brief TxIN pin mapping structure */
typedef const struct
{
    Ifx_GPT12  *module;         /**< \brief Base address */
    uint8       timer;          /**< \brief Timer number */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxGpt12_TxIn_In;

/** \brief TxOUT pin mapping structure */
typedef const struct
{
    Ifx_GPT12        *module;                            /**< \brief Base address */
    IfxPort_Pin       pin;                               /**< \brief Port pin */
    IfxPort_OutputIdx select;                            /**< \brief Port control code */
} IfxGpt12_TxOut_Out;

IFX_EXTERN IfxGpt12_Capin_In  IfxGpt120_CAPINA_P13_2_IN; /**< \brief GPT120 CAPINA (CAPINA) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T2EUDA_P00_8_IN; /**< \brief GPT120 T2EUDA (T2EUDA) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T2EUDB_P33_6_IN; /**< \brief GPT120 T2EUDB (T2EUDB) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T3EUDA_P02_7_IN; /**< \brief GPT120 T3EUDA (T3EUDA) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T3EUDB_P10_7_IN; /**< \brief GPT120 T3EUDB (T3EUDB) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T4EUDA_P00_9_IN; /**< \brief GPT120 T4EUDA (T4EUDA) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T4EUDB_P33_5_IN; /**< \brief GPT120 T4EUDB (T4EUDB) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T5EUDA_P21_6_IN; /**< \brief GPT120 T5EUDA (T5EUDA) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T5EUDB_P10_1_IN; /**< \brief GPT120 T5EUDB (T5EUDB) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T6EUDA_P20_0_IN; /**< \brief GPT120 T6EUDA (T6EUDA) */
IFX_EXTERN IfxGpt12_TxEud_In  IfxGpt120_T6EUDB_P10_0_IN; /**< \brief GPT120 T6EUDB (T6EUDB) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T2INA_P00_7_IN;  /**< \brief GPT120 T2INA (T2INA) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T2INB_P33_7_IN;  /**< \brief GPT120 T2INB (T2INB) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T3INA_P02_6_IN;  /**< \brief GPT120 T3INA (T3INA) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T3INB_P10_4_IN;  /**< \brief GPT120 T3INB (T3INB) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T4INA_P02_8_IN;  /**< \brief GPT120 T4INA (T4INA) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T4INB_P10_8_IN;  /**< \brief GPT120 T4INB (T4INB) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T5INA_P21_7_IN;  /**< \brief GPT120 T5INA (T5INA) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T5INB_P10_3_IN;  /**< \brief GPT120 T5INB (T5INB) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T6INA_P20_3_IN;  /**< \brief GPT120 T6INA (T6INA) */
IFX_EXTERN IfxGpt12_TxIn_In   IfxGpt120_T6INB_P10_2_IN;  /**< \brief GPT120 T6INB (T6INB) */
IFX_EXTERN IfxGpt12_TxOut_Out IfxGpt120_T3OUT_P10_6_OUT; /**< \brief GPT120 T3OUT (T3OUT) */
IFX_EXTERN IfxGpt12_TxOut_Out IfxGpt120_T3OUT_P21_6_OUT; /**< \brief GPT120 T3OUT (T3OUT) */
IFX_EXTERN IfxGpt12_TxOut_Out IfxGpt120_T6OUT_P10_5_OUT; /**< \brief GPT120 T6OUT (T6OUT) */
IFX_EXTERN IfxGpt12_TxOut_Out IfxGpt120_T6OUT_P21_7_OUT; /**< \brief GPT120 T6OUT (T6OUT) */


IFX_EXTERN void IfxGpt12_configureTxInPin(IfxGpt12_TxIn_In* config, IfxPort_InputMode pinMode);
IFX_EXTERN void IfxGpt12_configureTxEudPin(IfxGpt12_TxEud_In* config, IfxPort_InputMode pinMode);
/** \} */

#endif /* IFXGPT12_PINMAP_H */
