/**
 * \file IfxGtm_PinMap.h
 * \brief GTM I/O map
 * \ingroup IfxLld_Gtm
 *
 * \copyright Copyright (c) 2013 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1.1
 * $Date: $2013-08-07 08:57:37 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_Gtm_pinmap GTM Pin Mapping
 * \ingroup IfxLld_Gtm
 */

#ifndef IFXGTM_PINMAP_H
#define IFXGTM_PINMAP_H

#include <_Reg/IfxGtm_reg.h>
#include <_Impl/IfxGtm_cfg.h>
#include <Port/Std/IfxPort.h>
#include <Gtm/Std/IfxGtmAtom.h>
#include <Gtm/Std/IfxGtmTom.h>
#include <Gtm/Std/IfxGtmTim.h>

/** \addtogroup IfxLld_Gtm_pinmap
 * \{ */

/** \brief CHxSEL register control code */
typedef enum
{
    IfxGtm_ChXSel_a,
    IfxGtm_ChXSel_b,
    IfxGtm_ChXSel_c,
    IfxGtm_ChXSel_d,

    IfxGtm_ChXSel_e,
    IfxGtm_ChXSel_f,
    IfxGtm_ChXSel_g,
    IfxGtm_ChXSel_h,

    IfxGtm_ChXSel_i,
    IfxGtm_ChXSel_j,
    IfxGtm_ChXSel_k,
    IfxGtm_ChXSel_l,

    IfxGtm_ChXSel_m,
    IfxGtm_ChXSel_n,
    IfxGtm_ChXSel_o,
    IfxGtm_ChXSel_p
} IfxGtm_ChXSel;

/** \brief TOUTSEL register control code */
typedef enum
{
    IfxGtm_ToutSel_a,
    IfxGtm_ToutSel_b,
    IfxGtm_ToutSel_c,
    IfxGtm_ToutSel_d
} IfxGtm_ToutSel;

/** \brief TIN pin mapping structure */
typedef const struct
{
    IfxGtmTim     tim;          /**< \brief TIM unit index */

    IfxGtmTim_Ch  channel;      /**< \brief TIM channel index */

    IfxPort_Pin   pin;          /**< \brief Port pin */
    IfxGtm_ChXSel select;       /**< \brief Input multiplexer value */
} IfxGtmTim_TinMap;

/** \brief ATOM TOUT pin mapping structure */
typedef const struct
{
    IfxGtmAtom        atom;         /**< \brief ATOM unit index */

    IfxGtmAtom_Ch     channel;      /**< \brief ATOM channel index */

    IfxGtm_ToutSel    toutSel;      /**< \brief TOUTSEL register control code */

    uint32            toutn;        /**< \brief TOUT number */

    IfxPort_Pin       pin;          /**< \brief Port pin */

    IfxPort_OutputIdx select;       /**< \brief Port control code */
} IfxGtmAtom_ToutMap;

/** \brief Pointer to \ref IfxGtmAtom_ToutMap */
typedef IfxGtmAtom_ToutMap *IfxGtmAtom_ToutMapP;

/** \brief TOM TOUT pin mapping structure */
typedef const struct
{
    IfxGtmTom         tom;          /**< \brief TOM unit index */

    IfxGtmTom_Ch      channel;      /**< \brief TOM channel index */

    IfxGtm_ToutSel    toutSel;      /**< \brief TOUTSEL register control code - verknpft channel mit ausgangspin*/

    uint32            toutn;        /**< \brief TOUT number */

    IfxPort_Pin       pin;          /**< \brief Port pin */

    IfxPort_OutputIdx select;       /**< \brief Port control code */
} IfxGtmTom_ToutMap;

/** \brief GTM Clock Output */
typedef const struct
{
    Ifx_GTM          *module;   /**< \brief Base address */
    IfxPort_Pin       pin;      /**< \brief Port pin */
    IfxPort_OutputIdx select;   /**< \brief Port control code */
} IfxGtm_Clk_Out;

/** \brief Pointer to \ref IfxGtmTom_ToutMap */
typedef IfxGtmTom_ToutMap *IfxGtmTom_ToutMapP;

IFX_EXTERN void IfxGtm_PinMap_setTimTin(IfxGtmTim_TinMap *config, IfxPort_InputMode inputMode);
IFX_EXTERN void IfxGtm_PinMap_setAtomTout(IfxGtmAtom_ToutMap *config, IfxPort_OutputMode outputMode, IfxPort_PadDriver padDriver);
IFX_EXTERN void IfxGtm_PinMap_setTomTout(IfxGtmTom_ToutMap *config, IfxPort_OutputMode outputMode, IfxPort_PadDriver padDriver);

IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_0_TOUT0_P02_0;     /**< \brief IfxGtm_ATOM0_0_TOUT0_P02_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_0_TOUT109_P10_7;   /**< \brief IfxGtm_ATOM0_0_TOUT109_P10_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_0_TOUT48_P22_1;    /**< \brief IfxGtm_ATOM0_0_TOUT48_P22_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_0_TOUT53_P21_2;    /**< \brief IfxGtm_ATOM0_0_TOUT53_P21_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_0_TOUT85_P14_5;    /**< \brief IfxGtm_ATOM0_0_TOUT85_P14_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_0_TOUT8_P02_8;     /**< \brief IfxGtm_ATOM0_0_TOUT8_P02_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_0_TOUT9_P00_0;     /**< \brief IfxGtm_ATOM0_0_TOUT9_P00_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT103_P10_1;   /**< \brief IfxGtm_ATOM0_1_TOUT103_P10_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT10_P00_1;    /**< \brief IfxGtm_ATOM0_1_TOUT10_P00_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT11_P00_2;    /**< \brief IfxGtm_ATOM0_1_TOUT11_P00_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT1_P02_1;     /**< \brief IfxGtm_ATOM0_1_TOUT1_P02_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT31_P33_9;    /**< \brief IfxGtm_ATOM0_1_TOUT31_P33_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT47_P22_0;    /**< \brief IfxGtm_ATOM0_1_TOUT47_P22_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT54_P21_3;    /**< \brief IfxGtm_ATOM0_1_TOUT54_P21_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_1_TOUT84_P14_4;    /**< \brief IfxGtm_ATOM0_1_TOUT84_P14_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT104_P10_2;   /**< \brief IfxGtm_ATOM0_2_TOUT104_P10_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT107_P10_5;   /**< \brief IfxGtm_ATOM0_2_TOUT107_P10_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT12_P00_3;    /**< \brief IfxGtm_ATOM0_2_TOUT12_P00_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT2_P02_2;     /**< \brief IfxGtm_ATOM0_2_TOUT2_P02_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT33_P33_11;   /**< \brief IfxGtm_ATOM0_2_TOUT33_P33_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT46_P23_5;    /**< \brief IfxGtm_ATOM0_2_TOUT46_P23_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT55_P21_4;    /**< \brief IfxGtm_ATOM0_2_TOUT55_P21_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_2_TOUT83_P14_3;    /**< \brief IfxGtm_ATOM0_2_TOUT83_P14_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT105_P10_3;   /**< \brief IfxGtm_ATOM0_3_TOUT105_P10_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT108_P10_6;   /**< \brief IfxGtm_ATOM0_3_TOUT108_P10_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT13_P00_4;    /**< \brief IfxGtm_ATOM0_3_TOUT13_P00_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT38_P32_2;    /**< \brief IfxGtm_ATOM0_3_TOUT38_P32_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT3_P02_3;     /**< \brief IfxGtm_ATOM0_3_TOUT3_P02_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT49_P22_2;    /**< \brief IfxGtm_ATOM0_3_TOUT49_P22_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT56_P21_5;    /**< \brief IfxGtm_ATOM0_3_TOUT56_P21_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT60_P20_1;    /**< \brief IfxGtm_ATOM0_3_TOUT60_P20_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_3_TOUT82_P14_2;    /**< \brief IfxGtm_ATOM0_3_TOUT82_P14_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT102_P10_0;   /**< \brief IfxGtm_ATOM0_4_TOUT102_P10_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT14_P00_5;    /**< \brief IfxGtm_ATOM0_4_TOUT14_P00_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT39_P32_3;    /**< \brief IfxGtm_ATOM0_4_TOUT39_P32_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT4_P02_4;     /**< \brief IfxGtm_ATOM0_4_TOUT4_P02_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT50_P22_3;    /**< \brief IfxGtm_ATOM0_4_TOUT50_P22_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT57_P21_6;    /**< \brief IfxGtm_ATOM0_4_TOUT57_P21_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT61_P20_3;    /**< \brief IfxGtm_ATOM0_4_TOUT61_P20_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_4_TOUT81_P14_1;    /**< \brief IfxGtm_ATOM0_4_TOUT81_P14_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_5_TOUT110_P10_8;   /**< \brief IfxGtm_ATOM0_5_TOUT110_P10_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_5_TOUT15_P00_6;    /**< \brief IfxGtm_ATOM0_5_TOUT15_P00_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_5_TOUT23_P33_1;    /**< \brief IfxGtm_ATOM0_5_TOUT23_P33_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_5_TOUT40_P32_4;    /**< \brief IfxGtm_ATOM0_5_TOUT40_P32_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_5_TOUT41_P23_0;    /**< \brief IfxGtm_ATOM0_5_TOUT41_P23_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_5_TOUT58_P21_7;    /**< \brief IfxGtm_ATOM0_5_TOUT58_P21_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_5_TOUT5_P02_5;     /**< \brief IfxGtm_ATOM0_5_TOUT5_P02_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_6_TOUT106_P10_4;   /**< \brief IfxGtm_ATOM0_6_TOUT106_P10_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_6_TOUT16_P00_7;    /**< \brief IfxGtm_ATOM0_6_TOUT16_P00_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_6_TOUT24_P33_2;    /**< \brief IfxGtm_ATOM0_6_TOUT24_P33_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_6_TOUT42_P23_1;    /**< \brief IfxGtm_ATOM0_6_TOUT42_P23_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_6_TOUT59_P20_0;    /**< \brief IfxGtm_ATOM0_6_TOUT59_P20_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_6_TOUT6_P02_6;     /**< \brief IfxGtm_ATOM0_6_TOUT6_P02_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_7_TOUT17_P00_8;    /**< \brief IfxGtm_ATOM0_7_TOUT17_P00_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_7_TOUT25_P33_3;    /**< \brief IfxGtm_ATOM0_7_TOUT25_P33_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_7_TOUT45_P23_4;    /**< \brief IfxGtm_ATOM0_7_TOUT45_P23_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_7_TOUT64_P20_8;    /**< \brief IfxGtm_ATOM0_7_TOUT64_P20_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM0_7_TOUT7_P02_7;     /**< \brief IfxGtm_ATOM0_7_TOUT7_P02_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT0_P02_0;     /**< \brief IfxGtm_ATOM1_0_TOUT0_P02_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT109_P10_7;   /**< \brief IfxGtm_ATOM1_0_TOUT109_P10_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT48_P22_1;    /**< \brief IfxGtm_ATOM1_0_TOUT48_P22_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT53_P21_2;    /**< \brief IfxGtm_ATOM1_0_TOUT53_P21_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT68_P20_12;   /**< \brief IfxGtm_ATOM1_0_TOUT68_P20_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT76_P15_5;    /**< \brief IfxGtm_ATOM1_0_TOUT76_P15_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT77_P15_6;    /**< \brief IfxGtm_ATOM1_0_TOUT77_P15_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT87_P14_7;    /**< \brief IfxGtm_ATOM1_0_TOUT87_P14_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT8_P02_8;     /**< \brief IfxGtm_ATOM1_0_TOUT8_P02_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_0_TOUT9_P00_0;     /**< \brief IfxGtm_ATOM1_0_TOUT9_P00_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT103_P10_1;   /**< \brief IfxGtm_ATOM1_1_TOUT103_P10_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT10_P00_1;    /**< \brief IfxGtm_ATOM1_1_TOUT10_P00_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT11_P00_2;    /**< \brief IfxGtm_ATOM1_1_TOUT11_P00_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT1_P02_1;     /**< \brief IfxGtm_ATOM1_1_TOUT1_P02_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT31_P33_9;    /**< \brief IfxGtm_ATOM1_1_TOUT31_P33_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT47_P22_0;    /**< \brief IfxGtm_ATOM1_1_TOUT47_P22_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT54_P21_3;    /**< \brief IfxGtm_ATOM1_1_TOUT54_P21_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT69_P20_13;   /**< \brief IfxGtm_ATOM1_1_TOUT69_P20_13 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT78_P15_7;    /**< \brief IfxGtm_ATOM1_1_TOUT78_P15_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT79_P15_8;    /**< \brief IfxGtm_ATOM1_1_TOUT79_P15_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_1_TOUT86_P14_6;    /**< \brief IfxGtm_ATOM1_1_TOUT86_P14_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT104_P10_2;   /**< \brief IfxGtm_ATOM1_2_TOUT104_P10_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT107_P10_5;   /**< \brief IfxGtm_ATOM1_2_TOUT107_P10_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT12_P00_3;    /**< \brief IfxGtm_ATOM1_2_TOUT12_P00_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT2_P02_2;     /**< \brief IfxGtm_ATOM1_2_TOUT2_P02_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT33_P33_11;   /**< \brief IfxGtm_ATOM1_2_TOUT33_P33_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT46_P23_5;    /**< \brief IfxGtm_ATOM1_2_TOUT46_P23_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT55_P21_4;    /**< \brief IfxGtm_ATOM1_2_TOUT55_P21_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT70_P20_14;   /**< \brief IfxGtm_ATOM1_2_TOUT70_P20_14 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_2_TOUT80_P14_0;    /**< \brief IfxGtm_ATOM1_2_TOUT80_P14_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT105_P10_3;   /**< \brief IfxGtm_ATOM1_3_TOUT105_P10_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT108_P10_6;   /**< \brief IfxGtm_ATOM1_3_TOUT108_P10_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT13_P00_4;    /**< \brief IfxGtm_ATOM1_3_TOUT13_P00_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT38_P32_2;    /**< \brief IfxGtm_ATOM1_3_TOUT38_P32_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT3_P02_3;     /**< \brief IfxGtm_ATOM1_3_TOUT3_P02_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT49_P22_2;    /**< \brief IfxGtm_ATOM1_3_TOUT49_P22_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT56_P21_5;    /**< \brief IfxGtm_ATOM1_3_TOUT56_P21_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT60_P20_1;    /**< \brief IfxGtm_ATOM1_3_TOUT60_P20_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_3_TOUT71_P15_0;    /**< \brief IfxGtm_ATOM1_3_TOUT71_P15_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT102_P10_0;   /**< \brief IfxGtm_ATOM1_4_TOUT102_P10_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT14_P00_5;    /**< \brief IfxGtm_ATOM1_4_TOUT14_P00_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT39_P32_3;    /**< \brief IfxGtm_ATOM1_4_TOUT39_P32_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT4_P02_4;     /**< \brief IfxGtm_ATOM1_4_TOUT4_P02_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT50_P22_3;    /**< \brief IfxGtm_ATOM1_4_TOUT50_P22_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT57_P21_6;    /**< \brief IfxGtm_ATOM1_4_TOUT57_P21_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT61_P20_3;    /**< \brief IfxGtm_ATOM1_4_TOUT61_P20_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_4_TOUT72_P15_1;    /**< \brief IfxGtm_ATOM1_4_TOUT72_P15_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT110_P10_8;   /**< \brief IfxGtm_ATOM1_5_TOUT110_P10_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT15_P00_6;    /**< \brief IfxGtm_ATOM1_5_TOUT15_P00_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT23_P33_1;    /**< \brief IfxGtm_ATOM1_5_TOUT23_P33_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT40_P32_4;    /**< \brief IfxGtm_ATOM1_5_TOUT40_P32_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT41_P23_0;    /**< \brief IfxGtm_ATOM1_5_TOUT41_P23_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT58_P21_7;    /**< \brief IfxGtm_ATOM1_5_TOUT58_P21_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT5_P02_5;     /**< \brief IfxGtm_ATOM1_5_TOUT5_P02_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT65_P20_9;    /**< \brief IfxGtm_ATOM1_5_TOUT65_P20_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_5_TOUT73_P15_2;    /**< \brief IfxGtm_ATOM1_5_TOUT73_P15_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT106_P10_4;   /**< \brief IfxGtm_ATOM1_6_TOUT106_P10_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT16_P00_7;    /**< \brief IfxGtm_ATOM1_6_TOUT16_P00_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT24_P33_2;    /**< \brief IfxGtm_ATOM1_6_TOUT24_P33_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT42_P23_1;    /**< \brief IfxGtm_ATOM1_6_TOUT42_P23_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT59_P20_0;    /**< \brief IfxGtm_ATOM1_6_TOUT59_P20_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT66_P20_10;   /**< \brief IfxGtm_ATOM1_6_TOUT66_P20_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT6_P02_6;     /**< \brief IfxGtm_ATOM1_6_TOUT6_P02_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_6_TOUT74_P15_3;    /**< \brief IfxGtm_ATOM1_6_TOUT74_P15_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_7_TOUT17_P00_8;    /**< \brief IfxGtm_ATOM1_7_TOUT17_P00_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_7_TOUT25_P33_3;    /**< \brief IfxGtm_ATOM1_7_TOUT25_P33_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_7_TOUT45_P23_4;    /**< \brief IfxGtm_ATOM1_7_TOUT45_P23_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_7_TOUT67_P20_11;   /**< \brief IfxGtm_ATOM1_7_TOUT67_P20_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_7_TOUT75_P15_4;    /**< \brief IfxGtm_ATOM1_7_TOUT75_P15_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM1_7_TOUT7_P02_7;     /**< \brief IfxGtm_ATOM1_7_TOUT7_P02_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_0_TOUT18_P00_9;    /**< \brief IfxGtm_ATOM2_0_TOUT18_P00_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_0_TOUT26_P33_4;    /**< \brief IfxGtm_ATOM2_0_TOUT26_P33_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_0_TOUT32_P33_10;   /**< \brief IfxGtm_ATOM2_0_TOUT32_P33_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_0_TOUT68_P20_12;   /**< \brief IfxGtm_ATOM2_0_TOUT68_P20_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_0_TOUT94_P13_3;    /**< \brief IfxGtm_ATOM2_0_TOUT94_P13_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_1_TOUT19_P00_10;   /**< \brief IfxGtm_ATOM2_1_TOUT19_P00_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_1_TOUT27_P33_5;    /**< \brief IfxGtm_ATOM2_1_TOUT27_P33_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_1_TOUT43_P23_2;    /**< \brief IfxGtm_ATOM2_1_TOUT43_P23_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_1_TOUT69_P20_13;   /**< \brief IfxGtm_ATOM2_1_TOUT69_P20_13 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_1_TOUT95_P11_2;    /**< \brief IfxGtm_ATOM2_1_TOUT95_P11_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_2_TOUT20_P00_11;   /**< \brief IfxGtm_ATOM2_2_TOUT20_P00_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_2_TOUT28_P33_6;    /**< \brief IfxGtm_ATOM2_2_TOUT28_P33_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_2_TOUT44_P23_3;    /**< \brief IfxGtm_ATOM2_2_TOUT44_P23_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_2_TOUT70_P20_14;   /**< \brief IfxGtm_ATOM2_2_TOUT70_P20_14 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_2_TOUT88_P14_8;    /**< \brief IfxGtm_ATOM2_2_TOUT88_P14_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_2_TOUT96_P11_3;    /**< \brief IfxGtm_ATOM2_2_TOUT96_P11_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_3_TOUT21_P00_12;   /**< \brief IfxGtm_ATOM2_3_TOUT21_P00_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_3_TOUT29_P33_7;    /**< \brief IfxGtm_ATOM2_3_TOUT29_P33_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_3_TOUT71_P15_0;    /**< \brief IfxGtm_ATOM2_3_TOUT71_P15_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_3_TOUT89_P14_9;    /**< \brief IfxGtm_ATOM2_3_TOUT89_P14_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_3_TOUT97_P11_6;    /**< \brief IfxGtm_ATOM2_3_TOUT97_P11_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_4_TOUT22_P33_0;    /**< \brief IfxGtm_ATOM2_4_TOUT22_P33_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_4_TOUT30_P33_8;    /**< \brief IfxGtm_ATOM2_4_TOUT30_P33_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_4_TOUT34_P33_12;   /**< \brief IfxGtm_ATOM2_4_TOUT34_P33_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_4_TOUT51_P21_0;    /**< \brief IfxGtm_ATOM2_4_TOUT51_P21_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_4_TOUT72_P15_1;    /**< \brief IfxGtm_ATOM2_4_TOUT72_P15_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_4_TOUT90_P14_10;   /**< \brief IfxGtm_ATOM2_4_TOUT90_P14_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_4_TOUT98_P11_9;    /**< \brief IfxGtm_ATOM2_4_TOUT98_P11_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_5_TOUT35_P33_13;   /**< \brief IfxGtm_ATOM2_5_TOUT35_P33_13 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_5_TOUT52_P21_1;    /**< \brief IfxGtm_ATOM2_5_TOUT52_P21_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_5_TOUT65_P20_9;    /**< \brief IfxGtm_ATOM2_5_TOUT65_P20_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_5_TOUT73_P15_2;    /**< \brief IfxGtm_ATOM2_5_TOUT73_P15_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_5_TOUT91_P13_0;    /**< \brief IfxGtm_ATOM2_5_TOUT91_P13_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_5_TOUT99_P11_10;   /**< \brief IfxGtm_ATOM2_5_TOUT99_P11_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_6_TOUT100_P11_11;  /**< \brief IfxGtm_ATOM2_6_TOUT100_P11_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_6_TOUT36_P32_0;    /**< \brief IfxGtm_ATOM2_6_TOUT36_P32_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_6_TOUT62_P20_6;    /**< \brief IfxGtm_ATOM2_6_TOUT62_P20_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_6_TOUT66_P20_10;   /**< \brief IfxGtm_ATOM2_6_TOUT66_P20_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_6_TOUT74_P15_3;    /**< \brief IfxGtm_ATOM2_6_TOUT74_P15_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_6_TOUT92_P13_1;    /**< \brief IfxGtm_ATOM2_6_TOUT92_P13_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_7_TOUT101_P11_12;  /**< \brief IfxGtm_ATOM2_7_TOUT101_P11_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_7_TOUT63_P20_7;    /**< \brief IfxGtm_ATOM2_7_TOUT63_P20_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_7_TOUT64_P20_8;    /**< \brief IfxGtm_ATOM2_7_TOUT64_P20_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_7_TOUT67_P20_11;   /**< \brief IfxGtm_ATOM2_7_TOUT67_P20_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_7_TOUT75_P15_4;    /**< \brief IfxGtm_ATOM2_7_TOUT75_P15_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM2_7_TOUT93_P13_2;    /**< \brief IfxGtm_ATOM2_7_TOUT93_P13_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT18_P00_9;    /**< \brief IfxGtm_ATOM3_0_TOUT18_P00_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT26_P33_4;    /**< \brief IfxGtm_ATOM3_0_TOUT26_P33_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT32_P33_10;   /**< \brief IfxGtm_ATOM3_0_TOUT32_P33_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT76_P15_5;    /**< \brief IfxGtm_ATOM3_0_TOUT76_P15_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT77_P15_6;    /**< \brief IfxGtm_ATOM3_0_TOUT77_P15_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT85_P14_5;    /**< \brief IfxGtm_ATOM3_0_TOUT85_P14_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT87_P14_7;    /**< \brief IfxGtm_ATOM3_0_TOUT87_P14_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_0_TOUT94_P13_3;    /**< \brief IfxGtm_ATOM3_0_TOUT94_P13_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT19_P00_10;   /**< \brief IfxGtm_ATOM3_1_TOUT19_P00_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT27_P33_5;    /**< \brief IfxGtm_ATOM3_1_TOUT27_P33_5 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT43_P23_2;    /**< \brief IfxGtm_ATOM3_1_TOUT43_P23_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT78_P15_7;    /**< \brief IfxGtm_ATOM3_1_TOUT78_P15_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT79_P15_8;    /**< \brief IfxGtm_ATOM3_1_TOUT79_P15_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT84_P14_4;    /**< \brief IfxGtm_ATOM3_1_TOUT84_P14_4 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT86_P14_6;    /**< \brief IfxGtm_ATOM3_1_TOUT86_P14_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_1_TOUT95_P11_2;    /**< \brief IfxGtm_ATOM3_1_TOUT95_P11_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_2_TOUT20_P00_11;   /**< \brief IfxGtm_ATOM3_2_TOUT20_P00_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_2_TOUT28_P33_6;    /**< \brief IfxGtm_ATOM3_2_TOUT28_P33_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_2_TOUT44_P23_3;    /**< \brief IfxGtm_ATOM3_2_TOUT44_P23_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_2_TOUT80_P14_0;    /**< \brief IfxGtm_ATOM3_2_TOUT80_P14_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_2_TOUT83_P14_3;    /**< \brief IfxGtm_ATOM3_2_TOUT83_P14_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_2_TOUT88_P14_8;    /**< \brief IfxGtm_ATOM3_2_TOUT88_P14_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_2_TOUT96_P11_3;    /**< \brief IfxGtm_ATOM3_2_TOUT96_P11_3 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_3_TOUT21_P00_12;   /**< \brief IfxGtm_ATOM3_3_TOUT21_P00_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_3_TOUT29_P33_7;    /**< \brief IfxGtm_ATOM3_3_TOUT29_P33_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_3_TOUT82_P14_2;    /**< \brief IfxGtm_ATOM3_3_TOUT82_P14_2 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_3_TOUT89_P14_9;    /**< \brief IfxGtm_ATOM3_3_TOUT89_P14_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_3_TOUT97_P11_6;    /**< \brief IfxGtm_ATOM3_3_TOUT97_P11_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_4_TOUT22_P33_0;    /**< \brief IfxGtm_ATOM3_4_TOUT22_P33_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_4_TOUT30_P33_8;    /**< \brief IfxGtm_ATOM3_4_TOUT30_P33_8 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_4_TOUT34_P33_12;   /**< \brief IfxGtm_ATOM3_4_TOUT34_P33_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_4_TOUT51_P21_0;    /**< \brief IfxGtm_ATOM3_4_TOUT51_P21_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_4_TOUT81_P14_1;    /**< \brief IfxGtm_ATOM3_4_TOUT81_P14_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_4_TOUT90_P14_10;   /**< \brief IfxGtm_ATOM3_4_TOUT90_P14_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_4_TOUT98_P11_9;    /**< \brief IfxGtm_ATOM3_4_TOUT98_P11_9 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_5_TOUT35_P33_13;   /**< \brief IfxGtm_ATOM3_5_TOUT35_P33_13 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_5_TOUT52_P21_1;    /**< \brief IfxGtm_ATOM3_5_TOUT52_P21_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_5_TOUT91_P13_0;    /**< \brief IfxGtm_ATOM3_5_TOUT91_P13_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_5_TOUT99_P11_10;   /**< \brief IfxGtm_ATOM3_5_TOUT99_P11_10 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_6_TOUT100_P11_11;  /**< \brief IfxGtm_ATOM3_6_TOUT100_P11_11 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_6_TOUT36_P32_0;    /**< \brief IfxGtm_ATOM3_6_TOUT36_P32_0 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_6_TOUT62_P20_6;    /**< \brief IfxGtm_ATOM3_6_TOUT62_P20_6 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_6_TOUT92_P13_1;    /**< \brief IfxGtm_ATOM3_6_TOUT92_P13_1 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_7_TOUT101_P11_12;  /**< \brief IfxGtm_ATOM3_7_TOUT101_P11_12 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_7_TOUT63_P20_7;    /**< \brief IfxGtm_ATOM3_7_TOUT63_P20_7 */
IFX_EXTERN IfxGtmAtom_ToutMap IfxGtm_ATOM3_7_TOUT93_P13_2;    /**< \brief IfxGtm_ATOM3_7_TOUT93_P13_2 */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN0_P02_0_IN;    /**< \brief IfxGtm_TIM0_0_TIN0_P02_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN109_P10_7_IN;  /**< \brief IfxGtm_TIM0_0_TIN109_P10_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN18_P00_9_IN;   /**< \brief IfxGtm_TIM0_0_TIN18_P00_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN26_P33_4_IN;   /**< \brief IfxGtm_TIM0_0_TIN26_P33_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN32_P33_10_IN;  /**< \brief IfxGtm_TIM0_0_TIN32_P33_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN34_P33_12_IN;  /**< \brief IfxGtm_TIM0_0_TIN34_P33_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN48_P22_1_IN;   /**< \brief IfxGtm_TIM0_0_TIN48_P22_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN53_P21_2_IN;   /**< \brief IfxGtm_TIM0_0_TIN53_P21_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN77_P15_6_IN;   /**< \brief IfxGtm_TIM0_0_TIN77_P15_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN85_P14_5_IN;   /**< \brief IfxGtm_TIM0_0_TIN85_P14_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN87_P14_7_IN;   /**< \brief IfxGtm_TIM0_0_TIN87_P14_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN8_P02_8_IN;    /**< \brief IfxGtm_TIM0_0_TIN8_P02_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_0_TIN9_P00_0_IN;    /**< \brief IfxGtm_TIM0_0_TIN9_P00_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN103_P10_1_IN;  /**< \brief IfxGtm_TIM0_1_TIN103_P10_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN10_P00_1_IN;   /**< \brief IfxGtm_TIM0_1_TIN10_P00_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN11_P00_2_IN;   /**< \brief IfxGtm_TIM0_1_TIN11_P00_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN19_P00_10_IN;  /**< \brief IfxGtm_TIM0_1_TIN19_P00_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN1_P02_1_IN;    /**< \brief IfxGtm_TIM0_1_TIN1_P02_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN27_P33_5_IN;   /**< \brief IfxGtm_TIM0_1_TIN27_P33_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN31_P33_9_IN;   /**< \brief IfxGtm_TIM0_1_TIN31_P33_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN35_P33_13_IN;  /**< \brief IfxGtm_TIM0_1_TIN35_P33_13_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN47_P22_0_IN;   /**< \brief IfxGtm_TIM0_1_TIN47_P22_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN54_P21_3_IN;   /**< \brief IfxGtm_TIM0_1_TIN54_P21_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN78_P15_7_IN;   /**< \brief IfxGtm_TIM0_1_TIN78_P15_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_1_TIN86_P14_6_IN;   /**< \brief IfxGtm_TIM0_1_TIN86_P14_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN104_P10_2_IN;  /**< \brief IfxGtm_TIM0_2_TIN104_P10_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN107_P10_5_IN;  /**< \brief IfxGtm_TIM0_2_TIN107_P10_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN20_P00_11_IN;  /**< \brief IfxGtm_TIM0_2_TIN20_P00_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN28_P33_6_IN;   /**< \brief IfxGtm_TIM0_2_TIN28_P33_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN2_P02_2_IN;    /**< \brief IfxGtm_TIM0_2_TIN2_P02_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN33_P33_11_IN;  /**< \brief IfxGtm_TIM0_2_TIN33_P33_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN36_P32_0_IN;   /**< \brief IfxGtm_TIM0_2_TIN36_P32_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN46_P23_5_IN;   /**< \brief IfxGtm_TIM0_2_TIN46_P23_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN55_P21_4_IN;   /**< \brief IfxGtm_TIM0_2_TIN55_P21_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_2_TIN79_P15_8_IN;   /**< \brief IfxGtm_TIM0_2_TIN79_P15_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN105_P10_3_IN;  /**< \brief IfxGtm_TIM0_3_TIN105_P10_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN108_P10_6_IN;  /**< \brief IfxGtm_TIM0_3_TIN108_P10_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN21_P00_12_IN;  /**< \brief IfxGtm_TIM0_3_TIN21_P00_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN29_P33_7_IN;   /**< \brief IfxGtm_TIM0_3_TIN29_P33_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN38_P32_2_IN;   /**< \brief IfxGtm_TIM0_3_TIN38_P32_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN3_P02_3_IN;    /**< \brief IfxGtm_TIM0_3_TIN3_P02_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN49_P22_2_IN;   /**< \brief IfxGtm_TIM0_3_TIN49_P22_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN51_P21_0_IN;   /**< \brief IfxGtm_TIM0_3_TIN51_P21_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN56_P21_5_IN;   /**< \brief IfxGtm_TIM0_3_TIN56_P21_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN60_P20_1_IN;   /**< \brief IfxGtm_TIM0_3_TIN60_P20_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_3_TIN80_P14_0_IN;   /**< \brief IfxGtm_TIM0_3_TIN80_P14_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN102_P10_0_IN;  /**< \brief IfxGtm_TIM0_4_TIN102_P10_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN22_P33_0_IN;   /**< \brief IfxGtm_TIM0_4_TIN22_P33_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN30_P33_8_IN;   /**< \brief IfxGtm_TIM0_4_TIN30_P33_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN39_P32_3_IN;   /**< \brief IfxGtm_TIM0_4_TIN39_P32_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN4_P02_4_IN;    /**< \brief IfxGtm_TIM0_4_TIN4_P02_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN50_P22_3_IN;   /**< \brief IfxGtm_TIM0_4_TIN50_P22_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN52_P21_1_IN;   /**< \brief IfxGtm_TIM0_4_TIN52_P21_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN57_P21_6_IN;   /**< \brief IfxGtm_TIM0_4_TIN57_P21_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN61_P20_3_IN;   /**< \brief IfxGtm_TIM0_4_TIN61_P20_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_4_TIN81_P14_1_IN;   /**< \brief IfxGtm_TIM0_4_TIN81_P14_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_5_TIN110_P10_8_IN;  /**< \brief IfxGtm_TIM0_5_TIN110_P10_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_5_TIN23_P33_1_IN;   /**< \brief IfxGtm_TIM0_5_TIN23_P33_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_5_TIN40_P32_4_IN;   /**< \brief IfxGtm_TIM0_5_TIN40_P32_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_5_TIN41_P23_0_IN;   /**< \brief IfxGtm_TIM0_5_TIN41_P23_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_5_TIN58_P21_7_IN;   /**< \brief IfxGtm_TIM0_5_TIN58_P21_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_5_TIN5_P02_5_IN;    /**< \brief IfxGtm_TIM0_5_TIN5_P02_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_5_TIN82_P14_2_IN;   /**< \brief IfxGtm_TIM0_5_TIN82_P14_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN106_P10_4_IN;  /**< \brief IfxGtm_TIM0_6_TIN106_P10_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN24_P33_2_IN;   /**< \brief IfxGtm_TIM0_6_TIN24_P33_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN42_P23_1_IN;   /**< \brief IfxGtm_TIM0_6_TIN42_P23_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN43_P23_2_IN;   /**< \brief IfxGtm_TIM0_6_TIN43_P23_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN59_P20_0_IN;   /**< \brief IfxGtm_TIM0_6_TIN59_P20_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN62_P20_6_IN;   /**< \brief IfxGtm_TIM0_6_TIN62_P20_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN62_P20_6_IN;   /**< \brief IfxGtm_TIM0_6_TIN62_P20_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_6_TIN83_P14_3_IN;   /**< \brief IfxGtm_TIM0_6_TIN83_P14_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_7_TIN25_P33_3_IN;   /**< \brief IfxGtm_TIM0_7_TIN25_P33_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_7_TIN44_P23_3_IN;   /**< \brief IfxGtm_TIM0_7_TIN44_P23_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_7_TIN45_P23_4_IN;   /**< \brief IfxGtm_TIM0_7_TIN45_P23_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_7_TIN63_P20_7_IN;   /**< \brief IfxGtm_TIM0_7_TIN63_P20_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_7_TIN64_P20_8_IN;   /**< \brief IfxGtm_TIM0_7_TIN64_P20_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_7_TIN7_P02_7_IN;    /**< \brief IfxGtm_TIM0_7_TIN7_P02_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM0_7_TIN84_P14_4_IN;   /**< \brief IfxGtm_TIM0_7_TIN84_P14_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN0_P02_0_IN;    /**< \brief IfxGtm_TIM1_0_TIN0_P02_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN109_P10_7_IN;  /**< \brief IfxGtm_TIM1_0_TIN109_P10_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN18_P00_9_IN;   /**< \brief IfxGtm_TIM1_0_TIN18_P00_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN26_P33_4_IN;   /**< \brief IfxGtm_TIM1_0_TIN26_P33_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN32_P33_10_IN;  /**< \brief IfxGtm_TIM1_0_TIN32_P33_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN48_P22_1_IN;   /**< \brief IfxGtm_TIM1_0_TIN48_P22_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN53_P21_2_IN;   /**< \brief IfxGtm_TIM1_0_TIN53_P21_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN68_P20_12_IN;  /**< \brief IfxGtm_TIM1_0_TIN68_P20_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN76_P15_5_IN;   /**< \brief IfxGtm_TIM1_0_TIN76_P15_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN77_P15_6_IN;   /**< \brief IfxGtm_TIM1_0_TIN77_P15_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN85_P14_5_IN;   /**< \brief IfxGtm_TIM1_0_TIN85_P14_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN87_P14_7_IN;   /**< \brief IfxGtm_TIM1_0_TIN87_P14_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_0_TIN94_P13_3_IN;   /**< \brief IfxGtm_TIM1_0_TIN94_P13_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN103_P10_1_IN;  /**< \brief IfxGtm_TIM1_1_TIN103_P10_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN19_P00_10_IN;  /**< \brief IfxGtm_TIM1_1_TIN19_P00_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN1_P02_1_IN;    /**< \brief IfxGtm_TIM1_1_TIN1_P02_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN27_P33_5_IN;   /**< \brief IfxGtm_TIM1_1_TIN27_P33_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN31_P33_9_IN;   /**< \brief IfxGtm_TIM1_1_TIN31_P33_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN47_P22_0_IN;   /**< \brief IfxGtm_TIM1_1_TIN47_P22_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN54_P21_3_IN;   /**< \brief IfxGtm_TIM1_1_TIN54_P21_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN69_P20_13_IN;  /**< \brief IfxGtm_TIM1_1_TIN69_P20_13_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN78_P15_7_IN;   /**< \brief IfxGtm_TIM1_1_TIN78_P15_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN86_P14_6_IN;   /**< \brief IfxGtm_TIM1_1_TIN86_P14_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_1_TIN95_P11_2_IN;   /**< \brief IfxGtm_TIM1_1_TIN95_P11_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN104_P10_2_IN;  /**< \brief IfxGtm_TIM1_2_TIN104_P10_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN107_P10_5_IN;  /**< \brief IfxGtm_TIM1_2_TIN107_P10_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN12_P00_3_IN;   /**< \brief IfxGtm_TIM1_2_TIN12_P00_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN20_P00_11_IN;  /**< \brief IfxGtm_TIM1_2_TIN20_P00_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN28_P33_6_IN;   /**< \brief IfxGtm_TIM1_2_TIN28_P33_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN2_P02_2_IN;    /**< \brief IfxGtm_TIM1_2_TIN2_P02_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN33_P33_11_IN;  /**< \brief IfxGtm_TIM1_2_TIN33_P33_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN46_P23_5_IN;   /**< \brief IfxGtm_TIM1_2_TIN46_P23_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN55_P21_4_IN;   /**< \brief IfxGtm_TIM1_2_TIN55_P21_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN70_P20_14_IN;  /**< \brief IfxGtm_TIM1_2_TIN70_P20_14_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN79_P15_8_IN;   /**< \brief IfxGtm_TIM1_2_TIN79_P15_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_2_TIN96_P11_3_IN;   /**< \brief IfxGtm_TIM1_2_TIN96_P11_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN105_P10_3_IN;  /**< \brief IfxGtm_TIM1_3_TIN105_P10_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN108_P10_6_IN;  /**< \brief IfxGtm_TIM1_3_TIN108_P10_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN13_P00_4_IN;   /**< \brief IfxGtm_TIM1_3_TIN13_P00_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN21_P00_12_IN;  /**< \brief IfxGtm_TIM1_3_TIN21_P00_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN29_P33_7_IN;   /**< \brief IfxGtm_TIM1_3_TIN29_P33_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN38_P32_2_IN;   /**< \brief IfxGtm_TIM1_3_TIN38_P32_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN3_P02_3_IN;    /**< \brief IfxGtm_TIM1_3_TIN3_P02_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN49_P22_2_IN;   /**< \brief IfxGtm_TIM1_3_TIN49_P22_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN56_P21_5_IN;   /**< \brief IfxGtm_TIM1_3_TIN56_P21_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN71_P15_0_IN;   /**< \brief IfxGtm_TIM1_3_TIN71_P15_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN80_P14_0_IN;   /**< \brief IfxGtm_TIM1_3_TIN80_P14_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_3_TIN97_P11_6_IN;   /**< \brief IfxGtm_TIM1_3_TIN97_P11_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN102_P10_0_IN;  /**< \brief IfxGtm_TIM1_4_TIN102_P10_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN14_P00_5_IN;   /**< \brief IfxGtm_TIM1_4_TIN14_P00_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN22_P33_0_IN;   /**< \brief IfxGtm_TIM1_4_TIN22_P33_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN30_P33_8_IN;   /**< \brief IfxGtm_TIM1_4_TIN30_P33_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN39_P32_3_IN;   /**< \brief IfxGtm_TIM1_4_TIN39_P32_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN4_P02_4_IN;    /**< \brief IfxGtm_TIM1_4_TIN4_P02_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN50_P22_3_IN;   /**< \brief IfxGtm_TIM1_4_TIN50_P22_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN57_P21_6_IN;   /**< \brief IfxGtm_TIM1_4_TIN57_P21_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN72_P15_1_IN;   /**< \brief IfxGtm_TIM1_4_TIN72_P15_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN81_P14_1_IN;   /**< \brief IfxGtm_TIM1_4_TIN81_P14_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_4_TIN98_P11_9_IN;   /**< \brief IfxGtm_TIM1_4_TIN98_P11_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN110_P10_8_IN;  /**< \brief IfxGtm_TIM1_5_TIN110_P10_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN15_P00_6_IN;   /**< \brief IfxGtm_TIM1_5_TIN15_P00_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN40_P32_4_IN;   /**< \brief IfxGtm_TIM1_5_TIN40_P32_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN41_P23_0_IN;   /**< \brief IfxGtm_TIM1_5_TIN41_P23_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN58_P21_7_IN;   /**< \brief IfxGtm_TIM1_5_TIN58_P21_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN5_P02_5_IN;    /**< \brief IfxGtm_TIM1_5_TIN5_P02_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN65_P20_9_IN;   /**< \brief IfxGtm_TIM1_5_TIN65_P20_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN73_P15_2_IN;   /**< \brief IfxGtm_TIM1_5_TIN73_P15_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN82_P14_2_IN;   /**< \brief IfxGtm_TIM1_5_TIN82_P14_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN91_P13_0_IN;   /**< \brief IfxGtm_TIM1_5_TIN91_P13_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_5_TIN99_P11_10_IN;  /**< \brief IfxGtm_TIM1_5_TIN99_P11_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN100_P11_11_IN; /**< \brief IfxGtm_TIM1_6_TIN100_P11_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN106_P10_4_IN;  /**< \brief IfxGtm_TIM1_6_TIN106_P10_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN16_P00_7_IN;   /**< \brief IfxGtm_TIM1_6_TIN16_P00_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN24_P33_2_IN;   /**< \brief IfxGtm_TIM1_6_TIN24_P33_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN42_P23_1_IN;   /**< \brief IfxGtm_TIM1_6_TIN42_P23_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN43_P23_2_IN;   /**< \brief IfxGtm_TIM1_6_TIN43_P23_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN59_P20_0_IN;   /**< \brief IfxGtm_TIM1_6_TIN59_P20_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN66_P20_10_IN;  /**< \brief IfxGtm_TIM1_6_TIN66_P20_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN6_P02_6_IN;    /**< \brief IfxGtm_TIM1_6_TIN6_P02_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN74_P15_3_IN;   /**< \brief IfxGtm_TIM1_6_TIN74_P15_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN83_P14_3_IN;   /**< \brief IfxGtm_TIM1_6_TIN83_P14_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_6_TIN92_P13_1_IN;   /**< \brief IfxGtm_TIM1_6_TIN92_P13_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN101_P11_12_IN; /**< \brief IfxGtm_TIM1_7_TIN101_P11_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN17_P00_8_IN;   /**< \brief IfxGtm_TIM1_7_TIN17_P00_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN25_P33_3_IN;   /**< \brief IfxGtm_TIM1_7_TIN25_P33_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN44_P23_3_IN;   /**< \brief IfxGtm_TIM1_7_TIN44_P23_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN45_P23_4_IN;   /**< \brief IfxGtm_TIM1_7_TIN45_P23_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN64_P20_8_IN;   /**< \brief IfxGtm_TIM1_7_TIN64_P20_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN67_P20_11_IN;  /**< \brief IfxGtm_TIM1_7_TIN67_P20_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN75_P15_4_IN;   /**< \brief IfxGtm_TIM1_7_TIN75_P15_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN7_P02_7_IN;    /**< \brief IfxGtm_TIM1_7_TIN7_P02_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN84_P14_4_IN;   /**< \brief IfxGtm_TIM1_7_TIN84_P14_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM1_7_TIN93_P13_2_IN;   /**< \brief IfxGtm_TIM1_7_TIN93_P13_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_0_TIN34_P33_12_IN;  /**< \brief IfxGtm_TIM2_0_TIN34_P33_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_0_TIN68_P20_12_IN;  /**< \brief IfxGtm_TIM2_0_TIN68_P20_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_0_TIN76_P15_5_IN;   /**< \brief IfxGtm_TIM2_0_TIN76_P15_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_0_TIN8_P02_8_IN;    /**< \brief IfxGtm_TIM2_0_TIN8_P02_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_0_TIN94_P13_3_IN;   /**< \brief IfxGtm_TIM2_0_TIN94_P13_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_0_TIN9_P00_0_IN;    /**< \brief IfxGtm_TIM2_0_TIN9_P00_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_1_TIN10_P00_1_IN;   /**< \brief IfxGtm_TIM2_1_TIN10_P00_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_1_TIN11_P00_2_IN;   /**< \brief IfxGtm_TIM2_1_TIN11_P00_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_1_TIN35_P33_13_IN;  /**< \brief IfxGtm_TIM2_1_TIN35_P33_13_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_1_TIN69_P20_13_IN;  /**< \brief IfxGtm_TIM2_1_TIN69_P20_13_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_1_TIN95_P11_2_IN;   /**< \brief IfxGtm_TIM2_1_TIN95_P11_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_2_TIN12_P00_3_IN;   /**< \brief IfxGtm_TIM2_2_TIN12_P00_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_2_TIN36_P32_0_IN;   /**< \brief IfxGtm_TIM2_2_TIN36_P32_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_2_TIN70_P20_14_IN;  /**< \brief IfxGtm_TIM2_2_TIN70_P20_14_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_2_TIN88_P14_8_IN;   /**< \brief IfxGtm_TIM2_2_TIN88_P14_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_2_TIN96_P11_3_IN;   /**< \brief IfxGtm_TIM2_2_TIN96_P11_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_3_TIN13_P00_4_IN;   /**< \brief IfxGtm_TIM2_3_TIN13_P00_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_3_TIN60_P20_1_IN;   /**< \brief IfxGtm_TIM2_3_TIN60_P20_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_3_TIN71_P15_0_IN;   /**< \brief IfxGtm_TIM2_3_TIN71_P15_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_3_TIN89_P14_9_IN;   /**< \brief IfxGtm_TIM2_3_TIN89_P14_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_3_TIN97_P11_6_IN;   /**< \brief IfxGtm_TIM2_3_TIN97_P11_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_4_TIN14_P00_5_IN;   /**< \brief IfxGtm_TIM2_4_TIN14_P00_5_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_4_TIN51_P21_0_IN;   /**< \brief IfxGtm_TIM2_4_TIN51_P21_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_4_TIN61_P20_3_IN;   /**< \brief IfxGtm_TIM2_4_TIN61_P20_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_4_TIN72_P15_1_IN;   /**< \brief IfxGtm_TIM2_4_TIN72_P15_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_4_TIN90_P14_10_IN;  /**< \brief IfxGtm_TIM2_4_TIN90_P14_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_4_TIN98_P11_9_IN;   /**< \brief IfxGtm_TIM2_4_TIN98_P11_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_5_TIN15_P00_6_IN;   /**< \brief IfxGtm_TIM2_5_TIN15_P00_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_5_TIN52_P21_1_IN;   /**< \brief IfxGtm_TIM2_5_TIN52_P21_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_5_TIN65_P20_9_IN;   /**< \brief IfxGtm_TIM2_5_TIN65_P20_9_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_5_TIN73_P15_2_IN;   /**< \brief IfxGtm_TIM2_5_TIN73_P15_2_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_5_TIN91_P13_0_IN;   /**< \brief IfxGtm_TIM2_5_TIN91_P13_0_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_5_TIN99_P11_10_IN;  /**< \brief IfxGtm_TIM2_5_TIN99_P11_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_6_TIN100_P11_11_IN; /**< \brief IfxGtm_TIM2_6_TIN100_P11_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_6_TIN16_P00_7_IN;   /**< \brief IfxGtm_TIM2_6_TIN16_P00_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_6_TIN62_P20_6_IN;   /**< \brief IfxGtm_TIM2_6_TIN62_P20_6_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_6_TIN66_P20_10_IN;  /**< \brief IfxGtm_TIM2_6_TIN66_P20_10_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_6_TIN74_P15_3_IN;   /**< \brief IfxGtm_TIM2_6_TIN74_P15_3_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_6_TIN92_P13_1_IN;   /**< \brief IfxGtm_TIM2_6_TIN92_P13_1_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_7_TIN101_P11_12_IN; /**< \brief IfxGtm_TIM2_7_TIN101_P11_12_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_7_TIN17_P00_8_IN;   /**< \brief IfxGtm_TIM2_7_TIN17_P00_8_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_7_TIN63_P20_7_IN;   /**< \brief IfxGtm_TIM2_7_TIN63_P20_7_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_7_TIN67_P20_11_IN;  /**< \brief IfxGtm_TIM2_7_TIN67_P20_11_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_7_TIN75_P15_4_IN;   /**< \brief IfxGtm_TIM2_7_TIN75_P15_4_IN */
IFX_EXTERN IfxGtmTim_TinMap   IfxGtm_TIM2_7_TIN93_P13_2_IN;   /**< \brief IfxGtm_TIM2_7_TIN93_P13_2_IN */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT109_P10_7;    /**< \brief IfxGtm_TOM0_0_TOUT109_P10_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT18_P00_9;     /**< \brief IfxGtm_TOM0_0_TOUT18_P00_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT26_P33_4;     /**< \brief IfxGtm_TOM0_0_TOUT26_P33_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT32_P33_10;    /**< \brief IfxGtm_TOM0_0_TOUT32_P33_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT53_P21_2;     /**< \brief IfxGtm_TOM0_0_TOUT53_P21_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT76_P15_5;     /**< \brief IfxGtm_TOM0_0_TOUT76_P15_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT77_P15_6;     /**< \brief IfxGtm_TOM0_0_TOUT77_P15_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT85_P14_5;     /**< \brief IfxGtm_TOM0_0_TOUT85_P14_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_0_TOUT87_P14_7;     /**< \brief IfxGtm_TOM0_0_TOUT87_P14_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_10_TOUT12_P00_3;    /**< \brief IfxGtm_TOM0_10_TOUT12_P00_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_10_TOUT2_P02_2;     /**< \brief IfxGtm_TOM0_10_TOUT2_P02_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_10_TOUT41_P23_0;    /**< \brief IfxGtm_TOM0_10_TOUT41_P23_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_10_TOUT46_P23_5;    /**< \brief IfxGtm_TOM0_10_TOUT46_P23_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_10_TOUT62_P20_6;    /**< \brief IfxGtm_TOM0_10_TOUT62_P20_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_10_TOUT70_P20_14;   /**< \brief IfxGtm_TOM0_10_TOUT70_P20_14 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_10_TOUT96_P11_3;    /**< \brief IfxGtm_TOM0_10_TOUT96_P11_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_11_TOUT13_P00_4;    /**< \brief IfxGtm_TOM0_11_TOUT13_P00_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_11_TOUT3_P02_3;     /**< \brief IfxGtm_TOM0_11_TOUT3_P02_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_11_TOUT43_P23_2;    /**< \brief IfxGtm_TOM0_11_TOUT43_P23_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_11_TOUT49_P22_2;    /**< \brief IfxGtm_TOM0_11_TOUT49_P22_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_11_TOUT63_P20_7;    /**< \brief IfxGtm_TOM0_11_TOUT63_P20_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_11_TOUT71_P15_0;    /**< \brief IfxGtm_TOM0_11_TOUT71_P15_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_11_TOUT97_P11_6;    /**< \brief IfxGtm_TOM0_11_TOUT97_P11_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_12_TOUT14_P00_5;    /**< \brief IfxGtm_TOM0_12_TOUT14_P00_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_12_TOUT34_P33_12;   /**< \brief IfxGtm_TOM0_12_TOUT34_P33_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_12_TOUT44_P23_3;    /**< \brief IfxGtm_TOM0_12_TOUT44_P23_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_12_TOUT4_P02_4;     /**< \brief IfxGtm_TOM0_12_TOUT4_P02_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_12_TOUT50_P22_3;    /**< \brief IfxGtm_TOM0_12_TOUT50_P22_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_12_TOUT72_P15_1;    /**< \brief IfxGtm_TOM0_12_TOUT72_P15_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_12_TOUT98_P11_9;    /**< \brief IfxGtm_TOM0_12_TOUT98_P11_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_13_TOUT15_P00_6;    /**< \brief IfxGtm_TOM0_13_TOUT15_P00_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_13_TOUT35_P33_13;   /**< \brief IfxGtm_TOM0_13_TOUT35_P33_13 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_13_TOUT5_P02_5;     /**< \brief IfxGtm_TOM0_13_TOUT5_P02_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_13_TOUT65_P20_9;    /**< \brief IfxGtm_TOM0_13_TOUT65_P20_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_13_TOUT73_P15_2;    /**< \brief IfxGtm_TOM0_13_TOUT73_P15_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_13_TOUT99_P11_10;   /**< \brief IfxGtm_TOM0_13_TOUT99_P11_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_14_TOUT100_P11_11;  /**< \brief IfxGtm_TOM0_14_TOUT100_P11_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_14_TOUT16_P00_7;    /**< \brief IfxGtm_TOM0_14_TOUT16_P00_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_14_TOUT36_P32_0;    /**< \brief IfxGtm_TOM0_14_TOUT36_P32_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_14_TOUT66_P20_10;   /**< \brief IfxGtm_TOM0_14_TOUT66_P20_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_14_TOUT6_P02_6;     /**< \brief IfxGtm_TOM0_14_TOUT6_P02_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_14_TOUT74_P15_3;    /**< \brief IfxGtm_TOM0_14_TOUT74_P15_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_15_TOUT101_P11_12;  /**< \brief IfxGtm_TOM0_15_TOUT101_P11_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_15_TOUT17_P00_8;    /**< \brief IfxGtm_TOM0_15_TOUT17_P00_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_15_TOUT42_P23_1;    /**< \brief IfxGtm_TOM0_15_TOUT42_P23_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_15_TOUT67_P20_11;   /**< \brief IfxGtm_TOM0_15_TOUT67_P20_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_15_TOUT75_P15_4;    /**< \brief IfxGtm_TOM0_15_TOUT75_P15_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_15_TOUT7_P02_7;     /**< \brief IfxGtm_TOM0_15_TOUT7_P02_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_1_TOUT103_P10_1;    /**< \brief IfxGtm_TOM0_1_TOUT103_P10_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_1_TOUT19_P00_10;    /**< \brief IfxGtm_TOM0_1_TOUT19_P00_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_1_TOUT27_P33_5;     /**< \brief IfxGtm_TOM0_1_TOUT27_P33_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_1_TOUT31_P33_9;     /**< \brief IfxGtm_TOM0_1_TOUT31_P33_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_1_TOUT54_P21_3;     /**< \brief IfxGtm_TOM0_1_TOUT54_P21_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_1_TOUT78_P15_7;     /**< \brief IfxGtm_TOM0_1_TOUT78_P15_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_1_TOUT86_P14_6;     /**< \brief IfxGtm_TOM0_1_TOUT86_P14_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT104_P10_2;    /**< \brief IfxGtm_TOM0_2_TOUT104_P10_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT107_P10_5;    /**< \brief IfxGtm_TOM0_2_TOUT107_P10_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT20_P00_11;    /**< \brief IfxGtm_TOM0_2_TOUT20_P00_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT28_P33_6;     /**< \brief IfxGtm_TOM0_2_TOUT28_P33_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT33_P33_11;    /**< \brief IfxGtm_TOM0_2_TOUT33_P33_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT55_P21_4;     /**< \brief IfxGtm_TOM0_2_TOUT55_P21_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT79_P15_8;     /**< \brief IfxGtm_TOM0_2_TOUT79_P15_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_2_TOUT88_P14_8;     /**< \brief IfxGtm_TOM0_2_TOUT88_P14_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT105_P10_3;    /**< \brief IfxGtm_TOM0_3_TOUT105_P10_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT108_P10_6;    /**< \brief IfxGtm_TOM0_3_TOUT108_P10_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT21_P00_12;    /**< \brief IfxGtm_TOM0_3_TOUT21_P00_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT29_P33_7;     /**< \brief IfxGtm_TOM0_3_TOUT29_P33_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT38_P32_2;     /**< \brief IfxGtm_TOM0_3_TOUT38_P32_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT56_P21_5;     /**< \brief IfxGtm_TOM0_3_TOUT56_P21_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT60_P20_1;     /**< \brief IfxGtm_TOM0_3_TOUT60_P20_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT80_P14_0;     /**< \brief IfxGtm_TOM0_3_TOUT80_P14_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_3_TOUT89_P14_9;     /**< \brief IfxGtm_TOM0_3_TOUT89_P14_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT102_P10_0;    /**< \brief IfxGtm_TOM0_4_TOUT102_P10_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT22_P33_0;     /**< \brief IfxGtm_TOM0_4_TOUT22_P33_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT30_P33_8;     /**< \brief IfxGtm_TOM0_4_TOUT30_P33_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT39_P32_3;     /**< \brief IfxGtm_TOM0_4_TOUT39_P32_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT57_P21_6;     /**< \brief IfxGtm_TOM0_4_TOUT57_P21_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT61_P20_3;     /**< \brief IfxGtm_TOM0_4_TOUT61_P20_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT81_P14_1;     /**< \brief IfxGtm_TOM0_4_TOUT81_P14_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_4_TOUT90_P14_10;    /**< \brief IfxGtm_TOM0_4_TOUT90_P14_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_5_TOUT110_P10_8;    /**< \brief IfxGtm_TOM0_5_TOUT110_P10_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_5_TOUT23_P33_1;     /**< \brief IfxGtm_TOM0_5_TOUT23_P33_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_5_TOUT40_P32_4;     /**< \brief IfxGtm_TOM0_5_TOUT40_P32_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_5_TOUT58_P21_7;     /**< \brief IfxGtm_TOM0_5_TOUT58_P21_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_5_TOUT82_P14_2;     /**< \brief IfxGtm_TOM0_5_TOUT82_P14_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_5_TOUT91_P13_0;     /**< \brief IfxGtm_TOM0_5_TOUT91_P13_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_6_TOUT106_P10_4;    /**< \brief IfxGtm_TOM0_6_TOUT106_P10_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_6_TOUT24_P33_2;     /**< \brief IfxGtm_TOM0_6_TOUT24_P33_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_6_TOUT42_P23_1;     /**< \brief IfxGtm_TOM0_6_TOUT42_P23_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_6_TOUT59_P20_0;     /**< \brief IfxGtm_TOM0_6_TOUT59_P20_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_6_TOUT83_P14_3;     /**< \brief IfxGtm_TOM0_6_TOUT83_P14_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_6_TOUT92_P13_1;     /**< \brief IfxGtm_TOM0_6_TOUT92_P13_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_7_TOUT25_P33_3;     /**< \brief IfxGtm_TOM0_7_TOUT25_P33_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_7_TOUT45_P23_4;     /**< \brief IfxGtm_TOM0_7_TOUT45_P23_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_7_TOUT64_P20_8;     /**< \brief IfxGtm_TOM0_7_TOUT64_P20_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_7_TOUT84_P14_4;     /**< \brief IfxGtm_TOM0_7_TOUT84_P14_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_7_TOUT93_P13_2;     /**< \brief IfxGtm_TOM0_7_TOUT93_P13_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT0_P02_0;      /**< \brief IfxGtm_TOM0_8_TOUT0_P02_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT48_P22_1;     /**< \brief IfxGtm_TOM0_8_TOUT48_P22_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT51_P21_0;     /**< \brief IfxGtm_TOM0_8_TOUT51_P21_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT68_P20_12;    /**< \brief IfxGtm_TOM0_8_TOUT68_P20_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT8_P02_8;      /**< \brief IfxGtm_TOM0_8_TOUT8_P02_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT94_P13_3;     /**< \brief IfxGtm_TOM0_8_TOUT94_P13_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT95_P11_2;     /**< \brief IfxGtm_TOM0_8_TOUT95_P11_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_8_TOUT9_P00_0;      /**< \brief IfxGtm_TOM0_8_TOUT9_P00_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_9_TOUT10_P00_1;     /**< \brief IfxGtm_TOM0_9_TOUT10_P00_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_9_TOUT11_P00_2;     /**< \brief IfxGtm_TOM0_9_TOUT11_P00_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_9_TOUT1_P02_1;      /**< \brief IfxGtm_TOM0_9_TOUT1_P02_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_9_TOUT47_P22_0;     /**< \brief IfxGtm_TOM0_9_TOUT47_P22_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_9_TOUT52_P21_1;     /**< \brief IfxGtm_TOM0_9_TOUT52_P21_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM0_9_TOUT69_P20_13;    /**< \brief IfxGtm_TOM0_9_TOUT69_P20_13 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT18_P00_9;     /**< \brief IfxGtm_TOM1_0_TOUT18_P00_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT26_P33_4;     /**< \brief IfxGtm_TOM1_0_TOUT26_P33_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT32_P33_10;    /**< \brief IfxGtm_TOM1_0_TOUT32_P33_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT48_P22_1;     /**< \brief IfxGtm_TOM1_0_TOUT48_P22_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT53_P21_2;     /**< \brief IfxGtm_TOM1_0_TOUT53_P21_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT68_P20_12;    /**< \brief IfxGtm_TOM1_0_TOUT68_P20_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT76_P15_5;     /**< \brief IfxGtm_TOM1_0_TOUT76_P15_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT77_P15_6;     /**< \brief IfxGtm_TOM1_0_TOUT77_P15_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT85_P14_5;     /**< \brief IfxGtm_TOM1_0_TOUT85_P14_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT87_P14_7;     /**< \brief IfxGtm_TOM1_0_TOUT87_P14_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT8_P02_8;      /**< \brief IfxGtm_TOM1_0_TOUT8_P02_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT94_P13_3;     /**< \brief IfxGtm_TOM1_0_TOUT94_P13_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_0_TOUT9_P00_0;      /**< \brief IfxGtm_TOM1_0_TOUT9_P00_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_10_TOUT104_P10_2;   /**< \brief IfxGtm_TOM1_10_TOUT104_P10_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_10_TOUT107_P10_5;   /**< \brief IfxGtm_TOM1_10_TOUT107_P10_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_10_TOUT2_P02_2;     /**< \brief IfxGtm_TOM1_10_TOUT2_P02_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_10_TOUT62_P20_6;    /**< \brief IfxGtm_TOM1_10_TOUT62_P20_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_11_TOUT105_P10_3;   /**< \brief IfxGtm_TOM1_11_TOUT105_P10_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_11_TOUT108_P10_6;   /**< \brief IfxGtm_TOM1_11_TOUT108_P10_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_11_TOUT3_P02_3;     /**< \brief IfxGtm_TOM1_11_TOUT3_P02_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_11_TOUT60_P20_1;    /**< \brief IfxGtm_TOM1_11_TOUT60_P20_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_11_TOUT63_P20_7;    /**< \brief IfxGtm_TOM1_11_TOUT63_P20_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_12_TOUT102_P10_0;   /**< \brief IfxGtm_TOM1_12_TOUT102_P10_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_12_TOUT34_P33_12;   /**< \brief IfxGtm_TOM1_12_TOUT34_P33_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_12_TOUT4_P02_4;     /**< \brief IfxGtm_TOM1_12_TOUT4_P02_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_12_TOUT61_P20_3;    /**< \brief IfxGtm_TOM1_12_TOUT61_P20_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_13_TOUT110_P10_8;   /**< \brief IfxGtm_TOM1_13_TOUT110_P10_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_13_TOUT35_P33_13;   /**< \brief IfxGtm_TOM1_13_TOUT35_P33_13 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_13_TOUT5_P02_5;     /**< \brief IfxGtm_TOM1_13_TOUT5_P02_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_13_TOUT65_P20_9;    /**< \brief IfxGtm_TOM1_13_TOUT65_P20_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_14_TOUT36_P32_0;    /**< \brief IfxGtm_TOM1_14_TOUT36_P32_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_14_TOUT66_P20_10;   /**< \brief IfxGtm_TOM1_14_TOUT66_P20_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_14_TOUT6_P02_6;     /**< \brief IfxGtm_TOM1_14_TOUT6_P02_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_15_TOUT67_P20_11;   /**< \brief IfxGtm_TOM1_15_TOUT67_P20_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_15_TOUT7_P02_7;     /**< \brief IfxGtm_TOM1_15_TOUT7_P02_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT10_P00_1;     /**< \brief IfxGtm_TOM1_1_TOUT10_P00_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT11_P00_2;     /**< \brief IfxGtm_TOM1_1_TOUT11_P00_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT19_P00_10;    /**< \brief IfxGtm_TOM1_1_TOUT19_P00_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT27_P33_5;     /**< \brief IfxGtm_TOM1_1_TOUT27_P33_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT31_P33_9;     /**< \brief IfxGtm_TOM1_1_TOUT31_P33_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT47_P22_0;     /**< \brief IfxGtm_TOM1_1_TOUT47_P22_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT54_P21_3;     /**< \brief IfxGtm_TOM1_1_TOUT54_P21_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT69_P20_13;    /**< \brief IfxGtm_TOM1_1_TOUT69_P20_13 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT78_P15_7;     /**< \brief IfxGtm_TOM1_1_TOUT78_P15_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT86_P14_6;     /**< \brief IfxGtm_TOM1_1_TOUT86_P14_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_1_TOUT95_P11_2;     /**< \brief IfxGtm_TOM1_1_TOUT95_P11_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT12_P00_3;     /**< \brief IfxGtm_TOM1_2_TOUT12_P00_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT20_P00_11;    /**< \brief IfxGtm_TOM1_2_TOUT20_P00_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT28_P33_6;     /**< \brief IfxGtm_TOM1_2_TOUT28_P33_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT33_P33_11;    /**< \brief IfxGtm_TOM1_2_TOUT33_P33_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT46_P23_5;     /**< \brief IfxGtm_TOM1_2_TOUT46_P23_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT55_P21_4;     /**< \brief IfxGtm_TOM1_2_TOUT55_P21_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT70_P20_14;    /**< \brief IfxGtm_TOM1_2_TOUT70_P20_14 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT79_P15_8;     /**< \brief IfxGtm_TOM1_2_TOUT79_P15_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT88_P14_8;     /**< \brief IfxGtm_TOM1_2_TOUT88_P14_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_2_TOUT96_P11_3;     /**< \brief IfxGtm_TOM1_2_TOUT96_P11_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT13_P00_4;     /**< \brief IfxGtm_TOM1_3_TOUT13_P00_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT21_P00_12;    /**< \brief IfxGtm_TOM1_3_TOUT21_P00_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT29_P33_7;     /**< \brief IfxGtm_TOM1_3_TOUT29_P33_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT38_P32_2;     /**< \brief IfxGtm_TOM1_3_TOUT38_P32_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT49_P22_2;     /**< \brief IfxGtm_TOM1_3_TOUT49_P22_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT56_P21_5;     /**< \brief IfxGtm_TOM1_3_TOUT56_P21_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT71_P15_0;     /**< \brief IfxGtm_TOM1_3_TOUT71_P15_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT80_P14_0;     /**< \brief IfxGtm_TOM1_3_TOUT80_P14_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT89_P14_9;     /**< \brief IfxGtm_TOM1_3_TOUT89_P14_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_3_TOUT97_P11_6;     /**< \brief IfxGtm_TOM1_3_TOUT97_P11_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT14_P00_5;     /**< \brief IfxGtm_TOM1_4_TOUT14_P00_5 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT22_P33_0;     /**< \brief IfxGtm_TOM1_4_TOUT22_P33_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT30_P33_8;     /**< \brief IfxGtm_TOM1_4_TOUT30_P33_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT39_P32_3;     /**< \brief IfxGtm_TOM1_4_TOUT39_P32_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT50_P22_3;     /**< \brief IfxGtm_TOM1_4_TOUT50_P22_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT57_P21_6;     /**< \brief IfxGtm_TOM1_4_TOUT57_P21_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT72_P15_1;     /**< \brief IfxGtm_TOM1_4_TOUT72_P15_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT81_P14_1;     /**< \brief IfxGtm_TOM1_4_TOUT81_P14_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT90_P14_10;    /**< \brief IfxGtm_TOM1_4_TOUT90_P14_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_4_TOUT98_P11_9;     /**< \brief IfxGtm_TOM1_4_TOUT98_P11_9 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT15_P00_6;     /**< \brief IfxGtm_TOM1_5_TOUT15_P00_6 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT23_P33_1;     /**< \brief IfxGtm_TOM1_5_TOUT23_P33_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT40_P32_4;     /**< \brief IfxGtm_TOM1_5_TOUT40_P32_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT41_P23_0;     /**< \brief IfxGtm_TOM1_5_TOUT41_P23_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT58_P21_7;     /**< \brief IfxGtm_TOM1_5_TOUT58_P21_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT73_P15_2;     /**< \brief IfxGtm_TOM1_5_TOUT73_P15_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT82_P14_2;     /**< \brief IfxGtm_TOM1_5_TOUT82_P14_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT91_P13_0;     /**< \brief IfxGtm_TOM1_5_TOUT91_P13_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_5_TOUT99_P11_10;    /**< \brief IfxGtm_TOM1_5_TOUT99_P11_10 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT100_P11_11;   /**< \brief IfxGtm_TOM1_6_TOUT100_P11_11 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT106_P10_4;    /**< \brief IfxGtm_TOM1_6_TOUT106_P10_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT16_P00_7;     /**< \brief IfxGtm_TOM1_6_TOUT16_P00_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT24_P33_2;     /**< \brief IfxGtm_TOM1_6_TOUT24_P33_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT43_P23_2;     /**< \brief IfxGtm_TOM1_6_TOUT43_P23_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT59_P20_0;     /**< \brief IfxGtm_TOM1_6_TOUT59_P20_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT74_P15_3;     /**< \brief IfxGtm_TOM1_6_TOUT74_P15_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT83_P14_3;     /**< \brief IfxGtm_TOM1_6_TOUT83_P14_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_6_TOUT92_P13_1;     /**< \brief IfxGtm_TOM1_6_TOUT92_P13_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT101_P11_12;   /**< \brief IfxGtm_TOM1_7_TOUT101_P11_12 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT17_P00_8;     /**< \brief IfxGtm_TOM1_7_TOUT17_P00_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT25_P33_3;     /**< \brief IfxGtm_TOM1_7_TOUT25_P33_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT44_P23_3;     /**< \brief IfxGtm_TOM1_7_TOUT44_P23_3 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT45_P23_4;     /**< \brief IfxGtm_TOM1_7_TOUT45_P23_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT64_P20_8;     /**< \brief IfxGtm_TOM1_7_TOUT64_P20_8 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT75_P15_4;     /**< \brief IfxGtm_TOM1_7_TOUT75_P15_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT84_P14_4;     /**< \brief IfxGtm_TOM1_7_TOUT84_P14_4 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_7_TOUT93_P13_2;     /**< \brief IfxGtm_TOM1_7_TOUT93_P13_2 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_8_TOUT0_P02_0;      /**< \brief IfxGtm_TOM1_8_TOUT0_P02_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_8_TOUT109_P10_7;    /**< \brief IfxGtm_TOM1_8_TOUT109_P10_7 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_8_TOUT51_P21_0;     /**< \brief IfxGtm_TOM1_8_TOUT51_P21_0 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_9_TOUT103_P10_1;    /**< \brief IfxGtm_TOM1_9_TOUT103_P10_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_9_TOUT1_P02_1;      /**< \brief IfxGtm_TOM1_9_TOUT1_P02_1 */
IFX_EXTERN IfxGtmTom_ToutMap  IfxGtm_TOM1_9_TOUT52_P21_1;     /**< \brief IfxGtm_TOM1_9_TOUT52_P21_1 */
IFX_EXTERN IfxGtm_Clk_Out     IfxGtm_CLK0_P23_1_OUT;          /**< \brief GTM CLK0 (GTMCLK0) */
IFX_EXTERN IfxGtm_Clk_Out     IfxGtm_CLK1_P32_4_OUT;          /**< \brief GTM CLK1 (GTMCLK1) */
IFX_EXTERN IfxGtm_Clk_Out     IfxGtm_CLK2_P11_12_OUT;         /**< \brief GTM CLK2 (GTMCLK2) */

/** \} */

#endif /* IFXGTM_PINMAP_H */
