/**
 * \file IfxQspi_PinMap.h
 * \brief QSPI I/O map
 * \ingroup IfxLld_Qspi
 *
 * \copyright Copyright (c) 2013 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1.1
 * $Date: $2013-08-12 11:20:28 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_Qspi_pinmap QSPI Pin Mapping
 * \ingroup IfxLld_Qspi
 */

#ifndef IFXQSPI_PINMAP_H
#define IFXQSPI_PINMAP_H

#include <_Reg/IfxQspi_reg.h>
#include <_Impl/IfxQspi_cfg.h>
#include <Port/Std/IfxPort.h>

/** \addtogroup IfxLld_Qspi_pinmap
 * \{ */

/** \brief MRST pin mapping structure */
typedef const struct
{
    Ifx_QSPI   *module;         /**< \brief Base address */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxQspi_Mrst_In;

/** \brief MTSR pin mapping structure */
typedef const struct
{
    Ifx_QSPI   *module;         /**< \brief Base address */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxQspi_Mtsr_In;

/** \brief SCLK pin mapping structure */
typedef const struct
{
    Ifx_QSPI   *module;         /**< \brief Base address */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxQspi_Sclk_In;

/** \brief SLSI pin mapping structure */
typedef const struct
{
    Ifx_QSPI   *module;         /**< \brief Base address */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxQspi_Slsi_In;

/** \brief HSICIN pin mapping structure */
typedef const struct
{
    Ifx_QSPI   *module;         /**< \brief Base address */
    IfxPort_Pin pin;            /**< \brief Port pin */
    Ifx_RxSel   select;         /**< \brief Input multiplexer value */
} IfxQspi_Hsicin_In;

/** \brief MRST pin mapping structure */
typedef const struct
{
    Ifx_QSPI         *module;   /**< \brief Base address */
    IfxPort_Pin       pin;      /**< \brief Port pin */
    IfxPort_OutputIdx select;   /**< \brief Port control code */
} IfxQspi_Mrst_Out;

/** \brief MTSR pin mapping structure */
typedef const struct
{
    Ifx_QSPI         *module;   /**< \brief Base address */
    IfxPort_Pin       pin;      /**< \brief Port pin */
    IfxPort_OutputIdx select;   /**< \brief Port control code */
} IfxQspi_Mtsr_Out;

/** \brief SCLK pin mapping structure */
typedef const struct
{
    Ifx_QSPI         *module;   /**< \brief Base address */
    IfxPort_Pin       pin;      /**< \brief Port pin */
    IfxPort_OutputIdx select;   /**< \brief Port control code */
} IfxQspi_Sclk_Out;

/** \brief SLSO pin mapping structure */
typedef struct
{
    Ifx_QSPI         *module;   /**< \brief Base address */
    IfxPort_Pin       pin;      /**< \brief Port pin */
    IfxPort_OutputIdx select;   /**< \brief Port control code */
    sint32            slsoNr;
} IfxQspi_Slso_Out;

IFX_EXTERN IfxQspi_Hsicin_In IfxQspi2_HSICINA_P15_2_IN;  /**< \brief QSPI2 HSICINA (HSIC2INA_n) */
IFX_EXTERN IfxQspi_Hsicin_In IfxQspi2_HSICINB_P15_3_IN;  /**< \brief QSPI2 HSICINB (HSIC2INB_n) */
IFX_EXTERN IfxQspi_Hsicin_In IfxQspi3_HSICINA_P33_9_IN;  /**< \brief QSPI3 HSICINA (HSIC3INA_n) */
IFX_EXTERN IfxQspi_Hsicin_In IfxQspi3_HSICINB_P33_10_IN; /**< \brief QSPI3 HSICINB (HSIC3INB_n) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi0_MRSTA_P20_12_IN;   /**< \brief QSPI0 MRSTA (MRST0A) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi1_MRSTA_P10_1_IN;    /**< \brief QSPI1 MRSTA (MRST1A) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi1_MRSTB_P11_3_IN;    /**< \brief QSPI1 MRSTB (MRST1B) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi2_MRSTA_P15_4_IN;    /**< \brief QSPI2 MRSTA (MRST2A) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi2_MRSTB_P15_7_IN;    /**< \brief QSPI2 MRSTB (MRST2B) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi2_MRSTCN_P21_2_IN;   /**< \brief QSPI2 MRSTCN (MRST2CN) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi2_MRSTCP_P21_3_IN;   /**< \brief QSPI2 MRSTCP (MRST2CP) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi2_MRSTE_P15_2_IN;    /**< \brief QSPI2 MRSTE (MRST2E_n) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi3_MRSTA_P02_5_IN;    /**< \brief QSPI3 MRSTA (MRST3A) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi3_MRSTB_P10_7_IN;    /**< \brief QSPI3 MRSTB (MRST3B) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi3_MRSTD_P33_13_IN;   /**< \brief QSPI3 MRSTD (MRST3D) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi3_MRSTE_P22_1_IN;    /**< \brief QSPI3 MRSTE (MRST3E) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi3_MRSTFN_P21_2_IN;   /**< \brief QSPI3 MRSTFN (MRST3FN) */
IFX_EXTERN IfxQspi_Mrst_In   IfxQspi3_MRSTFP_P21_3_IN;   /**< \brief QSPI3 MRSTFP (MRST3FP) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi0_MRST_P20_12_OUT;   /**< \brief QSPI0 MRST (MRST0) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi1_MRST_P10_1_OUT;    /**< \brief QSPI1 MRST (MRST1) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi1_MRST_P10_6_OUT;    /**< \brief QSPI1 MRST (MRST1) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi1_MRST_P11_3_OUT;    /**< \brief QSPI1 MRST (MRST1) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi2_MRST_P15_4_OUT;    /**< \brief QSPI2 MRST (MRST2) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi2_MRST_P15_7_OUT;    /**< \brief QSPI2 MRST (MRST2) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi3_MRST_P02_5_OUT;    /**< \brief QSPI3 MRST (MRST3) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi3_MRST_P10_7_OUT;    /**< \brief QSPI3 MRST (MRST3) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi3_MRST_P22_1_OUT;    /**< \brief QSPI3 MRST (MRST3) */
IFX_EXTERN IfxQspi_Mrst_Out  IfxQspi3_MRST_P33_13_OUT;   /**< \brief QSPI3 MRST (MRST3) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi0_MTSRA_P20_14_IN;   /**< \brief QSPI0 MTSRA (MTSR0A) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi1_MTSRA_P10_3_IN;    /**< \brief QSPI1 MTSRA (MTSR1A) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi1_MTSRB_P11_9_IN;    /**< \brief QSPI1 MTSRB (MTSR1B) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi1_MTSRC_P10_4_IN;    /**< \brief QSPI1 MTSRC (MTSR1C) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi2_MTSRA_P15_5_IN;    /**< \brief QSPI2 MTSRA (MTSR2A) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi2_MTSRB_P15_6_IN;    /**< \brief QSPI2 MTSRB (MTSR2B) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi3_MTSRA_P02_6_IN;    /**< \brief QSPI3 MTSRA (MTSR3A) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi3_MTSRB_P10_6_IN;    /**< \brief QSPI3 MTSRB (MTSR3B) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi3_MTSRD_P33_12_IN;   /**< \brief QSPI3 MTSRD (MTSR3D) */
IFX_EXTERN IfxQspi_Mtsr_In   IfxQspi3_MTSRE_P22_0_IN;    /**< \brief QSPI3 MTSRE (MTSR3E) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi0_MTSR_P20_12_OUT;   /**< \brief QSPI0 MTSR (MTSR0) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi0_MTSR_P20_14_OUT;   /**< \brief QSPI0 MTSR (MTSR0) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi1_MTSR_P10_1_OUT;    /**< \brief QSPI1 MTSR (MTSR1) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi1_MTSR_P10_3_OUT;    /**< \brief QSPI1 MTSR (MTSR1) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi1_MTSR_P10_4_OUT;    /**< \brief QSPI1 MTSR (MTSR1) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi1_MTSR_P11_9_OUT;    /**< \brief QSPI1 MTSR (MTSR1) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi2_MTSRN_P13_2_OUT;   /**< \brief QSPI2 MTSRN (MTSR2N) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi2_MTSRP_P13_3_OUT;   /**< \brief QSPI2 MTSRP (MTSR2P) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi2_MTSR_P15_5_OUT;    /**< \brief QSPI2 MTSR (MTSR2) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi2_MTSR_P15_6_OUT;    /**< \brief QSPI2 MTSR (MTSR2) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi3_MTSRN_P22_2_OUT;   /**< \brief QSPI3 MTSRN (MTSR3N) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi3_MTSRP_P22_3_OUT;   /**< \brief QSPI3 MTSRP (MTSR3P) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi3_MTSR_P02_6_OUT;    /**< \brief QSPI3 MTSR (MTSR3) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi3_MTSR_P10_6_OUT;    /**< \brief QSPI3 MTSR (MTSR3) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi3_MTSR_P22_0_OUT;    /**< \brief QSPI3 MTSR (MTSR3) */
IFX_EXTERN IfxQspi_Mtsr_Out  IfxQspi3_MTSR_P33_12_OUT;   /**< \brief QSPI3 MTSR (MTSR3) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi0_SCLKA_P20_11_IN;   /**< \brief QSPI0 SCLKA (SCLK0A) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi1_SCLKA_P10_2_IN;    /**< \brief QSPI1 SCLKA (SCLK1A) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi1_SCLKB_P11_6_IN;    /**< \brief QSPI1 SCLKB (SCLK1B) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi2_SCLKA_P15_3_IN;    /**< \brief QSPI2 SCLKA (SCLK2A) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi2_SCLKB_P15_8_IN;    /**< \brief QSPI2 SCLKB (SCLK2B) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi3_SCLKA_P02_7_IN;    /**< \brief QSPI3 SCLKA (SCLK3A) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi3_SCLKB_P10_8_IN;    /**< \brief QSPI3 SCLKB (SCLK3B) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi3_SCLKD_P33_11_IN;   /**< \brief QSPI3 SCLKD (SCLK3D) */
IFX_EXTERN IfxQspi_Sclk_In   IfxQspi3_SCLKE_P22_3_IN;    /**< \brief QSPI3 SCLKE (SCLK3E) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi0_SCLK_P20_11_OUT;   /**< \brief QSPI0 SCLK (SCLK0) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi0_SCLK_P20_13_OUT;   /**< \brief QSPI0 SCLK (SCLK0) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi1_SCLK_P10_2_OUT;    /**< \brief QSPI1 SCLK (SCLK1) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi1_SCLK_P11_6_OUT;    /**< \brief QSPI1 SCLK (SCLK1) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi2_SCLKN_P13_0_OUT;   /**< \brief QSPI2 SCLKN (SCLK2N) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi2_SCLKP_P13_1_OUT;   /**< \brief QSPI2 SCLKP (SCLK2P) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi2_SCLK_P15_3_OUT;    /**< \brief QSPI2 SCLK (SCLK2) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi2_SCLK_P15_6_OUT;    /**< \brief QSPI2 SCLK (SCLK2) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi2_SCLK_P15_8_OUT;    /**< \brief QSPI2 SCLK (SCLK2) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi3_SCLKN_P22_0_OUT;   /**< \brief QSPI3 SCLKN (SCLK3N) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi3_SCLKP_P22_1_OUT;   /**< \brief QSPI3 SCLKP (SCLK3P) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi3_SCLK_P02_7_OUT;    /**< \brief QSPI3 SCLK (SCLK3) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi3_SCLK_P10_8_OUT;    /**< \brief QSPI3 SCLK (SCLK3) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi3_SCLK_P22_3_OUT;    /**< \brief QSPI3 SCLK (SCLK3) */
IFX_EXTERN IfxQspi_Sclk_Out  IfxQspi3_SCLK_P33_11_OUT;   /**< \brief QSPI3 SCLK (SCLK3) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi0_SLSIA_P20_13_IN;   /**< \brief QSPI0 SLSIA (SLSI0A_n) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi0_SLSIB_P20_9_IN;    /**< \brief QSPI0 SLSIB (SLSI0B_n) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi1_SLSIA_P11_10_IN;   /**< \brief QSPI1 SLSIA (SLSI1A_n) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi2_SLSIA_P15_2_IN;    /**< \brief QSPI2 SLSIA (SLSI2A_n) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi2_SLSIB_P15_1_IN;    /**< \brief QSPI2 SLSIB (SLSI2B_n) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi3_SLSIA_P02_4_IN;    /**< \brief QSPI3 SLSIA (SLSI3A_n) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi3_SLSIC_P33_10_IN;   /**< \brief QSPI3 SLSIC (SLSI3C_n) */
IFX_EXTERN IfxQspi_Slsi_In   IfxQspi3_SLSID_P22_2_IN;    /**< \brief QSPI3 SLSID (SLSI3D_n) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO0_P20_8_OUT;   /**< \brief QSPI0 SLSO0 (SLSO00) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO13_P15_0_OUT;  /**< \brief QSPI0 SLSO13 (SLSO013) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO1_P20_9_OUT;   /**< \brief QSPI0 SLSO1 (SLSO01) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO2_P20_13_OUT;  /**< \brief QSPI0 SLSO2 (SLSO02) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO3_P11_10_OUT;  /**< \brief QSPI0 SLSO3 (SLSO03) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO4_P11_11_OUT;  /**< \brief QSPI0 SLSO4 (SLSO04) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO5_P11_2_OUT;   /**< \brief QSPI0 SLSO5 (SLSO05) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO6_P20_10_OUT;  /**< \brief QSPI0 SLSO6 (SLSO06) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO7_P33_5_OUT;   /**< \brief QSPI0 SLSO7 (SLSO07) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO8_P20_6_OUT;   /**< \brief QSPI0 SLSO8 (SLSO08) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi0_SLSO9_P20_3_OUT;   /**< \brief QSPI0 SLSO9 (SLSO09) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO0_P20_8_OUT;   /**< \brief QSPI1 SLSO0 (SLSO10) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO10_P10_0_OUT;  /**< \brief QSPI1 SLSO10 (SLSO110) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO1_P20_9_OUT;   /**< \brief QSPI1 SLSO1 (SLSO11) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO2_P20_13_OUT;  /**< \brief QSPI1 SLSO2 (SLSO12) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO3_P11_10_OUT;  /**< \brief QSPI1 SLSO3 (SLSO13) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO4_P11_11_OUT;  /**< \brief QSPI1 SLSO4 (SLSO14) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO5_P11_2_OUT;   /**< \brief QSPI1 SLSO5 (SLSO15) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO6_P33_10_OUT;  /**< \brief QSPI1 SLSO6 (SLSO16) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO7_P33_5_OUT;   /**< \brief QSPI1 SLSO7 (SLSO17) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO8_P10_4_OUT;   /**< \brief QSPI1 SLSO8 (SLSO18) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi1_SLSO9_P10_5_OUT;   /**< \brief QSPI1 SLSO9 (SLSO19) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO0_P15_2_OUT;   /**< \brief QSPI2 SLSO0 (SLSO20) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO1_P14_2_OUT;   /**< \brief QSPI2 SLSO1 (SLSO21) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO2_P14_6_OUT;   /**< \brief QSPI2 SLSO2 (SLSO22) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO3_P14_3_OUT;   /**< \brief QSPI2 SLSO3 (SLSO23) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO4_P14_7_OUT;   /**< \brief QSPI2 SLSO4 (SLSO24) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO5_P15_1_OUT;   /**< \brief QSPI2 SLSO5 (SLSO25) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO6_P33_13_OUT;  /**< \brief QSPI2 SLSO6 (SLSO26) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO7_P20_10_OUT;  /**< \brief QSPI2 SLSO7 (SLSO27) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO8_P20_6_OUT;   /**< \brief QSPI2 SLSO8 (SLSO28) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi2_SLSO9_P20_3_OUT;   /**< \brief QSPI2 SLSO9 (SLSO29) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO0_P02_4_OUT;   /**< \brief QSPI3 SLSO0 (SLSO30) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO11_P33_10_OUT; /**< \brief QSPI3 SLSO11 (SLSO311) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO12_P22_2_OUT;  /**< \brief QSPI3 SLSO12 (SLSO312) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO13_P23_1_OUT;  /**< \brief QSPI3 SLSO13 (SLSO313) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO1_P02_0_OUT;   /**< \brief QSPI3 SLSO1 (SLSO31) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO1_P33_9_OUT;   /**< \brief QSPI3 SLSO1 (SLSO31) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO2_P02_1_OUT;   /**< \brief QSPI3 SLSO2 (SLSO32) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO2_P33_8_OUT;   /**< \brief QSPI3 SLSO2 (SLSO32) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO3_P02_2_OUT;   /**< \brief QSPI3 SLSO3 (SLSO33) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO4_P02_3_OUT;   /**< \brief QSPI3 SLSO4 (SLSO34) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO4_P23_5_OUT;   /**< \brief QSPI3 SLSO4 (SLSO34) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO5_P02_8_OUT;   /**< \brief QSPI3 SLSO5 (SLSO35) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO5_P23_4_OUT;   /**< \brief QSPI3 SLSO5 (SLSO35) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO6_P00_8_OUT;   /**< \brief QSPI3 SLSO6 (SLSO36) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO7_P00_9_OUT;   /**< \brief QSPI3 SLSO7 (SLSO37) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO7_P33_7_OUT;   /**< \brief QSPI3 SLSO7 (SLSO37) */
IFX_EXTERN IfxQspi_Slso_Out  IfxQspi3_SLSO8_P10_5_OUT;   /**< \brief QSPI3 SLSO8 (SLSO38) */

/** \} */

#endif /* IFXQSPI_PINMAP_H */
