/**
 * \file IfxScu_PinMap.h
 * \brief SCU I/O map
 * \ingroup IfxLld_Scu
 *
 * \copyright Copyright (c) 2013 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1.1
 * $Date: $2013-08-07 08:57:48 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_Scu_pinmap SCU Pin Mapping
 * \ingroup IfxLld_Scu
 */

#ifndef IFXSCU_PINMAP_H
#define IFXSCU_PINMAP_H

#include <_Reg/IfxScu_reg.h>
#include <_Impl/IfxScu_cfg.h>
#include <Port/Std/IfxPort.h>

/** \addtogroup IfxLld_Scu_pinmap
 * \{ */

/** \brief EVR Wakeup pin mapping structure */
typedef const struct
{
    Ifx_SCU    *module;          /**< \brief Base address */
    IfxPort_Pin pin;             /**< \brief Port pin */
    Ifx_RxSel   select;          /**< \brief Input multiplexer value */
} IfxScu_Evrwup_In;

/** \brief Hardware Configuration pin mapping structure */
typedef const struct
{
    Ifx_SCU    *module;          /**< \brief Base address */
    IfxPort_Pin pin;             /**< \brief Port pin */
} IfxScu_Hwcfg_In;

/** \brief External Request pin mapping structure */
typedef const struct
{
    Ifx_SCU    *module;          /**< \brief Base address */
    uint8       requestId;       /**< \brief Request ID */
    IfxPort_Pin pin;             /**< \brief Port pin */
} IfxScu_Req_In;

/** \brief DCDC Sync pin mapping structure */
typedef const struct
{
    Ifx_SCU          *module;    /**< \brief Base address */
    IfxPort_Pin       pin;       /**< \brief Port pin */
    IfxPort_OutputIdx select;    /**< \brief Port control code */
} IfxScu_Dcdcsync_Out;

/** \brief Emergency Stop pin mapping structure */
typedef const struct
{
    Ifx_SCU    *module;          /**< \brief Base address */
    IfxPort_Pin pin;             /**< \brief Port pin */
    Ifx_RxSel   select;          /**< \brief Input multiplexer value */
} IfxScu_Emgstop_In;

/** \brief Watchdog Timer Lock pin mapping structure */
typedef const struct
{
    Ifx_SCU          *module;    /**< \brief Base address */
    IfxPort_Pin       pin;       /**< \brief Port pin */
    IfxPort_OutputIdx select;    /**< \brief Port control code */
} IfxScu_Wdtlck_Out;

/** \brief External Clock pin mapping structure */
typedef const struct
{
    Ifx_SCU          *module;                               /**< \brief Base address */
    IfxPort_Pin       pin;                                  /**< \brief Port pin */
    IfxPort_OutputIdx select;                               /**< \brief Port control code */
} IfxScu_Extclk_Out;

IFX_EXTERN IfxScu_Dcdcsync_Out IfxScu_DCDCSYNC_P32_2_OUT;   /**< \brief SCU DCDCSYNC (DCDCSYNC) */
IFX_EXTERN IfxScu_Dcdcsync_Out IfxScu_DCDCSYNC_P33_13_OUT;  /**< \brief SCU DCDCSYNC (DCDCSYNC) */
IFX_EXTERN IfxScu_Emgstop_In   IfxScu_EMGSTOPA_P33_8_IN;    /**< \brief SCU EMGSTOPA (EMGSTOPA) */
IFX_EXTERN IfxScu_Emgstop_In   IfxScu_EMGSTOPB_P21_2_IN;    /**< \brief SCU EMGSTOPB (EMGSTOPB) */
IFX_EXTERN IfxScu_Evrwup_In    IfxScu_EVRWUPA_P14_1_IN;     /**< \brief SCU EVRWUPA (EVRWUPA) */
IFX_EXTERN IfxScu_Evrwup_In    IfxScu_EVRWUPB_P15_1_IN;     /**< \brief SCU EVRWUPB (EVRWUPB) */
IFX_EXTERN IfxScu_Extclk_Out   IfxScu_EXTCLK0_P23_1_OUT;    /**< \brief SCU EXTCLK0 (EXTCLK0) */
IFX_EXTERN IfxScu_Extclk_Out   IfxScu_EXTCLK1_P11_12_OUT;   /**< \brief SCU EXTCLK1 (EXTCLK1) */
IFX_EXTERN IfxScu_Extclk_Out   IfxScu_EXTCLK1_P32_4_OUT;    /**< \brief SCU EXTCLK1 (EXTCLK1) */
IFX_EXTERN IfxScu_Hwcfg_In     IfxScu_HWCFG0DCLDO_P14_6_IN; /**< \brief SCU HWCFG0DCLDO (HWCFG0DCLDO) */
IFX_EXTERN IfxScu_Hwcfg_In     IfxScu_HWCFG1EVR33_P14_5_IN; /**< \brief SCU HWCFG1EVR33 (HWCFG1EVR33) */
IFX_EXTERN IfxScu_Hwcfg_In     IfxScu_HWCFG2EVR13_P14_2_IN; /**< \brief SCU HWCFG2EVR13 (HWCFG2EVR13) */
IFX_EXTERN IfxScu_Hwcfg_In     IfxScu_HWCFG3_BMI_P14_3_IN;  /**< \brief SCU HWCFG3_BMI (HWCFG3_BMI) */
IFX_EXTERN IfxScu_Hwcfg_In     IfxScu_HWCFG4_P10_5_IN;      /**< \brief SCU HWCFG4 (HWCFG4) */
IFX_EXTERN IfxScu_Hwcfg_In     IfxScu_HWCFG5_P10_6_IN;      /**< \brief SCU HWCFG5 (HWCFG5) */
IFX_EXTERN IfxScu_Hwcfg_In     IfxScu_HWCFG6_P14_4_IN;      /**< \brief SCU HWCFG6 (HWCFG6) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ0_P15_4_IN;        /**< \brief SCU REQ0 (REQ0) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ10_P14_3_IN;       /**< \brief SCU REQ10 (REQ10) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ11_P20_9_IN;       /**< \brief SCU REQ11 (REQ11) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ12_P11_10_IN;      /**< \brief SCU REQ12 (REQ12) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ13_P15_5_IN;       /**< \brief SCU REQ13 (REQ13) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ14_P02_1_IN;       /**< \brief SCU REQ14 (REQ14) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ15_P14_1_IN;       /**< \brief SCU REQ15 (REQ15) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ16_P15_1_IN;       /**< \brief SCU REQ16 (REQ16) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ1_P15_8_IN;        /**< \brief SCU REQ1 (REQ1) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ2_P10_2_IN;        /**< \brief SCU REQ2 (REQ2) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ3_P10_3_IN;        /**< \brief SCU REQ3 (REQ3) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ4_P10_7_IN;        /**< \brief SCU REQ4 (REQ4) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ5_P10_8_IN;        /**< \brief SCU REQ5 (REQ5) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ6_P02_0_IN;        /**< \brief SCU REQ6 (REQ6) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ7_P00_4_IN;        /**< \brief SCU REQ7 (REQ7) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ8_P33_7_IN;        /**< \brief SCU REQ8 (REQ8) */
IFX_EXTERN IfxScu_Req_In       IfxScu_REQ9_P20_0_IN;        /**< \brief SCU REQ9 (REQ9) */
IFX_EXTERN IfxScu_Wdtlck_Out   IfxScu_WDT0LCK_P20_8_OUT;    /**< \brief SCU WDT0LCK (WDT0LCK) */
IFX_EXTERN IfxScu_Wdtlck_Out   IfxScu_WDT1LCK_P20_7_OUT;    /**< \brief SCU WDT1LCK (WDT1LCK) */
IFX_EXTERN IfxScu_Wdtlck_Out   IfxScu_WDTSLCK_P20_9_OUT;    /**< \brief SCU WDTSLCK (WDTSLCK) */

/** \} */

#endif /* IFXSCU_PINMAP_H */
