/**
 * \file IfxVadc_PinMap.h
 * \brief VADC I/O map
 * \ingroup IfxLld_Vadc
 *
 * \copyright Copyright (c) 2013 Infineon Technologies AG. All rights reserved.
 *
 * $Revision: $1.1
 * $Date: $2013-08-07 08:57:50 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_Vadc_pinmap VADC Pin Mapping
 * \ingroup IfxLld_Vadc
 */

#ifndef IFXVADC_PINMAP_H
#define IFXVADC_PINMAP_H

#include <_Reg/IfxVadc_reg.h>
#include <_Impl/IfxVadc_cfg.h>
#include <Port/Std/IfxPort.h>

/** \addtogroup IfxLld_Vadc_pinmap
 * \{ */

/** \brief VADC Boundary Flag pin mapping structure */
typedef const struct
{
    Ifx_VADC         *module;    /**< \brief Base address */
    IfxVadc_GroupId   groupId;   /**< \brief Group ID */
    IfxPort_Pin       pin;       /**< \brief Port pin */
    IfxPort_OutputIdx select;    /**< \brief Port control code */
} IfxVadc_GxBfl_Out;

/** \brief VADC External Mux pin mapping structure */
typedef const struct
{
    Ifx_VADC         *module;                          /**< \brief Base address */
    IfxPort_Pin       pin;                             /**< \brief Port pin */
    IfxPort_OutputIdx select;                          /**< \brief Port control code */
} IfxVadc_Emux_Out;

IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX00_P02_6_OUT; /**< \brief VADC EMUX00 (VADCEMUX00) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX00_P33_3_OUT; /**< \brief VADC EMUX00 (VADCEMUX00) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX01_P02_7_OUT; /**< \brief VADC EMUX01 (VADCEMUX01) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX01_P33_2_OUT; /**< \brief VADC EMUX01 (VADCEMUX01) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX02_P02_8_OUT; /**< \brief VADC EMUX02 (VADCEMUX02) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX02_P33_1_OUT; /**< \brief VADC EMUX02 (VADCEMUX02) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX10_P00_6_OUT; /**< \brief VADC EMUX10 (VADCEMUX10) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX10_P33_6_OUT; /**< \brief VADC EMUX10 (VADCEMUX10) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX11_P00_7_OUT; /**< \brief VADC EMUX11 (VADCEMUX11) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX11_P33_5_OUT; /**< \brief VADC EMUX11 (VADCEMUX11) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX12_P00_8_OUT; /**< \brief VADC EMUX12 (VADCEMUX12) */
IFX_EXTERN IfxVadc_Emux_Out  IfxVadc_EMUX12_P33_4_OUT; /**< \brief VADC EMUX12 (VADCEMUX12) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G0BFL0_P33_4_OUT; /**< \brief VADC G0BFL0 (VADCG0BFL0) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G0BFL1_P33_5_OUT; /**< \brief VADC G0BFL1 (VADCG0BFL1) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G0BFL2_P33_6_OUT; /**< \brief VADC G0BFL2 (VADCG0BFL2) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G0BFL3_P33_7_OUT; /**< \brief VADC G0BFL3 (VADCG0BFL3) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G1BFL0_P33_0_OUT; /**< \brief VADC G1BFL0 (VADCG1BFL0) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G1BFL1_P33_1_OUT; /**< \brief VADC G1BFL1 (VADCG1BFL1) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G1BFL2_P33_2_OUT; /**< \brief VADC G1BFL2 (VADCG1BFL2) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G1BFL3_P33_3_OUT; /**< \brief VADC G1BFL3 (VADCG1BFL3) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G2BFL0_P00_4_OUT; /**< \brief VADC G2BFL0 (VADCG2BFL0) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G2BFL1_P00_5_OUT; /**< \brief VADC G2BFL1 (VADCG2BFL1) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G2BFL2_P00_6_OUT; /**< \brief VADC G2BFL2 (VADCG2BFL2) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G2BFL3_P00_7_OUT; /**< \brief VADC G2BFL3 (VADCG2BFL3) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G3BFL0_P10_0_OUT; /**< \brief VADC G3BFL0 (VADCG3BFL0) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G3BFL0_P10_6_OUT; /**< \brief VADC G3BFL0 (VADCG3BFL0) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G3BFL1_P10_1_OUT; /**< \brief VADC G3BFL1 (VADCG3BFL1) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G3BFL1_P10_7_OUT; /**< \brief VADC G3BFL1 (VADCG3BFL1) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G3BFL2_P10_2_OUT; /**< \brief VADC G3BFL2 (VADCG3BFL2) */
IFX_EXTERN IfxVadc_GxBfl_Out IfxVadc_G3BFL3_P10_3_OUT; /**< \brief VADC G3BFL3 (VADCG3BFL3) */

/** \} */

#endif /* IFXVADC_PINMAP_H */
