/**
 * \file IfxMcds_reg.h
 * \brief
 * \copyright Copyright (c) 2012 Infineon Technologies AG. All rights reserved.
 *
 *
 * $Revision: $1527.1
 * $Date: $2013-06-10 08:50:01 GMT
 *
 *                                 IMPORTANT NOTICE
 *
 *
 * Infineon Technologies AG (Infineon) is supplying this file for use
 * exclusively with Infineon's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * \defgroup IfxLld_mcds_cfg Mcds address
 * \ingroup IfxLld_mcds
 * 
 * \defgroup IfxLld_mcds_cfg_base_address Base address
 * \ingroup IfxLld_mcds_cfg
 * 
 * \defgroup IfxLld_mcds_cfg_mcds 2-MCDS
 * \ingroup IfxLld_mcds_cfg
 * 
 */
#ifndef IFXMCDS_REG_H
#define IFXMCDS_REG_H
/******************************************************************************/
#include "IfxMcds_regdef.h"
/******************************************************************************/
/** \addtogroup IfxLld_mcds_cfg_base_address
 * \{  */

/** \\brief  MCDS object */
#define MODULE_MCDS /* lint --e(923)*/ ((*(Ifx_MCDS*)0xF90E8000u))
/** \}  */
/******************************************************************************/
/******************************************************************************/
/** \addtogroup IfxLld_mcds_cfg_mcds
 * \{  */

/** \\brief  0, Clock Control Register */
#define MCDS_CLC /* lint --e(923)*/ (*(volatile Ifx_MCDS_CLC*)0xF90E8000u)

/** \\brief  10, MCDS Control Register */
#define MCDS_CT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CT*)0xF90E8010u)

/** \\brief  204, Trace Buffer Bottom Register */
#define MCDS_FIFOBOT /* lint --e(923)*/ (*(volatile Ifx_MCDS_FIFOBOT*)0xF90E8204u)

/** \\brief  210, Trace Buffer Control Register */
#define MCDS_FIFOCTL /* lint --e(923)*/ (*(volatile Ifx_MCDS_FIFOCTL*)0xF90E8210u)

/** \\brief  200, Trace Buffer Write Pointer */
#define MCDS_FIFONOW /* lint --e(923)*/ (*(volatile Ifx_MCDS_FIFONOW*)0xF90E8200u)

/** \\brief  208, Trace Buffer PRE/POST Register */
#define MCDS_FIFOPRE /* lint --e(923)*/ (*(volatile Ifx_MCDS_FIFOPRE*)0xF90E8208u)

/** \\brief  20C, Trace Buffer Top Register */
#define MCDS_FIFOTOP /* lint --e(923)*/ (*(volatile Ifx_MCDS_FIFOTOP*)0xF90E820Cu)

/** \\brief  214, Trace Buffer Comparator Register */
#define MCDS_FIFOWARN0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_FIFOWARN0*)0xF90E8214u)

/** \\brief  218, Trace Buffer Comparator Register */
#define MCDS_FIFOWARN1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_FIFOWARN1*)0xF90E8218u)

/** \\brief  8, Module Identification Register */
#define MCDS_ID /* lint --e(923)*/ (*(volatile Ifx_MCDS_ID*)0xF90E8008u)

/** \\brief  880, Action Definition Register */
#define MCDS_MCX_ACT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8880u)

/** Alias (User Manual Name) for MCDS_MCX_ACT0.
* To use register names with standard convension, please use MCDS_MCX_ACT0.
*/
#define	MCDS_MCXACT0	(MCDS_MCX_ACT0)

/** \\brief  884, Action Definition Register */
#define MCDS_MCX_ACT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8884u)

/** Alias (User Manual Name) for MCDS_MCX_ACT1.
* To use register names with standard convension, please use MCDS_MCX_ACT1.
*/
#define	MCDS_MCXACT1	(MCDS_MCX_ACT1)

/** \\brief  8A8, Action Definition Register */
#define MCDS_MCX_ACT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88A8u)

/** Alias (User Manual Name) for MCDS_MCX_ACT10.
* To use register names with standard convension, please use MCDS_MCX_ACT10.
*/
#define	MCDS_MCXACT10	(MCDS_MCX_ACT10)

/** \\brief  8AC, Action Definition Register */
#define MCDS_MCX_ACT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88ACu)

/** Alias (User Manual Name) for MCDS_MCX_ACT11.
* To use register names with standard convension, please use MCDS_MCX_ACT11.
*/
#define	MCDS_MCXACT11	(MCDS_MCX_ACT11)

/** \\brief  8B0, Action Definition Register */
#define MCDS_MCX_ACT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88B0u)

/** Alias (User Manual Name) for MCDS_MCX_ACT12.
* To use register names with standard convension, please use MCDS_MCX_ACT12.
*/
#define	MCDS_MCXACT12	(MCDS_MCX_ACT12)

/** \\brief  8B4, Action Definition Register */
#define MCDS_MCX_ACT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88B4u)

/** Alias (User Manual Name) for MCDS_MCX_ACT13.
* To use register names with standard convension, please use MCDS_MCX_ACT13.
*/
#define	MCDS_MCXACT13	(MCDS_MCX_ACT13)

/** \\brief  8B8, Action Definition Register */
#define MCDS_MCX_ACT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88B8u)

/** Alias (User Manual Name) for MCDS_MCX_ACT14.
* To use register names with standard convension, please use MCDS_MCX_ACT14.
*/
#define	MCDS_MCXACT14	(MCDS_MCX_ACT14)

/** \\brief  8BC, Action Definition Register */
#define MCDS_MCX_ACT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88BCu)

/** Alias (User Manual Name) for MCDS_MCX_ACT15.
* To use register names with standard convension, please use MCDS_MCX_ACT15.
*/
#define	MCDS_MCXACT15	(MCDS_MCX_ACT15)

/** \\brief  8C0, Action Definition Register */
#define MCDS_MCX_ACT16 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88C0u)

/** Alias (User Manual Name) for MCDS_MCX_ACT16.
* To use register names with standard convension, please use MCDS_MCX_ACT16.
*/
#define	MCDS_MCXACT16	(MCDS_MCX_ACT16)

/** \\brief  8C4, Action Definition Register */
#define MCDS_MCX_ACT17 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88C4u)

/** Alias (User Manual Name) for MCDS_MCX_ACT17.
* To use register names with standard convension, please use MCDS_MCX_ACT17.
*/
#define	MCDS_MCXACT17	(MCDS_MCX_ACT17)

/** \\brief  8C8, Action Definition Register */
#define MCDS_MCX_ACT18 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88C8u)

/** Alias (User Manual Name) for MCDS_MCX_ACT18.
* To use register names with standard convension, please use MCDS_MCX_ACT18.
*/
#define	MCDS_MCXACT18	(MCDS_MCX_ACT18)

/** \\brief  8CC, Action Definition Register */
#define MCDS_MCX_ACT19 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88CCu)

/** Alias (User Manual Name) for MCDS_MCX_ACT19.
* To use register names with standard convension, please use MCDS_MCX_ACT19.
*/
#define	MCDS_MCXACT19	(MCDS_MCX_ACT19)

/** \\brief  888, Action Definition Register */
#define MCDS_MCX_ACT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8888u)

/** Alias (User Manual Name) for MCDS_MCX_ACT2.
* To use register names with standard convension, please use MCDS_MCX_ACT2.
*/
#define	MCDS_MCXACT2	(MCDS_MCX_ACT2)

/** \\brief  8D0, Action Definition Register */
#define MCDS_MCX_ACT20 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88D0u)

/** Alias (User Manual Name) for MCDS_MCX_ACT20.
* To use register names with standard convension, please use MCDS_MCX_ACT20.
*/
#define	MCDS_MCXACT20	(MCDS_MCX_ACT20)

/** \\brief  8D4, Action Definition Register */
#define MCDS_MCX_ACT21 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88D4u)

/** Alias (User Manual Name) for MCDS_MCX_ACT21.
* To use register names with standard convension, please use MCDS_MCX_ACT21.
*/
#define	MCDS_MCXACT21	(MCDS_MCX_ACT21)

/** \\brief  8D8, Action Definition Register */
#define MCDS_MCX_ACT22 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88D8u)

/** Alias (User Manual Name) for MCDS_MCX_ACT22.
* To use register names with standard convension, please use MCDS_MCX_ACT22.
*/
#define	MCDS_MCXACT22	(MCDS_MCX_ACT22)

/** \\brief  8DC, Action Definition Register */
#define MCDS_MCX_ACT23 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88DCu)

/** Alias (User Manual Name) for MCDS_MCX_ACT23.
* To use register names with standard convension, please use MCDS_MCX_ACT23.
*/
#define	MCDS_MCXACT23	(MCDS_MCX_ACT23)

/** \\brief  8E0, Action Definition Register */
#define MCDS_MCX_ACT24 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88E0u)

/** Alias (User Manual Name) for MCDS_MCX_ACT24.
* To use register names with standard convension, please use MCDS_MCX_ACT24.
*/
#define	MCDS_MCXACT24	(MCDS_MCX_ACT24)

/** \\brief  8E4, Action Definition Register */
#define MCDS_MCX_ACT25 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88E4u)

/** Alias (User Manual Name) for MCDS_MCX_ACT25.
* To use register names with standard convension, please use MCDS_MCX_ACT25.
*/
#define	MCDS_MCXACT25	(MCDS_MCX_ACT25)

/** \\brief  8E8, Action Definition Register */
#define MCDS_MCX_ACT26 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88E8u)

/** Alias (User Manual Name) for MCDS_MCX_ACT26.
* To use register names with standard convension, please use MCDS_MCX_ACT26.
*/
#define	MCDS_MCXACT26	(MCDS_MCX_ACT26)

/** \\brief  8EC, Action Definition Register */
#define MCDS_MCX_ACT27 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88ECu)

/** Alias (User Manual Name) for MCDS_MCX_ACT27.
* To use register names with standard convension, please use MCDS_MCX_ACT27.
*/
#define	MCDS_MCXACT27	(MCDS_MCX_ACT27)

/** \\brief  8F0, Action Definition Register */
#define MCDS_MCX_ACT28 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88F0u)

/** Alias (User Manual Name) for MCDS_MCX_ACT28.
* To use register names with standard convension, please use MCDS_MCX_ACT28.
*/
#define	MCDS_MCXACT28	(MCDS_MCX_ACT28)

/** \\brief  8F4, Action Definition Register */
#define MCDS_MCX_ACT29 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88F4u)

/** Alias (User Manual Name) for MCDS_MCX_ACT29.
* To use register names with standard convension, please use MCDS_MCX_ACT29.
*/
#define	MCDS_MCXACT29	(MCDS_MCX_ACT29)

/** \\brief  88C, Action Definition Register */
#define MCDS_MCX_ACT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E888Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT3.
* To use register names with standard convension, please use MCDS_MCX_ACT3.
*/
#define	MCDS_MCXACT3	(MCDS_MCX_ACT3)

/** \\brief  8F8, Action Definition Register */
#define MCDS_MCX_ACT30 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88F8u)

/** Alias (User Manual Name) for MCDS_MCX_ACT30.
* To use register names with standard convension, please use MCDS_MCX_ACT30.
*/
#define	MCDS_MCXACT30	(MCDS_MCX_ACT30)

/** \\brief  8FC, Action Definition Register */
#define MCDS_MCX_ACT31 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88FCu)

/** Alias (User Manual Name) for MCDS_MCX_ACT31.
* To use register names with standard convension, please use MCDS_MCX_ACT31.
*/
#define	MCDS_MCXACT31	(MCDS_MCX_ACT31)

/** \\brief  900, Action Definition Register */
#define MCDS_MCX_ACT32 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8900u)

/** Alias (User Manual Name) for MCDS_MCX_ACT32.
* To use register names with standard convension, please use MCDS_MCX_ACT32.
*/
#define	MCDS_MCXACT32	(MCDS_MCX_ACT32)

/** \\brief  904, Action Definition Register */
#define MCDS_MCX_ACT33 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8904u)

/** Alias (User Manual Name) for MCDS_MCX_ACT33.
* To use register names with standard convension, please use MCDS_MCX_ACT33.
*/
#define	MCDS_MCXACT33	(MCDS_MCX_ACT33)

/** \\brief  908, Action Definition Register */
#define MCDS_MCX_ACT34 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8908u)

/** Alias (User Manual Name) for MCDS_MCX_ACT34.
* To use register names with standard convension, please use MCDS_MCX_ACT34.
*/
#define	MCDS_MCXACT34	(MCDS_MCX_ACT34)

/** \\brief  90C, Action Definition Register */
#define MCDS_MCX_ACT35 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E890Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT35.
* To use register names with standard convension, please use MCDS_MCX_ACT35.
*/
#define	MCDS_MCXACT35	(MCDS_MCX_ACT35)

/** \\brief  910, Action Definition Register */
#define MCDS_MCX_ACT36 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8910u)

/** Alias (User Manual Name) for MCDS_MCX_ACT36.
* To use register names with standard convension, please use MCDS_MCX_ACT36.
*/
#define	MCDS_MCXACT36	(MCDS_MCX_ACT36)

/** \\brief  914, Action Definition Register */
#define MCDS_MCX_ACT37 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8914u)

/** Alias (User Manual Name) for MCDS_MCX_ACT37.
* To use register names with standard convension, please use MCDS_MCX_ACT37.
*/
#define	MCDS_MCXACT37	(MCDS_MCX_ACT37)

/** \\brief  918, Action Definition Register */
#define MCDS_MCX_ACT38 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8918u)

/** Alias (User Manual Name) for MCDS_MCX_ACT38.
* To use register names with standard convension, please use MCDS_MCX_ACT38.
*/
#define	MCDS_MCXACT38	(MCDS_MCX_ACT38)

/** \\brief  91C, Action Definition Register */
#define MCDS_MCX_ACT39 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E891Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT39.
* To use register names with standard convension, please use MCDS_MCX_ACT39.
*/
#define	MCDS_MCXACT39	(MCDS_MCX_ACT39)

/** \\brief  890, Action Definition Register */
#define MCDS_MCX_ACT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8890u)

/** Alias (User Manual Name) for MCDS_MCX_ACT4.
* To use register names with standard convension, please use MCDS_MCX_ACT4.
*/
#define	MCDS_MCXACT4	(MCDS_MCX_ACT4)

/** \\brief  920, Action Definition Register */
#define MCDS_MCX_ACT40 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8920u)

/** Alias (User Manual Name) for MCDS_MCX_ACT40.
* To use register names with standard convension, please use MCDS_MCX_ACT40.
*/
#define	MCDS_MCXACT40	(MCDS_MCX_ACT40)

/** \\brief  924, Action Definition Register */
#define MCDS_MCX_ACT41 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8924u)

/** Alias (User Manual Name) for MCDS_MCX_ACT41.
* To use register names with standard convension, please use MCDS_MCX_ACT41.
*/
#define	MCDS_MCXACT41	(MCDS_MCX_ACT41)

/** \\brief  928, Action Definition Register */
#define MCDS_MCX_ACT42 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8928u)

/** Alias (User Manual Name) for MCDS_MCX_ACT42.
* To use register names with standard convension, please use MCDS_MCX_ACT42.
*/
#define	MCDS_MCXACT42	(MCDS_MCX_ACT42)

/** \\brief  92C, Action Definition Register */
#define MCDS_MCX_ACT43 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E892Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT43.
* To use register names with standard convension, please use MCDS_MCX_ACT43.
*/
#define	MCDS_MCXACT43	(MCDS_MCX_ACT43)

/** \\brief  930, Action Definition Register */
#define MCDS_MCX_ACT44 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8930u)

/** Alias (User Manual Name) for MCDS_MCX_ACT44.
* To use register names with standard convension, please use MCDS_MCX_ACT44.
*/
#define	MCDS_MCXACT44	(MCDS_MCX_ACT44)

/** \\brief  934, Action Definition Register */
#define MCDS_MCX_ACT45 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8934u)

/** Alias (User Manual Name) for MCDS_MCX_ACT45.
* To use register names with standard convension, please use MCDS_MCX_ACT45.
*/
#define	MCDS_MCXACT45	(MCDS_MCX_ACT45)

/** \\brief  938, Action Definition Register */
#define MCDS_MCX_ACT46 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8938u)

/** Alias (User Manual Name) for MCDS_MCX_ACT46.
* To use register names with standard convension, please use MCDS_MCX_ACT46.
*/
#define	MCDS_MCXACT46	(MCDS_MCX_ACT46)

/** \\brief  93C, Action Definition Register */
#define MCDS_MCX_ACT47 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E893Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT47.
* To use register names with standard convension, please use MCDS_MCX_ACT47.
*/
#define	MCDS_MCXACT47	(MCDS_MCX_ACT47)

/** \\brief  940, Action Definition Register */
#define MCDS_MCX_ACT48 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8940u)

/** Alias (User Manual Name) for MCDS_MCX_ACT48.
* To use register names with standard convension, please use MCDS_MCX_ACT48.
*/
#define	MCDS_MCXACT48	(MCDS_MCX_ACT48)

/** \\brief  944, Action Definition Register */
#define MCDS_MCX_ACT49 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8944u)

/** Alias (User Manual Name) for MCDS_MCX_ACT49.
* To use register names with standard convension, please use MCDS_MCX_ACT49.
*/
#define	MCDS_MCXACT49	(MCDS_MCX_ACT49)

/** \\brief  894, Action Definition Register */
#define MCDS_MCX_ACT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8894u)

/** Alias (User Manual Name) for MCDS_MCX_ACT5.
* To use register names with standard convension, please use MCDS_MCX_ACT5.
*/
#define	MCDS_MCXACT5	(MCDS_MCX_ACT5)

/** \\brief  948, Action Definition Register */
#define MCDS_MCX_ACT50 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8948u)

/** Alias (User Manual Name) for MCDS_MCX_ACT50.
* To use register names with standard convension, please use MCDS_MCX_ACT50.
*/
#define	MCDS_MCXACT50	(MCDS_MCX_ACT50)

/** \\brief  94C, Action Definition Register */
#define MCDS_MCX_ACT51 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E894Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT51.
* To use register names with standard convension, please use MCDS_MCX_ACT51.
*/
#define	MCDS_MCXACT51	(MCDS_MCX_ACT51)

/** \\brief  950, Action Definition Register */
#define MCDS_MCX_ACT52 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8950u)

/** Alias (User Manual Name) for MCDS_MCX_ACT52.
* To use register names with standard convension, please use MCDS_MCX_ACT52.
*/
#define	MCDS_MCXACT52	(MCDS_MCX_ACT52)

/** \\brief  954, Action Definition Register */
#define MCDS_MCX_ACT53 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8954u)

/** Alias (User Manual Name) for MCDS_MCX_ACT53.
* To use register names with standard convension, please use MCDS_MCX_ACT53.
*/
#define	MCDS_MCXACT53	(MCDS_MCX_ACT53)

/** \\brief  958, Action Definition Register */
#define MCDS_MCX_ACT54 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8958u)

/** Alias (User Manual Name) for MCDS_MCX_ACT54.
* To use register names with standard convension, please use MCDS_MCX_ACT54.
*/
#define	MCDS_MCXACT54	(MCDS_MCX_ACT54)

/** \\brief  95C, Action Definition Register */
#define MCDS_MCX_ACT55 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E895Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT55.
* To use register names with standard convension, please use MCDS_MCX_ACT55.
*/
#define	MCDS_MCXACT55	(MCDS_MCX_ACT55)

/** \\brief  960, Action Definition Register */
#define MCDS_MCX_ACT56 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8960u)

/** Alias (User Manual Name) for MCDS_MCX_ACT56.
* To use register names with standard convension, please use MCDS_MCX_ACT56.
*/
#define	MCDS_MCXACT56	(MCDS_MCX_ACT56)

/** \\brief  964, Action Definition Register */
#define MCDS_MCX_ACT57 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8964u)

/** Alias (User Manual Name) for MCDS_MCX_ACT57.
* To use register names with standard convension, please use MCDS_MCX_ACT57.
*/
#define	MCDS_MCXACT57	(MCDS_MCX_ACT57)

/** \\brief  968, Action Definition Register */
#define MCDS_MCX_ACT58 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8968u)

/** Alias (User Manual Name) for MCDS_MCX_ACT58.
* To use register names with standard convension, please use MCDS_MCX_ACT58.
*/
#define	MCDS_MCXACT58	(MCDS_MCX_ACT58)

/** \\brief  96C, Action Definition Register */
#define MCDS_MCX_ACT59 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E896Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT59.
* To use register names with standard convension, please use MCDS_MCX_ACT59.
*/
#define	MCDS_MCXACT59	(MCDS_MCX_ACT59)

/** \\brief  898, Action Definition Register */
#define MCDS_MCX_ACT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8898u)

/** Alias (User Manual Name) for MCDS_MCX_ACT6.
* To use register names with standard convension, please use MCDS_MCX_ACT6.
*/
#define	MCDS_MCXACT6	(MCDS_MCX_ACT6)

/** \\brief  970, Action Definition Register */
#define MCDS_MCX_ACT60 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8970u)

/** Alias (User Manual Name) for MCDS_MCX_ACT60.
* To use register names with standard convension, please use MCDS_MCX_ACT60.
*/
#define	MCDS_MCXACT60	(MCDS_MCX_ACT60)

/** \\brief  974, Action Definition Register */
#define MCDS_MCX_ACT61 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8974u)

/** Alias (User Manual Name) for MCDS_MCX_ACT61.
* To use register names with standard convension, please use MCDS_MCX_ACT61.
*/
#define	MCDS_MCXACT61	(MCDS_MCX_ACT61)

/** \\brief  978, Action Definition Register */
#define MCDS_MCX_ACT62 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8978u)

/** Alias (User Manual Name) for MCDS_MCX_ACT62.
* To use register names with standard convension, please use MCDS_MCX_ACT62.
*/
#define	MCDS_MCXACT62	(MCDS_MCX_ACT62)

/** \\brief  97C, Action Definition Register */
#define MCDS_MCX_ACT63 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E897Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT63.
* To use register names with standard convension, please use MCDS_MCX_ACT63.
*/
#define	MCDS_MCXACT63	(MCDS_MCX_ACT63)

/** \\brief  980, Action Definition Register */
#define MCDS_MCX_ACT64 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8980u)

/** Alias (User Manual Name) for MCDS_MCX_ACT64.
* To use register names with standard convension, please use MCDS_MCX_ACT64.
*/
#define	MCDS_MCXACT64	(MCDS_MCX_ACT64)

/** \\brief  984, Action Definition Register */
#define MCDS_MCX_ACT65 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8984u)

/** Alias (User Manual Name) for MCDS_MCX_ACT65.
* To use register names with standard convension, please use MCDS_MCX_ACT65.
*/
#define	MCDS_MCXACT65	(MCDS_MCX_ACT65)

/** \\brief  988, Action Definition Register */
#define MCDS_MCX_ACT66 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8988u)

/** Alias (User Manual Name) for MCDS_MCX_ACT66.
* To use register names with standard convension, please use MCDS_MCX_ACT66.
*/
#define	MCDS_MCXACT66	(MCDS_MCX_ACT66)

/** \\brief  98C, Action Definition Register */
#define MCDS_MCX_ACT67 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E898Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT67.
* To use register names with standard convension, please use MCDS_MCX_ACT67.
*/
#define	MCDS_MCXACT67	(MCDS_MCX_ACT67)

/** \\brief  990, Action Definition Register */
#define MCDS_MCX_ACT68 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8990u)

/** Alias (User Manual Name) for MCDS_MCX_ACT68.
* To use register names with standard convension, please use MCDS_MCX_ACT68.
*/
#define	MCDS_MCXACT68	(MCDS_MCX_ACT68)

/** \\brief  994, Action Definition Register */
#define MCDS_MCX_ACT69 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8994u)

/** Alias (User Manual Name) for MCDS_MCX_ACT69.
* To use register names with standard convension, please use MCDS_MCX_ACT69.
*/
#define	MCDS_MCXACT69	(MCDS_MCX_ACT69)

/** \\brief  89C, Action Definition Register */
#define MCDS_MCX_ACT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E889Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT7.
* To use register names with standard convension, please use MCDS_MCX_ACT7.
*/
#define	MCDS_MCXACT7	(MCDS_MCX_ACT7)

/** \\brief  998, Action Definition Register */
#define MCDS_MCX_ACT70 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E8998u)

/** Alias (User Manual Name) for MCDS_MCX_ACT70.
* To use register names with standard convension, please use MCDS_MCX_ACT70.
*/
#define	MCDS_MCXACT70	(MCDS_MCX_ACT70)

/** \\brief  99C, Action Definition Register */
#define MCDS_MCX_ACT71 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E899Cu)

/** Alias (User Manual Name) for MCDS_MCX_ACT71.
* To use register names with standard convension, please use MCDS_MCX_ACT71.
*/
#define	MCDS_MCXACT71	(MCDS_MCX_ACT71)

/** \\brief  8A0, Action Definition Register */
#define MCDS_MCX_ACT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88A0u)

/** Alias (User Manual Name) for MCDS_MCX_ACT8.
* To use register names with standard convension, please use MCDS_MCX_ACT8.
*/
#define	MCDS_MCXACT8	(MCDS_MCX_ACT8)

/** \\brief  8A4, Action Definition Register */
#define MCDS_MCX_ACT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90E88A4u)

/** Alias (User Manual Name) for MCDS_MCX_ACT9.
* To use register names with standard convension, please use MCDS_MCX_ACT9.
*/
#define	MCDS_MCXACT9	(MCDS_MCX_ACT9)

/** \\brief  A00, Counter Control Register */
#define MCDS_MCX_CNT0_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A00u)

/** Alias (User Manual Name) for MCDS_MCX_CNT0_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT0_CCL.
*/
#define	MCDS_MCXCCL0	(MCDS_MCX_CNT0_CCL)

/** \\brief  A08, Current Count Register */
#define MCDS_MCX_CNT0_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A08u)

/** Alias (User Manual Name) for MCDS_MCX_CNT0_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT0_CNT.
*/
#define	MCDS_MCXCNT0	(MCDS_MCX_CNT0_CNT)

/** \\brief  A04, Counter Limit Register */
#define MCDS_MCX_CNT0_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A04u)

/** Alias (User Manual Name) for MCDS_MCX_CNT0_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT0_LMT.
*/
#define	MCDS_MCXLMT0	(MCDS_MCX_CNT0_LMT)

/** \\brief  AA0, Counter Control Register */
#define MCDS_MCX_CNT10_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8AA0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT10_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT10_CCL.
*/
#define	MCDS_MCXCCL10	(MCDS_MCX_CNT10_CCL)

/** \\brief  AA8, Current Count Register */
#define MCDS_MCX_CNT10_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8AA8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT10_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT10_CNT.
*/
#define	MCDS_MCXCNT10	(MCDS_MCX_CNT10_CNT)

/** \\brief  AA4, Counter Limit Register */
#define MCDS_MCX_CNT10_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8AA4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT10_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT10_LMT.
*/
#define	MCDS_MCXLMT10	(MCDS_MCX_CNT10_LMT)

/** \\brief  AB0, Counter Control Register */
#define MCDS_MCX_CNT11_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8AB0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT11_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT11_CCL.
*/
#define	MCDS_MCXCCL11	(MCDS_MCX_CNT11_CCL)

/** \\brief  AB8, Current Count Register */
#define MCDS_MCX_CNT11_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8AB8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT11_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT11_CNT.
*/
#define	MCDS_MCXCNT11	(MCDS_MCX_CNT11_CNT)

/** \\brief  AB4, Counter Limit Register */
#define MCDS_MCX_CNT11_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8AB4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT11_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT11_LMT.
*/
#define	MCDS_MCXLMT11	(MCDS_MCX_CNT11_LMT)

/** \\brief  AC0, Counter Control Register */
#define MCDS_MCX_CNT12_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8AC0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT12_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT12_CCL.
*/
#define	MCDS_MCXCCL12	(MCDS_MCX_CNT12_CCL)

/** \\brief  AC8, Current Count Register */
#define MCDS_MCX_CNT12_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8AC8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT12_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT12_CNT.
*/
#define	MCDS_MCXCNT12	(MCDS_MCX_CNT12_CNT)

/** \\brief  AC4, Counter Limit Register */
#define MCDS_MCX_CNT12_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8AC4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT12_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT12_LMT.
*/
#define	MCDS_MCXLMT12	(MCDS_MCX_CNT12_LMT)

/** \\brief  AD0, Counter Control Register */
#define MCDS_MCX_CNT13_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8AD0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT13_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT13_CCL.
*/
#define	MCDS_MCXCCL13	(MCDS_MCX_CNT13_CCL)

/** \\brief  AD8, Current Count Register */
#define MCDS_MCX_CNT13_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8AD8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT13_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT13_CNT.
*/
#define	MCDS_MCXCNT13	(MCDS_MCX_CNT13_CNT)

/** \\brief  AD4, Counter Limit Register */
#define MCDS_MCX_CNT13_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8AD4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT13_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT13_LMT.
*/
#define	MCDS_MCXLMT13	(MCDS_MCX_CNT13_LMT)

/** \\brief  AE0, Counter Control Register */
#define MCDS_MCX_CNT14_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8AE0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT14_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT14_CCL.
*/
#define	MCDS_MCXCCL14	(MCDS_MCX_CNT14_CCL)

/** \\brief  AE8, Current Count Register */
#define MCDS_MCX_CNT14_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8AE8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT14_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT14_CNT.
*/
#define	MCDS_MCXCNT14	(MCDS_MCX_CNT14_CNT)

/** \\brief  AE4, Counter Limit Register */
#define MCDS_MCX_CNT14_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8AE4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT14_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT14_LMT.
*/
#define	MCDS_MCXLMT14	(MCDS_MCX_CNT14_LMT)

/** \\brief  AF0, Counter Control Register */
#define MCDS_MCX_CNT15_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8AF0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT15_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT15_CCL.
*/
#define	MCDS_MCXCCL15	(MCDS_MCX_CNT15_CCL)

/** \\brief  AF8, Current Count Register */
#define MCDS_MCX_CNT15_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8AF8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT15_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT15_CNT.
*/
#define	MCDS_MCXCNT15	(MCDS_MCX_CNT15_CNT)

/** \\brief  AF4, Counter Limit Register */
#define MCDS_MCX_CNT15_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8AF4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT15_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT15_LMT.
*/
#define	MCDS_MCXLMT15	(MCDS_MCX_CNT15_LMT)

/** \\brief  B00, Counter Control Register */
#define MCDS_MCX_CNT16_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B00u)

/** Alias (User Manual Name) for MCDS_MCX_CNT16_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT16_CCL.
*/
#define	MCDS_MCXCCL16	(MCDS_MCX_CNT16_CCL)

/** \\brief  B08, Current Count Register */
#define MCDS_MCX_CNT16_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B08u)

/** Alias (User Manual Name) for MCDS_MCX_CNT16_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT16_CNT.
*/
#define	MCDS_MCXCNT16	(MCDS_MCX_CNT16_CNT)

/** \\brief  B04, Counter Limit Register */
#define MCDS_MCX_CNT16_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B04u)

/** Alias (User Manual Name) for MCDS_MCX_CNT16_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT16_LMT.
*/
#define	MCDS_MCXLMT16	(MCDS_MCX_CNT16_LMT)

/** \\brief  B10, Counter Control Register */
#define MCDS_MCX_CNT17_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B10u)

/** Alias (User Manual Name) for MCDS_MCX_CNT17_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT17_CCL.
*/
#define	MCDS_MCXCCL17	(MCDS_MCX_CNT17_CCL)

/** \\brief  B18, Current Count Register */
#define MCDS_MCX_CNT17_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B18u)

/** Alias (User Manual Name) for MCDS_MCX_CNT17_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT17_CNT.
*/
#define	MCDS_MCXCNT17	(MCDS_MCX_CNT17_CNT)

/** \\brief  B14, Counter Limit Register */
#define MCDS_MCX_CNT17_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B14u)

/** Alias (User Manual Name) for MCDS_MCX_CNT17_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT17_LMT.
*/
#define	MCDS_MCXLMT17	(MCDS_MCX_CNT17_LMT)

/** \\brief  B20, Counter Control Register */
#define MCDS_MCX_CNT18_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B20u)

/** Alias (User Manual Name) for MCDS_MCX_CNT18_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT18_CCL.
*/
#define	MCDS_MCXCCL18	(MCDS_MCX_CNT18_CCL)

/** \\brief  B28, Current Count Register */
#define MCDS_MCX_CNT18_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B28u)

/** Alias (User Manual Name) for MCDS_MCX_CNT18_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT18_CNT.
*/
#define	MCDS_MCXCNT18	(MCDS_MCX_CNT18_CNT)

/** \\brief  B24, Counter Limit Register */
#define MCDS_MCX_CNT18_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B24u)

/** Alias (User Manual Name) for MCDS_MCX_CNT18_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT18_LMT.
*/
#define	MCDS_MCXLMT18	(MCDS_MCX_CNT18_LMT)

/** \\brief  B30, Counter Control Register */
#define MCDS_MCX_CNT19_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B30u)

/** Alias (User Manual Name) for MCDS_MCX_CNT19_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT19_CCL.
*/
#define	MCDS_MCXCCL19	(MCDS_MCX_CNT19_CCL)

/** \\brief  B38, Current Count Register */
#define MCDS_MCX_CNT19_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B38u)

/** Alias (User Manual Name) for MCDS_MCX_CNT19_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT19_CNT.
*/
#define	MCDS_MCXCNT19	(MCDS_MCX_CNT19_CNT)

/** \\brief  B34, Counter Limit Register */
#define MCDS_MCX_CNT19_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B34u)

/** Alias (User Manual Name) for MCDS_MCX_CNT19_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT19_LMT.
*/
#define	MCDS_MCXLMT19	(MCDS_MCX_CNT19_LMT)

/** \\brief  A10, Counter Control Register */
#define MCDS_MCX_CNT1_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A10u)

/** Alias (User Manual Name) for MCDS_MCX_CNT1_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT1_CCL.
*/
#define	MCDS_MCXCCL1	(MCDS_MCX_CNT1_CCL)

/** \\brief  A18, Current Count Register */
#define MCDS_MCX_CNT1_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A18u)

/** Alias (User Manual Name) for MCDS_MCX_CNT1_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT1_CNT.
*/
#define	MCDS_MCXCNT1	(MCDS_MCX_CNT1_CNT)

/** \\brief  A14, Counter Limit Register */
#define MCDS_MCX_CNT1_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A14u)

/** Alias (User Manual Name) for MCDS_MCX_CNT1_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT1_LMT.
*/
#define	MCDS_MCXLMT1	(MCDS_MCX_CNT1_LMT)

/** \\brief  B40, Counter Control Register */
#define MCDS_MCX_CNT20_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B40u)

/** Alias (User Manual Name) for MCDS_MCX_CNT20_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT20_CCL.
*/
#define	MCDS_MCXCCL20	(MCDS_MCX_CNT20_CCL)

/** \\brief  B48, Current Count Register */
#define MCDS_MCX_CNT20_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B48u)

/** Alias (User Manual Name) for MCDS_MCX_CNT20_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT20_CNT.
*/
#define	MCDS_MCXCNT20	(MCDS_MCX_CNT20_CNT)

/** \\brief  B44, Counter Limit Register */
#define MCDS_MCX_CNT20_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B44u)

/** Alias (User Manual Name) for MCDS_MCX_CNT20_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT20_LMT.
*/
#define	MCDS_MCXLMT20	(MCDS_MCX_CNT20_LMT)

/** \\brief  B50, Counter Control Register */
#define MCDS_MCX_CNT21_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B50u)

/** Alias (User Manual Name) for MCDS_MCX_CNT21_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT21_CCL.
*/
#define	MCDS_MCXCCL21	(MCDS_MCX_CNT21_CCL)

/** \\brief  B58, Current Count Register */
#define MCDS_MCX_CNT21_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B58u)

/** Alias (User Manual Name) for MCDS_MCX_CNT21_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT21_CNT.
*/
#define	MCDS_MCXCNT21	(MCDS_MCX_CNT21_CNT)

/** \\brief  B54, Counter Limit Register */
#define MCDS_MCX_CNT21_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B54u)

/** Alias (User Manual Name) for MCDS_MCX_CNT21_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT21_LMT.
*/
#define	MCDS_MCXLMT21	(MCDS_MCX_CNT21_LMT)

/** \\brief  B60, Counter Control Register */
#define MCDS_MCX_CNT22_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B60u)

/** Alias (User Manual Name) for MCDS_MCX_CNT22_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT22_CCL.
*/
#define	MCDS_MCXCCL22	(MCDS_MCX_CNT22_CCL)

/** \\brief  B68, Current Count Register */
#define MCDS_MCX_CNT22_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B68u)

/** Alias (User Manual Name) for MCDS_MCX_CNT22_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT22_CNT.
*/
#define	MCDS_MCXCNT22	(MCDS_MCX_CNT22_CNT)

/** \\brief  B64, Counter Limit Register */
#define MCDS_MCX_CNT22_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B64u)

/** Alias (User Manual Name) for MCDS_MCX_CNT22_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT22_LMT.
*/
#define	MCDS_MCXLMT22	(MCDS_MCX_CNT22_LMT)

/** \\brief  B70, Counter Control Register */
#define MCDS_MCX_CNT23_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B70u)

/** Alias (User Manual Name) for MCDS_MCX_CNT23_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT23_CCL.
*/
#define	MCDS_MCXCCL23	(MCDS_MCX_CNT23_CCL)

/** \\brief  B78, Current Count Register */
#define MCDS_MCX_CNT23_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B78u)

/** Alias (User Manual Name) for MCDS_MCX_CNT23_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT23_CNT.
*/
#define	MCDS_MCXCNT23	(MCDS_MCX_CNT23_CNT)

/** \\brief  B74, Counter Limit Register */
#define MCDS_MCX_CNT23_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B74u)

/** Alias (User Manual Name) for MCDS_MCX_CNT23_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT23_LMT.
*/
#define	MCDS_MCXLMT23	(MCDS_MCX_CNT23_LMT)

/** \\brief  B80, Counter Control Register */
#define MCDS_MCX_CNT24_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B80u)

/** Alias (User Manual Name) for MCDS_MCX_CNT24_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT24_CCL.
*/
#define	MCDS_MCXCCL24	(MCDS_MCX_CNT24_CCL)

/** \\brief  B88, Current Count Register */
#define MCDS_MCX_CNT24_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B88u)

/** Alias (User Manual Name) for MCDS_MCX_CNT24_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT24_CNT.
*/
#define	MCDS_MCXCNT24	(MCDS_MCX_CNT24_CNT)

/** \\brief  B84, Counter Limit Register */
#define MCDS_MCX_CNT24_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B84u)

/** Alias (User Manual Name) for MCDS_MCX_CNT24_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT24_LMT.
*/
#define	MCDS_MCXLMT24	(MCDS_MCX_CNT24_LMT)

/** \\brief  B90, Counter Control Register */
#define MCDS_MCX_CNT25_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8B90u)

/** Alias (User Manual Name) for MCDS_MCX_CNT25_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT25_CCL.
*/
#define	MCDS_MCXCCL25	(MCDS_MCX_CNT25_CCL)

/** \\brief  B98, Current Count Register */
#define MCDS_MCX_CNT25_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8B98u)

/** Alias (User Manual Name) for MCDS_MCX_CNT25_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT25_CNT.
*/
#define	MCDS_MCXCNT25	(MCDS_MCX_CNT25_CNT)

/** \\brief  B94, Counter Limit Register */
#define MCDS_MCX_CNT25_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8B94u)

/** Alias (User Manual Name) for MCDS_MCX_CNT25_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT25_LMT.
*/
#define	MCDS_MCXLMT25	(MCDS_MCX_CNT25_LMT)

/** \\brief  BA0, Counter Control Register */
#define MCDS_MCX_CNT26_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8BA0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT26_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT26_CCL.
*/
#define	MCDS_MCXCCL26	(MCDS_MCX_CNT26_CCL)

/** \\brief  BA8, Current Count Register */
#define MCDS_MCX_CNT26_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8BA8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT26_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT26_CNT.
*/
#define	MCDS_MCXCNT26	(MCDS_MCX_CNT26_CNT)

/** \\brief  BA4, Counter Limit Register */
#define MCDS_MCX_CNT26_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8BA4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT26_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT26_LMT.
*/
#define	MCDS_MCXLMT26	(MCDS_MCX_CNT26_LMT)

/** \\brief  BB0, Counter Control Register */
#define MCDS_MCX_CNT27_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8BB0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT27_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT27_CCL.
*/
#define	MCDS_MCXCCL27	(MCDS_MCX_CNT27_CCL)

/** \\brief  BB8, Current Count Register */
#define MCDS_MCX_CNT27_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8BB8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT27_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT27_CNT.
*/
#define	MCDS_MCXCNT27	(MCDS_MCX_CNT27_CNT)

/** \\brief  BB4, Counter Limit Register */
#define MCDS_MCX_CNT27_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8BB4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT27_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT27_LMT.
*/
#define	MCDS_MCXLMT27	(MCDS_MCX_CNT27_LMT)

/** \\brief  BC0, Counter Control Register */
#define MCDS_MCX_CNT28_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8BC0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT28_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT28_CCL.
*/
#define	MCDS_MCXCCL28	(MCDS_MCX_CNT28_CCL)

/** \\brief  BC8, Current Count Register */
#define MCDS_MCX_CNT28_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8BC8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT28_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT28_CNT.
*/
#define	MCDS_MCXCNT28	(MCDS_MCX_CNT28_CNT)

/** \\brief  BC4, Counter Limit Register */
#define MCDS_MCX_CNT28_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8BC4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT28_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT28_LMT.
*/
#define	MCDS_MCXLMT28	(MCDS_MCX_CNT28_LMT)

/** \\brief  BD0, Counter Control Register */
#define MCDS_MCX_CNT29_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8BD0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT29_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT29_CCL.
*/
#define	MCDS_MCXCCL29	(MCDS_MCX_CNT29_CCL)

/** \\brief  BD8, Current Count Register */
#define MCDS_MCX_CNT29_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8BD8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT29_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT29_CNT.
*/
#define	MCDS_MCXCNT29	(MCDS_MCX_CNT29_CNT)

/** \\brief  BD4, Counter Limit Register */
#define MCDS_MCX_CNT29_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8BD4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT29_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT29_LMT.
*/
#define	MCDS_MCXLMT29	(MCDS_MCX_CNT29_LMT)

/** \\brief  A20, Counter Control Register */
#define MCDS_MCX_CNT2_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A20u)

/** Alias (User Manual Name) for MCDS_MCX_CNT2_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT2_CCL.
*/
#define	MCDS_MCXCCL2	(MCDS_MCX_CNT2_CCL)

/** \\brief  A28, Current Count Register */
#define MCDS_MCX_CNT2_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A28u)

/** Alias (User Manual Name) for MCDS_MCX_CNT2_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT2_CNT.
*/
#define	MCDS_MCXCNT2	(MCDS_MCX_CNT2_CNT)

/** \\brief  A24, Counter Limit Register */
#define MCDS_MCX_CNT2_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A24u)

/** Alias (User Manual Name) for MCDS_MCX_CNT2_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT2_LMT.
*/
#define	MCDS_MCXLMT2	(MCDS_MCX_CNT2_LMT)

/** \\brief  BE0, Counter Control Register */
#define MCDS_MCX_CNT30_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8BE0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT30_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT30_CCL.
*/
#define	MCDS_MCXCCL30	(MCDS_MCX_CNT30_CCL)

/** \\brief  BE8, Current Count Register */
#define MCDS_MCX_CNT30_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8BE8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT30_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT30_CNT.
*/
#define	MCDS_MCXCNT30	(MCDS_MCX_CNT30_CNT)

/** \\brief  BE4, Counter Limit Register */
#define MCDS_MCX_CNT30_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8BE4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT30_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT30_LMT.
*/
#define	MCDS_MCXLMT30	(MCDS_MCX_CNT30_LMT)

/** \\brief  BF0, Counter Control Register */
#define MCDS_MCX_CNT31_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8BF0u)

/** Alias (User Manual Name) for MCDS_MCX_CNT31_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT31_CCL.
*/
#define	MCDS_MCXCCL31	(MCDS_MCX_CNT31_CCL)

/** \\brief  BF8, Current Count Register */
#define MCDS_MCX_CNT31_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8BF8u)

/** Alias (User Manual Name) for MCDS_MCX_CNT31_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT31_CNT.
*/
#define	MCDS_MCXCNT31	(MCDS_MCX_CNT31_CNT)

/** \\brief  BF4, Counter Limit Register */
#define MCDS_MCX_CNT31_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8BF4u)

/** Alias (User Manual Name) for MCDS_MCX_CNT31_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT31_LMT.
*/
#define	MCDS_MCXLMT31	(MCDS_MCX_CNT31_LMT)

/** \\brief  A30, Counter Control Register */
#define MCDS_MCX_CNT3_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A30u)

/** Alias (User Manual Name) for MCDS_MCX_CNT3_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT3_CCL.
*/
#define	MCDS_MCXCCL3	(MCDS_MCX_CNT3_CCL)

/** \\brief  A38, Current Count Register */
#define MCDS_MCX_CNT3_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A38u)

/** Alias (User Manual Name) for MCDS_MCX_CNT3_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT3_CNT.
*/
#define	MCDS_MCXCNT3	(MCDS_MCX_CNT3_CNT)

/** \\brief  A34, Counter Limit Register */
#define MCDS_MCX_CNT3_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A34u)

/** Alias (User Manual Name) for MCDS_MCX_CNT3_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT3_LMT.
*/
#define	MCDS_MCXLMT3	(MCDS_MCX_CNT3_LMT)

/** \\brief  A40, Counter Control Register */
#define MCDS_MCX_CNT4_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A40u)

/** Alias (User Manual Name) for MCDS_MCX_CNT4_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT4_CCL.
*/
#define	MCDS_MCXCCL4	(MCDS_MCX_CNT4_CCL)

/** \\brief  A48, Current Count Register */
#define MCDS_MCX_CNT4_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A48u)

/** Alias (User Manual Name) for MCDS_MCX_CNT4_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT4_CNT.
*/
#define	MCDS_MCXCNT4	(MCDS_MCX_CNT4_CNT)

/** \\brief  A44, Counter Limit Register */
#define MCDS_MCX_CNT4_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A44u)

/** Alias (User Manual Name) for MCDS_MCX_CNT4_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT4_LMT.
*/
#define	MCDS_MCXLMT4	(MCDS_MCX_CNT4_LMT)

/** \\brief  A50, Counter Control Register */
#define MCDS_MCX_CNT5_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A50u)

/** Alias (User Manual Name) for MCDS_MCX_CNT5_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT5_CCL.
*/
#define	MCDS_MCXCCL5	(MCDS_MCX_CNT5_CCL)

/** \\brief  A58, Current Count Register */
#define MCDS_MCX_CNT5_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A58u)

/** Alias (User Manual Name) for MCDS_MCX_CNT5_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT5_CNT.
*/
#define	MCDS_MCXCNT5	(MCDS_MCX_CNT5_CNT)

/** \\brief  A54, Counter Limit Register */
#define MCDS_MCX_CNT5_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A54u)

/** Alias (User Manual Name) for MCDS_MCX_CNT5_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT5_LMT.
*/
#define	MCDS_MCXLMT5	(MCDS_MCX_CNT5_LMT)

/** \\brief  A60, Counter Control Register */
#define MCDS_MCX_CNT6_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A60u)

/** Alias (User Manual Name) for MCDS_MCX_CNT6_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT6_CCL.
*/
#define	MCDS_MCXCCL6	(MCDS_MCX_CNT6_CCL)

/** \\brief  A68, Current Count Register */
#define MCDS_MCX_CNT6_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A68u)

/** Alias (User Manual Name) for MCDS_MCX_CNT6_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT6_CNT.
*/
#define	MCDS_MCXCNT6	(MCDS_MCX_CNT6_CNT)

/** \\brief  A64, Counter Limit Register */
#define MCDS_MCX_CNT6_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A64u)

/** Alias (User Manual Name) for MCDS_MCX_CNT6_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT6_LMT.
*/
#define	MCDS_MCXLMT6	(MCDS_MCX_CNT6_LMT)

/** \\brief  A70, Counter Control Register */
#define MCDS_MCX_CNT7_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A70u)

/** Alias (User Manual Name) for MCDS_MCX_CNT7_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT7_CCL.
*/
#define	MCDS_MCXCCL7	(MCDS_MCX_CNT7_CCL)

/** \\brief  A78, Current Count Register */
#define MCDS_MCX_CNT7_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A78u)

/** Alias (User Manual Name) for MCDS_MCX_CNT7_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT7_CNT.
*/
#define	MCDS_MCXCNT7	(MCDS_MCX_CNT7_CNT)

/** \\brief  A74, Counter Limit Register */
#define MCDS_MCX_CNT7_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A74u)

/** Alias (User Manual Name) for MCDS_MCX_CNT7_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT7_LMT.
*/
#define	MCDS_MCXLMT7	(MCDS_MCX_CNT7_LMT)

/** \\brief  A80, Counter Control Register */
#define MCDS_MCX_CNT8_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A80u)

/** Alias (User Manual Name) for MCDS_MCX_CNT8_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT8_CCL.
*/
#define	MCDS_MCXCCL8	(MCDS_MCX_CNT8_CCL)

/** \\brief  A88, Current Count Register */
#define MCDS_MCX_CNT8_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A88u)

/** Alias (User Manual Name) for MCDS_MCX_CNT8_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT8_CNT.
*/
#define	MCDS_MCXCNT8	(MCDS_MCX_CNT8_CNT)

/** \\brief  A84, Counter Limit Register */
#define MCDS_MCX_CNT8_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A84u)

/** Alias (User Manual Name) for MCDS_MCX_CNT8_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT8_LMT.
*/
#define	MCDS_MCXLMT8	(MCDS_MCX_CNT8_LMT)

/** \\brief  A90, Counter Control Register */
#define MCDS_MCX_CNT9_CCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CCL*)0xF90E8A90u)

/** Alias (User Manual Name) for MCDS_MCX_CNT9_CCL.
* To use register names with standard convension, please use MCDS_MCX_CNT9_CCL.
*/
#define	MCDS_MCXCCL9	(MCDS_MCX_CNT9_CCL)

/** \\brief  A98, Current Count Register */
#define MCDS_MCX_CNT9_CNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_CNT*)0xF90E8A98u)

/** Alias (User Manual Name) for MCDS_MCX_CNT9_CNT.
* To use register names with standard convension, please use MCDS_MCX_CNT9_CNT.
*/
#define	MCDS_MCXCNT9	(MCDS_MCX_CNT9_CNT)

/** \\brief  A94, Counter Limit Register */
#define MCDS_MCX_CNT9_LMT /* lint --e(923)*/ (*(volatile Ifx_MCDS_CNT_LMT*)0xF90E8A94u)

/** Alias (User Manual Name) for MCDS_MCX_CNT9_LMT.
* To use register names with standard convension, please use MCDS_MCX_CNT9_LMT.
*/
#define	MCDS_MCXLMT9	(MCDS_MCX_CNT9_LMT)

/** \\brief  800, Event Definition Register */
#define MCDS_MCX_EVT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8800u)

/** Alias (User Manual Name) for MCDS_MCX_EVT0.
* To use register names with standard convension, please use MCDS_MCX_EVT0.
*/
#define	MCDS_MCXEVT0	(MCDS_MCX_EVT0)

/** \\brief  804, Event Definition Register */
#define MCDS_MCX_EVT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8804u)

/** Alias (User Manual Name) for MCDS_MCX_EVT1.
* To use register names with standard convension, please use MCDS_MCX_EVT1.
*/
#define	MCDS_MCXEVT1	(MCDS_MCX_EVT1)

/** \\brief  828, Event Definition Register */
#define MCDS_MCX_EVT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8828u)

/** Alias (User Manual Name) for MCDS_MCX_EVT10.
* To use register names with standard convension, please use MCDS_MCX_EVT10.
*/
#define	MCDS_MCXEVT10	(MCDS_MCX_EVT10)

/** \\brief  82C, Event Definition Register */
#define MCDS_MCX_EVT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E882Cu)

/** Alias (User Manual Name) for MCDS_MCX_EVT11.
* To use register names with standard convension, please use MCDS_MCX_EVT11.
*/
#define	MCDS_MCXEVT11	(MCDS_MCX_EVT11)

/** \\brief  830, Event Definition Register */
#define MCDS_MCX_EVT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8830u)

/** Alias (User Manual Name) for MCDS_MCX_EVT12.
* To use register names with standard convension, please use MCDS_MCX_EVT12.
*/
#define	MCDS_MCXEVT12	(MCDS_MCX_EVT12)

/** \\brief  834, Event Definition Register */
#define MCDS_MCX_EVT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8834u)

/** Alias (User Manual Name) for MCDS_MCX_EVT13.
* To use register names with standard convension, please use MCDS_MCX_EVT13.
*/
#define	MCDS_MCXEVT13	(MCDS_MCX_EVT13)

/** \\brief  838, Event Definition Register */
#define MCDS_MCX_EVT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8838u)

/** Alias (User Manual Name) for MCDS_MCX_EVT14.
* To use register names with standard convension, please use MCDS_MCX_EVT14.
*/
#define	MCDS_MCXEVT14	(MCDS_MCX_EVT14)

/** \\brief  83C, Event Definition Register */
#define MCDS_MCX_EVT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E883Cu)

/** Alias (User Manual Name) for MCDS_MCX_EVT15.
* To use register names with standard convension, please use MCDS_MCX_EVT15.
*/
#define	MCDS_MCXEVT15	(MCDS_MCX_EVT15)

/** \\brief  840, Event Definition Register */
#define MCDS_MCX_EVT16 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8840u)

/** Alias (User Manual Name) for MCDS_MCX_EVT16.
* To use register names with standard convension, please use MCDS_MCX_EVT16.
*/
#define	MCDS_MCXEVT16	(MCDS_MCX_EVT16)

/** \\brief  844, Event Definition Register */
#define MCDS_MCX_EVT17 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8844u)

/** Alias (User Manual Name) for MCDS_MCX_EVT17.
* To use register names with standard convension, please use MCDS_MCX_EVT17.
*/
#define	MCDS_MCXEVT17	(MCDS_MCX_EVT17)

/** \\brief  848, Event Definition Register */
#define MCDS_MCX_EVT18 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8848u)

/** Alias (User Manual Name) for MCDS_MCX_EVT18.
* To use register names with standard convension, please use MCDS_MCX_EVT18.
*/
#define	MCDS_MCXEVT18	(MCDS_MCX_EVT18)

/** \\brief  84C, Event Definition Register */
#define MCDS_MCX_EVT19 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E884Cu)

/** Alias (User Manual Name) for MCDS_MCX_EVT19.
* To use register names with standard convension, please use MCDS_MCX_EVT19.
*/
#define	MCDS_MCXEVT19	(MCDS_MCX_EVT19)

/** \\brief  808, Event Definition Register */
#define MCDS_MCX_EVT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8808u)

/** Alias (User Manual Name) for MCDS_MCX_EVT2.
* To use register names with standard convension, please use MCDS_MCX_EVT2.
*/
#define	MCDS_MCXEVT2	(MCDS_MCX_EVT2)

/** \\brief  850, Event Definition Register */
#define MCDS_MCX_EVT20 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8850u)

/** Alias (User Manual Name) for MCDS_MCX_EVT20.
* To use register names with standard convension, please use MCDS_MCX_EVT20.
*/
#define	MCDS_MCXEVT20	(MCDS_MCX_EVT20)

/** \\brief  854, Event Definition Register */
#define MCDS_MCX_EVT21 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8854u)

/** Alias (User Manual Name) for MCDS_MCX_EVT21.
* To use register names with standard convension, please use MCDS_MCX_EVT21.
*/
#define	MCDS_MCXEVT21	(MCDS_MCX_EVT21)

/** \\brief  858, Event Definition Register */
#define MCDS_MCX_EVT22 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8858u)

/** Alias (User Manual Name) for MCDS_MCX_EVT22.
* To use register names with standard convension, please use MCDS_MCX_EVT22.
*/
#define	MCDS_MCXEVT22	(MCDS_MCX_EVT22)

/** \\brief  85C, Event Definition Register */
#define MCDS_MCX_EVT23 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E885Cu)

/** Alias (User Manual Name) for MCDS_MCX_EVT23.
* To use register names with standard convension, please use MCDS_MCX_EVT23.
*/
#define	MCDS_MCXEVT23	(MCDS_MCX_EVT23)

/** \\brief  80C, Event Definition Register */
#define MCDS_MCX_EVT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E880Cu)

/** Alias (User Manual Name) for MCDS_MCX_EVT3.
* To use register names with standard convension, please use MCDS_MCX_EVT3.
*/
#define	MCDS_MCXEVT3	(MCDS_MCX_EVT3)

/** \\brief  810, Event Definition Register */
#define MCDS_MCX_EVT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8810u)

/** Alias (User Manual Name) for MCDS_MCX_EVT4.
* To use register names with standard convension, please use MCDS_MCX_EVT4.
*/
#define	MCDS_MCXEVT4	(MCDS_MCX_EVT4)

/** \\brief  814, Event Definition Register */
#define MCDS_MCX_EVT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8814u)

/** Alias (User Manual Name) for MCDS_MCX_EVT5.
* To use register names with standard convension, please use MCDS_MCX_EVT5.
*/
#define	MCDS_MCXEVT5	(MCDS_MCX_EVT5)

/** \\brief  818, Event Definition Register */
#define MCDS_MCX_EVT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8818u)

/** Alias (User Manual Name) for MCDS_MCX_EVT6.
* To use register names with standard convension, please use MCDS_MCX_EVT6.
*/
#define	MCDS_MCXEVT6	(MCDS_MCX_EVT6)

/** \\brief  81C, Event Definition Register */
#define MCDS_MCX_EVT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E881Cu)

/** Alias (User Manual Name) for MCDS_MCX_EVT7.
* To use register names with standard convension, please use MCDS_MCX_EVT7.
*/
#define	MCDS_MCXEVT7	(MCDS_MCX_EVT7)

/** \\brief  820, Event Definition Register */
#define MCDS_MCX_EVT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8820u)

/** Alias (User Manual Name) for MCDS_MCX_EVT8.
* To use register names with standard convension, please use MCDS_MCX_EVT8.
*/
#define	MCDS_MCXEVT8	(MCDS_MCX_EVT8)

/** \\brief  824, Event Definition Register */
#define MCDS_MCX_EVT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90E8824u)

/** Alias (User Manual Name) for MCDS_MCX_EVT9.
* To use register names with standard convension, please use MCDS_MCX_EVT9.
*/
#define	MCDS_MCXEVT9	(MCDS_MCX_EVT9)

/** \\brief  14, MCDS Signal Source Control */
#define MCDS_MUX /* lint --e(923)*/ (*(volatile Ifx_MCDS_MUX*)0xF90E8014u)

/** \\brief  4, OCDS Control and Status */
#define MCDS_OCS /* lint --e(923)*/ (*(volatile Ifx_MCDS_OCS*)0xF90E8004u)

/** \\brief  1C, Session ID High Register */
#define MCDS_SESSIDH /* lint --e(923)*/ (*(volatile Ifx_MCDS_SESSIDH*)0xF90E801Cu)

/** \\brief  18, Session ID Low Register */
#define MCDS_SESSIDL /* lint --e(923)*/ (*(volatile Ifx_MCDS_SESSIDL*)0xF90E8018u)

/** \\brief  6500, Comparator Bound Register */
#define MCDS_SPB_AC0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_BND*)0xF90EE500u)

/** Alias (User Manual Name) for MCDS_SPB_AC0_BND.
* To use register names with standard convension, please use MCDS_SPB_AC0_BND.
*/
#define	MCDS_SPBACBND0	(MCDS_SPB_AC0_BND)

/** \\brief  6508, Comparator Mask Register */
#define MCDS_SPB_AC0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_MSK*)0xF90EE508u)

/** Alias (User Manual Name) for MCDS_SPB_AC0_MSK.
* To use register names with standard convension, please use MCDS_SPB_AC0_MSK.
*/
#define	MCDS_SPBACMSK0	(MCDS_SPB_AC0_MSK)

/** \\brief  6504, Comparator Range Register */
#define MCDS_SPB_AC0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_RNG*)0xF90EE504u)

/** Alias (User Manual Name) for MCDS_SPB_AC0_RNG.
* To use register names with standard convension, please use MCDS_SPB_AC0_RNG.
*/
#define	MCDS_SPBACRNG0	(MCDS_SPB_AC0_RNG)

/** \\brief  6510, Comparator Bound Register */
#define MCDS_SPB_AC1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_BND*)0xF90EE510u)

/** Alias (User Manual Name) for MCDS_SPB_AC1_BND.
* To use register names with standard convension, please use MCDS_SPB_AC1_BND.
*/
#define	MCDS_SPBACBND1	(MCDS_SPB_AC1_BND)

/** \\brief  6518, Comparator Mask Register */
#define MCDS_SPB_AC1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_MSK*)0xF90EE518u)

/** Alias (User Manual Name) for MCDS_SPB_AC1_MSK.
* To use register names with standard convension, please use MCDS_SPB_AC1_MSK.
*/
#define	MCDS_SPBACMSK1	(MCDS_SPB_AC1_MSK)

/** \\brief  6514, Comparator Range Register */
#define MCDS_SPB_AC1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_RNG*)0xF90EE514u)

/** Alias (User Manual Name) for MCDS_SPB_AC1_RNG.
* To use register names with standard convension, please use MCDS_SPB_AC1_RNG.
*/
#define	MCDS_SPBACRNG1	(MCDS_SPB_AC1_RNG)

/** \\brief  6520, Comparator Bound Register */
#define MCDS_SPB_AC2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_BND*)0xF90EE520u)

/** Alias (User Manual Name) for MCDS_SPB_AC2_BND.
* To use register names with standard convension, please use MCDS_SPB_AC2_BND.
*/
#define	MCDS_SPBACBND2	(MCDS_SPB_AC2_BND)

/** \\brief  6528, Comparator Mask Register */
#define MCDS_SPB_AC2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_MSK*)0xF90EE528u)

/** Alias (User Manual Name) for MCDS_SPB_AC2_MSK.
* To use register names with standard convension, please use MCDS_SPB_AC2_MSK.
*/
#define	MCDS_SPBACMSK2	(MCDS_SPB_AC2_MSK)

/** \\brief  6524, Comparator Range Register */
#define MCDS_SPB_AC2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_RNG*)0xF90EE524u)

/** Alias (User Manual Name) for MCDS_SPB_AC2_RNG.
* To use register names with standard convension, please use MCDS_SPB_AC2_RNG.
*/
#define	MCDS_SPBACRNG2	(MCDS_SPB_AC2_RNG)

/** \\brief  6530, Comparator Bound Register */
#define MCDS_SPB_AC3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_BND*)0xF90EE530u)

/** Alias (User Manual Name) for MCDS_SPB_AC3_BND.
* To use register names with standard convension, please use MCDS_SPB_AC3_BND.
*/
#define	MCDS_SPBACBND3	(MCDS_SPB_AC3_BND)

/** \\brief  6538, Comparator Mask Register */
#define MCDS_SPB_AC3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_MSK*)0xF90EE538u)

/** Alias (User Manual Name) for MCDS_SPB_AC3_MSK.
* To use register names with standard convension, please use MCDS_SPB_AC3_MSK.
*/
#define	MCDS_SPBACMSK3	(MCDS_SPB_AC3_MSK)

/** \\brief  6534, Comparator Range Register */
#define MCDS_SPB_AC3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBAC_RNG*)0xF90EE534u)

/** Alias (User Manual Name) for MCDS_SPB_AC3_RNG.
* To use register names with standard convension, please use MCDS_SPB_AC3_RNG.
*/
#define	MCDS_SPBACRNG3	(MCDS_SPB_AC3_RNG)

/** \\brief  6880, Action Definition Register */
#define MCDS_SPB_ACT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE880u)

/** Alias (User Manual Name) for MCDS_SPB_ACT0.
* To use register names with standard convension, please use MCDS_SPB_ACT0.
*/
#define	MCDS_SPBACT0	(MCDS_SPB_ACT0)

/** \\brief  6884, Action Definition Register */
#define MCDS_SPB_ACT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE884u)

/** Alias (User Manual Name) for MCDS_SPB_ACT1.
* To use register names with standard convension, please use MCDS_SPB_ACT1.
*/
#define	MCDS_SPBACT1	(MCDS_SPB_ACT1)

/** \\brief  68A8, Action Definition Register */
#define MCDS_SPB_ACT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE8A8u)

/** Alias (User Manual Name) for MCDS_SPB_ACT10.
* To use register names with standard convension, please use MCDS_SPB_ACT10.
*/
#define	MCDS_SPBACT10	(MCDS_SPB_ACT10)

/** \\brief  68AC, Action Definition Register */
#define MCDS_SPB_ACT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE8ACu)

/** Alias (User Manual Name) for MCDS_SPB_ACT11.
* To use register names with standard convension, please use MCDS_SPB_ACT11.
*/
#define	MCDS_SPBACT11	(MCDS_SPB_ACT11)

/** \\brief  68B0, Action Definition Register */
#define MCDS_SPB_ACT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE8B0u)

/** Alias (User Manual Name) for MCDS_SPB_ACT12.
* To use register names with standard convension, please use MCDS_SPB_ACT12.
*/
#define	MCDS_SPBACT12	(MCDS_SPB_ACT12)

/** \\brief  68B4, Action Definition Register */
#define MCDS_SPB_ACT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE8B4u)

/** Alias (User Manual Name) for MCDS_SPB_ACT13.
* To use register names with standard convension, please use MCDS_SPB_ACT13.
*/
#define	MCDS_SPBACT13	(MCDS_SPB_ACT13)

/** \\brief  68B8, Action Definition Register */
#define MCDS_SPB_ACT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE8B8u)

/** Alias (User Manual Name) for MCDS_SPB_ACT14.
* To use register names with standard convension, please use MCDS_SPB_ACT14.
*/
#define	MCDS_SPBACT14	(MCDS_SPB_ACT14)

/** \\brief  6888, Action Definition Register */
#define MCDS_SPB_ACT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE888u)

/** Alias (User Manual Name) for MCDS_SPB_ACT2.
* To use register names with standard convension, please use MCDS_SPB_ACT2.
*/
#define	MCDS_SPBACT2	(MCDS_SPB_ACT2)

/** \\brief  688C, Action Definition Register */
#define MCDS_SPB_ACT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE88Cu)

/** Alias (User Manual Name) for MCDS_SPB_ACT3.
* To use register names with standard convension, please use MCDS_SPB_ACT3.
*/
#define	MCDS_SPBACT3	(MCDS_SPB_ACT3)

/** \\brief  6890, Action Definition Register */
#define MCDS_SPB_ACT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE890u)

/** Alias (User Manual Name) for MCDS_SPB_ACT4.
* To use register names with standard convension, please use MCDS_SPB_ACT4.
*/
#define	MCDS_SPBACT4	(MCDS_SPB_ACT4)

/** \\brief  6894, Action Definition Register */
#define MCDS_SPB_ACT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE894u)

/** Alias (User Manual Name) for MCDS_SPB_ACT5.
* To use register names with standard convension, please use MCDS_SPB_ACT5.
*/
#define	MCDS_SPBACT5	(MCDS_SPB_ACT5)

/** \\brief  6898, Action Definition Register */
#define MCDS_SPB_ACT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE898u)

/** Alias (User Manual Name) for MCDS_SPB_ACT6.
* To use register names with standard convension, please use MCDS_SPB_ACT6.
*/
#define	MCDS_SPBACT6	(MCDS_SPB_ACT6)

/** \\brief  689C, Action Definition Register */
#define MCDS_SPB_ACT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE89Cu)

/** Alias (User Manual Name) for MCDS_SPB_ACT7.
* To use register names with standard convension, please use MCDS_SPB_ACT7.
*/
#define	MCDS_SPBACT7	(MCDS_SPB_ACT7)

/** \\brief  68A0, Action Definition Register */
#define MCDS_SPB_ACT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE8A0u)

/** Alias (User Manual Name) for MCDS_SPB_ACT8.
* To use register names with standard convension, please use MCDS_SPB_ACT8.
*/
#define	MCDS_SPBACT8	(MCDS_SPB_ACT8)

/** \\brief  68A4, Action Definition Register */
#define MCDS_SPB_ACT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EE8A4u)

/** Alias (User Manual Name) for MCDS_SPB_ACT9.
* To use register names with standard convension, please use MCDS_SPB_ACT9.
*/
#define	MCDS_SPBACT9	(MCDS_SPB_ACT9)

/** \\brief  6000, Debug Status Register */
#define MCDS_SPB_DCSTS /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPB_DCSTS*)0xF90EE000u)

/** Alias (User Manual Name) for MCDS_SPB_DCSTS.
* To use register names with standard convension, please use MCDS_SPB_DCSTS.
*/
#define	MCDS_SPBDCSTS	(MCDS_SPB_DCSTS)

/** \\brief  6400, Comparator Bound Register */
#define MCDS_SPB_EA0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_BND*)0xF90EE400u)

/** Alias (User Manual Name) for MCDS_SPB_EA0_BND.
* To use register names with standard convension, please use MCDS_SPB_EA0_BND.
*/
#define	MCDS_SPBEABND0	(MCDS_SPB_EA0_BND)

/** \\brief  6404, Comparator Range Register */
#define MCDS_SPB_EA0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_RNG*)0xF90EE404u)

/** Alias (User Manual Name) for MCDS_SPB_EA0_RNG.
* To use register names with standard convension, please use MCDS_SPB_EA0_RNG.
*/
#define	MCDS_SPBEARNG0	(MCDS_SPB_EA0_RNG)

/** \\brief  6410, Comparator Bound Register */
#define MCDS_SPB_EA1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_BND*)0xF90EE410u)

/** Alias (User Manual Name) for MCDS_SPB_EA1_BND.
* To use register names with standard convension, please use MCDS_SPB_EA1_BND.
*/
#define	MCDS_SPBEABND1	(MCDS_SPB_EA1_BND)

/** \\brief  6414, Comparator Range Register */
#define MCDS_SPB_EA1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_RNG*)0xF90EE414u)

/** Alias (User Manual Name) for MCDS_SPB_EA1_RNG.
* To use register names with standard convension, please use MCDS_SPB_EA1_RNG.
*/
#define	MCDS_SPBEARNG1	(MCDS_SPB_EA1_RNG)

/** \\brief  6420, Comparator Bound Register */
#define MCDS_SPB_EA2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_BND*)0xF90EE420u)

/** Alias (User Manual Name) for MCDS_SPB_EA2_BND.
* To use register names with standard convension, please use MCDS_SPB_EA2_BND.
*/
#define	MCDS_SPBEABND2	(MCDS_SPB_EA2_BND)

/** \\brief  6424, Comparator Range Register */
#define MCDS_SPB_EA2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_RNG*)0xF90EE424u)

/** Alias (User Manual Name) for MCDS_SPB_EA2_RNG.
* To use register names with standard convension, please use MCDS_SPB_EA2_RNG.
*/
#define	MCDS_SPBEARNG2	(MCDS_SPB_EA2_RNG)

/** \\brief  6430, Comparator Bound Register */
#define MCDS_SPB_EA3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_BND*)0xF90EE430u)

/** Alias (User Manual Name) for MCDS_SPB_EA3_BND.
* To use register names with standard convension, please use MCDS_SPB_EA3_BND.
*/
#define	MCDS_SPBEABND3	(MCDS_SPB_EA3_BND)

/** \\brief  6434, Comparator Range Register */
#define MCDS_SPB_EA3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBEA_RNG*)0xF90EE434u)

/** Alias (User Manual Name) for MCDS_SPB_EA3_RNG.
* To use register names with standard convension, please use MCDS_SPB_EA3_RNG.
*/
#define	MCDS_SPBEARNG3	(MCDS_SPB_EA3_RNG)

/** \\brief  6800, Event Definition Register */
#define MCDS_SPB_EVT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE800u)

/** Alias (User Manual Name) for MCDS_SPB_EVT0.
* To use register names with standard convension, please use MCDS_SPB_EVT0.
*/
#define	MCDS_SPBEVT0	(MCDS_SPB_EVT0)

/** \\brief  6804, Event Definition Register */
#define MCDS_SPB_EVT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE804u)

/** Alias (User Manual Name) for MCDS_SPB_EVT1.
* To use register names with standard convension, please use MCDS_SPB_EVT1.
*/
#define	MCDS_SPBEVT1	(MCDS_SPB_EVT1)

/** \\brief  6828, Event Definition Register */
#define MCDS_SPB_EVT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE828u)

/** Alias (User Manual Name) for MCDS_SPB_EVT10.
* To use register names with standard convension, please use MCDS_SPB_EVT10.
*/
#define	MCDS_SPBEVT10	(MCDS_SPB_EVT10)

/** \\brief  682C, Event Definition Register */
#define MCDS_SPB_EVT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE82Cu)

/** Alias (User Manual Name) for MCDS_SPB_EVT11.
* To use register names with standard convension, please use MCDS_SPB_EVT11.
*/
#define	MCDS_SPBEVT11	(MCDS_SPB_EVT11)

/** \\brief  6830, Event Definition Register */
#define MCDS_SPB_EVT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE830u)

/** Alias (User Manual Name) for MCDS_SPB_EVT12.
* To use register names with standard convension, please use MCDS_SPB_EVT12.
*/
#define	MCDS_SPBEVT12	(MCDS_SPB_EVT12)

/** \\brief  6834, Event Definition Register */
#define MCDS_SPB_EVT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE834u)

/** Alias (User Manual Name) for MCDS_SPB_EVT13.
* To use register names with standard convension, please use MCDS_SPB_EVT13.
*/
#define	MCDS_SPBEVT13	(MCDS_SPB_EVT13)

/** \\brief  6838, Event Definition Register */
#define MCDS_SPB_EVT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE838u)

/** Alias (User Manual Name) for MCDS_SPB_EVT14.
* To use register names with standard convension, please use MCDS_SPB_EVT14.
*/
#define	MCDS_SPBEVT14	(MCDS_SPB_EVT14)

/** \\brief  683C, Event Definition Register */
#define MCDS_SPB_EVT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE83Cu)

/** Alias (User Manual Name) for MCDS_SPB_EVT15.
* To use register names with standard convension, please use MCDS_SPB_EVT15.
*/
#define	MCDS_SPBEVT15	(MCDS_SPB_EVT15)

/** \\brief  6808, Event Definition Register */
#define MCDS_SPB_EVT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE808u)

/** Alias (User Manual Name) for MCDS_SPB_EVT2.
* To use register names with standard convension, please use MCDS_SPB_EVT2.
*/
#define	MCDS_SPBEVT2	(MCDS_SPB_EVT2)

/** \\brief  680C, Event Definition Register */
#define MCDS_SPB_EVT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE80Cu)

/** Alias (User Manual Name) for MCDS_SPB_EVT3.
* To use register names with standard convension, please use MCDS_SPB_EVT3.
*/
#define	MCDS_SPBEVT3	(MCDS_SPB_EVT3)

/** \\brief  6810, Event Definition Register */
#define MCDS_SPB_EVT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE810u)

/** Alias (User Manual Name) for MCDS_SPB_EVT4.
* To use register names with standard convension, please use MCDS_SPB_EVT4.
*/
#define	MCDS_SPBEVT4	(MCDS_SPB_EVT4)

/** \\brief  6814, Event Definition Register */
#define MCDS_SPB_EVT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE814u)

/** Alias (User Manual Name) for MCDS_SPB_EVT5.
* To use register names with standard convension, please use MCDS_SPB_EVT5.
*/
#define	MCDS_SPBEVT5	(MCDS_SPB_EVT5)

/** \\brief  6818, Event Definition Register */
#define MCDS_SPB_EVT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE818u)

/** Alias (User Manual Name) for MCDS_SPB_EVT6.
* To use register names with standard convension, please use MCDS_SPB_EVT6.
*/
#define	MCDS_SPBEVT6	(MCDS_SPB_EVT6)

/** \\brief  681C, Event Definition Register */
#define MCDS_SPB_EVT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE81Cu)

/** Alias (User Manual Name) for MCDS_SPB_EVT7.
* To use register names with standard convension, please use MCDS_SPB_EVT7.
*/
#define	MCDS_SPBEVT7	(MCDS_SPB_EVT7)

/** \\brief  6820, Event Definition Register */
#define MCDS_SPB_EVT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE820u)

/** Alias (User Manual Name) for MCDS_SPB_EVT8.
* To use register names with standard convension, please use MCDS_SPB_EVT8.
*/
#define	MCDS_SPBEVT8	(MCDS_SPB_EVT8)

/** \\brief  6824, Event Definition Register */
#define MCDS_SPB_EVT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EE824u)

/** Alias (User Manual Name) for MCDS_SPB_EVT9.
* To use register names with standard convension, please use MCDS_SPB_EVT9.
*/
#define	MCDS_SPBEVT9	(MCDS_SPB_EVT9)

/** \\brief  6480, Comparator Bound Register */
#define MCDS_SPB_WD0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_BND*)0xF90EE480u)

/** Alias (User Manual Name) for MCDS_SPB_WD0_BND.
* To use register names with standard convension, please use MCDS_SPB_WD0_BND.
*/
#define	MCDS_SPBWDBND0	(MCDS_SPB_WD0_BND)

/** \\brief  6488, Comparator Mask Register */
#define MCDS_SPB_WD0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_MSK*)0xF90EE488u)

/** Alias (User Manual Name) for MCDS_SPB_WD0_MSK.
* To use register names with standard convension, please use MCDS_SPB_WD0_MSK.
*/
#define	MCDS_SPBWDMSK0	(MCDS_SPB_WD0_MSK)

/** \\brief  6484, Comparator Range Register */
#define MCDS_SPB_WD0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_RNG*)0xF90EE484u)

/** Alias (User Manual Name) for MCDS_SPB_WD0_RNG.
* To use register names with standard convension, please use MCDS_SPB_WD0_RNG.
*/
#define	MCDS_SPBWDRNG0	(MCDS_SPB_WD0_RNG)

/** \\brief  648C, Comparator Sign Register */
#define MCDS_SPB_WD0_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_SGN*)0xF90EE48Cu)

/** Alias (User Manual Name) for MCDS_SPB_WD0_SGN.
* To use register names with standard convension, please use MCDS_SPB_WD0_SGN.
*/
#define	MCDS_SPBWDSGN0	(MCDS_SPB_WD0_SGN)

/** \\brief  6490, Comparator Bound Register */
#define MCDS_SPB_WD1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_BND*)0xF90EE490u)

/** Alias (User Manual Name) for MCDS_SPB_WD1_BND.
* To use register names with standard convension, please use MCDS_SPB_WD1_BND.
*/
#define	MCDS_SPBWDBND1	(MCDS_SPB_WD1_BND)

/** \\brief  6498, Comparator Mask Register */
#define MCDS_SPB_WD1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_MSK*)0xF90EE498u)

/** Alias (User Manual Name) for MCDS_SPB_WD1_MSK.
* To use register names with standard convension, please use MCDS_SPB_WD1_MSK.
*/
#define	MCDS_SPBWDMSK1	(MCDS_SPB_WD1_MSK)

/** \\brief  6494, Comparator Range Register */
#define MCDS_SPB_WD1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_RNG*)0xF90EE494u)

/** Alias (User Manual Name) for MCDS_SPB_WD1_RNG.
* To use register names with standard convension, please use MCDS_SPB_WD1_RNG.
*/
#define	MCDS_SPBWDRNG1	(MCDS_SPB_WD1_RNG)

/** \\brief  649C, Comparator Sign Register */
#define MCDS_SPB_WD1_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_SGN*)0xF90EE49Cu)

/** Alias (User Manual Name) for MCDS_SPB_WD1_SGN.
* To use register names with standard convension, please use MCDS_SPB_WD1_SGN.
*/
#define	MCDS_SPBWDSGN1	(MCDS_SPB_WD1_SGN)

/** \\brief  64A0, Comparator Bound Register */
#define MCDS_SPB_WD2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_BND*)0xF90EE4A0u)

/** Alias (User Manual Name) for MCDS_SPB_WD2_BND.
* To use register names with standard convension, please use MCDS_SPB_WD2_BND.
*/
#define	MCDS_SPBWDBND2	(MCDS_SPB_WD2_BND)

/** \\brief  64A8, Comparator Mask Register */
#define MCDS_SPB_WD2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_MSK*)0xF90EE4A8u)

/** Alias (User Manual Name) for MCDS_SPB_WD2_MSK.
* To use register names with standard convension, please use MCDS_SPB_WD2_MSK.
*/
#define	MCDS_SPBWDMSK2	(MCDS_SPB_WD2_MSK)

/** \\brief  64A4, Comparator Range Register */
#define MCDS_SPB_WD2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_RNG*)0xF90EE4A4u)

/** Alias (User Manual Name) for MCDS_SPB_WD2_RNG.
* To use register names with standard convension, please use MCDS_SPB_WD2_RNG.
*/
#define	MCDS_SPBWDRNG2	(MCDS_SPB_WD2_RNG)

/** \\brief  64AC, Comparator Sign Register */
#define MCDS_SPB_WD2_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_SGN*)0xF90EE4ACu)

/** Alias (User Manual Name) for MCDS_SPB_WD2_SGN.
* To use register names with standard convension, please use MCDS_SPB_WD2_SGN.
*/
#define	MCDS_SPBWDSGN2	(MCDS_SPB_WD2_SGN)

/** \\brief  64B0, Comparator Bound Register */
#define MCDS_SPB_WD3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_BND*)0xF90EE4B0u)

/** Alias (User Manual Name) for MCDS_SPB_WD3_BND.
* To use register names with standard convension, please use MCDS_SPB_WD3_BND.
*/
#define	MCDS_SPBWDBND3	(MCDS_SPB_WD3_BND)

/** \\brief  64B8, Comparator Mask Register */
#define MCDS_SPB_WD3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_MSK*)0xF90EE4B8u)

/** Alias (User Manual Name) for MCDS_SPB_WD3_MSK.
* To use register names with standard convension, please use MCDS_SPB_WD3_MSK.
*/
#define	MCDS_SPBWDMSK3	(MCDS_SPB_WD3_MSK)

/** \\brief  64B4, Comparator Range Register */
#define MCDS_SPB_WD3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_RNG*)0xF90EE4B4u)

/** Alias (User Manual Name) for MCDS_SPB_WD3_RNG.
* To use register names with standard convension, please use MCDS_SPB_WD3_RNG.
*/
#define	MCDS_SPBWDRNG3	(MCDS_SPB_WD3_RNG)

/** \\brief  64BC, Comparator Sign Register */
#define MCDS_SPB_WD3_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SPBWD_SGN*)0xF90EE4BCu)

/** Alias (User Manual Name) for MCDS_SPB_WD3_SGN.
* To use register names with standard convension, please use MCDS_SPB_WD3_SGN.
*/
#define	MCDS_SPBWDSGN3	(MCDS_SPB_WD3_SGN)

/** \\brief  7500, Comparator Bound Register */
#define MCDS_SRI_SRI1AC0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF500u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC0_BND.
*/
#define	MCDS_SRI1ACBND0	(MCDS_SRI_SRI1AC0_BND)

/** \\brief  7508, Comparator Mask Register */
#define MCDS_SRI_SRI1AC0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF508u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC0_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC0_MSK.
*/
#define	MCDS_SRI1ACMSK0	(MCDS_SRI_SRI1AC0_MSK)

/** \\brief  7504, Comparator Range Register */
#define MCDS_SRI_SRI1AC0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF504u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC0_RNG.
*/
#define	MCDS_SRI1ACRNG0	(MCDS_SRI_SRI1AC0_RNG)

/** \\brief  7510, Comparator Bound Register */
#define MCDS_SRI_SRI1AC1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF510u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC1_BND.
*/
#define	MCDS_SRI1ACBND1	(MCDS_SRI_SRI1AC1_BND)

/** \\brief  7518, Comparator Mask Register */
#define MCDS_SRI_SRI1AC1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF518u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC1_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC1_MSK.
*/
#define	MCDS_SRI1ACMSK1	(MCDS_SRI_SRI1AC1_MSK)

/** \\brief  7514, Comparator Range Register */
#define MCDS_SRI_SRI1AC1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF514u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC1_RNG.
*/
#define	MCDS_SRI1ACRNG1	(MCDS_SRI_SRI1AC1_RNG)

/** \\brief  7520, Comparator Bound Register */
#define MCDS_SRI_SRI1AC2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF520u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC2_BND.
*/
#define	MCDS_SRI1ACBND2	(MCDS_SRI_SRI1AC2_BND)

/** \\brief  7528, Comparator Mask Register */
#define MCDS_SRI_SRI1AC2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF528u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC2_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC2_MSK.
*/
#define	MCDS_SRI1ACMSK2	(MCDS_SRI_SRI1AC2_MSK)

/** \\brief  7524, Comparator Range Register */
#define MCDS_SRI_SRI1AC2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF524u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC2_RNG.
*/
#define	MCDS_SRI1ACRNG2	(MCDS_SRI_SRI1AC2_RNG)

/** \\brief  7530, Comparator Bound Register */
#define MCDS_SRI_SRI1AC3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF530u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC3_BND.
*/
#define	MCDS_SRI1ACBND3	(MCDS_SRI_SRI1AC3_BND)

/** \\brief  7538, Comparator Mask Register */
#define MCDS_SRI_SRI1AC3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF538u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC3_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC3_MSK.
*/
#define	MCDS_SRI1ACMSK3	(MCDS_SRI_SRI1AC3_MSK)

/** \\brief  7534, Comparator Range Register */
#define MCDS_SRI_SRI1AC3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF534u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1AC3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1AC3_RNG.
*/
#define	MCDS_SRI1ACRNG3	(MCDS_SRI_SRI1AC3_RNG)

/** \\brief  7210, Lookup Table Base Register */
#define MCDS_SRI_SRI1BAL0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF210u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL0_BND.
*/
#define	MCDS_SRI1BALBND0	(MCDS_SRI_SRI1BAL0_BND)

/** \\brief  7218, Lookup Table Mapping Register */
#define MCDS_SRI_SRI1BAL0_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF218u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL0_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL0_MAP.
*/
#define	MCDS_SRI1BALMAP0	(MCDS_SRI_SRI1BAL0_MAP)

/** \\brief  7214, Lookup Table Range Register */
#define MCDS_SRI_SRI1BAL0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF214u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL0_RNG.
*/
#define	MCDS_SRI1BALRNG0	(MCDS_SRI_SRI1BAL0_RNG)

/** \\brief  7220, Lookup Table Base Register */
#define MCDS_SRI_SRI1BAL1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF220u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL1_BND.
*/
#define	MCDS_SRI1BALBND1	(MCDS_SRI_SRI1BAL1_BND)

/** \\brief  7228, Lookup Table Mapping Register */
#define MCDS_SRI_SRI1BAL1_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF228u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL1_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL1_MAP.
*/
#define	MCDS_SRI1BALMAP1	(MCDS_SRI_SRI1BAL1_MAP)

/** \\brief  7224, Lookup Table Range Register */
#define MCDS_SRI_SRI1BAL1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF224u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL1_RNG.
*/
#define	MCDS_SRI1BALRNG1	(MCDS_SRI_SRI1BAL1_RNG)

/** \\brief  7230, Lookup Table Base Register */
#define MCDS_SRI_SRI1BAL2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF230u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL2_BND.
*/
#define	MCDS_SRI1BALBND2	(MCDS_SRI_SRI1BAL2_BND)

/** \\brief  7238, Lookup Table Mapping Register */
#define MCDS_SRI_SRI1BAL2_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF238u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL2_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL2_MAP.
*/
#define	MCDS_SRI1BALMAP2	(MCDS_SRI_SRI1BAL2_MAP)

/** \\brief  7234, Lookup Table Range Register */
#define MCDS_SRI_SRI1BAL2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF234u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL2_RNG.
*/
#define	MCDS_SRI1BALRNG2	(MCDS_SRI_SRI1BAL2_RNG)

/** \\brief  7240, Lookup Table Base Register */
#define MCDS_SRI_SRI1BAL3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF240u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL3_BND.
*/
#define	MCDS_SRI1BALBND3	(MCDS_SRI_SRI1BAL3_BND)

/** \\brief  7248, Lookup Table Mapping Register */
#define MCDS_SRI_SRI1BAL3_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF248u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL3_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL3_MAP.
*/
#define	MCDS_SRI1BALMAP3	(MCDS_SRI_SRI1BAL3_MAP)

/** \\brief  7244, Lookup Table Range Register */
#define MCDS_SRI_SRI1BAL3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF244u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BAL3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1BAL3_RNG.
*/
#define	MCDS_SRI1BALRNG3	(MCDS_SRI_SRI1BAL3_RNG)

/** \\brief  7204, Lookup Table Address Register */
#define MCDS_SRI_SRI1BALLU_TA /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TA*)0xF90EF204u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BALLU_TA.
* To use register names with standard convension, please use MCDS_SRI_SRI1BALLU_TA.
*/
#define	MCDS_SRI1BALLUTA	(MCDS_SRI_SRI1BALLU_TA)

/** \\brief  7200, Lookup Table Data Register */
#define MCDS_SRI_SRI1BALLU_TD /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TD*)0xF90EF200u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1BALLU_TD.
* To use register names with standard convension, please use MCDS_SRI_SRI1BALLU_TD.
*/
#define	MCDS_SRI1BALLUTD	(MCDS_SRI_SRI1BALLU_TD)

/** \\brief  7400, Comparator Bound Register */
#define MCDS_SRI_SRI1EA0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF400u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA0_BND.
*/
#define	MCDS_SRI1EABND0	(MCDS_SRI_SRI1EA0_BND)

/** \\brief  7404, Comparator Range Register */
#define MCDS_SRI_SRI1EA0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF404u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA0_RNG.
*/
#define	MCDS_SRI1EARNG0	(MCDS_SRI_SRI1EA0_RNG)

/** \\brief  7410, Comparator Bound Register */
#define MCDS_SRI_SRI1EA1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF410u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA1_BND.
*/
#define	MCDS_SRI1EABND1	(MCDS_SRI_SRI1EA1_BND)

/** \\brief  7414, Comparator Range Register */
#define MCDS_SRI_SRI1EA1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF414u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA1_RNG.
*/
#define	MCDS_SRI1EARNG1	(MCDS_SRI_SRI1EA1_RNG)

/** \\brief  7420, Comparator Bound Register */
#define MCDS_SRI_SRI1EA2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF420u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA2_BND.
*/
#define	MCDS_SRI1EABND2	(MCDS_SRI_SRI1EA2_BND)

/** \\brief  7424, Comparator Range Register */
#define MCDS_SRI_SRI1EA2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF424u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA2_RNG.
*/
#define	MCDS_SRI1EARNG2	(MCDS_SRI_SRI1EA2_RNG)

/** \\brief  7430, Comparator Bound Register */
#define MCDS_SRI_SRI1EA3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF430u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA3_BND.
*/
#define	MCDS_SRI1EABND3	(MCDS_SRI_SRI1EA3_BND)

/** \\brief  7434, Comparator Range Register */
#define MCDS_SRI_SRI1EA3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF434u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1EA3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1EA3_RNG.
*/
#define	MCDS_SRI1EARNG3	(MCDS_SRI_SRI1EA3_RNG)

/** \\brief  7480, Comparator Bound Register */
#define MCDS_SRI_SRI1WD0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF480u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD0_BND.
*/
#define	MCDS_SRI1WDBND0	(MCDS_SRI_SRI1WD0_BND)

/** \\brief  7484, Comparator Bound Register */
#define MCDS_SRI_SRI1WD0_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF484u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD0_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD0_HBND.
*/
#define	MCDS_SRI1WDHBND0	(MCDS_SRI_SRI1WD0_HBND)

/** \\brief  7494, Comparator Mask Register */
#define MCDS_SRI_SRI1WD0_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF494u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD0_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD0_HMSK.
*/
#define	MCDS_SRI1WDHMSK0	(MCDS_SRI_SRI1WD0_HMSK)

/** \\brief  748C, Comparator Range Register */
#define MCDS_SRI_SRI1WD0_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF48Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD0_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD0_HRNG.
*/
#define	MCDS_SRI1WDHRNG0	(MCDS_SRI_SRI1WD0_HRNG)

/** \\brief  7490, Comparator Mask Register */
#define MCDS_SRI_SRI1WD0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF490u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD0_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD0_MSK.
*/
#define	MCDS_SRI1WDMSK0	(MCDS_SRI_SRI1WD0_MSK)

/** \\brief  7488, Comparator Range Register */
#define MCDS_SRI_SRI1WD0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF488u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD0_RNG.
*/
#define	MCDS_SRI1WDRNG0	(MCDS_SRI_SRI1WD0_RNG)

/** \\brief  749C, Comparator Sign Register */
#define MCDS_SRI_SRI1WD0_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF49Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD0_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD0_SGN.
*/
#define	MCDS_SRI1WDSGN0	(MCDS_SRI_SRI1WD0_SGN)

/** \\brief  74A0, Comparator Bound Register */
#define MCDS_SRI_SRI1WD1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF4A0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD1_BND.
*/
#define	MCDS_SRI1WDBND1	(MCDS_SRI_SRI1WD1_BND)

/** \\brief  74A4, Comparator Bound Register */
#define MCDS_SRI_SRI1WD1_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF4A4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD1_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD1_HBND.
*/
#define	MCDS_SRI1WDHBND1	(MCDS_SRI_SRI1WD1_HBND)

/** \\brief  74B4, Comparator Mask Register */
#define MCDS_SRI_SRI1WD1_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF4B4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD1_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD1_HMSK.
*/
#define	MCDS_SRI1WDHMSK1	(MCDS_SRI_SRI1WD1_HMSK)

/** \\brief  74AC, Comparator Range Register */
#define MCDS_SRI_SRI1WD1_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF4ACu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD1_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD1_HRNG.
*/
#define	MCDS_SRI1WDHRNG1	(MCDS_SRI_SRI1WD1_HRNG)

/** \\brief  74B0, Comparator Mask Register */
#define MCDS_SRI_SRI1WD1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF4B0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD1_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD1_MSK.
*/
#define	MCDS_SRI1WDMSK1	(MCDS_SRI_SRI1WD1_MSK)

/** \\brief  74A8, Comparator Range Register */
#define MCDS_SRI_SRI1WD1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF4A8u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD1_RNG.
*/
#define	MCDS_SRI1WDRNG1	(MCDS_SRI_SRI1WD1_RNG)

/** \\brief  74BC, Comparator Sign Register */
#define MCDS_SRI_SRI1WD1_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF4BCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD1_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD1_SGN.
*/
#define	MCDS_SRI1WDSGN1	(MCDS_SRI_SRI1WD1_SGN)

/** \\brief  74C0, Comparator Bound Register */
#define MCDS_SRI_SRI1WD2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF4C0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD2_BND.
*/
#define	MCDS_SRI1WDBND2	(MCDS_SRI_SRI1WD2_BND)

/** \\brief  74C4, Comparator Bound Register */
#define MCDS_SRI_SRI1WD2_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF4C4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD2_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD2_HBND.
*/
#define	MCDS_SRI1WDHBND2	(MCDS_SRI_SRI1WD2_HBND)

/** \\brief  74D4, Comparator Mask Register */
#define MCDS_SRI_SRI1WD2_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF4D4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD2_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD2_HMSK.
*/
#define	MCDS_SRI1WDHMSK2	(MCDS_SRI_SRI1WD2_HMSK)

/** \\brief  74CC, Comparator Range Register */
#define MCDS_SRI_SRI1WD2_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF4CCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD2_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD2_HRNG.
*/
#define	MCDS_SRI1WDHRNG2	(MCDS_SRI_SRI1WD2_HRNG)

/** \\brief  74D0, Comparator Mask Register */
#define MCDS_SRI_SRI1WD2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF4D0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD2_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD2_MSK.
*/
#define	MCDS_SRI1WDMSK2	(MCDS_SRI_SRI1WD2_MSK)

/** \\brief  74C8, Comparator Range Register */
#define MCDS_SRI_SRI1WD2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF4C8u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD2_RNG.
*/
#define	MCDS_SRI1WDRNG2	(MCDS_SRI_SRI1WD2_RNG)

/** \\brief  74DC, Comparator Sign Register */
#define MCDS_SRI_SRI1WD2_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF4DCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD2_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD2_SGN.
*/
#define	MCDS_SRI1WDSGN2	(MCDS_SRI_SRI1WD2_SGN)

/** \\brief  74E0, Comparator Bound Register */
#define MCDS_SRI_SRI1WD3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF4E0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD3_BND.
*/
#define	MCDS_SRI1WDBND3	(MCDS_SRI_SRI1WD3_BND)

/** \\brief  74E4, Comparator Bound Register */
#define MCDS_SRI_SRI1WD3_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF4E4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD3_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD3_HBND.
*/
#define	MCDS_SRI1WDHBND3	(MCDS_SRI_SRI1WD3_HBND)

/** \\brief  74F4, Comparator Mask Register */
#define MCDS_SRI_SRI1WD3_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF4F4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD3_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD3_HMSK.
*/
#define	MCDS_SRI1WDHMSK3	(MCDS_SRI_SRI1WD3_HMSK)

/** \\brief  74EC, Comparator Range Register */
#define MCDS_SRI_SRI1WD3_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF4ECu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD3_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD3_HRNG.
*/
#define	MCDS_SRI1WDHRNG3	(MCDS_SRI_SRI1WD3_HRNG)

/** \\brief  74F0, Comparator Mask Register */
#define MCDS_SRI_SRI1WD3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF4F0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD3_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD3_MSK.
*/
#define	MCDS_SRI1WDMSK3	(MCDS_SRI_SRI1WD3_MSK)

/** \\brief  74E8, Comparator Range Register */
#define MCDS_SRI_SRI1WD3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF4E8u)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD3_RNG.
*/
#define	MCDS_SRI1WDRNG3	(MCDS_SRI_SRI1WD3_RNG)

/** \\brief  74FC, Comparator Sign Register */
#define MCDS_SRI_SRI1WD3_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF4FCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI1WD3_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI1WD3_SGN.
*/
#define	MCDS_SRI1WDSGN3	(MCDS_SRI_SRI1WD3_SGN)

/** \\brief  7700, Comparator Bound Register */
#define MCDS_SRI_SRI2AC0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF700u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC0_BND.
*/
#define	MCDS_SRI2ACBND0	(MCDS_SRI_SRI2AC0_BND)

/** \\brief  7708, Comparator Mask Register */
#define MCDS_SRI_SRI2AC0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF708u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC0_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC0_MSK.
*/
#define	MCDS_SRI2ACMSK0	(MCDS_SRI_SRI2AC0_MSK)

/** \\brief  7704, Comparator Range Register */
#define MCDS_SRI_SRI2AC0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF704u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC0_RNG.
*/
#define	MCDS_SRI2ACRNG0	(MCDS_SRI_SRI2AC0_RNG)

/** \\brief  7710, Comparator Bound Register */
#define MCDS_SRI_SRI2AC1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF710u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC1_BND.
*/
#define	MCDS_SRI2ACBND1	(MCDS_SRI_SRI2AC1_BND)

/** \\brief  7718, Comparator Mask Register */
#define MCDS_SRI_SRI2AC1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF718u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC1_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC1_MSK.
*/
#define	MCDS_SRI2ACMSK1	(MCDS_SRI_SRI2AC1_MSK)

/** \\brief  7714, Comparator Range Register */
#define MCDS_SRI_SRI2AC1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF714u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC1_RNG.
*/
#define	MCDS_SRI2ACRNG1	(MCDS_SRI_SRI2AC1_RNG)

/** \\brief  7720, Comparator Bound Register */
#define MCDS_SRI_SRI2AC2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF720u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC2_BND.
*/
#define	MCDS_SRI2ACBND2	(MCDS_SRI_SRI2AC2_BND)

/** \\brief  7728, Comparator Mask Register */
#define MCDS_SRI_SRI2AC2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF728u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC2_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC2_MSK.
*/
#define	MCDS_SRI2ACMSK2	(MCDS_SRI_SRI2AC2_MSK)

/** \\brief  7724, Comparator Range Register */
#define MCDS_SRI_SRI2AC2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF724u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC2_RNG.
*/
#define	MCDS_SRI2ACRNG2	(MCDS_SRI_SRI2AC2_RNG)

/** \\brief  7730, Comparator Bound Register */
#define MCDS_SRI_SRI2AC3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_BND*)0xF90EF730u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC3_BND.
*/
#define	MCDS_SRI2ACBND3	(MCDS_SRI_SRI2AC3_BND)

/** \\brief  7738, Comparator Mask Register */
#define MCDS_SRI_SRI2AC3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_MSK*)0xF90EF738u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC3_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC3_MSK.
*/
#define	MCDS_SRI2ACMSK3	(MCDS_SRI_SRI2AC3_MSK)

/** \\brief  7734, Comparator Range Register */
#define MCDS_SRI_SRI2AC3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIAC_RNG*)0xF90EF734u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2AC3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2AC3_RNG.
*/
#define	MCDS_SRI2ACRNG3	(MCDS_SRI_SRI2AC3_RNG)

/** \\brief  7310, Lookup Table Base Register */
#define MCDS_SRI_SRI2BAL0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF310u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL0_BND.
*/
#define	MCDS_SRI2BALBND0	(MCDS_SRI_SRI2BAL0_BND)

/** \\brief  7318, Lookup Table Mapping Register */
#define MCDS_SRI_SRI2BAL0_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF318u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL0_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL0_MAP.
*/
#define	MCDS_SRI2BALMAP0	(MCDS_SRI_SRI2BAL0_MAP)

/** \\brief  7314, Lookup Table Range Register */
#define MCDS_SRI_SRI2BAL0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF314u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL0_RNG.
*/
#define	MCDS_SRI2BALRNG0	(MCDS_SRI_SRI2BAL0_RNG)

/** \\brief  7320, Lookup Table Base Register */
#define MCDS_SRI_SRI2BAL1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF320u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL1_BND.
*/
#define	MCDS_SRI2BALBND1	(MCDS_SRI_SRI2BAL1_BND)

/** \\brief  7328, Lookup Table Mapping Register */
#define MCDS_SRI_SRI2BAL1_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF328u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL1_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL1_MAP.
*/
#define	MCDS_SRI2BALMAP1	(MCDS_SRI_SRI2BAL1_MAP)

/** \\brief  7324, Lookup Table Range Register */
#define MCDS_SRI_SRI2BAL1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF324u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL1_RNG.
*/
#define	MCDS_SRI2BALRNG1	(MCDS_SRI_SRI2BAL1_RNG)

/** \\brief  7330, Lookup Table Base Register */
#define MCDS_SRI_SRI2BAL2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF330u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL2_BND.
*/
#define	MCDS_SRI2BALBND2	(MCDS_SRI_SRI2BAL2_BND)

/** \\brief  7338, Lookup Table Mapping Register */
#define MCDS_SRI_SRI2BAL2_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF338u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL2_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL2_MAP.
*/
#define	MCDS_SRI2BALMAP2	(MCDS_SRI_SRI2BAL2_MAP)

/** \\brief  7334, Lookup Table Range Register */
#define MCDS_SRI_SRI2BAL2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF334u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL2_RNG.
*/
#define	MCDS_SRI2BALRNG2	(MCDS_SRI_SRI2BAL2_RNG)

/** \\brief  7340, Lookup Table Base Register */
#define MCDS_SRI_SRI2BAL3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_BND*)0xF90EF340u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL3_BND.
*/
#define	MCDS_SRI2BALBND3	(MCDS_SRI_SRI2BAL3_BND)

/** \\brief  7348, Lookup Table Mapping Register */
#define MCDS_SRI_SRI2BAL3_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_MAP*)0xF90EF348u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL3_MAP.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL3_MAP.
*/
#define	MCDS_SRI2BALMAP3	(MCDS_SRI_SRI2BAL3_MAP)

/** \\brief  7344, Lookup Table Range Register */
#define MCDS_SRI_SRI2BAL3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIBAL_RNG*)0xF90EF344u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BAL3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2BAL3_RNG.
*/
#define	MCDS_SRI2BALRNG3	(MCDS_SRI_SRI2BAL3_RNG)

/** \\brief  7304, Lookup Table Address Register */
#define MCDS_SRI_SRI2BALLU_TA /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TA*)0xF90EF304u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BALLU_TA.
* To use register names with standard convension, please use MCDS_SRI_SRI2BALLU_TA.
*/
#define	MCDS_SRI2BALLUTA	(MCDS_SRI_SRI2BALLU_TA)

/** \\brief  7300, Lookup Table Data Register */
#define MCDS_SRI_SRI2BALLU_TD /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TD*)0xF90EF300u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2BALLU_TD.
* To use register names with standard convension, please use MCDS_SRI_SRI2BALLU_TD.
*/
#define	MCDS_SRI2BALLUTD	(MCDS_SRI_SRI2BALLU_TD)

/** \\brief  7600, Comparator Bound Register */
#define MCDS_SRI_SRI2EA0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF600u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA0_BND.
*/
#define	MCDS_SRI2EABND0	(MCDS_SRI_SRI2EA0_BND)

/** \\brief  7604, Comparator Range Register */
#define MCDS_SRI_SRI2EA0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF604u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA0_RNG.
*/
#define	MCDS_SRI2EARNG0	(MCDS_SRI_SRI2EA0_RNG)

/** \\brief  7610, Comparator Bound Register */
#define MCDS_SRI_SRI2EA1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF610u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA1_BND.
*/
#define	MCDS_SRI2EABND1	(MCDS_SRI_SRI2EA1_BND)

/** \\brief  7614, Comparator Range Register */
#define MCDS_SRI_SRI2EA1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF614u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA1_RNG.
*/
#define	MCDS_SRI2EARNG1	(MCDS_SRI_SRI2EA1_RNG)

/** \\brief  7620, Comparator Bound Register */
#define MCDS_SRI_SRI2EA2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF620u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA2_BND.
*/
#define	MCDS_SRI2EABND2	(MCDS_SRI_SRI2EA2_BND)

/** \\brief  7624, Comparator Range Register */
#define MCDS_SRI_SRI2EA2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF624u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA2_RNG.
*/
#define	MCDS_SRI2EARNG2	(MCDS_SRI_SRI2EA2_RNG)

/** \\brief  7630, Comparator Bound Register */
#define MCDS_SRI_SRI2EA3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_BND*)0xF90EF630u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA3_BND.
*/
#define	MCDS_SRI2EABND3	(MCDS_SRI_SRI2EA3_BND)

/** \\brief  7634, Comparator Range Register */
#define MCDS_SRI_SRI2EA3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIEA_RNG*)0xF90EF634u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2EA3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2EA3_RNG.
*/
#define	MCDS_SRI2EARNG3	(MCDS_SRI_SRI2EA3_RNG)

/** \\brief  7680, Comparator Bound Register */
#define MCDS_SRI_SRI2WD0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF680u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD0_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD0_BND.
*/
#define	MCDS_SRI2WDBND0	(MCDS_SRI_SRI2WD0_BND)

/** \\brief  7684, Comparator Bound Register */
#define MCDS_SRI_SRI2WD0_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF684u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD0_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD0_HBND.
*/
#define	MCDS_SRI2WDHBND0	(MCDS_SRI_SRI2WD0_HBND)

/** \\brief  7694, Comparator Mask Register */
#define MCDS_SRI_SRI2WD0_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF694u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD0_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD0_HMSK.
*/
#define	MCDS_SRI2WDHMSK0	(MCDS_SRI_SRI2WD0_HMSK)

/** \\brief  768C, Comparator Range Register */
#define MCDS_SRI_SRI2WD0_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF68Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD0_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD0_HRNG.
*/
#define	MCDS_SRI2WDHRNG0	(MCDS_SRI_SRI2WD0_HRNG)

/** \\brief  7690, Comparator Mask Register */
#define MCDS_SRI_SRI2WD0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF690u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD0_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD0_MSK.
*/
#define	MCDS_SRI2WDMSK0	(MCDS_SRI_SRI2WD0_MSK)

/** \\brief  7688, Comparator Range Register */
#define MCDS_SRI_SRI2WD0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF688u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD0_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD0_RNG.
*/
#define	MCDS_SRI2WDRNG0	(MCDS_SRI_SRI2WD0_RNG)

/** \\brief  769C, Comparator Sign Register */
#define MCDS_SRI_SRI2WD0_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF69Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD0_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD0_SGN.
*/
#define	MCDS_SRI2WDSGN0	(MCDS_SRI_SRI2WD0_SGN)

/** \\brief  76A0, Comparator Bound Register */
#define MCDS_SRI_SRI2WD1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF6A0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD1_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD1_BND.
*/
#define	MCDS_SRI2WDBND1	(MCDS_SRI_SRI2WD1_BND)

/** \\brief  76A4, Comparator Bound Register */
#define MCDS_SRI_SRI2WD1_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF6A4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD1_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD1_HBND.
*/
#define	MCDS_SRI2WDHBND1	(MCDS_SRI_SRI2WD1_HBND)

/** \\brief  76B4, Comparator Mask Register */
#define MCDS_SRI_SRI2WD1_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF6B4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD1_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD1_HMSK.
*/
#define	MCDS_SRI2WDHMSK1	(MCDS_SRI_SRI2WD1_HMSK)

/** \\brief  76AC, Comparator Range Register */
#define MCDS_SRI_SRI2WD1_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF6ACu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD1_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD1_HRNG.
*/
#define	MCDS_SRI2WDHRNG1	(MCDS_SRI_SRI2WD1_HRNG)

/** \\brief  76B0, Comparator Mask Register */
#define MCDS_SRI_SRI2WD1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF6B0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD1_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD1_MSK.
*/
#define	MCDS_SRI2WDMSK1	(MCDS_SRI_SRI2WD1_MSK)

/** \\brief  76A8, Comparator Range Register */
#define MCDS_SRI_SRI2WD1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF6A8u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD1_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD1_RNG.
*/
#define	MCDS_SRI2WDRNG1	(MCDS_SRI_SRI2WD1_RNG)

/** \\brief  76BC, Comparator Sign Register */
#define MCDS_SRI_SRI2WD1_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF6BCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD1_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD1_SGN.
*/
#define	MCDS_SRI2WDSGN1	(MCDS_SRI_SRI2WD1_SGN)

/** \\brief  76C0, Comparator Bound Register */
#define MCDS_SRI_SRI2WD2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF6C0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD2_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD2_BND.
*/
#define	MCDS_SRI2WDBND2	(MCDS_SRI_SRI2WD2_BND)

/** \\brief  76C4, Comparator Bound Register */
#define MCDS_SRI_SRI2WD2_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF6C4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD2_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD2_HBND.
*/
#define	MCDS_SRI2WDHBND2	(MCDS_SRI_SRI2WD2_HBND)

/** \\brief  76D4, Comparator Mask Register */
#define MCDS_SRI_SRI2WD2_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF6D4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD2_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD2_HMSK.
*/
#define	MCDS_SRI2WDHMSK2	(MCDS_SRI_SRI2WD2_HMSK)

/** \\brief  76CC, Comparator Range Register */
#define MCDS_SRI_SRI2WD2_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF6CCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD2_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD2_HRNG.
*/
#define	MCDS_SRI2WDHRNG2	(MCDS_SRI_SRI2WD2_HRNG)

/** \\brief  76D0, Comparator Mask Register */
#define MCDS_SRI_SRI2WD2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF6D0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD2_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD2_MSK.
*/
#define	MCDS_SRI2WDMSK2	(MCDS_SRI_SRI2WD2_MSK)

/** \\brief  76C8, Comparator Range Register */
#define MCDS_SRI_SRI2WD2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF6C8u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD2_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD2_RNG.
*/
#define	MCDS_SRI2WDRNG2	(MCDS_SRI_SRI2WD2_RNG)

/** \\brief  76DC, Comparator Sign Register */
#define MCDS_SRI_SRI2WD2_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF6DCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD2_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD2_SGN.
*/
#define	MCDS_SRI2WDSGN2	(MCDS_SRI_SRI2WD2_SGN)

/** \\brief  76E0, Comparator Bound Register */
#define MCDS_SRI_SRI2WD3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_BND*)0xF90EF6E0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD3_BND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD3_BND.
*/
#define	MCDS_SRI2WDBND3	(MCDS_SRI_SRI2WD3_BND)

/** \\brief  76E4, Comparator Bound Register */
#define MCDS_SRI_SRI2WD3_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HBND*)0xF90EF6E4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD3_HBND.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD3_HBND.
*/
#define	MCDS_SRI2WDHBND3	(MCDS_SRI_SRI2WD3_HBND)

/** \\brief  76F4, Comparator Mask Register */
#define MCDS_SRI_SRI2WD3_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HMSK*)0xF90EF6F4u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD3_HMSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD3_HMSK.
*/
#define	MCDS_SRI2WDHMSK3	(MCDS_SRI_SRI2WD3_HMSK)

/** \\brief  76EC, Comparator Range Register */
#define MCDS_SRI_SRI2WD3_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_HRNG*)0xF90EF6ECu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD3_HRNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD3_HRNG.
*/
#define	MCDS_SRI2WDHRNG3	(MCDS_SRI_SRI2WD3_HRNG)

/** \\brief  76F0, Comparator Mask Register */
#define MCDS_SRI_SRI2WD3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_MSK*)0xF90EF6F0u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD3_MSK.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD3_MSK.
*/
#define	MCDS_SRI2WDMSK3	(MCDS_SRI_SRI2WD3_MSK)

/** \\brief  76E8, Comparator Range Register */
#define MCDS_SRI_SRI2WD3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_RNG*)0xF90EF6E8u)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD3_RNG.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD3_RNG.
*/
#define	MCDS_SRI2WDRNG3	(MCDS_SRI_SRI2WD3_RNG)

/** \\brief  76FC, Comparator Sign Register */
#define MCDS_SRI_SRI2WD3_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRIWD_SGN*)0xF90EF6FCu)

/** Alias (User Manual Name) for MCDS_SRI_SRI2WD3_SGN.
* To use register names with standard convension, please use MCDS_SRI_SRI2WD3_SGN.
*/
#define	MCDS_SRI2WDSGN3	(MCDS_SRI_SRI2WD3_SGN)

/** \\brief  7880, Action Definition Register */
#define MCDS_SRI_SRIACT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF880u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT0.
* To use register names with standard convension, please use MCDS_SRI_SRIACT0.
*/
#define	MCDS_SRIACT0	(MCDS_SRI_SRIACT0)

/** \\brief  7884, Action Definition Register */
#define MCDS_SRI_SRIACT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF884u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT1.
* To use register names with standard convension, please use MCDS_SRI_SRIACT1.
*/
#define	MCDS_SRIACT1	(MCDS_SRI_SRIACT1)

/** \\brief  78A8, Action Definition Register */
#define MCDS_SRI_SRIACT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8A8u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT10.
* To use register names with standard convension, please use MCDS_SRI_SRIACT10.
*/
#define	MCDS_SRIACT10	(MCDS_SRI_SRIACT10)

/** \\brief  78AC, Action Definition Register */
#define MCDS_SRI_SRIACT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8ACu)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT11.
* To use register names with standard convension, please use MCDS_SRI_SRIACT11.
*/
#define	MCDS_SRIACT11	(MCDS_SRI_SRIACT11)

/** \\brief  78B0, Action Definition Register */
#define MCDS_SRI_SRIACT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8B0u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT12.
* To use register names with standard convension, please use MCDS_SRI_SRIACT12.
*/
#define	MCDS_SRIACT12	(MCDS_SRI_SRIACT12)

/** \\brief  78B4, Action Definition Register */
#define MCDS_SRI_SRIACT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8B4u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT13.
* To use register names with standard convension, please use MCDS_SRI_SRIACT13.
*/
#define	MCDS_SRIACT13	(MCDS_SRI_SRIACT13)

/** \\brief  78B8, Action Definition Register */
#define MCDS_SRI_SRIACT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8B8u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT14.
* To use register names with standard convension, please use MCDS_SRI_SRIACT14.
*/
#define	MCDS_SRIACT14	(MCDS_SRI_SRIACT14)

/** \\brief  78BC, Action Definition Register */
#define MCDS_SRI_SRIACT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8BCu)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT15.
* To use register names with standard convension, please use MCDS_SRI_SRIACT15.
*/
#define	MCDS_SRIACT15	(MCDS_SRI_SRIACT15)

/** \\brief  78C0, Action Definition Register */
#define MCDS_SRI_SRIACT16 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8C0u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT16.
* To use register names with standard convension, please use MCDS_SRI_SRIACT16.
*/
#define	MCDS_SRIACT16	(MCDS_SRI_SRIACT16)

/** \\brief  78C4, Action Definition Register */
#define MCDS_SRI_SRIACT17 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8C4u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT17.
* To use register names with standard convension, please use MCDS_SRI_SRIACT17.
*/
#define	MCDS_SRIACT17	(MCDS_SRI_SRIACT17)

/** \\brief  78C8, Action Definition Register */
#define MCDS_SRI_SRIACT18 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8C8u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT18.
* To use register names with standard convension, please use MCDS_SRI_SRIACT18.
*/
#define	MCDS_SRIACT18	(MCDS_SRI_SRIACT18)

/** \\brief  78CC, Action Definition Register */
#define MCDS_SRI_SRIACT19 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8CCu)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT19.
* To use register names with standard convension, please use MCDS_SRI_SRIACT19.
*/
#define	MCDS_SRIACT19	(MCDS_SRI_SRIACT19)

/** \\brief  7888, Action Definition Register */
#define MCDS_SRI_SRIACT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF888u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT2.
* To use register names with standard convension, please use MCDS_SRI_SRIACT2.
*/
#define	MCDS_SRIACT2	(MCDS_SRI_SRIACT2)

/** \\brief  78D0, Action Definition Register */
#define MCDS_SRI_SRIACT20 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8D0u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT20.
* To use register names with standard convension, please use MCDS_SRI_SRIACT20.
*/
#define	MCDS_SRIACT20	(MCDS_SRI_SRIACT20)

/** \\brief  78D4, Action Definition Register */
#define MCDS_SRI_SRIACT21 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8D4u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT21.
* To use register names with standard convension, please use MCDS_SRI_SRIACT21.
*/
#define	MCDS_SRIACT21	(MCDS_SRI_SRIACT21)

/** \\brief  78D8, Action Definition Register */
#define MCDS_SRI_SRIACT22 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8D8u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT22.
* To use register names with standard convension, please use MCDS_SRI_SRIACT22.
*/
#define	MCDS_SRIACT22	(MCDS_SRI_SRIACT22)

/** \\brief  78DC, Action Definition Register */
#define MCDS_SRI_SRIACT23 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8DCu)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT23.
* To use register names with standard convension, please use MCDS_SRI_SRIACT23.
*/
#define	MCDS_SRIACT23	(MCDS_SRI_SRIACT23)

/** \\brief  78E0, Action Definition Register */
#define MCDS_SRI_SRIACT24 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8E0u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT24.
* To use register names with standard convension, please use MCDS_SRI_SRIACT24.
*/
#define	MCDS_SRIACT24	(MCDS_SRI_SRIACT24)

/** \\brief  78E4, Action Definition Register */
#define MCDS_SRI_SRIACT25 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8E4u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT25.
* To use register names with standard convension, please use MCDS_SRI_SRIACT25.
*/
#define	MCDS_SRIACT25	(MCDS_SRI_SRIACT25)

/** \\brief  78E8, Action Definition Register */
#define MCDS_SRI_SRIACT26 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8E8u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT26.
* To use register names with standard convension, please use MCDS_SRI_SRIACT26.
*/
#define	MCDS_SRIACT26	(MCDS_SRI_SRIACT26)

/** \\brief  788C, Action Definition Register */
#define MCDS_SRI_SRIACT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF88Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT3.
* To use register names with standard convension, please use MCDS_SRI_SRIACT3.
*/
#define	MCDS_SRIACT3	(MCDS_SRI_SRIACT3)

/** \\brief  7890, Action Definition Register */
#define MCDS_SRI_SRIACT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF890u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT4.
* To use register names with standard convension, please use MCDS_SRI_SRIACT4.
*/
#define	MCDS_SRIACT4	(MCDS_SRI_SRIACT4)

/** \\brief  7894, Action Definition Register */
#define MCDS_SRI_SRIACT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF894u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT5.
* To use register names with standard convension, please use MCDS_SRI_SRIACT5.
*/
#define	MCDS_SRIACT5	(MCDS_SRI_SRIACT5)

/** \\brief  7898, Action Definition Register */
#define MCDS_SRI_SRIACT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF898u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT6.
* To use register names with standard convension, please use MCDS_SRI_SRIACT6.
*/
#define	MCDS_SRIACT6	(MCDS_SRI_SRIACT6)

/** \\brief  789C, Action Definition Register */
#define MCDS_SRI_SRIACT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF89Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT7.
* To use register names with standard convension, please use MCDS_SRI_SRIACT7.
*/
#define	MCDS_SRIACT7	(MCDS_SRI_SRIACT7)

/** \\brief  78A0, Action Definition Register */
#define MCDS_SRI_SRIACT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8A0u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT8.
* To use register names with standard convension, please use MCDS_SRI_SRIACT8.
*/
#define	MCDS_SRIACT8	(MCDS_SRI_SRIACT8)

/** \\brief  78A4, Action Definition Register */
#define MCDS_SRI_SRIACT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EF8A4u)

/** Alias (User Manual Name) for MCDS_SRI_SRIACT9.
* To use register names with standard convension, please use MCDS_SRI_SRIACT9.
*/
#define	MCDS_SRIACT9	(MCDS_SRI_SRIACT9)

/** \\brief  7000, Debug Status Register */
#define MCDS_SRI_SRIDCSTS /* lint --e(923)*/ (*(volatile Ifx_MCDS_SRI_SRIDCSTS*)0xF90EF000u)

/** Alias (User Manual Name) for MCDS_SRI_SRIDCSTS.
* To use register names with standard convension, please use MCDS_SRI_SRIDCSTS.
*/
#define	MCDS_SRIDCSTS	(MCDS_SRI_SRIDCSTS)

/** \\brief  7800, Event Definition Register */
#define MCDS_SRI_SRIEVT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF800u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT0.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT0.
*/
#define	MCDS_SRIEVT0	(MCDS_SRI_SRIEVT0)

/** \\brief  7804, Event Definition Register */
#define MCDS_SRI_SRIEVT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF804u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT1.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT1.
*/
#define	MCDS_SRIEVT1	(MCDS_SRI_SRIEVT1)

/** \\brief  7828, Event Definition Register */
#define MCDS_SRI_SRIEVT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF828u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT10.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT10.
*/
#define	MCDS_SRIEVT10	(MCDS_SRI_SRIEVT10)

/** \\brief  782C, Event Definition Register */
#define MCDS_SRI_SRIEVT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF82Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT11.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT11.
*/
#define	MCDS_SRIEVT11	(MCDS_SRI_SRIEVT11)

/** \\brief  7830, Event Definition Register */
#define MCDS_SRI_SRIEVT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF830u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT12.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT12.
*/
#define	MCDS_SRIEVT12	(MCDS_SRI_SRIEVT12)

/** \\brief  7834, Event Definition Register */
#define MCDS_SRI_SRIEVT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF834u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT13.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT13.
*/
#define	MCDS_SRIEVT13	(MCDS_SRI_SRIEVT13)

/** \\brief  7838, Event Definition Register */
#define MCDS_SRI_SRIEVT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF838u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT14.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT14.
*/
#define	MCDS_SRIEVT14	(MCDS_SRI_SRIEVT14)

/** \\brief  783C, Event Definition Register */
#define MCDS_SRI_SRIEVT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF83Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT15.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT15.
*/
#define	MCDS_SRIEVT15	(MCDS_SRI_SRIEVT15)

/** \\brief  7808, Event Definition Register */
#define MCDS_SRI_SRIEVT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF808u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT2.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT2.
*/
#define	MCDS_SRIEVT2	(MCDS_SRI_SRIEVT2)

/** \\brief  780C, Event Definition Register */
#define MCDS_SRI_SRIEVT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF80Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT3.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT3.
*/
#define	MCDS_SRIEVT3	(MCDS_SRI_SRIEVT3)

/** \\brief  7810, Event Definition Register */
#define MCDS_SRI_SRIEVT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF810u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT4.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT4.
*/
#define	MCDS_SRIEVT4	(MCDS_SRI_SRIEVT4)

/** \\brief  7814, Event Definition Register */
#define MCDS_SRI_SRIEVT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF814u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT5.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT5.
*/
#define	MCDS_SRIEVT5	(MCDS_SRI_SRIEVT5)

/** \\brief  7818, Event Definition Register */
#define MCDS_SRI_SRIEVT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF818u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT6.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT6.
*/
#define	MCDS_SRIEVT6	(MCDS_SRI_SRIEVT6)

/** \\brief  781C, Event Definition Register */
#define MCDS_SRI_SRIEVT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF81Cu)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT7.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT7.
*/
#define	MCDS_SRIEVT7	(MCDS_SRI_SRIEVT7)

/** \\brief  7820, Event Definition Register */
#define MCDS_SRI_SRIEVT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF820u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT8.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT8.
*/
#define	MCDS_SRIEVT8	(MCDS_SRI_SRIEVT8)

/** \\brief  7824, Event Definition Register */
#define MCDS_SRI_SRIEVT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EF824u)

/** Alias (User Manual Name) for MCDS_SRI_SRIEVT9.
* To use register names with standard convension, please use MCDS_SRI_SRIEVT9.
*/
#define	MCDS_SRIEVT9	(MCDS_SRI_SRIEVT9)

/** \\brief  2880, Action Definition Register */
#define MCDS_TCX_ACT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA880u)

/** Alias (User Manual Name) for MCDS_TCX_ACT0.
* To use register names with standard convension, please use MCDS_TCX_ACT0.
*/
#define	MCDS_TCXACT0	(MCDS_TCX_ACT0)

/** \\brief  2884, Action Definition Register */
#define MCDS_TCX_ACT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA884u)

/** Alias (User Manual Name) for MCDS_TCX_ACT1.
* To use register names with standard convension, please use MCDS_TCX_ACT1.
*/
#define	MCDS_TCXACT1	(MCDS_TCX_ACT1)

/** \\brief  28A8, Action Definition Register */
#define MCDS_TCX_ACT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8A8u)

/** Alias (User Manual Name) for MCDS_TCX_ACT10.
* To use register names with standard convension, please use MCDS_TCX_ACT10.
*/
#define	MCDS_TCXACT10	(MCDS_TCX_ACT10)

/** \\brief  28AC, Action Definition Register */
#define MCDS_TCX_ACT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8ACu)

/** Alias (User Manual Name) for MCDS_TCX_ACT11.
* To use register names with standard convension, please use MCDS_TCX_ACT11.
*/
#define	MCDS_TCXACT11	(MCDS_TCX_ACT11)

/** \\brief  28B0, Action Definition Register */
#define MCDS_TCX_ACT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8B0u)

/** Alias (User Manual Name) for MCDS_TCX_ACT12.
* To use register names with standard convension, please use MCDS_TCX_ACT12.
*/
#define	MCDS_TCXACT12	(MCDS_TCX_ACT12)

/** \\brief  28B4, Action Definition Register */
#define MCDS_TCX_ACT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8B4u)

/** Alias (User Manual Name) for MCDS_TCX_ACT13.
* To use register names with standard convension, please use MCDS_TCX_ACT13.
*/
#define	MCDS_TCXACT13	(MCDS_TCX_ACT13)

/** \\brief  28B8, Action Definition Register */
#define MCDS_TCX_ACT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8B8u)

/** Alias (User Manual Name) for MCDS_TCX_ACT14.
* To use register names with standard convension, please use MCDS_TCX_ACT14.
*/
#define	MCDS_TCXACT14	(MCDS_TCX_ACT14)

/** \\brief  28BC, Action Definition Register */
#define MCDS_TCX_ACT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8BCu)

/** Alias (User Manual Name) for MCDS_TCX_ACT15.
* To use register names with standard convension, please use MCDS_TCX_ACT15.
*/
#define	MCDS_TCXACT15	(MCDS_TCX_ACT15)

/** \\brief  28C0, Action Definition Register */
#define MCDS_TCX_ACT16 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8C0u)

/** Alias (User Manual Name) for MCDS_TCX_ACT16.
* To use register names with standard convension, please use MCDS_TCX_ACT16.
*/
#define	MCDS_TCXACT16	(MCDS_TCX_ACT16)

/** \\brief  28C4, Action Definition Register */
#define MCDS_TCX_ACT17 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8C4u)

/** Alias (User Manual Name) for MCDS_TCX_ACT17.
* To use register names with standard convension, please use MCDS_TCX_ACT17.
*/
#define	MCDS_TCXACT17	(MCDS_TCX_ACT17)

/** \\brief  28C8, Action Definition Register */
#define MCDS_TCX_ACT18 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8C8u)

/** Alias (User Manual Name) for MCDS_TCX_ACT18.
* To use register names with standard convension, please use MCDS_TCX_ACT18.
*/
#define	MCDS_TCXACT18	(MCDS_TCX_ACT18)

/** \\brief  28CC, Action Definition Register */
#define MCDS_TCX_ACT19 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8CCu)

/** Alias (User Manual Name) for MCDS_TCX_ACT19.
* To use register names with standard convension, please use MCDS_TCX_ACT19.
*/
#define	MCDS_TCXACT19	(MCDS_TCX_ACT19)

/** \\brief  2888, Action Definition Register */
#define MCDS_TCX_ACT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA888u)

/** Alias (User Manual Name) for MCDS_TCX_ACT2.
* To use register names with standard convension, please use MCDS_TCX_ACT2.
*/
#define	MCDS_TCXACT2	(MCDS_TCX_ACT2)

/** \\brief  28D0, Action Definition Register */
#define MCDS_TCX_ACT20 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8D0u)

/** Alias (User Manual Name) for MCDS_TCX_ACT20.
* To use register names with standard convension, please use MCDS_TCX_ACT20.
*/
#define	MCDS_TCXACT20	(MCDS_TCX_ACT20)

/** \\brief  28D4, Action Definition Register */
#define MCDS_TCX_ACT21 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8D4u)

/** Alias (User Manual Name) for MCDS_TCX_ACT21.
* To use register names with standard convension, please use MCDS_TCX_ACT21.
*/
#define	MCDS_TCXACT21	(MCDS_TCX_ACT21)

/** \\brief  28D8, Action Definition Register */
#define MCDS_TCX_ACT22 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8D8u)

/** Alias (User Manual Name) for MCDS_TCX_ACT22.
* To use register names with standard convension, please use MCDS_TCX_ACT22.
*/
#define	MCDS_TCXACT22	(MCDS_TCX_ACT22)

/** \\brief  288C, Action Definition Register */
#define MCDS_TCX_ACT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA88Cu)

/** Alias (User Manual Name) for MCDS_TCX_ACT3.
* To use register names with standard convension, please use MCDS_TCX_ACT3.
*/
#define	MCDS_TCXACT3	(MCDS_TCX_ACT3)

/** \\brief  2890, Action Definition Register */
#define MCDS_TCX_ACT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA890u)

/** Alias (User Manual Name) for MCDS_TCX_ACT4.
* To use register names with standard convension, please use MCDS_TCX_ACT4.
*/
#define	MCDS_TCXACT4	(MCDS_TCX_ACT4)

/** \\brief  2894, Action Definition Register */
#define MCDS_TCX_ACT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA894u)

/** Alias (User Manual Name) for MCDS_TCX_ACT5.
* To use register names with standard convension, please use MCDS_TCX_ACT5.
*/
#define	MCDS_TCXACT5	(MCDS_TCX_ACT5)

/** \\brief  2898, Action Definition Register */
#define MCDS_TCX_ACT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA898u)

/** Alias (User Manual Name) for MCDS_TCX_ACT6.
* To use register names with standard convension, please use MCDS_TCX_ACT6.
*/
#define	MCDS_TCXACT6	(MCDS_TCX_ACT6)

/** \\brief  289C, Action Definition Register */
#define MCDS_TCX_ACT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA89Cu)

/** Alias (User Manual Name) for MCDS_TCX_ACT7.
* To use register names with standard convension, please use MCDS_TCX_ACT7.
*/
#define	MCDS_TCXACT7	(MCDS_TCX_ACT7)

/** \\brief  28A0, Action Definition Register */
#define MCDS_TCX_ACT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8A0u)

/** Alias (User Manual Name) for MCDS_TCX_ACT8.
* To use register names with standard convension, please use MCDS_TCX_ACT8.
*/
#define	MCDS_TCXACT8	(MCDS_TCX_ACT8)

/** \\brief  28A4, Action Definition Register */
#define MCDS_TCX_ACT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EA8A4u)

/** Alias (User Manual Name) for MCDS_TCX_ACT9.
* To use register names with standard convension, please use MCDS_TCX_ACT9.
*/
#define	MCDS_TCXACT9	(MCDS_TCX_ACT9)

/** \\brief  200C, Compact Function Trace Register */
#define MCDS_TCX_CFT /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCX_CFT*)0xF90EA00Cu)

/** Alias (User Manual Name) for MCDS_TCX_CFT.
* To use register names with standard convension, please use MCDS_TCX_CFT.
*/
#define	MCDS_TCXCFT	(MCDS_TCX_CFT)

/** \\brief  2004, Current Process ID */
#define MCDS_TCX_CID /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCX_CID*)0xF90EA004u)

/** Alias (User Manual Name) for MCDS_TCX_CID.
* To use register names with standard convension, please use MCDS_TCX_CID.
*/
#define	MCDS_TCXCID	(MCDS_TCX_CID)

/** \\brief  2008, Current Instruction Pointer */
#define MCDS_TCX_CIP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCX_CIP*)0xF90EA008u)

/** Alias (User Manual Name) for MCDS_TCX_CIP.
* To use register names with standard convension, please use MCDS_TCX_CIP.
*/
#define	MCDS_TCXCIP	(MCDS_TCX_CIP)

/** \\brief  2000, Debug Status Register */
#define MCDS_TCX_DCSTS /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCX_DCSTS*)0xF90EA000u)

/** Alias (User Manual Name) for MCDS_TCX_DCSTS.
* To use register names with standard convension, please use MCDS_TCX_DCSTS.
*/
#define	MCDS_TCXDCSTS	(MCDS_TCX_DCSTS)

/** \\brief  2400, Comparator Bound Register */
#define MCDS_TCX_EA0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA400u)

/** Alias (User Manual Name) for MCDS_TCX_EA0_BND.
* To use register names with standard convension, please use MCDS_TCX_EA0_BND.
*/
#define	MCDS_TCXEABND0	(MCDS_TCX_EA0_BND)

/** \\brief  2404, Comparator Range Register */
#define MCDS_TCX_EA0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA404u)

/** Alias (User Manual Name) for MCDS_TCX_EA0_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA0_RNG.
*/
#define	MCDS_TCXEARNG0	(MCDS_TCX_EA0_RNG)

/** \\brief  2410, Comparator Bound Register */
#define MCDS_TCX_EA1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA410u)

/** Alias (User Manual Name) for MCDS_TCX_EA1_BND.
* To use register names with standard convension, please use MCDS_TCX_EA1_BND.
*/
#define	MCDS_TCXEABND1	(MCDS_TCX_EA1_BND)

/** \\brief  2414, Comparator Range Register */
#define MCDS_TCX_EA1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA414u)

/** Alias (User Manual Name) for MCDS_TCX_EA1_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA1_RNG.
*/
#define	MCDS_TCXEARNG1	(MCDS_TCX_EA1_RNG)

/** \\brief  2420, Comparator Bound Register */
#define MCDS_TCX_EA2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA420u)

/** Alias (User Manual Name) for MCDS_TCX_EA2_BND.
* To use register names with standard convension, please use MCDS_TCX_EA2_BND.
*/
#define	MCDS_TCXEABND2	(MCDS_TCX_EA2_BND)

/** \\brief  2424, Comparator Range Register */
#define MCDS_TCX_EA2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA424u)

/** Alias (User Manual Name) for MCDS_TCX_EA2_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA2_RNG.
*/
#define	MCDS_TCXEARNG2	(MCDS_TCX_EA2_RNG)

/** \\brief  2430, Comparator Bound Register */
#define MCDS_TCX_EA3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA430u)

/** Alias (User Manual Name) for MCDS_TCX_EA3_BND.
* To use register names with standard convension, please use MCDS_TCX_EA3_BND.
*/
#define	MCDS_TCXEABND3	(MCDS_TCX_EA3_BND)

/** \\brief  2434, Comparator Range Register */
#define MCDS_TCX_EA3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA434u)

/** Alias (User Manual Name) for MCDS_TCX_EA3_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA3_RNG.
*/
#define	MCDS_TCXEARNG3	(MCDS_TCX_EA3_RNG)

/** \\brief  2440, Comparator Bound Register */
#define MCDS_TCX_EA4_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA440u)

/** Alias (User Manual Name) for MCDS_TCX_EA4_BND.
* To use register names with standard convension, please use MCDS_TCX_EA4_BND.
*/
#define	MCDS_TCXEABND4	(MCDS_TCX_EA4_BND)

/** \\brief  2444, Comparator Range Register */
#define MCDS_TCX_EA4_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA444u)

/** Alias (User Manual Name) for MCDS_TCX_EA4_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA4_RNG.
*/
#define	MCDS_TCXEARNG4	(MCDS_TCX_EA4_RNG)

/** \\brief  2450, Comparator Bound Register */
#define MCDS_TCX_EA5_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA450u)

/** Alias (User Manual Name) for MCDS_TCX_EA5_BND.
* To use register names with standard convension, please use MCDS_TCX_EA5_BND.
*/
#define	MCDS_TCXEABND5	(MCDS_TCX_EA5_BND)

/** \\brief  2454, Comparator Range Register */
#define MCDS_TCX_EA5_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA454u)

/** Alias (User Manual Name) for MCDS_TCX_EA5_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA5_RNG.
*/
#define	MCDS_TCXEARNG5	(MCDS_TCX_EA5_RNG)

/** \\brief  2460, Comparator Bound Register */
#define MCDS_TCX_EA6_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA460u)

/** Alias (User Manual Name) for MCDS_TCX_EA6_BND.
* To use register names with standard convension, please use MCDS_TCX_EA6_BND.
*/
#define	MCDS_TCXEABND6	(MCDS_TCX_EA6_BND)

/** \\brief  2464, Comparator Range Register */
#define MCDS_TCX_EA6_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA464u)

/** Alias (User Manual Name) for MCDS_TCX_EA6_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA6_RNG.
*/
#define	MCDS_TCXEARNG6	(MCDS_TCX_EA6_RNG)

/** \\brief  2470, Comparator Bound Register */
#define MCDS_TCX_EA7_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_BND*)0xF90EA470u)

/** Alias (User Manual Name) for MCDS_TCX_EA7_BND.
* To use register names with standard convension, please use MCDS_TCX_EA7_BND.
*/
#define	MCDS_TCXEABND7	(MCDS_TCX_EA7_BND)

/** \\brief  2474, Comparator Range Register */
#define MCDS_TCX_EA7_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXEA_RNG*)0xF90EA474u)

/** Alias (User Manual Name) for MCDS_TCX_EA7_RNG.
* To use register names with standard convension, please use MCDS_TCX_EA7_RNG.
*/
#define	MCDS_TCXEARNG7	(MCDS_TCX_EA7_RNG)

/** \\brief  2800, Event Definition Register */
#define MCDS_TCX_EVT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA800u)

/** Alias (User Manual Name) for MCDS_TCX_EVT0.
* To use register names with standard convension, please use MCDS_TCX_EVT0.
*/
#define	MCDS_TCXEVT0	(MCDS_TCX_EVT0)

/** \\brief  2804, Event Definition Register */
#define MCDS_TCX_EVT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA804u)

/** Alias (User Manual Name) for MCDS_TCX_EVT1.
* To use register names with standard convension, please use MCDS_TCX_EVT1.
*/
#define	MCDS_TCXEVT1	(MCDS_TCX_EVT1)

/** \\brief  2828, Event Definition Register */
#define MCDS_TCX_EVT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA828u)

/** Alias (User Manual Name) for MCDS_TCX_EVT10.
* To use register names with standard convension, please use MCDS_TCX_EVT10.
*/
#define	MCDS_TCXEVT10	(MCDS_TCX_EVT10)

/** \\brief  282C, Event Definition Register */
#define MCDS_TCX_EVT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA82Cu)

/** Alias (User Manual Name) for MCDS_TCX_EVT11.
* To use register names with standard convension, please use MCDS_TCX_EVT11.
*/
#define	MCDS_TCXEVT11	(MCDS_TCX_EVT11)

/** \\brief  2830, Event Definition Register */
#define MCDS_TCX_EVT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA830u)

/** Alias (User Manual Name) for MCDS_TCX_EVT12.
* To use register names with standard convension, please use MCDS_TCX_EVT12.
*/
#define	MCDS_TCXEVT12	(MCDS_TCX_EVT12)

/** \\brief  2834, Event Definition Register */
#define MCDS_TCX_EVT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA834u)

/** Alias (User Manual Name) for MCDS_TCX_EVT13.
* To use register names with standard convension, please use MCDS_TCX_EVT13.
*/
#define	MCDS_TCXEVT13	(MCDS_TCX_EVT13)

/** \\brief  2838, Event Definition Register */
#define MCDS_TCX_EVT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA838u)

/** Alias (User Manual Name) for MCDS_TCX_EVT14.
* To use register names with standard convension, please use MCDS_TCX_EVT14.
*/
#define	MCDS_TCXEVT14	(MCDS_TCX_EVT14)

/** \\brief  283C, Event Definition Register */
#define MCDS_TCX_EVT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA83Cu)

/** Alias (User Manual Name) for MCDS_TCX_EVT15.
* To use register names with standard convension, please use MCDS_TCX_EVT15.
*/
#define	MCDS_TCXEVT15	(MCDS_TCX_EVT15)

/** \\brief  2808, Event Definition Register */
#define MCDS_TCX_EVT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA808u)

/** Alias (User Manual Name) for MCDS_TCX_EVT2.
* To use register names with standard convension, please use MCDS_TCX_EVT2.
*/
#define	MCDS_TCXEVT2	(MCDS_TCX_EVT2)

/** \\brief  280C, Event Definition Register */
#define MCDS_TCX_EVT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA80Cu)

/** Alias (User Manual Name) for MCDS_TCX_EVT3.
* To use register names with standard convension, please use MCDS_TCX_EVT3.
*/
#define	MCDS_TCXEVT3	(MCDS_TCX_EVT3)

/** \\brief  2810, Event Definition Register */
#define MCDS_TCX_EVT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA810u)

/** Alias (User Manual Name) for MCDS_TCX_EVT4.
* To use register names with standard convension, please use MCDS_TCX_EVT4.
*/
#define	MCDS_TCXEVT4	(MCDS_TCX_EVT4)

/** \\brief  2814, Event Definition Register */
#define MCDS_TCX_EVT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA814u)

/** Alias (User Manual Name) for MCDS_TCX_EVT5.
* To use register names with standard convension, please use MCDS_TCX_EVT5.
*/
#define	MCDS_TCXEVT5	(MCDS_TCX_EVT5)

/** \\brief  2818, Event Definition Register */
#define MCDS_TCX_EVT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA818u)

/** Alias (User Manual Name) for MCDS_TCX_EVT6.
* To use register names with standard convension, please use MCDS_TCX_EVT6.
*/
#define	MCDS_TCXEVT6	(MCDS_TCX_EVT6)

/** \\brief  281C, Event Definition Register */
#define MCDS_TCX_EVT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA81Cu)

/** Alias (User Manual Name) for MCDS_TCX_EVT7.
* To use register names with standard convension, please use MCDS_TCX_EVT7.
*/
#define	MCDS_TCXEVT7	(MCDS_TCX_EVT7)

/** \\brief  2820, Event Definition Register */
#define MCDS_TCX_EVT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA820u)

/** Alias (User Manual Name) for MCDS_TCX_EVT8.
* To use register names with standard convension, please use MCDS_TCX_EVT8.
*/
#define	MCDS_TCXEVT8	(MCDS_TCX_EVT8)

/** \\brief  2824, Event Definition Register */
#define MCDS_TCX_EVT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EA824u)

/** Alias (User Manual Name) for MCDS_TCX_EVT9.
* To use register names with standard convension, please use MCDS_TCX_EVT9.
*/
#define	MCDS_TCXEVT9	(MCDS_TCX_EVT9)

/** \\brief  2C00, Comparator Bound Register */
#define MCDS_TCX_ID0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_BND*)0xF90EAC00u)

/** Alias (User Manual Name) for MCDS_TCX_ID0_BND.
* To use register names with standard convension, please use MCDS_TCX_ID0_BND.
*/
#define	MCDS_TCXIDBND0	(MCDS_TCX_ID0_BND)

/** \\brief  2C08, Comparator Mask Register */
#define MCDS_TCX_ID0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_MSK*)0xF90EAC08u)

/** Alias (User Manual Name) for MCDS_TCX_ID0_MSK.
* To use register names with standard convension, please use MCDS_TCX_ID0_MSK.
*/
#define	MCDS_TCXIDMSK0	(MCDS_TCX_ID0_MSK)

/** \\brief  2C04, Comparator Range Register */
#define MCDS_TCX_ID0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_RNG*)0xF90EAC04u)

/** Alias (User Manual Name) for MCDS_TCX_ID0_RNG.
* To use register names with standard convension, please use MCDS_TCX_ID0_RNG.
*/
#define	MCDS_TCXIDRNG0	(MCDS_TCX_ID0_RNG)

/** \\brief  2C0C, Comparator Sign Register */
#define MCDS_TCX_ID0_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_SGN*)0xF90EAC0Cu)

/** Alias (User Manual Name) for MCDS_TCX_ID0_SGN.
* To use register names with standard convension, please use MCDS_TCX_ID0_SGN.
*/
#define	MCDS_TCXIDSGN0	(MCDS_TCX_ID0_SGN)

/** \\brief  2C10, Comparator Bound Register */
#define MCDS_TCX_ID1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_BND*)0xF90EAC10u)

/** Alias (User Manual Name) for MCDS_TCX_ID1_BND.
* To use register names with standard convension, please use MCDS_TCX_ID1_BND.
*/
#define	MCDS_TCXIDBND1	(MCDS_TCX_ID1_BND)

/** \\brief  2C18, Comparator Mask Register */
#define MCDS_TCX_ID1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_MSK*)0xF90EAC18u)

/** Alias (User Manual Name) for MCDS_TCX_ID1_MSK.
* To use register names with standard convension, please use MCDS_TCX_ID1_MSK.
*/
#define	MCDS_TCXIDMSK1	(MCDS_TCX_ID1_MSK)

/** \\brief  2C14, Comparator Range Register */
#define MCDS_TCX_ID1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_RNG*)0xF90EAC14u)

/** Alias (User Manual Name) for MCDS_TCX_ID1_RNG.
* To use register names with standard convension, please use MCDS_TCX_ID1_RNG.
*/
#define	MCDS_TCXIDRNG1	(MCDS_TCX_ID1_RNG)

/** \\brief  2C1C, Comparator Sign Register */
#define MCDS_TCX_ID1_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXID_SGN*)0xF90EAC1Cu)

/** Alias (User Manual Name) for MCDS_TCX_ID1_SGN.
* To use register names with standard convension, please use MCDS_TCX_ID1_SGN.
*/
#define	MCDS_TCXIDSGN1	(MCDS_TCX_ID1_SGN)

/** \\brief  3000, Comparator Bound Register */
#define MCDS_TCX_IP0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_BND*)0xF90EB000u)

/** Alias (User Manual Name) for MCDS_TCX_IP0_BND.
* To use register names with standard convension, please use MCDS_TCX_IP0_BND.
*/
#define	MCDS_TCXIPBND0	(MCDS_TCX_IP0_BND)

/** \\brief  3004, Comparator Range Register */
#define MCDS_TCX_IP0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_RNG*)0xF90EB004u)

/** Alias (User Manual Name) for MCDS_TCX_IP0_RNG.
* To use register names with standard convension, please use MCDS_TCX_IP0_RNG.
*/
#define	MCDS_TCXIPRNG0	(MCDS_TCX_IP0_RNG)

/** \\brief  3010, Comparator Bound Register */
#define MCDS_TCX_IP1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_BND*)0xF90EB010u)

/** Alias (User Manual Name) for MCDS_TCX_IP1_BND.
* To use register names with standard convension, please use MCDS_TCX_IP1_BND.
*/
#define	MCDS_TCXIPBND1	(MCDS_TCX_IP1_BND)

/** \\brief  3014, Comparator Range Register */
#define MCDS_TCX_IP1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_RNG*)0xF90EB014u)

/** Alias (User Manual Name) for MCDS_TCX_IP1_RNG.
* To use register names with standard convension, please use MCDS_TCX_IP1_RNG.
*/
#define	MCDS_TCXIPRNG1	(MCDS_TCX_IP1_RNG)

/** \\brief  3020, Comparator Bound Register */
#define MCDS_TCX_IP2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_BND*)0xF90EB020u)

/** Alias (User Manual Name) for MCDS_TCX_IP2_BND.
* To use register names with standard convension, please use MCDS_TCX_IP2_BND.
*/
#define	MCDS_TCXIPBND2	(MCDS_TCX_IP2_BND)

/** \\brief  3024, Comparator Range Register */
#define MCDS_TCX_IP2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_RNG*)0xF90EB024u)

/** Alias (User Manual Name) for MCDS_TCX_IP2_RNG.
* To use register names with standard convension, please use MCDS_TCX_IP2_RNG.
*/
#define	MCDS_TCXIPRNG2	(MCDS_TCX_IP2_RNG)

/** \\brief  3030, Comparator Bound Register */
#define MCDS_TCX_IP3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_BND*)0xF90EB030u)

/** Alias (User Manual Name) for MCDS_TCX_IP3_BND.
* To use register names with standard convension, please use MCDS_TCX_IP3_BND.
*/
#define	MCDS_TCXIPBND3	(MCDS_TCX_IP3_BND)

/** \\brief  3034, Comparator Range Register */
#define MCDS_TCX_IP3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_RNG*)0xF90EB034u)

/** Alias (User Manual Name) for MCDS_TCX_IP3_RNG.
* To use register names with standard convension, please use MCDS_TCX_IP3_RNG.
*/
#define	MCDS_TCXIPRNG3	(MCDS_TCX_IP3_RNG)

/** \\brief  3040, Comparator Bound Register */
#define MCDS_TCX_IP4_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_BND*)0xF90EB040u)

/** Alias (User Manual Name) for MCDS_TCX_IP4_BND.
* To use register names with standard convension, please use MCDS_TCX_IP4_BND.
*/
#define	MCDS_TCXIPBND4	(MCDS_TCX_IP4_BND)

/** \\brief  3044, Comparator Range Register */
#define MCDS_TCX_IP4_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_RNG*)0xF90EB044u)

/** Alias (User Manual Name) for MCDS_TCX_IP4_RNG.
* To use register names with standard convension, please use MCDS_TCX_IP4_RNG.
*/
#define	MCDS_TCXIPRNG4	(MCDS_TCX_IP4_RNG)

/** \\brief  3050, Comparator Bound Register */
#define MCDS_TCX_IP5_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_BND*)0xF90EB050u)

/** Alias (User Manual Name) for MCDS_TCX_IP5_BND.
* To use register names with standard convension, please use MCDS_TCX_IP5_BND.
*/
#define	MCDS_TCXIPBND5	(MCDS_TCX_IP5_BND)

/** \\brief  3054, Comparator Range Register */
#define MCDS_TCX_IP5_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXIP_RNG*)0xF90EB054u)

/** Alias (User Manual Name) for MCDS_TCX_IP5_RNG.
* To use register names with standard convension, please use MCDS_TCX_IP5_RNG.
*/
#define	MCDS_TCXIPRNG5	(MCDS_TCX_IP5_RNG)

/** \\brief  2210, Lookup Table Base Register */
#define MCDS_TCX_PAL0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_BND*)0xF90EA210u)

/** Alias (User Manual Name) for MCDS_TCX_PAL0_BND.
* To use register names with standard convension, please use MCDS_TCX_PAL0_BND.
*/
#define	MCDS_TCXPALBND0	(MCDS_TCX_PAL0_BND)

/** \\brief  2218, Lookup Table Range Register */
#define MCDS_TCX_PAL0_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_MAP*)0xF90EA218u)

/** Alias (User Manual Name) for MCDS_TCX_PAL0_MAP.
* To use register names with standard convension, please use MCDS_TCX_PAL0_MAP.
*/
#define	MCDS_TCXPALMAP0	(MCDS_TCX_PAL0_MAP)

/** \\brief  2214, Lookup Table Range Register */
#define MCDS_TCX_PAL0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_RNG*)0xF90EA214u)

/** Alias (User Manual Name) for MCDS_TCX_PAL0_RNG.
* To use register names with standard convension, please use MCDS_TCX_PAL0_RNG.
*/
#define	MCDS_TCXPALRNG0	(MCDS_TCX_PAL0_RNG)

/** \\brief  2220, Lookup Table Base Register */
#define MCDS_TCX_PAL1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_BND*)0xF90EA220u)

/** Alias (User Manual Name) for MCDS_TCX_PAL1_BND.
* To use register names with standard convension, please use MCDS_TCX_PAL1_BND.
*/
#define	MCDS_TCXPALBND1	(MCDS_TCX_PAL1_BND)

/** \\brief  2228, Lookup Table Range Register */
#define MCDS_TCX_PAL1_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_MAP*)0xF90EA228u)

/** Alias (User Manual Name) for MCDS_TCX_PAL1_MAP.
* To use register names with standard convension, please use MCDS_TCX_PAL1_MAP.
*/
#define	MCDS_TCXPALMAP1	(MCDS_TCX_PAL1_MAP)

/** \\brief  2224, Lookup Table Range Register */
#define MCDS_TCX_PAL1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_RNG*)0xF90EA224u)

/** Alias (User Manual Name) for MCDS_TCX_PAL1_RNG.
* To use register names with standard convension, please use MCDS_TCX_PAL1_RNG.
*/
#define	MCDS_TCXPALRNG1	(MCDS_TCX_PAL1_RNG)

/** \\brief  2230, Lookup Table Base Register */
#define MCDS_TCX_PAL2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_BND*)0xF90EA230u)

/** Alias (User Manual Name) for MCDS_TCX_PAL2_BND.
* To use register names with standard convension, please use MCDS_TCX_PAL2_BND.
*/
#define	MCDS_TCXPALBND2	(MCDS_TCX_PAL2_BND)

/** \\brief  2238, Lookup Table Range Register */
#define MCDS_TCX_PAL2_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_MAP*)0xF90EA238u)

/** Alias (User Manual Name) for MCDS_TCX_PAL2_MAP.
* To use register names with standard convension, please use MCDS_TCX_PAL2_MAP.
*/
#define	MCDS_TCXPALMAP2	(MCDS_TCX_PAL2_MAP)

/** \\brief  2234, Lookup Table Range Register */
#define MCDS_TCX_PAL2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_RNG*)0xF90EA234u)

/** Alias (User Manual Name) for MCDS_TCX_PAL2_RNG.
* To use register names with standard convension, please use MCDS_TCX_PAL2_RNG.
*/
#define	MCDS_TCXPALRNG2	(MCDS_TCX_PAL2_RNG)

/** \\brief  2240, Lookup Table Base Register */
#define MCDS_TCX_PAL3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_BND*)0xF90EA240u)

/** Alias (User Manual Name) for MCDS_TCX_PAL3_BND.
* To use register names with standard convension, please use MCDS_TCX_PAL3_BND.
*/
#define	MCDS_TCXPALBND3	(MCDS_TCX_PAL3_BND)

/** \\brief  2248, Lookup Table Range Register */
#define MCDS_TCX_PAL3_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_MAP*)0xF90EA248u)

/** Alias (User Manual Name) for MCDS_TCX_PAL3_MAP.
* To use register names with standard convension, please use MCDS_TCX_PAL3_MAP.
*/
#define	MCDS_TCXPALMAP3	(MCDS_TCX_PAL3_MAP)

/** \\brief  2244, Lookup Table Range Register */
#define MCDS_TCX_PAL3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXPAL_RNG*)0xF90EA244u)

/** Alias (User Manual Name) for MCDS_TCX_PAL3_RNG.
* To use register names with standard convension, please use MCDS_TCX_PAL3_RNG.
*/
#define	MCDS_TCXPALRNG3	(MCDS_TCX_PAL3_RNG)

/** \\brief  2204, Lookup Table Address Register */
#define MCDS_TCX_PALLU_TA /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TA*)0xF90EA204u)

/** Alias (User Manual Name) for MCDS_TCX_PALLU_TA.
* To use register names with standard convension, please use MCDS_TCX_PALLU_TA.
*/
#define	MCDS_TCXPALLUTA	(MCDS_TCX_PALLU_TA)

/** \\brief  2200, Lookup Table Data Register */
#define MCDS_TCX_PALLU_TD /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TD*)0xF90EA200u)

/** Alias (User Manual Name) for MCDS_TCX_PALLU_TD.
* To use register names with standard convension, please use MCDS_TCX_PALLU_TD.
*/
#define	MCDS_TCXPALLUTD	(MCDS_TCX_PALLU_TD)

/** \\brief  2480, Comparator Bound Register */
#define MCDS_TCX_WD0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_BND*)0xF90EA480u)

/** Alias (User Manual Name) for MCDS_TCX_WD0_BND.
* To use register names with standard convension, please use MCDS_TCX_WD0_BND.
*/
#define	MCDS_TCXWDBND0	(MCDS_TCX_WD0_BND)

/** \\brief  2484, Comparator Bound Register */
#define MCDS_TCX_WD0_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HBND*)0xF90EA484u)

/** Alias (User Manual Name) for MCDS_TCX_WD0_HBND.
* To use register names with standard convension, please use MCDS_TCX_WD0_HBND.
*/
#define	MCDS_TCXWDHBND0	(MCDS_TCX_WD0_HBND)

/** \\brief  2494, Comparator Mask Register */
#define MCDS_TCX_WD0_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HMSK*)0xF90EA494u)

/** Alias (User Manual Name) for MCDS_TCX_WD0_HMSK.
* To use register names with standard convension, please use MCDS_TCX_WD0_HMSK.
*/
#define	MCDS_TCXWDHMSK0	(MCDS_TCX_WD0_HMSK)

/** \\brief  248C, Comparator Range Register */
#define MCDS_TCX_WD0_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HRNG*)0xF90EA48Cu)

/** Alias (User Manual Name) for MCDS_TCX_WD0_HRNG.
* To use register names with standard convension, please use MCDS_TCX_WD0_HRNG.
*/
#define	MCDS_TCXWDHRNG0	(MCDS_TCX_WD0_HRNG)

/** \\brief  2490, Comparator Mask Register */
#define MCDS_TCX_WD0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_MSK*)0xF90EA490u)

/** Alias (User Manual Name) for MCDS_TCX_WD0_MSK.
* To use register names with standard convension, please use MCDS_TCX_WD0_MSK.
*/
#define	MCDS_TCXWDMSK0	(MCDS_TCX_WD0_MSK)

/** \\brief  2488, Comparator Range Register */
#define MCDS_TCX_WD0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_RNG*)0xF90EA488u)

/** Alias (User Manual Name) for MCDS_TCX_WD0_RNG.
* To use register names with standard convension, please use MCDS_TCX_WD0_RNG.
*/
#define	MCDS_TCXWDRNG0	(MCDS_TCX_WD0_RNG)

/** \\brief  249C, Comparator Sign Register */
#define MCDS_TCX_WD0_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_SGN*)0xF90EA49Cu)

/** Alias (User Manual Name) for MCDS_TCX_WD0_SGN.
* To use register names with standard convension, please use MCDS_TCX_WD0_SGN.
*/
#define	MCDS_TCXWDSGN0	(MCDS_TCX_WD0_SGN)

/** \\brief  24A0, Comparator Bound Register */
#define MCDS_TCX_WD1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_BND*)0xF90EA4A0u)

/** Alias (User Manual Name) for MCDS_TCX_WD1_BND.
* To use register names with standard convension, please use MCDS_TCX_WD1_BND.
*/
#define	MCDS_TCXWDBND1	(MCDS_TCX_WD1_BND)

/** \\brief  24A4, Comparator Bound Register */
#define MCDS_TCX_WD1_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HBND*)0xF90EA4A4u)

/** Alias (User Manual Name) for MCDS_TCX_WD1_HBND.
* To use register names with standard convension, please use MCDS_TCX_WD1_HBND.
*/
#define	MCDS_TCXWDHBND1	(MCDS_TCX_WD1_HBND)

/** \\brief  24B4, Comparator Mask Register */
#define MCDS_TCX_WD1_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HMSK*)0xF90EA4B4u)

/** Alias (User Manual Name) for MCDS_TCX_WD1_HMSK.
* To use register names with standard convension, please use MCDS_TCX_WD1_HMSK.
*/
#define	MCDS_TCXWDHMSK1	(MCDS_TCX_WD1_HMSK)

/** \\brief  24AC, Comparator Range Register */
#define MCDS_TCX_WD1_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HRNG*)0xF90EA4ACu)

/** Alias (User Manual Name) for MCDS_TCX_WD1_HRNG.
* To use register names with standard convension, please use MCDS_TCX_WD1_HRNG.
*/
#define	MCDS_TCXWDHRNG1	(MCDS_TCX_WD1_HRNG)

/** \\brief  24B0, Comparator Mask Register */
#define MCDS_TCX_WD1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_MSK*)0xF90EA4B0u)

/** Alias (User Manual Name) for MCDS_TCX_WD1_MSK.
* To use register names with standard convension, please use MCDS_TCX_WD1_MSK.
*/
#define	MCDS_TCXWDMSK1	(MCDS_TCX_WD1_MSK)

/** \\brief  24A8, Comparator Range Register */
#define MCDS_TCX_WD1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_RNG*)0xF90EA4A8u)

/** Alias (User Manual Name) for MCDS_TCX_WD1_RNG.
* To use register names with standard convension, please use MCDS_TCX_WD1_RNG.
*/
#define	MCDS_TCXWDRNG1	(MCDS_TCX_WD1_RNG)

/** \\brief  24BC, Comparator Sign Register */
#define MCDS_TCX_WD1_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_SGN*)0xF90EA4BCu)

/** Alias (User Manual Name) for MCDS_TCX_WD1_SGN.
* To use register names with standard convension, please use MCDS_TCX_WD1_SGN.
*/
#define	MCDS_TCXWDSGN1	(MCDS_TCX_WD1_SGN)

/** \\brief  24C0, Comparator Bound Register */
#define MCDS_TCX_WD2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_BND*)0xF90EA4C0u)

/** Alias (User Manual Name) for MCDS_TCX_WD2_BND.
* To use register names with standard convension, please use MCDS_TCX_WD2_BND.
*/
#define	MCDS_TCXWDBND2	(MCDS_TCX_WD2_BND)

/** \\brief  24C4, Comparator Bound Register */
#define MCDS_TCX_WD2_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HBND*)0xF90EA4C4u)

/** Alias (User Manual Name) for MCDS_TCX_WD2_HBND.
* To use register names with standard convension, please use MCDS_TCX_WD2_HBND.
*/
#define	MCDS_TCXWDHBND2	(MCDS_TCX_WD2_HBND)

/** \\brief  24D4, Comparator Mask Register */
#define MCDS_TCX_WD2_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HMSK*)0xF90EA4D4u)

/** Alias (User Manual Name) for MCDS_TCX_WD2_HMSK.
* To use register names with standard convension, please use MCDS_TCX_WD2_HMSK.
*/
#define	MCDS_TCXWDHMSK2	(MCDS_TCX_WD2_HMSK)

/** \\brief  24CC, Comparator Range Register */
#define MCDS_TCX_WD2_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HRNG*)0xF90EA4CCu)

/** Alias (User Manual Name) for MCDS_TCX_WD2_HRNG.
* To use register names with standard convension, please use MCDS_TCX_WD2_HRNG.
*/
#define	MCDS_TCXWDHRNG2	(MCDS_TCX_WD2_HRNG)

/** \\brief  24D0, Comparator Mask Register */
#define MCDS_TCX_WD2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_MSK*)0xF90EA4D0u)

/** Alias (User Manual Name) for MCDS_TCX_WD2_MSK.
* To use register names with standard convension, please use MCDS_TCX_WD2_MSK.
*/
#define	MCDS_TCXWDMSK2	(MCDS_TCX_WD2_MSK)

/** \\brief  24C8, Comparator Range Register */
#define MCDS_TCX_WD2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_RNG*)0xF90EA4C8u)

/** Alias (User Manual Name) for MCDS_TCX_WD2_RNG.
* To use register names with standard convension, please use MCDS_TCX_WD2_RNG.
*/
#define	MCDS_TCXWDRNG2	(MCDS_TCX_WD2_RNG)

/** \\brief  24DC, Comparator Sign Register */
#define MCDS_TCX_WD2_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_SGN*)0xF90EA4DCu)

/** Alias (User Manual Name) for MCDS_TCX_WD2_SGN.
* To use register names with standard convension, please use MCDS_TCX_WD2_SGN.
*/
#define	MCDS_TCXWDSGN2	(MCDS_TCX_WD2_SGN)

/** \\brief  24E0, Comparator Bound Register */
#define MCDS_TCX_WD3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_BND*)0xF90EA4E0u)

/** Alias (User Manual Name) for MCDS_TCX_WD3_BND.
* To use register names with standard convension, please use MCDS_TCX_WD3_BND.
*/
#define	MCDS_TCXWDBND3	(MCDS_TCX_WD3_BND)

/** \\brief  24E4, Comparator Bound Register */
#define MCDS_TCX_WD3_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HBND*)0xF90EA4E4u)

/** Alias (User Manual Name) for MCDS_TCX_WD3_HBND.
* To use register names with standard convension, please use MCDS_TCX_WD3_HBND.
*/
#define	MCDS_TCXWDHBND3	(MCDS_TCX_WD3_HBND)

/** \\brief  24F4, Comparator Mask Register */
#define MCDS_TCX_WD3_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HMSK*)0xF90EA4F4u)

/** Alias (User Manual Name) for MCDS_TCX_WD3_HMSK.
* To use register names with standard convension, please use MCDS_TCX_WD3_HMSK.
*/
#define	MCDS_TCXWDHMSK3	(MCDS_TCX_WD3_HMSK)

/** \\brief  24EC, Comparator Range Register */
#define MCDS_TCX_WD3_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_HRNG*)0xF90EA4ECu)

/** Alias (User Manual Name) for MCDS_TCX_WD3_HRNG.
* To use register names with standard convension, please use MCDS_TCX_WD3_HRNG.
*/
#define	MCDS_TCXWDHRNG3	(MCDS_TCX_WD3_HRNG)

/** \\brief  24F0, Comparator Mask Register */
#define MCDS_TCX_WD3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_MSK*)0xF90EA4F0u)

/** Alias (User Manual Name) for MCDS_TCX_WD3_MSK.
* To use register names with standard convension, please use MCDS_TCX_WD3_MSK.
*/
#define	MCDS_TCXWDMSK3	(MCDS_TCX_WD3_MSK)

/** \\brief  24E8, Comparator Range Register */
#define MCDS_TCX_WD3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_RNG*)0xF90EA4E8u)

/** Alias (User Manual Name) for MCDS_TCX_WD3_RNG.
* To use register names with standard convension, please use MCDS_TCX_WD3_RNG.
*/
#define	MCDS_TCXWDRNG3	(MCDS_TCX_WD3_RNG)

/** \\brief  24FC, Comparator Sign Register */
#define MCDS_TCX_WD3_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCXWD_SGN*)0xF90EA4FCu)

/** Alias (User Manual Name) for MCDS_TCX_WD3_SGN.
* To use register names with standard convension, please use MCDS_TCX_WD3_SGN.
*/
#define	MCDS_TCXWDSGN3	(MCDS_TCX_WD3_SGN)

/** \\brief  4880, Action Definition Register */
#define MCDS_TCY_ACT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC880u)

/** Alias (User Manual Name) for MCDS_TCY_ACT0.
* To use register names with standard convension, please use MCDS_TCY_ACT0.
*/
#define	MCDS_TCYACT0	(MCDS_TCY_ACT0)

/** \\brief  4884, Action Definition Register */
#define MCDS_TCY_ACT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC884u)

/** Alias (User Manual Name) for MCDS_TCY_ACT1.
* To use register names with standard convension, please use MCDS_TCY_ACT1.
*/
#define	MCDS_TCYACT1	(MCDS_TCY_ACT1)

/** \\brief  48A8, Action Definition Register */
#define MCDS_TCY_ACT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8A8u)

/** Alias (User Manual Name) for MCDS_TCY_ACT10.
* To use register names with standard convension, please use MCDS_TCY_ACT10.
*/
#define	MCDS_TCYACT10	(MCDS_TCY_ACT10)

/** \\brief  48AC, Action Definition Register */
#define MCDS_TCY_ACT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8ACu)

/** Alias (User Manual Name) for MCDS_TCY_ACT11.
* To use register names with standard convension, please use MCDS_TCY_ACT11.
*/
#define	MCDS_TCYACT11	(MCDS_TCY_ACT11)

/** \\brief  48B0, Action Definition Register */
#define MCDS_TCY_ACT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8B0u)

/** Alias (User Manual Name) for MCDS_TCY_ACT12.
* To use register names with standard convension, please use MCDS_TCY_ACT12.
*/
#define	MCDS_TCYACT12	(MCDS_TCY_ACT12)

/** \\brief  48B4, Action Definition Register */
#define MCDS_TCY_ACT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8B4u)

/** Alias (User Manual Name) for MCDS_TCY_ACT13.
* To use register names with standard convension, please use MCDS_TCY_ACT13.
*/
#define	MCDS_TCYACT13	(MCDS_TCY_ACT13)

/** \\brief  48B8, Action Definition Register */
#define MCDS_TCY_ACT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8B8u)

/** Alias (User Manual Name) for MCDS_TCY_ACT14.
* To use register names with standard convension, please use MCDS_TCY_ACT14.
*/
#define	MCDS_TCYACT14	(MCDS_TCY_ACT14)

/** \\brief  48BC, Action Definition Register */
#define MCDS_TCY_ACT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8BCu)

/** Alias (User Manual Name) for MCDS_TCY_ACT15.
* To use register names with standard convension, please use MCDS_TCY_ACT15.
*/
#define	MCDS_TCYACT15	(MCDS_TCY_ACT15)

/** \\brief  48C0, Action Definition Register */
#define MCDS_TCY_ACT16 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8C0u)

/** Alias (User Manual Name) for MCDS_TCY_ACT16.
* To use register names with standard convension, please use MCDS_TCY_ACT16.
*/
#define	MCDS_TCYACT16	(MCDS_TCY_ACT16)

/** \\brief  48C4, Action Definition Register */
#define MCDS_TCY_ACT17 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8C4u)

/** Alias (User Manual Name) for MCDS_TCY_ACT17.
* To use register names with standard convension, please use MCDS_TCY_ACT17.
*/
#define	MCDS_TCYACT17	(MCDS_TCY_ACT17)

/** \\brief  48C8, Action Definition Register */
#define MCDS_TCY_ACT18 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8C8u)

/** Alias (User Manual Name) for MCDS_TCY_ACT18.
* To use register names with standard convension, please use MCDS_TCY_ACT18.
*/
#define	MCDS_TCYACT18	(MCDS_TCY_ACT18)

/** \\brief  48CC, Action Definition Register */
#define MCDS_TCY_ACT19 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8CCu)

/** Alias (User Manual Name) for MCDS_TCY_ACT19.
* To use register names with standard convension, please use MCDS_TCY_ACT19.
*/
#define	MCDS_TCYACT19	(MCDS_TCY_ACT19)

/** \\brief  4888, Action Definition Register */
#define MCDS_TCY_ACT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC888u)

/** Alias (User Manual Name) for MCDS_TCY_ACT2.
* To use register names with standard convension, please use MCDS_TCY_ACT2.
*/
#define	MCDS_TCYACT2	(MCDS_TCY_ACT2)

/** \\brief  48D0, Action Definition Register */
#define MCDS_TCY_ACT20 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8D0u)

/** Alias (User Manual Name) for MCDS_TCY_ACT20.
* To use register names with standard convension, please use MCDS_TCY_ACT20.
*/
#define	MCDS_TCYACT20	(MCDS_TCY_ACT20)

/** \\brief  48D4, Action Definition Register */
#define MCDS_TCY_ACT21 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8D4u)

/** Alias (User Manual Name) for MCDS_TCY_ACT21.
* To use register names with standard convension, please use MCDS_TCY_ACT21.
*/
#define	MCDS_TCYACT21	(MCDS_TCY_ACT21)

/** \\brief  48D8, Action Definition Register */
#define MCDS_TCY_ACT22 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8D8u)

/** Alias (User Manual Name) for MCDS_TCY_ACT22.
* To use register names with standard convension, please use MCDS_TCY_ACT22.
*/
#define	MCDS_TCYACT22	(MCDS_TCY_ACT22)

/** \\brief  488C, Action Definition Register */
#define MCDS_TCY_ACT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC88Cu)

/** Alias (User Manual Name) for MCDS_TCY_ACT3.
* To use register names with standard convension, please use MCDS_TCY_ACT3.
*/
#define	MCDS_TCYACT3	(MCDS_TCY_ACT3)

/** \\brief  4890, Action Definition Register */
#define MCDS_TCY_ACT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC890u)

/** Alias (User Manual Name) for MCDS_TCY_ACT4.
* To use register names with standard convension, please use MCDS_TCY_ACT4.
*/
#define	MCDS_TCYACT4	(MCDS_TCY_ACT4)

/** \\brief  4894, Action Definition Register */
#define MCDS_TCY_ACT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC894u)

/** Alias (User Manual Name) for MCDS_TCY_ACT5.
* To use register names with standard convension, please use MCDS_TCY_ACT5.
*/
#define	MCDS_TCYACT5	(MCDS_TCY_ACT5)

/** \\brief  4898, Action Definition Register */
#define MCDS_TCY_ACT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC898u)

/** Alias (User Manual Name) for MCDS_TCY_ACT6.
* To use register names with standard convension, please use MCDS_TCY_ACT6.
*/
#define	MCDS_TCYACT6	(MCDS_TCY_ACT6)

/** \\brief  489C, Action Definition Register */
#define MCDS_TCY_ACT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC89Cu)

/** Alias (User Manual Name) for MCDS_TCY_ACT7.
* To use register names with standard convension, please use MCDS_TCY_ACT7.
*/
#define	MCDS_TCYACT7	(MCDS_TCY_ACT7)

/** \\brief  48A0, Action Definition Register */
#define MCDS_TCY_ACT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8A0u)

/** Alias (User Manual Name) for MCDS_TCY_ACT8.
* To use register names with standard convension, please use MCDS_TCY_ACT8.
*/
#define	MCDS_TCYACT8	(MCDS_TCY_ACT8)

/** \\brief  48A4, Action Definition Register */
#define MCDS_TCY_ACT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_ACT*)0xF90EC8A4u)

/** Alias (User Manual Name) for MCDS_TCY_ACT9.
* To use register names with standard convension, please use MCDS_TCY_ACT9.
*/
#define	MCDS_TCYACT9	(MCDS_TCY_ACT9)

/** \\brief  400C, Compact Function Trace Register */
#define MCDS_TCY_CFT /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCY_CFT*)0xF90EC00Cu)

/** Alias (User Manual Name) for MCDS_TCY_CFT.
* To use register names with standard convension, please use MCDS_TCY_CFT.
*/
#define	MCDS_TCYCFT	(MCDS_TCY_CFT)

/** \\brief  4004, Current Process ID */
#define MCDS_TCY_CID /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCY_CID*)0xF90EC004u)

/** Alias (User Manual Name) for MCDS_TCY_CID.
* To use register names with standard convension, please use MCDS_TCY_CID.
*/
#define	MCDS_TCYCID	(MCDS_TCY_CID)

/** \\brief  4008, Current Instruction Pointer */
#define MCDS_TCY_CIP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCY_CIP*)0xF90EC008u)

/** Alias (User Manual Name) for MCDS_TCY_CIP.
* To use register names with standard convension, please use MCDS_TCY_CIP.
*/
#define	MCDS_TCYCIP	(MCDS_TCY_CIP)

/** \\brief  4000, Debug Status Register */
#define MCDS_TCY_DCSTS /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCY_DCSTS*)0xF90EC000u)

/** Alias (User Manual Name) for MCDS_TCY_DCSTS.
* To use register names with standard convension, please use MCDS_TCY_DCSTS.
*/
#define	MCDS_TCYDCSTS	(MCDS_TCY_DCSTS)

/** \\brief  4400, Comparator Bound Register */
#define MCDS_TCY_EA0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC400u)

/** Alias (User Manual Name) for MCDS_TCY_EA0_BND.
* To use register names with standard convension, please use MCDS_TCY_EA0_BND.
*/
#define	MCDS_TCYEABND0	(MCDS_TCY_EA0_BND)

/** \\brief  4404, Comparator Range Register */
#define MCDS_TCY_EA0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC404u)

/** Alias (User Manual Name) for MCDS_TCY_EA0_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA0_RNG.
*/
#define	MCDS_TCYEARNG0	(MCDS_TCY_EA0_RNG)

/** \\brief  4410, Comparator Bound Register */
#define MCDS_TCY_EA1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC410u)

/** Alias (User Manual Name) for MCDS_TCY_EA1_BND.
* To use register names with standard convension, please use MCDS_TCY_EA1_BND.
*/
#define	MCDS_TCYEABND1	(MCDS_TCY_EA1_BND)

/** \\brief  4414, Comparator Range Register */
#define MCDS_TCY_EA1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC414u)

/** Alias (User Manual Name) for MCDS_TCY_EA1_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA1_RNG.
*/
#define	MCDS_TCYEARNG1	(MCDS_TCY_EA1_RNG)

/** \\brief  4420, Comparator Bound Register */
#define MCDS_TCY_EA2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC420u)

/** Alias (User Manual Name) for MCDS_TCY_EA2_BND.
* To use register names with standard convension, please use MCDS_TCY_EA2_BND.
*/
#define	MCDS_TCYEABND2	(MCDS_TCY_EA2_BND)

/** \\brief  4424, Comparator Range Register */
#define MCDS_TCY_EA2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC424u)

/** Alias (User Manual Name) for MCDS_TCY_EA2_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA2_RNG.
*/
#define	MCDS_TCYEARNG2	(MCDS_TCY_EA2_RNG)

/** \\brief  4430, Comparator Bound Register */
#define MCDS_TCY_EA3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC430u)

/** Alias (User Manual Name) for MCDS_TCY_EA3_BND.
* To use register names with standard convension, please use MCDS_TCY_EA3_BND.
*/
#define	MCDS_TCYEABND3	(MCDS_TCY_EA3_BND)

/** \\brief  4434, Comparator Range Register */
#define MCDS_TCY_EA3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC434u)

/** Alias (User Manual Name) for MCDS_TCY_EA3_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA3_RNG.
*/
#define	MCDS_TCYEARNG3	(MCDS_TCY_EA3_RNG)

/** \\brief  4440, Comparator Bound Register */
#define MCDS_TCY_EA4_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC440u)

/** Alias (User Manual Name) for MCDS_TCY_EA4_BND.
* To use register names with standard convension, please use MCDS_TCY_EA4_BND.
*/
#define	MCDS_TCYEABND4	(MCDS_TCY_EA4_BND)

/** \\brief  4444, Comparator Range Register */
#define MCDS_TCY_EA4_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC444u)

/** Alias (User Manual Name) for MCDS_TCY_EA4_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA4_RNG.
*/
#define	MCDS_TCYEARNG4	(MCDS_TCY_EA4_RNG)

/** \\brief  4450, Comparator Bound Register */
#define MCDS_TCY_EA5_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC450u)

/** Alias (User Manual Name) for MCDS_TCY_EA5_BND.
* To use register names with standard convension, please use MCDS_TCY_EA5_BND.
*/
#define	MCDS_TCYEABND5	(MCDS_TCY_EA5_BND)

/** \\brief  4454, Comparator Range Register */
#define MCDS_TCY_EA5_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC454u)

/** Alias (User Manual Name) for MCDS_TCY_EA5_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA5_RNG.
*/
#define	MCDS_TCYEARNG5	(MCDS_TCY_EA5_RNG)

/** \\brief  4460, Comparator Bound Register */
#define MCDS_TCY_EA6_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC460u)

/** Alias (User Manual Name) for MCDS_TCY_EA6_BND.
* To use register names with standard convension, please use MCDS_TCY_EA6_BND.
*/
#define	MCDS_TCYEABND6	(MCDS_TCY_EA6_BND)

/** \\brief  4464, Comparator Range Register */
#define MCDS_TCY_EA6_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC464u)

/** Alias (User Manual Name) for MCDS_TCY_EA6_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA6_RNG.
*/
#define	MCDS_TCYEARNG6	(MCDS_TCY_EA6_RNG)

/** \\brief  4470, Comparator Bound Register */
#define MCDS_TCY_EA7_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_BND*)0xF90EC470u)

/** Alias (User Manual Name) for MCDS_TCY_EA7_BND.
* To use register names with standard convension, please use MCDS_TCY_EA7_BND.
*/
#define	MCDS_TCYEABND7	(MCDS_TCY_EA7_BND)

/** \\brief  4474, Comparator Range Register */
#define MCDS_TCY_EA7_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYEA_RNG*)0xF90EC474u)

/** Alias (User Manual Name) for MCDS_TCY_EA7_RNG.
* To use register names with standard convension, please use MCDS_TCY_EA7_RNG.
*/
#define	MCDS_TCYEARNG7	(MCDS_TCY_EA7_RNG)

/** \\brief  4800, Event Definition Register */
#define MCDS_TCY_EVT0 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC800u)

/** Alias (User Manual Name) for MCDS_TCY_EVT0.
* To use register names with standard convension, please use MCDS_TCY_EVT0.
*/
#define	MCDS_TCYEVT0	(MCDS_TCY_EVT0)

/** \\brief  4804, Event Definition Register */
#define MCDS_TCY_EVT1 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC804u)

/** Alias (User Manual Name) for MCDS_TCY_EVT1.
* To use register names with standard convension, please use MCDS_TCY_EVT1.
*/
#define	MCDS_TCYEVT1	(MCDS_TCY_EVT1)

/** \\brief  4828, Event Definition Register */
#define MCDS_TCY_EVT10 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC828u)

/** Alias (User Manual Name) for MCDS_TCY_EVT10.
* To use register names with standard convension, please use MCDS_TCY_EVT10.
*/
#define	MCDS_TCYEVT10	(MCDS_TCY_EVT10)

/** \\brief  482C, Event Definition Register */
#define MCDS_TCY_EVT11 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC82Cu)

/** Alias (User Manual Name) for MCDS_TCY_EVT11.
* To use register names with standard convension, please use MCDS_TCY_EVT11.
*/
#define	MCDS_TCYEVT11	(MCDS_TCY_EVT11)

/** \\brief  4830, Event Definition Register */
#define MCDS_TCY_EVT12 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC830u)

/** Alias (User Manual Name) for MCDS_TCY_EVT12.
* To use register names with standard convension, please use MCDS_TCY_EVT12.
*/
#define	MCDS_TCYEVT12	(MCDS_TCY_EVT12)

/** \\brief  4834, Event Definition Register */
#define MCDS_TCY_EVT13 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC834u)

/** Alias (User Manual Name) for MCDS_TCY_EVT13.
* To use register names with standard convension, please use MCDS_TCY_EVT13.
*/
#define	MCDS_TCYEVT13	(MCDS_TCY_EVT13)

/** \\brief  4838, Event Definition Register */
#define MCDS_TCY_EVT14 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC838u)

/** Alias (User Manual Name) for MCDS_TCY_EVT14.
* To use register names with standard convension, please use MCDS_TCY_EVT14.
*/
#define	MCDS_TCYEVT14	(MCDS_TCY_EVT14)

/** \\brief  483C, Event Definition Register */
#define MCDS_TCY_EVT15 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC83Cu)

/** Alias (User Manual Name) for MCDS_TCY_EVT15.
* To use register names with standard convension, please use MCDS_TCY_EVT15.
*/
#define	MCDS_TCYEVT15	(MCDS_TCY_EVT15)

/** \\brief  4808, Event Definition Register */
#define MCDS_TCY_EVT2 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC808u)

/** Alias (User Manual Name) for MCDS_TCY_EVT2.
* To use register names with standard convension, please use MCDS_TCY_EVT2.
*/
#define	MCDS_TCYEVT2	(MCDS_TCY_EVT2)

/** \\brief  480C, Event Definition Register */
#define MCDS_TCY_EVT3 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC80Cu)

/** Alias (User Manual Name) for MCDS_TCY_EVT3.
* To use register names with standard convension, please use MCDS_TCY_EVT3.
*/
#define	MCDS_TCYEVT3	(MCDS_TCY_EVT3)

/** \\brief  4810, Event Definition Register */
#define MCDS_TCY_EVT4 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC810u)

/** Alias (User Manual Name) for MCDS_TCY_EVT4.
* To use register names with standard convension, please use MCDS_TCY_EVT4.
*/
#define	MCDS_TCYEVT4	(MCDS_TCY_EVT4)

/** \\brief  4814, Event Definition Register */
#define MCDS_TCY_EVT5 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC814u)

/** Alias (User Manual Name) for MCDS_TCY_EVT5.
* To use register names with standard convension, please use MCDS_TCY_EVT5.
*/
#define	MCDS_TCYEVT5	(MCDS_TCY_EVT5)

/** \\brief  4818, Event Definition Register */
#define MCDS_TCY_EVT6 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC818u)

/** Alias (User Manual Name) for MCDS_TCY_EVT6.
* To use register names with standard convension, please use MCDS_TCY_EVT6.
*/
#define	MCDS_TCYEVT6	(MCDS_TCY_EVT6)

/** \\brief  481C, Event Definition Register */
#define MCDS_TCY_EVT7 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC81Cu)

/** Alias (User Manual Name) for MCDS_TCY_EVT7.
* To use register names with standard convension, please use MCDS_TCY_EVT7.
*/
#define	MCDS_TCYEVT7	(MCDS_TCY_EVT7)

/** \\brief  4820, Event Definition Register */
#define MCDS_TCY_EVT8 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC820u)

/** Alias (User Manual Name) for MCDS_TCY_EVT8.
* To use register names with standard convension, please use MCDS_TCY_EVT8.
*/
#define	MCDS_TCYEVT8	(MCDS_TCY_EVT8)

/** \\brief  4824, Event Definition Register */
#define MCDS_TCY_EVT9 /* lint --e(923)*/ (*(volatile Ifx_MCDS_EVT*)0xF90EC824u)

/** Alias (User Manual Name) for MCDS_TCY_EVT9.
* To use register names with standard convension, please use MCDS_TCY_EVT9.
*/
#define	MCDS_TCYEVT9	(MCDS_TCY_EVT9)

/** \\brief  4C00, Comparator Bound Register */
#define MCDS_TCY_ID0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_BND*)0xF90ECC00u)

/** Alias (User Manual Name) for MCDS_TCY_ID0_BND.
* To use register names with standard convension, please use MCDS_TCY_ID0_BND.
*/
#define	MCDS_TCYIDBND0	(MCDS_TCY_ID0_BND)

/** \\brief  4C08, Comparator Mask Register */
#define MCDS_TCY_ID0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_MSK*)0xF90ECC08u)

/** Alias (User Manual Name) for MCDS_TCY_ID0_MSK.
* To use register names with standard convension, please use MCDS_TCY_ID0_MSK.
*/
#define	MCDS_TCYIDMSK0	(MCDS_TCY_ID0_MSK)

/** \\brief  4C04, Comparator Range Register */
#define MCDS_TCY_ID0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_RNG*)0xF90ECC04u)

/** Alias (User Manual Name) for MCDS_TCY_ID0_RNG.
* To use register names with standard convension, please use MCDS_TCY_ID0_RNG.
*/
#define	MCDS_TCYIDRNG0	(MCDS_TCY_ID0_RNG)

/** \\brief  4C0C, Comparator Sign Register */
#define MCDS_TCY_ID0_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_SGN*)0xF90ECC0Cu)

/** Alias (User Manual Name) for MCDS_TCY_ID0_SGN.
* To use register names with standard convension, please use MCDS_TCY_ID0_SGN.
*/
#define	MCDS_TCYIDSGN0	(MCDS_TCY_ID0_SGN)

/** \\brief  4C10, Comparator Bound Register */
#define MCDS_TCY_ID1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_BND*)0xF90ECC10u)

/** Alias (User Manual Name) for MCDS_TCY_ID1_BND.
* To use register names with standard convension, please use MCDS_TCY_ID1_BND.
*/
#define	MCDS_TCYIDBND1	(MCDS_TCY_ID1_BND)

/** \\brief  4C18, Comparator Mask Register */
#define MCDS_TCY_ID1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_MSK*)0xF90ECC18u)

/** Alias (User Manual Name) for MCDS_TCY_ID1_MSK.
* To use register names with standard convension, please use MCDS_TCY_ID1_MSK.
*/
#define	MCDS_TCYIDMSK1	(MCDS_TCY_ID1_MSK)

/** \\brief  4C14, Comparator Range Register */
#define MCDS_TCY_ID1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_RNG*)0xF90ECC14u)

/** Alias (User Manual Name) for MCDS_TCY_ID1_RNG.
* To use register names with standard convension, please use MCDS_TCY_ID1_RNG.
*/
#define	MCDS_TCYIDRNG1	(MCDS_TCY_ID1_RNG)

/** \\brief  4C1C, Comparator Sign Register */
#define MCDS_TCY_ID1_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYID_SGN*)0xF90ECC1Cu)

/** Alias (User Manual Name) for MCDS_TCY_ID1_SGN.
* To use register names with standard convension, please use MCDS_TCY_ID1_SGN.
*/
#define	MCDS_TCYIDSGN1	(MCDS_TCY_ID1_SGN)

/** \\brief  5000, Comparator Bound Register */
#define MCDS_TCY_IP0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_BND*)0xF90ED000u)

/** Alias (User Manual Name) for MCDS_TCY_IP0_BND.
* To use register names with standard convension, please use MCDS_TCY_IP0_BND.
*/
#define	MCDS_TCYIPBND0	(MCDS_TCY_IP0_BND)

/** \\brief  5004, Comparator Range Register */
#define MCDS_TCY_IP0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_RNG*)0xF90ED004u)

/** Alias (User Manual Name) for MCDS_TCY_IP0_RNG.
* To use register names with standard convension, please use MCDS_TCY_IP0_RNG.
*/
#define	MCDS_TCYIPRNG0	(MCDS_TCY_IP0_RNG)

/** \\brief  5010, Comparator Bound Register */
#define MCDS_TCY_IP1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_BND*)0xF90ED010u)

/** Alias (User Manual Name) for MCDS_TCY_IP1_BND.
* To use register names with standard convension, please use MCDS_TCY_IP1_BND.
*/
#define	MCDS_TCYIPBND1	(MCDS_TCY_IP1_BND)

/** \\brief  5014, Comparator Range Register */
#define MCDS_TCY_IP1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_RNG*)0xF90ED014u)

/** Alias (User Manual Name) for MCDS_TCY_IP1_RNG.
* To use register names with standard convension, please use MCDS_TCY_IP1_RNG.
*/
#define	MCDS_TCYIPRNG1	(MCDS_TCY_IP1_RNG)

/** \\brief  5020, Comparator Bound Register */
#define MCDS_TCY_IP2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_BND*)0xF90ED020u)

/** Alias (User Manual Name) for MCDS_TCY_IP2_BND.
* To use register names with standard convension, please use MCDS_TCY_IP2_BND.
*/
#define	MCDS_TCYIPBND2	(MCDS_TCY_IP2_BND)

/** \\brief  5024, Comparator Range Register */
#define MCDS_TCY_IP2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_RNG*)0xF90ED024u)

/** Alias (User Manual Name) for MCDS_TCY_IP2_RNG.
* To use register names with standard convension, please use MCDS_TCY_IP2_RNG.
*/
#define	MCDS_TCYIPRNG2	(MCDS_TCY_IP2_RNG)

/** \\brief  5030, Comparator Bound Register */
#define MCDS_TCY_IP3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_BND*)0xF90ED030u)

/** Alias (User Manual Name) for MCDS_TCY_IP3_BND.
* To use register names with standard convension, please use MCDS_TCY_IP3_BND.
*/
#define	MCDS_TCYIPBND3	(MCDS_TCY_IP3_BND)

/** \\brief  5034, Comparator Range Register */
#define MCDS_TCY_IP3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_RNG*)0xF90ED034u)

/** Alias (User Manual Name) for MCDS_TCY_IP3_RNG.
* To use register names with standard convension, please use MCDS_TCY_IP3_RNG.
*/
#define	MCDS_TCYIPRNG3	(MCDS_TCY_IP3_RNG)

/** \\brief  5040, Comparator Bound Register */
#define MCDS_TCY_IP4_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_BND*)0xF90ED040u)

/** Alias (User Manual Name) for MCDS_TCY_IP4_BND.
* To use register names with standard convension, please use MCDS_TCY_IP4_BND.
*/
#define	MCDS_TCYIPBND4	(MCDS_TCY_IP4_BND)

/** \\brief  5044, Comparator Range Register */
#define MCDS_TCY_IP4_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_RNG*)0xF90ED044u)

/** Alias (User Manual Name) for MCDS_TCY_IP4_RNG.
* To use register names with standard convension, please use MCDS_TCY_IP4_RNG.
*/
#define	MCDS_TCYIPRNG4	(MCDS_TCY_IP4_RNG)

/** \\brief  5050, Comparator Bound Register */
#define MCDS_TCY_IP5_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_BND*)0xF90ED050u)

/** Alias (User Manual Name) for MCDS_TCY_IP5_BND.
* To use register names with standard convension, please use MCDS_TCY_IP5_BND.
*/
#define	MCDS_TCYIPBND5	(MCDS_TCY_IP5_BND)

/** \\brief  5054, Comparator Range Register */
#define MCDS_TCY_IP5_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYIP_RNG*)0xF90ED054u)

/** Alias (User Manual Name) for MCDS_TCY_IP5_RNG.
* To use register names with standard convension, please use MCDS_TCY_IP5_RNG.
*/
#define	MCDS_TCYIPRNG5	(MCDS_TCY_IP5_RNG)

/** \\brief  4210, Lookup Table Base Register */
#define MCDS_TCY_PAL0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_BND*)0xF90EC210u)

/** Alias (User Manual Name) for MCDS_TCY_PAL0_BND.
* To use register names with standard convension, please use MCDS_TCY_PAL0_BND.
*/
#define	MCDS_TCYPALBND0	(MCDS_TCY_PAL0_BND)

/** \\brief  4218, Lookup Table Range Register */
#define MCDS_TCY_PAL0_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_MAP*)0xF90EC218u)

/** Alias (User Manual Name) for MCDS_TCY_PAL0_MAP.
* To use register names with standard convension, please use MCDS_TCY_PAL0_MAP.
*/
#define	MCDS_TCYPALMAP0	(MCDS_TCY_PAL0_MAP)

/** \\brief  4214, Lookup Table Range Register */
#define MCDS_TCY_PAL0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_RNG*)0xF90EC214u)

/** Alias (User Manual Name) for MCDS_TCY_PAL0_RNG.
* To use register names with standard convension, please use MCDS_TCY_PAL0_RNG.
*/
#define	MCDS_TCYPALRNG0	(MCDS_TCY_PAL0_RNG)

/** \\brief  4220, Lookup Table Base Register */
#define MCDS_TCY_PAL1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_BND*)0xF90EC220u)

/** Alias (User Manual Name) for MCDS_TCY_PAL1_BND.
* To use register names with standard convension, please use MCDS_TCY_PAL1_BND.
*/
#define	MCDS_TCYPALBND1	(MCDS_TCY_PAL1_BND)

/** \\brief  4228, Lookup Table Range Register */
#define MCDS_TCY_PAL1_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_MAP*)0xF90EC228u)

/** Alias (User Manual Name) for MCDS_TCY_PAL1_MAP.
* To use register names with standard convension, please use MCDS_TCY_PAL1_MAP.
*/
#define	MCDS_TCYPALMAP1	(MCDS_TCY_PAL1_MAP)

/** \\brief  4224, Lookup Table Range Register */
#define MCDS_TCY_PAL1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_RNG*)0xF90EC224u)

/** Alias (User Manual Name) for MCDS_TCY_PAL1_RNG.
* To use register names with standard convension, please use MCDS_TCY_PAL1_RNG.
*/
#define	MCDS_TCYPALRNG1	(MCDS_TCY_PAL1_RNG)

/** \\brief  4230, Lookup Table Base Register */
#define MCDS_TCY_PAL2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_BND*)0xF90EC230u)

/** Alias (User Manual Name) for MCDS_TCY_PAL2_BND.
* To use register names with standard convension, please use MCDS_TCY_PAL2_BND.
*/
#define	MCDS_TCYPALBND2	(MCDS_TCY_PAL2_BND)

/** \\brief  4238, Lookup Table Range Register */
#define MCDS_TCY_PAL2_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_MAP*)0xF90EC238u)

/** Alias (User Manual Name) for MCDS_TCY_PAL2_MAP.
* To use register names with standard convension, please use MCDS_TCY_PAL2_MAP.
*/
#define	MCDS_TCYPALMAP2	(MCDS_TCY_PAL2_MAP)

/** \\brief  4234, Lookup Table Range Register */
#define MCDS_TCY_PAL2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_RNG*)0xF90EC234u)

/** Alias (User Manual Name) for MCDS_TCY_PAL2_RNG.
* To use register names with standard convension, please use MCDS_TCY_PAL2_RNG.
*/
#define	MCDS_TCYPALRNG2	(MCDS_TCY_PAL2_RNG)

/** \\brief  4240, Lookup Table Base Register */
#define MCDS_TCY_PAL3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_BND*)0xF90EC240u)

/** Alias (User Manual Name) for MCDS_TCY_PAL3_BND.
* To use register names with standard convension, please use MCDS_TCY_PAL3_BND.
*/
#define	MCDS_TCYPALBND3	(MCDS_TCY_PAL3_BND)

/** \\brief  4248, Lookup Table Range Register */
#define MCDS_TCY_PAL3_MAP /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_MAP*)0xF90EC248u)

/** Alias (User Manual Name) for MCDS_TCY_PAL3_MAP.
* To use register names with standard convension, please use MCDS_TCY_PAL3_MAP.
*/
#define	MCDS_TCYPALMAP3	(MCDS_TCY_PAL3_MAP)

/** \\brief  4244, Lookup Table Range Register */
#define MCDS_TCY_PAL3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYPAL_RNG*)0xF90EC244u)

/** Alias (User Manual Name) for MCDS_TCY_PAL3_RNG.
* To use register names with standard convension, please use MCDS_TCY_PAL3_RNG.
*/
#define	MCDS_TCYPALRNG3	(MCDS_TCY_PAL3_RNG)

/** \\brief  4204, Lookup Table Address Register */
#define MCDS_TCY_PALLU_TA /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TA*)0xF90EC204u)

/** Alias (User Manual Name) for MCDS_TCY_PALLU_TA.
* To use register names with standard convension, please use MCDS_TCY_PALLU_TA.
*/
#define	MCDS_TCYPALLUTA	(MCDS_TCY_PALLU_TA)

/** \\brief  4200, Lookup Table Data Register */
#define MCDS_TCY_PALLU_TD /* lint --e(923)*/ (*(volatile Ifx_MCDS_LOKUP_TD*)0xF90EC200u)

/** Alias (User Manual Name) for MCDS_TCY_PALLU_TD.
* To use register names with standard convension, please use MCDS_TCY_PALLU_TD.
*/
#define	MCDS_TCYPALLUTD	(MCDS_TCY_PALLU_TD)

/** \\brief  4480, Comparator Bound Register */
#define MCDS_TCY_WD0_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_BND*)0xF90EC480u)

/** Alias (User Manual Name) for MCDS_TCY_WD0_BND.
* To use register names with standard convension, please use MCDS_TCY_WD0_BND.
*/
#define	MCDS_TCYWDBND0	(MCDS_TCY_WD0_BND)

/** \\brief  4484, Comparator Bound Register */
#define MCDS_TCY_WD0_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HBND*)0xF90EC484u)

/** Alias (User Manual Name) for MCDS_TCY_WD0_HBND.
* To use register names with standard convension, please use MCDS_TCY_WD0_HBND.
*/
#define	MCDS_TCYWDHBND0	(MCDS_TCY_WD0_HBND)

/** \\brief  4494, Comparator Mask Register */
#define MCDS_TCY_WD0_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HMSK*)0xF90EC494u)

/** Alias (User Manual Name) for MCDS_TCY_WD0_HMSK.
* To use register names with standard convension, please use MCDS_TCY_WD0_HMSK.
*/
#define	MCDS_TCYWDHMSK0	(MCDS_TCY_WD0_HMSK)

/** \\brief  448C, Comparator Range Register */
#define MCDS_TCY_WD0_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HRNG*)0xF90EC48Cu)

/** Alias (User Manual Name) for MCDS_TCY_WD0_HRNG.
* To use register names with standard convension, please use MCDS_TCY_WD0_HRNG.
*/
#define	MCDS_TCYWDHRNG0	(MCDS_TCY_WD0_HRNG)

/** \\brief  4490, Comparator Mask Register */
#define MCDS_TCY_WD0_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_MSK*)0xF90EC490u)

/** Alias (User Manual Name) for MCDS_TCY_WD0_MSK.
* To use register names with standard convension, please use MCDS_TCY_WD0_MSK.
*/
#define	MCDS_TCYWDMSK0	(MCDS_TCY_WD0_MSK)

/** \\brief  4488, Comparator Range Register */
#define MCDS_TCY_WD0_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_RNG*)0xF90EC488u)

/** Alias (User Manual Name) for MCDS_TCY_WD0_RNG.
* To use register names with standard convension, please use MCDS_TCY_WD0_RNG.
*/
#define	MCDS_TCYWDRNG0	(MCDS_TCY_WD0_RNG)

/** \\brief  449C, Comparator Sign Register */
#define MCDS_TCY_WD0_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_SGN*)0xF90EC49Cu)

/** Alias (User Manual Name) for MCDS_TCY_WD0_SGN.
* To use register names with standard convension, please use MCDS_TCY_WD0_SGN.
*/
#define	MCDS_TCYWDSGN0	(MCDS_TCY_WD0_SGN)

/** \\brief  44A0, Comparator Bound Register */
#define MCDS_TCY_WD1_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_BND*)0xF90EC4A0u)

/** Alias (User Manual Name) for MCDS_TCY_WD1_BND.
* To use register names with standard convension, please use MCDS_TCY_WD1_BND.
*/
#define	MCDS_TCYWDBND1	(MCDS_TCY_WD1_BND)

/** \\brief  44A4, Comparator Bound Register */
#define MCDS_TCY_WD1_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HBND*)0xF90EC4A4u)

/** Alias (User Manual Name) for MCDS_TCY_WD1_HBND.
* To use register names with standard convension, please use MCDS_TCY_WD1_HBND.
*/
#define	MCDS_TCYWDHBND1	(MCDS_TCY_WD1_HBND)

/** \\brief  44B4, Comparator Mask Register */
#define MCDS_TCY_WD1_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HMSK*)0xF90EC4B4u)

/** Alias (User Manual Name) for MCDS_TCY_WD1_HMSK.
* To use register names with standard convension, please use MCDS_TCY_WD1_HMSK.
*/
#define	MCDS_TCYWDHMSK1	(MCDS_TCY_WD1_HMSK)

/** \\brief  44AC, Comparator Range Register */
#define MCDS_TCY_WD1_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HRNG*)0xF90EC4ACu)

/** Alias (User Manual Name) for MCDS_TCY_WD1_HRNG.
* To use register names with standard convension, please use MCDS_TCY_WD1_HRNG.
*/
#define	MCDS_TCYWDHRNG1	(MCDS_TCY_WD1_HRNG)

/** \\brief  44B0, Comparator Mask Register */
#define MCDS_TCY_WD1_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_MSK*)0xF90EC4B0u)

/** Alias (User Manual Name) for MCDS_TCY_WD1_MSK.
* To use register names with standard convension, please use MCDS_TCY_WD1_MSK.
*/
#define	MCDS_TCYWDMSK1	(MCDS_TCY_WD1_MSK)

/** \\brief  44A8, Comparator Range Register */
#define MCDS_TCY_WD1_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_RNG*)0xF90EC4A8u)

/** Alias (User Manual Name) for MCDS_TCY_WD1_RNG.
* To use register names with standard convension, please use MCDS_TCY_WD1_RNG.
*/
#define	MCDS_TCYWDRNG1	(MCDS_TCY_WD1_RNG)

/** \\brief  44BC, Comparator Sign Register */
#define MCDS_TCY_WD1_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_SGN*)0xF90EC4BCu)

/** Alias (User Manual Name) for MCDS_TCY_WD1_SGN.
* To use register names with standard convension, please use MCDS_TCY_WD1_SGN.
*/
#define	MCDS_TCYWDSGN1	(MCDS_TCY_WD1_SGN)

/** \\brief  44C0, Comparator Bound Register */
#define MCDS_TCY_WD2_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_BND*)0xF90EC4C0u)

/** Alias (User Manual Name) for MCDS_TCY_WD2_BND.
* To use register names with standard convension, please use MCDS_TCY_WD2_BND.
*/
#define	MCDS_TCYWDBND2	(MCDS_TCY_WD2_BND)

/** \\brief  44C4, Comparator Bound Register */
#define MCDS_TCY_WD2_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HBND*)0xF90EC4C4u)

/** Alias (User Manual Name) for MCDS_TCY_WD2_HBND.
* To use register names with standard convension, please use MCDS_TCY_WD2_HBND.
*/
#define	MCDS_TCYWDHBND2	(MCDS_TCY_WD2_HBND)

/** \\brief  44D4, Comparator Mask Register */
#define MCDS_TCY_WD2_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HMSK*)0xF90EC4D4u)

/** Alias (User Manual Name) for MCDS_TCY_WD2_HMSK.
* To use register names with standard convension, please use MCDS_TCY_WD2_HMSK.
*/
#define	MCDS_TCYWDHMSK2	(MCDS_TCY_WD2_HMSK)

/** \\brief  44CC, Comparator Range Register */
#define MCDS_TCY_WD2_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HRNG*)0xF90EC4CCu)

/** Alias (User Manual Name) for MCDS_TCY_WD2_HRNG.
* To use register names with standard convension, please use MCDS_TCY_WD2_HRNG.
*/
#define	MCDS_TCYWDHRNG2	(MCDS_TCY_WD2_HRNG)

/** \\brief  44D0, Comparator Mask Register */
#define MCDS_TCY_WD2_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_MSK*)0xF90EC4D0u)

/** Alias (User Manual Name) for MCDS_TCY_WD2_MSK.
* To use register names with standard convension, please use MCDS_TCY_WD2_MSK.
*/
#define	MCDS_TCYWDMSK2	(MCDS_TCY_WD2_MSK)

/** \\brief  44C8, Comparator Range Register */
#define MCDS_TCY_WD2_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_RNG*)0xF90EC4C8u)

/** Alias (User Manual Name) for MCDS_TCY_WD2_RNG.
* To use register names with standard convension, please use MCDS_TCY_WD2_RNG.
*/
#define	MCDS_TCYWDRNG2	(MCDS_TCY_WD2_RNG)

/** \\brief  44DC, Comparator Sign Register */
#define MCDS_TCY_WD2_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_SGN*)0xF90EC4DCu)

/** Alias (User Manual Name) for MCDS_TCY_WD2_SGN.
* To use register names with standard convension, please use MCDS_TCY_WD2_SGN.
*/
#define	MCDS_TCYWDSGN2	(MCDS_TCY_WD2_SGN)

/** \\brief  44E0, Comparator Bound Register */
#define MCDS_TCY_WD3_BND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_BND*)0xF90EC4E0u)

/** Alias (User Manual Name) for MCDS_TCY_WD3_BND.
* To use register names with standard convension, please use MCDS_TCY_WD3_BND.
*/
#define	MCDS_TCYWDBND3	(MCDS_TCY_WD3_BND)

/** \\brief  44E4, Comparator Bound Register */
#define MCDS_TCY_WD3_HBND /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HBND*)0xF90EC4E4u)

/** Alias (User Manual Name) for MCDS_TCY_WD3_HBND.
* To use register names with standard convension, please use MCDS_TCY_WD3_HBND.
*/
#define	MCDS_TCYWDHBND3	(MCDS_TCY_WD3_HBND)

/** \\brief  44F4, Comparator Mask Register */
#define MCDS_TCY_WD3_HMSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HMSK*)0xF90EC4F4u)

/** Alias (User Manual Name) for MCDS_TCY_WD3_HMSK.
* To use register names with standard convension, please use MCDS_TCY_WD3_HMSK.
*/
#define	MCDS_TCYWDHMSK3	(MCDS_TCY_WD3_HMSK)

/** \\brief  44EC, Comparator Range Register */
#define MCDS_TCY_WD3_HRNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_HRNG*)0xF90EC4ECu)

/** Alias (User Manual Name) for MCDS_TCY_WD3_HRNG.
* To use register names with standard convension, please use MCDS_TCY_WD3_HRNG.
*/
#define	MCDS_TCYWDHRNG3	(MCDS_TCY_WD3_HRNG)

/** \\brief  44F0, Comparator Mask Register */
#define MCDS_TCY_WD3_MSK /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_MSK*)0xF90EC4F0u)

/** Alias (User Manual Name) for MCDS_TCY_WD3_MSK.
* To use register names with standard convension, please use MCDS_TCY_WD3_MSK.
*/
#define	MCDS_TCYWDMSK3	(MCDS_TCY_WD3_MSK)

/** \\brief  44E8, Comparator Range Register */
#define MCDS_TCY_WD3_RNG /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_RNG*)0xF90EC4E8u)

/** Alias (User Manual Name) for MCDS_TCY_WD3_RNG.
* To use register names with standard convension, please use MCDS_TCY_WD3_RNG.
*/
#define	MCDS_TCYWDRNG3	(MCDS_TCY_WD3_RNG)

/** \\brief  44FC, Comparator Sign Register */
#define MCDS_TCY_WD3_SGN /* lint --e(923)*/ (*(volatile Ifx_MCDS_TCYWD_SGN*)0xF90EC4FCu)

/** Alias (User Manual Name) for MCDS_TCY_WD3_SGN.
* To use register names with standard convension, please use MCDS_TCY_WD3_SGN.
*/
#define	MCDS_TCYWDSGN3	(MCDS_TCY_WD3_SGN)

/** \\brief  408, Clock Counter Register */
#define MCDS_TSUEMUCNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_TSUEMUCNT*)0xF90E8408u)

/** \\brief  404, Clock Prescaler Register */
#define MCDS_TSUPRSCL /* lint --e(923)*/ (*(volatile Ifx_MCDS_TSUPRSCL*)0xF90E8404u)

/** \\brief  400, Clock Counter Register */
#define MCDS_TSUREFCNT /* lint --e(923)*/ (*(volatile Ifx_MCDS_TSUREFCNT*)0xF90E8400u)
/** \}  */
/******************************************************************************/
/******************************************************************************/
#endif /* IFXMCDS_REG_H */
